LAMMPS (4 Jan 2019)
#LAMMPS input script
#in.GD
#see README for details

###############################################################################
#initialize variables
clear

#frequency for outputting info (timesteps)
variable        dump_rate       equal 50
variable        thermo_rate     equal 10

#equilibration time (timesteps)
variable        equil           equal 1000

#stabilization time (timesteps to reach steady-state)
variable        stabil          equal 1000

#data collection time (timesteps)
variable        run             equal 2000

#length of pipe
variable        L               equal 30

#width of pipe
variable        d               equal 20

#flux (mass/sigma*tau)
variable        J               equal 0.1

#simulation box dimensions
variable        Lx              equal 100
variable        Ly              equal 40

#bulk fluid density
variable        dens            equal 0.8

#lattice spacing for wall atoms
variable        aWall           equal 1.0 #1.7472

#timestep
variable        ts              equal 0.001

#temperature
variable        T               equal 2.0

#thermostat damping constant
variable        tdamp           equal ${ts}*100
variable        tdamp           equal 0.001*100

units           lj
dimension       2
atom_style      atomic


###############################################################################
#create box

#create lattice with the spacing aWall
variable        rhoWall         equal ${aWall}^(-2)
variable        rhoWall         equal 1^(-2)
lattice         sq ${rhoWall}
lattice         sq 1
Lattice spacing in x,y,z = 1 1 1

#modify input dimensions to be multiples of aWall
variable        L1 equal round($L/${aWall})*${aWall}
variable        L1 equal round(30/${aWall})*${aWall}
variable        L1 equal round(30/1)*${aWall}
variable        L1 equal round(30/1)*1
variable        d1 equal round($d/${aWall})*${aWall}
variable        d1 equal round(20/${aWall})*${aWall}
variable        d1 equal round(20/1)*${aWall}
variable        d1 equal round(20/1)*1
variable        Ly1 equal round(${Ly}/${aWall})*${aWall}
variable        Ly1 equal round(40/${aWall})*${aWall}
variable        Ly1 equal round(40/1)*${aWall}
variable        Ly1 equal round(40/1)*1
variable        Lx1 equal round(${Lx}/${aWall})*${aWall}
variable        Lx1 equal round(100/${aWall})*${aWall}
variable        Lx1 equal round(100/1)*${aWall}
variable        Lx1 equal round(100/1)*1

#create simulation box
variable        lx2 equal ${Lx1}/2
variable        lx2 equal 100/2
variable        ly2 equal ${Ly1}/2
variable        ly2 equal 40/2
region          simbox block -${lx2} ${lx2} -${ly2} ${ly2} 0 0.1 units box
region          simbox block -50 ${lx2} -${ly2} ${ly2} 0 0.1 units box
region          simbox block -50 50 -${ly2} ${ly2} 0 0.1 units box
region          simbox block -50 50 -20 ${ly2} 0 0.1 units box
region          simbox block -50 50 -20 20 0 0.1 units box
create_box      2 simbox
Created orthogonal box = (-50 -20 0) to (50 20 0.1)
  4 by 2 by 1 MPI processor grid

#####################################################################
#set up potential

mass            1 1.0           #fluid atoms
mass            2 1.0           #wall atoms

pair_style      lj/cut 2.5
pair_modify     shift yes
pair_coeff      1 1 1.0 1.0 2.5
pair_coeff      1 2 1.0 1.0 1.12246
pair_coeff      2 2 0.0 0.0

neigh_modify  exclude type 2 2

timestep        ${ts}
timestep        0.001

#####################################################################
#create atoms

#create wall atoms everywhere
create_atoms    2 box
Created 4000 atoms
  Time spent = 0.00103269 secs

#define region which is "walled off"
variable        dhalf equal ${d1}/2
variable        dhalf equal 20/2
variable        Lhalf equal ${L1}/2
variable        Lhalf equal 30/2
region          walltop block -${Lhalf} ${Lhalf} ${dhalf} EDGE -0.1 0.1                 units box
region          walltop block -15 ${Lhalf} ${dhalf} EDGE -0.1 0.1                 units box
region          walltop block -15 15 ${dhalf} EDGE -0.1 0.1                 units box
region          walltop block -15 15 10 EDGE -0.1 0.1                 units box
region          wallbot block -${Lhalf} ${Lhalf} EDGE -${dhalf} -0.1 0.1                 units box
region          wallbot block -15 ${Lhalf} EDGE -${dhalf} -0.1 0.1                 units box
region          wallbot block -15 15 EDGE -${dhalf} -0.1 0.1                 units box
region          wallbot block -15 15 EDGE -10 -0.1 0.1                 units box
region          outsidewall union 2 walltop wallbot side out

#remove wall atoms outside wall region
group           outside region outsidewall
3349 atoms in group outside
delete_atoms    group outside
Deleted 3349 atoms, new total = 651

#remove wall atoms that aren't on edge of wall region
variable        x1 equal ${Lhalf}-${aWall}
variable        x1 equal 15-${aWall}
variable        x1 equal 15-1
variable        y1 equal ${dhalf}+${aWall}
variable        y1 equal 10+${aWall}
variable        y1 equal 10+1
region          insideTop block -${x1} ${x1} ${y1} EDGE -0.1 0.1 units box
region          insideTop block -14 ${x1} ${y1} EDGE -0.1 0.1 units box
region          insideTop block -14 14 ${y1} EDGE -0.1 0.1 units box
region          insideTop block -14 14 11 EDGE -0.1 0.1 units box
region          insideBot block -${x1} ${x1} EDGE -${y1} -0.1 0.1 units box
region          insideBot block -14 ${x1} EDGE -${y1} -0.1 0.1 units box
region          insideBot block -14 14 EDGE -${y1} -0.1 0.1 units box
region          insideBot block -14 14 EDGE -11 -0.1 0.1 units box
region          insideWall union 2 insideTop insideBot
group           insideWall region insideWall
551 atoms in group insideWall
delete_atoms    group insideWall
Deleted 551 atoms, new total = 100

#define new lattice, to give correct fluid density
#y lattice const must be a multiple of aWall
variable        atrue equal ${dens}^(-1/2)
variable        atrue equal 0.8^(-1/2)
variable        ay equal round(${atrue}/${aWall})*${aWall}
variable        ay equal round(1.11803398874989/${aWall})*${aWall}
variable        ay equal round(1.11803398874989/1)*${aWall}
variable        ay equal round(1.11803398874989/1)*1

#choose x lattice const to give correct density
variable        ax equal (${ay}*${dens})^(-1)
variable        ax equal (1*${dens})^(-1)
variable        ax equal (1*0.8)^(-1)

#change Lx to be multiple of ax
variable        Lx1 equal round(${Lx}/${ax})*${ax}
variable        Lx1 equal round(100/${ax})*${ax}
variable        Lx1 equal round(100/1.25)*${ax}
variable        Lx1 equal round(100/1.25)*1.25
variable        lx2 equal ${Lx1}/2
variable        lx2 equal 100/2
change_box      all x final -${lx2} ${lx2} units box
change_box      all x final -50 ${lx2} units box
change_box      all x final -50 50 units box
  orthogonal box = (-50 -20 0) to (50 20 0.1)

#define new lattice
lattice         custom ${dens}                 a1 ${ax} 0.0 0.0 a2 0.0 ${ay} 0.0 a3 0.0 0.0 1.0                 basis 0.0 0.0 0.0
lattice         custom 0.8                 a1 ${ax} 0.0 0.0 a2 0.0 ${ay} 0.0 a3 0.0 0.0 1.0                 basis 0.0 0.0 0.0
lattice         custom 0.8                 a1 1.25 0.0 0.0 a2 0.0 ${ay} 0.0 a3 0.0 0.0 1.0                 basis 0.0 0.0 0.0
lattice         custom 0.8                 a1 1.25 0.0 0.0 a2 0.0 1 0.0 a3 0.0 0.0 1.0                 basis 0.0 0.0 0.0
Lattice spacing in x,y,z = 1.25 1 1

#fill in rest of box with bulk particles
variable        delta equal 0.001
variable        Ldelt equal ${Lhalf}+${delta}
variable        Ldelt equal 15+${delta}
variable        Ldelt equal 15+0.001
variable        dDelt equal ${dhalf}-${delta}
variable        dDelt equal 10-${delta}
variable        dDelt equal 10-0.001
region          left block EDGE -${Ldelt} EDGE EDGE -0.1 0.1 units box
region          left block EDGE -15.001 EDGE EDGE -0.1 0.1 units box
region          right block ${Ldelt} EDGE EDGE EDGE -0.1 0.1 units box
region          right block 15.001 EDGE EDGE EDGE -0.1 0.1 units box
region          pipe block -${Ldelt} ${Ldelt} -${dDelt} ${dDelt} -0.1 0.1                 units box
region          pipe block -15.001 ${Ldelt} -${dDelt} ${dDelt} -0.1 0.1                 units box
region          pipe block -15.001 15.001 -${dDelt} ${dDelt} -0.1 0.1                 units box
region          pipe block -15.001 15.001 -9.999 ${dDelt} -0.1 0.1                 units box
region          pipe block -15.001 15.001 -9.999 9.999 -0.1 0.1                 units box

region          bulk union 3 left pipe right
create_atoms    1 region bulk
Created 2675 atoms
  Time spent = 0.000187999 secs

group           bulk type 1
2675 atoms in group bulk
group           wall type 2
100 atoms in group wall

#remove atoms that are too close to wall
delete_atoms    overlap 0.9 bulk wall
Neighbor list info ...
  update every 1 steps, delay 10 steps, check yes
  max neighbors/atom: 2000, page size: 100000
  master list distance cutoff = 2.8
  ghost atom cutoff = 2.8
  binsize = 1.4, bins = 72 29 1
  2 neighbor lists, perpetual/occasional/extra = 1 1 0
  (1) command delete_atoms, occasional
      attributes: full, newton on
      pair build: full/bin/atomonly
      stencil: full/bin/2d
      bin: standard
  (2) pair lj/cut, perpetual
      attributes: half, newton on
      pair build: half/bin/atomonly/newton
      stencil: half/bin/2d/newton
      bin: standard
Deleted 0 atoms, new total = 2775

neighbor        0.3 bin
neigh_modify    delay 0 every 1 check yes
neigh_modify    exclude group wall wall

velocity        bulk create $T 78915 dist gaussian rot yes mom yes loop geom
velocity        bulk create 2 78915 dist gaussian rot yes mom yes loop geom

#####################################################################
#set up PUT
#see Evans and Morriss, Phys. Rev. Lett. 56(20) 1986, p. 2172

#average number of particles per box, Evans and Morriss used 2.0
variable        NperBox equal 8.0

#calculate box sizes
variable        boxSide equal sqrt(${NperBox}/${dens})
variable        boxSide equal sqrt(8/${dens})
variable        boxSide equal sqrt(8/0.8)
variable        nX equal round(lx/${boxSide})
variable        nX equal round(lx/3.16227766016838)
variable        nY equal round(ly/${boxSide})
variable        nY equal round(ly/3.16227766016838)
variable        dX equal lx/${nX}
variable        dX equal lx/32
variable        dY equal ly/${nY}
variable        dY equal ly/13

#temperature of fluid (excluding wall)
compute         myT bulk temp

#profile-unbiased temperature of fluid
compute         myTp bulk temp/profile 1 1 0 xy ${nX} ${nY}
compute         myTp bulk temp/profile 1 1 0 xy 32 ${nY}
compute         myTp bulk temp/profile 1 1 0 xy 32 13

#thermo setup
thermo          ${thermo_rate}
thermo          10
thermo_style    custom step c_myT c_myTp etotal press

#dump initial configuration
# dump            55 all custom 1 all.init.lammpstrj id type x y z vx vy vz
# dump            56 wall custom 1 wall.init.lammpstrj id type x y z
# dump_modify     55 sort id
# dump_modify     56 sort id
run             0
WARNING: No fixes defined, atoms won't move (../verlet.cpp:55)
Neighbor list info ...
  update every 1 steps, delay 0 steps, check yes
  max neighbors/atom: 2000, page size: 100000
  master list distance cutoff = 2.8
  ghost atom cutoff = 2.8
  binsize = 1.4, bins = 72 29 1
  1 neighbor lists, perpetual/occasional/extra = 1 0 0
  (1) pair lj/cut, perpetual
      attributes: half, newton on
      pair build: half/bin/atomonly/newton
      stencil: half/bin/2d/newton
      bin: standard
Per MPI rank memory allocation (min/avg/max) = 3.063 | 3.064 | 3.065 Mbytes
Step c_myT c_myTp TotEng Press 
       0            2    2.0555109   0.77892922    7.3417096 
Loop time of 5.24713e-06 on 8 procs for 0 steps with 2775 atoms

78.6% CPU use with 8 MPI tasks x no OpenMP threads

MPI task timing breakdown:
Section |  min time  |  avg time  |  max time  |%varavg| %total
---------------------------------------------------------------
Pair    | 0          | 0          | 0          |   0.0 |  0.00
Neigh   | 0          | 0          | 0          |   0.0 |  0.00
Comm    | 0          | 0          | 0          |   0.0 |  0.00
Output  | 0          | 0          | 0          |   0.0 |  0.00
Modify  | 0          | 0          | 0          |   0.0 |  0.00
Other   |            | 5.247e-06  |            |       |100.00

Nlocal:    346.875 ave 400 max 283 min
Histogram: 2 2 0 0 0 0 0 0 0 4
Nghost:    195.625 ave 225 max 156 min
Histogram: 1 2 0 1 0 0 0 0 0 4
Neighs:    3300.75 ave 4000 max 2565 min
Histogram: 4 0 0 0 0 0 0 0 0 4

Total # of neighbors = 26406
Ave neighs/atom = 9.51568
Neighbor list builds = 0
Dangerous builds = 0
# undump          55
# undump          56

#####################################################################
#equilibrate without GD

fix             nvt bulk nvt temp $T $T ${tdamp}
fix             nvt bulk nvt temp 2 $T ${tdamp}
fix             nvt bulk nvt temp 2 2 ${tdamp}
fix             nvt bulk nvt temp 2 2 0.1
fix_modify      nvt temp myTp
WARNING: Temperature for fix modify is not for group all (../fix_nh.cpp:1411)
fix             2 bulk enforce2d

run             ${equil}
run             1000
Per MPI rank memory allocation (min/avg/max) = 3.126 | 3.126 | 3.127 Mbytes
Step c_myT c_myTp TotEng Press 
       0            2    2.0555109   0.77892922    7.3417096 
      10    1.9173594    1.9390034   0.77876976    7.6702228 
      20    1.7033394    1.6974676   0.77977799    8.5614784 
      30    1.5026161    1.4723993   0.78456655    9.4308258 
      40    1.4880481    1.4591602   0.79486693    9.6134304 
      50    1.6192437    1.6150635   0.81109069    9.2592835 
      60    1.7404087    1.7583444   0.82955456     8.952392 
      70    1.7757591    1.8006606    0.8452778    8.9717917 
      80    1.7573847    1.7813629   0.85769389    9.1936368 
      90    1.7491183    1.7726908   0.86882429    9.3712357 
     100    1.7798944    1.8079583   0.88029084    9.3871755 
     110    1.8440582    1.8793133   0.89259397    9.2582848 
     120    1.9191606    1.9673434   0.90533438    9.0680574 
     130    1.9883299    2.0484299   0.91755461      8.88117 
     140    2.0463366    2.1111872   0.92818114    8.7184178 
     150    2.0953769     2.167849   0.93639789    8.5713408 
     160    2.1442147    2.2216228   0.94145082    8.4082835 
     170    2.1797848    2.2631458   0.94246877    8.2767903 
     180    2.1863476    2.2700986   0.93873326    8.2311689 
     190    2.1832866    2.2710551   0.93003012    8.1959062 
     200    2.1937154    2.2868403   0.91642537    8.0842007 
     210    2.2022708    2.2915142   0.89824533    7.9575312 
     220    2.1884715    2.2770564   0.87677613    7.9000591 
     230    2.1671124    2.2496063   0.85409501    7.8673156 
     240    2.1560417    2.2379998   0.83167878    7.8003228 
     250    2.1421449    2.2240624   0.81004723    7.7491508 
     260    2.1172164    2.1971044   0.78931978    7.7457415 
     270    2.0856847    2.1672998   0.76956352    7.7719788 
     280    2.0670685    2.1449303   0.75073364    7.7524614 
     290    2.0639481    2.1428374   0.73258016    7.6727716 
     300     2.055776    2.1361719    0.7147669    7.6095248 
     310     2.038425    2.1209353   0.69722853    7.5797085 
     320    2.0203023    2.1066031   0.68006634    7.5521081 
     330    2.0118478    2.1039797   0.66330302    7.4877535 
     340    2.0159442    2.1096258   0.64673694    7.3761703 
     350    2.0166408    2.1075061   0.63020017       7.2788 
     360    2.0059407    2.0806316   0.61387618    7.2263941 
     370    1.9964281    2.0642074   0.59814148    7.1728041 
     380    1.9918446    2.0567527   0.58303017     7.101597 
     390     1.992835    2.0548138   0.56852431    7.0084774 
     400    2.0012934    2.0615016   0.55438401    6.8865948 
     410    2.0084291     2.073418   0.54034073    6.7697478 
     420     2.007464    2.0786717   0.52617041    6.6849032 
     430    1.9983712    2.0704366   0.51188183    6.6323103 
     440    1.9884651    2.0588515   0.49765394    6.5868356 
     450     1.982221    2.0467396    0.4837102    6.5311681 
     460    1.9738673     2.031238   0.47021649    6.4882783 
     470    1.9574246    2.0060447   0.45740021    6.4814923 
     480    1.9361065    1.9734507   0.44557947    6.4995199 
     490    1.9251024    1.9562469   0.43506067    6.4858343 
     500    1.9279545    1.9572145   0.42577835    6.4274765 
     510    1.9267504    1.9570246   0.41755013    6.3927027 
     520    1.9093405    1.9393872   0.41031829    6.4281888 
     530    1.8820555    1.9060756   0.40432569    6.5099401 
     540      1.86537    1.8912682    0.3999087      6.55843 
     550    1.8694252    1.9043192   0.39717519    6.5337875 
     560    1.8835224    1.9294105   0.39589322    6.4760141 
     570    1.8898719    1.9462433   0.39573596    6.4520041 
     580    1.8887698    1.9472764   0.39649878    6.4602989 
     590    1.8945125    1.9550624   0.39810844    6.4470226 
     600    1.9106571    1.9735939   0.40045321    6.3971026 
     610    1.9273243      1.98509   0.40330026    6.3474421 
     620    1.9351802    1.9888986    0.4064498    6.3340566 
     630    1.9337889    1.9846794   0.40981479    6.3610556 
     640    1.9257018    1.9757153    0.4134641    6.4184721 
     650    1.9204429    1.9718256   0.41750942    6.4679594 
     660    1.9220449    1.9701963   0.42202455    6.4919724 
     670    1.9230578    1.9707406    0.4270412    6.5178484 
     680    1.9204554    1.9740485   0.43255127    6.5572507 
     690    1.9201811    1.9762854   0.43847123    6.5869126 
     700    1.9271511    1.9867455   0.44474356    6.5882669 
     710    1.9418851    2.0042477   0.45120727     6.558573 
     720    1.9544547    2.0186724    0.4576061    6.5338329 
     730    1.9687971    2.0326169   0.46367507    6.4988775 
     740    1.9830308    2.0466267   0.46920367    6.4618136 
     750    1.9936981    2.0526606   0.47397868    6.4367349 
     760    2.0008431    2.0535449   0.47786748    6.4249001 
     770    1.9982133    2.0483219   0.48085757    6.4504786 
     780    1.9841544    2.0311693   0.48306488    6.5200512 
     790    1.9683122    2.0158738   0.48475632    6.5959263 
     800    1.9604618     2.003224   0.48619405    6.6392559 
     810    1.9629155    2.0075077   0.48756075    6.6406486 
     820    1.9683056    2.0110554   0.48883443    6.6269424 
     830     1.975409    2.0189161   0.48995399    6.6030215 
     840    1.9897264     2.035016    0.4907852    6.5485575 
     850    2.0094338    2.0555358   0.49104505    6.4719926 
     860    2.0217589    2.0643603   0.49040437    6.4233305 
     870    2.0147718    2.0641627   0.48866908    6.4491964 
     880    1.9883859    2.0324092   0.48592007    6.5488061 
     890    1.9625853    2.0028776   0.48263002    6.6452734 
     900    1.9520401    1.9889124   0.47925524    6.6808078 
     910    1.9559583    1.9952984   0.47597346    6.6573059 
     920    1.9657244    2.0083503   0.47268726    6.6073704 
     930     1.969288    2.0152339    0.4692054    6.5780416 
     940    1.9652206    2.0116384    0.4654438    6.5769812 
     950    1.9567495    1.9960693   0.46147541    6.5942022 
     960    1.9418452     1.980858   0.45753557    6.6369454 
     970    1.9247196    1.9585585   0.45390337    6.6888821 
     980    1.9128262    1.9481721   0.45090045    6.7198221 
     990    1.9167211    1.9451096   0.44869731    6.6912394 
    1000     1.935529    1.9662384   0.44728238    6.6079829 
Loop time of 0.188966 on 8 procs for 1000 steps with 2775 atoms

Performance: 457224.941 tau/day, 5291.955 timesteps/s
100.0% CPU use with 8 MPI tasks x no OpenMP threads

MPI task timing breakdown:
Section |  min time  |  avg time  |  max time  |%varavg| %total
---------------------------------------------------------------
Pair    | 0.037961   | 0.050654   | 0.063884   |   5.1 | 26.81
Neigh   | 0.0048209  | 0.0060835  | 0.0071921  |   1.3 |  3.22
Comm    | 0.022691   | 0.035725   | 0.049964   |   6.3 | 18.91
Output  | 0.0078258  | 0.0079963  | 0.0081901  |   0.1 |  4.23
Modify  | 0.07856    | 0.080659   | 0.082216   |   0.5 | 42.68
Other   |            | 0.007847   |            |       |  4.15

Nlocal:    346.875 ave 401 max 292 min
Histogram: 4 0 0 0 0 0 0 0 0 4
Nghost:    196.375 ave 230 max 164 min
Histogram: 4 0 0 0 0 0 0 0 1 3
Neighs:    3041.5 ave 3716 max 2301 min
Histogram: 3 1 0 0 0 0 0 0 0 4

Total # of neighbors = 24332
Ave neighs/atom = 8.76829
Neighbor list builds = 38
Dangerous builds = 0

#####################################################################
#initialize the COM velocity and run to achieve steady-state

#calculate velocity to add: V=J/rho_total
variable        Vadd            equal $J*lx*ly/count(bulk)
variable        Vadd            equal 0.1*lx*ly/count(bulk)

#first remove any COM velocity, then add back the streaming velocity
velocity        bulk zero linear
velocity        bulk set ${Vadd} 0.0 0.0 units box sum yes mom no
velocity        bulk set 0.149532710280374 0.0 0.0 units box sum yes mom no

fix             GD bulk flow/gauss 1 0 0 #energy yes
#fix_modify     GD energy yes

run             ${stabil}
run             1000
Per MPI rank memory allocation (min/avg/max) = 3.126 | 3.126 | 3.127 Mbytes
Step c_myT c_myTp TotEng Press 
    1000    1.9466974    1.9662384   0.45804438     6.615449 
    1010    1.9605467    1.9815754   0.45717241    6.5545496 
    1020    1.9560139    1.9823875   0.45660431    6.5672421 
    1030    1.9348326    1.9691606   0.45633148    6.6463667 
    1040    1.9167809    1.9449522   0.45657707    6.7139486 
    1050    1.9193541     1.943342   0.45767968    6.7014054 
    1060    1.9410751    1.9720491   0.45967742    6.6150379 
    1070    1.9658493    1.9964883   0.46221539    6.5178418 
    1080    1.9767205    2.0074304   0.46491236    6.4768594 
    1090    1.9714544    2.0003054   0.46759126    6.5026957 
    1100    1.9647035    1.9927455    0.4703109    6.5400181 
    1110    1.9657667    1.9959656   0.47317481    6.5519094 
    1120    1.9706062    1.9980802     0.476185    6.5512675 
    1130    1.9747655    2.0062292   0.47932281     6.554091 
    1140    1.9761245    2.0075076   0.48248327    6.5670381 
    1150    1.9744197    2.0073027   0.48562483    6.5914441 
    1160    1.9722698    2.0046687   0.48874207    6.6165575 
    1170    1.9692145    2.0013845   0.49187442    6.6438115 
    1180    1.9665609    1.9970724   0.49508053    6.6693821 
    1190    1.9625031    1.9908427   0.49843816    6.7002606 
    1200     1.960528     1.993084   0.50203044    6.7237076 
    1210    1.9649156    1.9981485   0.50587066    6.7217755 
    1220    1.9788059    2.0134511   0.50987442    6.6833452 
    1230    1.9952283    2.0343101   0.51379781    6.6340278 
    1240    2.0039391    2.0494196   0.51730872    6.6129751 
    1250    2.0019006    2.0526773   0.52014603    6.6320217 
    1260    1.9974025    2.0528914   0.52221385    6.6601786 
    1270    1.9953949    2.0561121    0.5234754    6.6796142 
    1280    1.9893864    2.0470375    0.5238632    6.7140134 
    1290    1.9694951     2.019253    0.5235093     6.798442 
    1300    1.9473901    1.9965919   0.52280384    6.8863369 
    1310    1.9511151     2.006161   0.52203882    6.8700917 
    1320     1.979341    2.0388959   0.52106938    6.7529595 
    1330    2.0073235    2.0720045   0.51935291    6.6297731 
    1340    2.0202482    2.0841419   0.51624273      6.55803 
    1350    2.0177489    2.0669046   0.51142591    6.5401753 
    1360    2.0069274      2.04717   0.50505824    6.5506533 
    1370     1.994854    2.0311383   0.49743042    6.5633001 
    1380    1.9793176    2.0077184   0.48890503    6.5859072 
    1390    1.9580907    1.9839831   0.48004316    6.6288992 
    1400    1.9415542    1.9594192   0.47143599    6.6534105 
    1410    1.9405188    1.9591825   0.46353105     6.620549 
    1420    1.9504784    1.9730647   0.45640199    6.5471784 
    1430    1.9594158    1.9819854   0.44995052    6.4802874 
    1440    1.9615108    1.9863792   0.44406411      6.44391 
    1450    1.9544127    1.9806249   0.43873409    6.4484818 
    1460    1.9384927    1.9614953   0.43408605    6.4905259 
    1470    1.9214711    1.9425515   0.43035972    6.5390434 
    1480    1.9170761    1.9300809   0.42775046    6.5409502 
    1490    1.9242904    1.9385731   0.42631007    6.5005057 
    1500    1.9307133    1.9446119    0.4258836    6.4660754 
    1510    1.9303576    1.9435389   0.42633976    6.4616415 
    1520    1.9248382    1.9408306   0.42765441    6.4832059 
    1530    1.9120794    1.9278123   0.42986958    6.5380951 
    1540     1.899122    1.9125029    0.4331459    6.5987181 
    1550    1.9030956    1.9187821   0.43765067    6.6012019 
    1560    1.9182961    1.9453782   0.44330842    6.5674222 
    1570    1.9272863    1.9613129   0.44971962    6.5619794 
    1580     1.931679    1.9698134   0.45643436    6.5780809 
    1590    1.9336692    1.9728684   0.46314752    6.6035675 
    1600     1.938895    1.9823104   0.46964519    6.6138411 
    1610    1.9510838    1.9937914   0.47568807    6.5916989 
    1620    1.9685387    2.0087314   0.48102339    6.5424432 
    1630    1.9894416    2.0295715   0.48539861    6.4757743 
    1640    1.9982699    2.0426949   0.48860411    6.4512418 
    1650    1.9901677    2.0363837   0.49062424    6.4879985 
    1660    1.9814216    2.0291326   0.49172203    6.5248034 
    1670    1.9812111    2.0293629   0.49218297    6.5253876 
    1680    1.9903906    2.0408376   0.49211747    6.4852787 
    1690    2.0015983    2.0538843    0.4914581    6.4325081 
    1700     2.009727    2.0503407   0.49011163    6.3878577 
    1710    2.0167822    2.0531002    0.4881688    6.3477054 
    1720    2.0189021    2.0445033   0.48564798    6.3273063 
    1730    2.0129713    2.0354734   0.48270666    6.3385541 
    1740    2.0048763    2.0199836   0.47950943    6.3587586 
    1750    1.9994843    2.0085942   0.47624908    6.3694119 
    1760    1.9940025    2.0072098   0.47305283    6.3816295 
    1770    1.9817431    1.9974066   0.46994486    6.4224295 
    1780     1.965171    1.9805421    0.4670779    6.4832371 
    1790    1.9474078    1.9662605   0.46466823    6.5516524 
    1800    1.9286009    1.9507751   0.46292015    6.6263366 
    1810    1.9168087    1.9437961   0.46199899    6.6759834 
    1820    1.9107555    1.9306323   0.46204129    6.7029857 
    1830    1.9135569     1.930819   0.46316484    6.6949737 
    1840    1.9345342    1.9553413   0.46532704    6.6178988 
    1850    1.9630349    1.9929548   0.46822932    6.5137866 
    1860    1.9820746    2.0188839   0.47135068    6.4489028 
    1870    1.9834959    2.0217145   0.47427805    6.4552721 
    1880    1.9731564    2.0120293   0.47692755    6.5100251 
    1890    1.9653605    2.0070624   0.47943307    6.5594235 
    1900    1.9630631    2.0095488   0.48192185    6.5912876 
    1910    1.9556778    2.0035006   0.48443107    6.6437189 
    1920    1.9408788    1.9828296   0.48710124    6.7228731 
    1930    1.9292393    1.9732376   0.49025327    6.7880112 
    1940    1.9263081    1.9708942   0.49416086    6.8162477 
    1950    1.9358375     1.976323   0.49899895    6.7946964 
    1960    1.9520543    1.9936542   0.50485961    6.7467481 
    1970    1.9709064    2.0108957   0.51165586    6.6909455 
    1980    1.9940026    2.0375428   0.51918913    6.6250463 
    1990    2.0171261    2.0646948   0.52705638    6.5649879 
    2000    2.0302713    2.0802515   0.53472229    6.5470853 
Loop time of 0.187817 on 8 procs for 1000 steps with 2775 atoms

Performance: 460022.239 tau/day, 5324.331 timesteps/s
100.0% CPU use with 8 MPI tasks x no OpenMP threads

MPI task timing breakdown:
Section |  min time  |  avg time  |  max time  |%varavg| %total
---------------------------------------------------------------
Pair    | 0.038038   | 0.051495   | 0.063654   |   5.0 | 27.42
Neigh   | 0.0046606  | 0.0058847  | 0.0068743  |   1.2 |  3.13
Comm    | 0.019886   | 0.032263   | 0.046773   |   6.5 | 17.18
Output  | 0.0076337  | 0.0077751  | 0.0079532  |   0.1 |  4.14
Modify  | 0.08127    | 0.083289   | 0.084974   |   0.5 | 44.35
Other   |            | 0.00711    |            |       |  3.79

Nlocal:    346.875 ave 400 max 293 min
Histogram: 4 0 0 0 0 0 0 0 0 4
Nghost:    198.125 ave 231 max 167 min
Histogram: 4 0 0 0 0 0 0 0 1 3
Neighs:    3050.5 ave 3680 max 2370 min
Histogram: 4 0 0 0 0 0 0 0 0 4

Total # of neighbors = 24404
Ave neighs/atom = 8.79423
Neighbor list builds = 36
Dangerous builds = 0

#####################################################################
#collect data

#print the applied force and total flux to ensure conservation of Jx
variable        Fapp equal f_GD[1]
compute         vxBulk bulk reduce sum vx
compute         vyBulk bulk reduce sum vy
variable        invVol equal 1.0/(lx*ly)
variable        jx equal c_vxBulk*${invVol}
variable        jx equal c_vxBulk*0.00025
variable        jy equal c_vyBulk*${invVol}
variable        jy equal c_vyBulk*0.00025
variable        curr_step equal step
variable        p_Fapp format Fapp %.3f
variable        p_jx format jx %.5g
variable        p_jy format jy %.5g
fix             print_vCOM all print ${dump_rate}                 "${curr_step} ${p_Fapp} ${p_jx} ${p_jy}" file GD.out screen no                 title "timestep Fapp Jx Jy"
fix             print_vCOM all print 50                 "${curr_step} ${p_Fapp} ${p_jx} ${p_jy}" file GD.out screen no                 title "timestep Fapp Jx Jy"

#compute IK1 pressure profile
#see Todd, Evans, and Davis, Phys. Rev. E 52(2) 1995, p. 1627
#use profile-unbiased temperature to remove the streaming velocity
#from the kinetic part of the pressure
compute         spa bulk stress/atom myTp

#for the pressure profile, use the same grid as the PUT
compute         chunkX bulk chunk/atom bin/1d x lower ${dX} units box
compute         chunkX bulk chunk/atom bin/1d x lower 3.125 units box

#output pressure profile and other profiles
#the pressure profile is (-1/2V)*(c_spa[1] + c_spa[2]), where
#V is the volume of a slice
fix             profiles bulk ave/chunk 1 1 ${dump_rate} chunkX                 vx density/mass  c_spa[1] c_spa[2]                 file x_profiles ave running overwrite
fix             profiles bulk ave/chunk 1 1 50 chunkX                 vx density/mass  c_spa[1] c_spa[2]                 file x_profiles ave running overwrite

#compute velocity profile across the pipe with a finer grid
variable        dYnew equal ${dY}/10
variable        dYnew equal 3.07692307692308/10
compute         chunkY bulk chunk/atom bin/1d y center ${dYnew} units box                 region pipe
compute         chunkY bulk chunk/atom bin/1d y center 0.307692307692308 units box                 region pipe
fix             velYprof bulk ave/chunk 1 1 ${dump_rate} chunkY                 vx file Vy_profile ave running overwrite
fix             velYprof bulk ave/chunk 1 1 50 chunkY                 vx file Vy_profile ave running overwrite

#full trajectory
# dump          7 bulk custom ${dump_rate} bulk.lammpstrj id type x y z
# dump_modify     7 sort id

run             ${run}
run             2000
Per MPI rank memory allocation (min/avg/max) = 5.134 | 5.135 | 5.135 Mbytes
Step c_myT c_myTp TotEng Press 
    2000    2.0302713    2.0802515   0.53472229    6.5470853 
    2010    2.0303419    2.0806129   0.54177821    6.5808527 
    2020    2.0245167    2.0792991   0.54803523    6.6381758 
    2030    2.0169072     2.065404   0.55345227    6.7008962 
    2040    2.0052526    2.0513817   0.55818432    6.7755868 
    2050    1.9953625    2.0366564   0.56245299    6.8382569 
    2060    2.0003667    2.0462109   0.56649798    6.8390557 
    2070    2.0238288    2.0834553   0.57023651    6.7637821 
    2080     2.045765    2.1173867    0.5730944    6.6861321 
    2090    2.0563925    2.1370313   0.57430831    6.6422581 
    2100    2.0620437    2.1480293   0.57319824    6.6080678 
    2110    2.0584437    2.1473173   0.56913597    6.5969671 
    2120    2.0532825    2.1393006   0.56154606    6.5799417 
    2130    2.0450143    2.1234905   0.55009479    6.5616931 
    2140    2.0229537    2.1004507   0.53511912    6.5854627 
    2150    1.9832556    2.0554119   0.51812599    6.6700591 
    2160    1.9444027    2.0110758   0.50163049    6.7534263 
    2170    1.9267473    1.9904528   0.48759542      6.76469 
    2180    1.9262232    1.9809353   0.47662199    6.7188048 
    2190    1.9359331    1.9854626   0.46836289    6.6406985 
    2200    1.9530728    1.9971865    0.4620366    6.5409943 
    2210    1.9657099    2.0056761   0.45692542    6.4639397 
    2220    1.9661008    2.0046161   0.45253504    6.4388081 
    2230    1.9574696    1.9947839   0.44864257    6.4528687 
    2240    1.9522284    1.9922663   0.44518111    6.4584458 
    2250    1.9518203    1.9950044   0.44206844    6.4491722 
    2260    1.9527908    1.9989603    0.4391804    6.4377912 
    2270    1.9452231    1.9932538   0.43643529    6.4607516 
    2280    1.9249341    1.9759145   0.43392742    6.5320897 
    2290    1.9087464     1.960985   0.43186869    6.5875176 
    2300    1.9103289     1.964731   0.43039882    6.5765021 
    2310    1.9182062    1.9783814    0.4294628    6.5434488 
    2320    1.9204281    1.9796609   0.42889381    6.5351629 
    2330     1.916279    1.9720659   0.42866391    6.5562619 
    2340    1.9062866    1.9587628   0.42890166    6.6033936 
    2350    1.9024117    1.9566812   0.42979475    6.6297969 
    2360     1.908153     1.960687   0.43141898    6.6215148 
    2370    1.9115944    1.9663337   0.43376668    6.6236491 
    2380    1.9086193    1.9637867    0.4367911    6.6529568 
    2390    1.9039907    1.9610268   0.44053991    6.6926343 
    2400    1.9034944    1.9609406   0.44508818    6.7193441 
    2410    1.9151521    1.9753641    0.4504458    6.7015957 
    2420    1.9314517    1.9925924   0.45644382    6.6669864 
    2430    1.9433933    2.0062001   0.46277215    6.6481527 
    2440    1.9504631    2.0087015   0.46917209    6.6475757 
    2450    1.9550092    2.0094957   0.47550077    6.6556459 
    2460    1.9609689    2.0147997   0.48170141    6.6568282 
    2470    1.9730726    2.0328127   0.48763131    6.6337545 
    2480    1.9838562    2.0466643   0.49303443    6.6143423 
    2490    1.9862031    2.0473388   0.49767532    6.6245587 
    2500    1.9817565    2.0455432   0.50152131    6.6573893 
    2510    1.9785788    2.0423176   0.50460561    6.6808042 
    2520    1.9823006    2.0505106   0.50696374    6.6726698 
    2530    1.9907178    2.0553736   0.50852885    6.6402082 
    2540    2.0005205    2.0690408   0.50919421    6.5966469 
    2550    2.0079727    2.0809816   0.50872954    6.5568419 
    2560    2.0133128     2.096271   0.50682742    6.5199915 
    2570    2.0141298    2.0990846   0.50314491    6.4951991 
    2580    2.0048768    2.0874319   0.49750096    6.5025454 
    2590    1.9876498    2.0638834    0.4900201    6.5333038 
    2600    1.9720479    2.0474479   0.48105263    6.5527157 
    2610    1.9596324    2.0355764    0.4710001    6.5547867 
    2620    1.9439039    2.0106405   0.46046644    6.5646889 
    2630    1.9321714    1.9924346   0.45021207    6.5589454 
    2640    1.9349378    1.9923889   0.44082833    6.5012762 
    2650    1.9448459    2.0069955   0.43251999    6.4228945 
    2660    1.9446852    2.0050346   0.42525857    6.3921645 
    2670    1.9325594    1.9884937   0.41913362    6.4169726 
    2680    1.9121687    1.9606084   0.41434428    6.4821267 
    2690    1.8923613    1.9339385   0.41105831    6.5517615 
    2700    1.8807238    1.9191801   0.40933203    6.5949447 
    2710    1.8797367     1.918758   0.40906826    6.6001309 
    2720    1.8852961    1.9225996   0.41005611      6.58191 
    2730    1.8937478    1.9357751   0.41204348    6.5541946 
    2740    1.9019279    1.9449374   0.41476104    6.5278575 
    2750    1.9134396    1.9614415   0.41800066    6.4890769 
    2760    1.9339551    1.9913779   0.42150554    6.4159805 
    2770    1.9597826    2.0220988   0.42487614    6.3232273 
    2780    1.9753466    2.0414907   0.42771704    6.2715489 
    2790    1.9720423    2.0402016   0.42976012    6.2949288 
    2800    1.9512893    2.0172711   0.43109201    6.3878056 
    2810    1.9232302    1.9870212    0.4320928    6.5101822 
    2820    1.9026913     1.959286   0.43326424    6.6024967 
    2830    1.9033802    1.9621601   0.43500785    6.6114274 
    2840    1.9214292    1.9833838   0.43733454    6.5508757 
    2850    1.9440563    2.0087358   0.43995473    6.4713496 
    2860    1.9589136    2.0211107   0.44250821    6.4232961 
    2870    1.9588429     2.022232   0.44477492    6.4355861 
    2880    1.9456751    2.0009513   0.44676532    6.5021746 
    2890    1.9269155    1.9782929   0.44877858    6.5926531 
    2900    1.9125262    1.9554653   0.45121196    6.6657808 
    2910    1.9187855    1.9572583   0.45438665    6.6589954 
    2920    1.9416112    1.9784518   0.45839212    6.5888253 
    2930    1.9613579    1.9975032   0.46305788    6.5317424 
    2940    1.9711529    2.0102501   0.46812715    6.5148943 
    2950    1.9707865    2.0133283   0.47345305    6.5389543 
    2960    1.9732526    2.0170219   0.47898306    6.5537092 
    2970    1.9871126    2.0282309   0.48465048    6.5273492 
    2980    1.9953449    2.0404164   0.49032615    6.5227325 
    2990    1.9909136     2.037246   0.49581423    6.5664662 
    3000    1.9872474    2.0307896    0.5011051    6.6060698 
    3010    1.9944885    2.0457308    0.5062755    6.6031811 
    3020    2.0103461    2.0599491   0.51116655    6.5654871 
    3030    2.0240275     2.077342    0.5154921    6.5358852 
    3040    2.0205953    2.0704954   0.51898871    6.5708937 
    3050    2.0032184    2.0463036   0.52167438     6.657741 
    3060    1.9889341    2.0265284   0.52385964    6.7329171 
    3070    1.9795143    2.0201081   0.52588914    6.7881407 
    3080    1.9713362    2.0123964   0.52797238    6.8362858 
    3090    1.9692592    2.0106467   0.53025538    6.8616268 
    3100    1.9722487    2.0259566   0.53277635    6.8689898 
    3110    1.9703322    2.0314028   0.53541462     6.895271 
    3120    1.9594359    2.0217586   0.53808512     6.954362 
    3130    1.9524729    2.0148628    0.5409094    6.9965233 
    3140    1.9630381    2.0260807   0.54400258     6.968082 
    3150    1.9902598    2.0549364   0.54720142    6.8698796 
    3160     2.029715    2.0923999   0.54995378    6.7193678 
    3170    2.0581544    2.1137995   0.55150021    6.6053728 
    3180    2.0590739    2.1156535   0.55123668    6.5919337 
    3190    2.0400682    2.0904721   0.54894762    6.6505757 
    3200    2.0211594    2.0682597   0.54484887    6.7046468 
    3210     2.012712    2.0573114   0.53922056    6.7130909 
    3220    2.0102377    2.0554701   0.53219251    6.6919068 
    3230    2.0017671    2.0505068   0.52386898    6.6867054 
    3240    1.9854941    2.0308454   0.51458791    6.7051085 
    3250    1.9767009    2.0187664   0.50486784    6.6916859 
    3260    1.9771733    2.0186148   0.49510721    6.6424305 
    3270     1.974003    2.0136039   0.48556818    6.6078903 
    3280    1.9627665    1.9989122   0.47654147    6.6067904 
    3290    1.9491247    1.9826247   0.46834865    6.6186709 
    3300    1.9414093    1.9724941    0.4612122    6.6119543 
    3310    1.9433901    1.9715482   0.45518879     6.570612 
    3320    1.9518837    1.9872717   0.45010165    6.5057947 
    3330    1.9603874    1.9957995   0.44566728    6.4428221 
    3340    1.9615962    1.9945224   0.44167201    6.4099339 
    3350     1.955918    1.9882866    0.4380303    6.4070811 
    3360    1.9463445    1.9763654   0.43480086    6.4241178 
    3370    1.9411187     1.968308    0.4320639    6.4296577 
    3380    1.9407224    1.9580074   0.42991627    6.4210217 
    3390    1.9402479    1.9530447   0.42850635    6.4170536 
    3400    1.9451337    1.9555771   0.42787382    6.3990336 
    3410    1.9475586    1.9612432   0.42797178    6.3953251 
    3420    1.9434927     1.960532    0.4286887    6.4210681 
    3430    1.9339054    1.9516935   0.43003682    6.4707071 
    3440    1.9234014    1.9464343   0.43214965    6.5248205 
    3450    1.9191846    1.9444777   0.43516361    6.5558451 
    3460     1.923218    1.9594606   0.43915611    6.5549213 
    3470    1.9328953    1.9792053   0.44397878    6.5327637 
    3480    1.9466227    1.9997841   0.44940599    6.4954965 
    3490    1.9672374    2.0323219   0.45511091    6.4358811 
    3500    1.9799622    2.0479841   0.46061029    6.4100217 
    3510      1.97942    2.0493411   0.46551964    6.4368108 
    3520    1.9725674    2.0389601   0.46976379    6.4892049 
    3530    1.9716429    2.0389798   0.47344292    6.5200899 
    3540    1.9789254    2.0486163   0.47659268    6.5198212 
    3550    1.9872455    2.0577517   0.47908145    6.5144586 
    3560    1.9808834    2.0545962   0.48076562    6.5633282 
    3570    1.9637165    2.0335394    0.4816783    6.6519124 
    3580    1.9407948    2.0067763   0.48212406    6.7605224 
    3590    1.9226532    1.9825887     0.482523    6.8486041 
    3600    1.9135067       1.9701   0.48328349    6.8977858 
    3610    1.9157516    1.9720028   0.48470695    6.8977759 
    3620    1.9328644    2.0001154   0.48688778    6.8361569 
    3630    1.9568208    2.0243053   0.48963934    6.7442107 
    3640    1.9824587    2.0569223   0.49259174    6.6452535 
    3650    1.9934906    2.0686357   0.49529039    6.6020219 
    3660    1.9996281    2.0747054   0.49732231    6.5808905 
    3670    2.0038801    2.0772777   0.49838834    6.5691351 
    3680    1.9941342    2.0712365   0.49826732    6.6088108 
    3690    1.9762631    2.0486045   0.49689109    6.6739003 
    3700    1.9667284    2.0349391   0.49438991    6.7010265 
    3710    1.9615089    2.0168113   0.49093735    6.7040384 
    3720    1.9613068     2.014749   0.48673788    6.6813041 
    3730    1.9731234    2.0290151   0.48175561    6.6096757 
    3740    1.9829764    2.0461907   0.47575173    6.5424753 
    3750    1.9792839    2.0454423   0.46852709    6.5237753 
    3760    1.9599692    2.0287014   0.46022485    6.5616271 
    3770     1.935975    2.0000948   0.45138016    6.6136471 
    3780    1.9236713    1.9834802   0.44262436    6.6187462 
    3790    1.9268004    1.9875324   0.43430113    6.5632771 
    3800     1.932601    1.9872595   0.42649563    6.4984764 
    3810    1.9322506    1.9814946   0.41928855    6.4617054 
    3820    1.9245737    1.9712821    0.4128224    6.4613779 
    3830    1.9148568    1.9555602   0.40721003    6.4774473 
    3840    1.9049961    1.9457058   0.40261179     6.502921 
    3850    1.8915137    1.9265198   0.39914961    6.5483593 
    3860    1.8784767    1.9058055   0.39700153    6.5962115 
    3870    1.8755236    1.9045157   0.39632769    6.6079035 
    3880    1.8841414    1.9140314   0.39710038    6.5777071 
    3890    1.8958027    1.9331149   0.39918951    6.5359785 
    3900    1.9064085     1.948805   0.40238577     6.499859 
    3910    1.9185093    1.9675733   0.40647524    6.4610682 
    3920    1.9342595    1.9933225   0.41115393    6.4122308 
    3930    1.9482664     2.007614   0.41603496     6.373684 
    3940    1.9557759    2.0161573   0.42084462    6.3636707 
    3950    1.9573687     2.016612   0.42540422    6.3804123 
    3960    1.9486354    1.9998027   0.42974612    6.4404943 
    3970     1.936214     1.980721   0.43412037    6.5176787 
    3980    1.9274292    1.9595259   0.43885103    6.5846209 
    3990    1.9233083    1.9534361   0.44425085    6.6354274 
    4000    1.9289166    1.9522097   0.45042645    6.6513835 
Loop time of 0.392479 on 8 procs for 2000 steps with 2775 atoms

Performance: 440277.958 tau/day, 5095.810 timesteps/s
100.0% CPU use with 8 MPI tasks x no OpenMP threads

MPI task timing breakdown:
Section |  min time  |  avg time  |  max time  |%varavg| %total
---------------------------------------------------------------
Pair    | 0.078849   | 0.10352    | 0.12786    |   7.0 | 26.38
Neigh   | 0.0095383  | 0.011677   | 0.013594   |   1.7 |  2.98
Comm    | 0.043474   | 0.067893   | 0.094187   |   9.0 | 17.30
Output  | 0.015672   | 0.020154   | 0.020959   |   1.2 |  5.14
Modify  | 0.17017    | 0.17441    | 0.18224    |   1.0 | 44.44
Other   |            | 0.01482    |            |       |  3.78

Nlocal:    346.875 ave 405 max 286 min
Histogram: 4 0 0 0 0 0 0 0 0 4
Nghost:    195.625 ave 226 max 164 min
Histogram: 2 2 0 0 0 0 0 0 1 3
Neighs:    3045.75 ave 3723 max 2279 min
Histogram: 2 2 0 0 0 0 0 0 0 4

Total # of neighbors = 24366
Ave neighs/atom = 8.78054
Neighbor list builds = 72
Dangerous builds = 0

Please see the log.cite file for references relevant to this simulation

Total wall time: 0:00:00
