LAMMPS (4 Jan 2019)
# Monte Carlo relaxation of perturbed 2d hex lattice

# set these parameters
# make sure neigh skin > 2*deltamove

variable iter loop 3000            # number of Monte Carlo moves
variable deltaperturb equal 0.2    # max size of initial perturbation per dim
variable deltamove equal 0.1       # max size of MC move in one dimension
variable density equal 1.0         # reduced LJ density of atoms on lattice
variable kT equal 0.05             # effective T in Boltzmann factor
variable seed equal 582783         # RNG seed

# problem setup

units		lj
atom_style	atomic
atom_modify     map array sort 0 0.0

dimension       2

lattice		hex ${density}
lattice		hex 1
Lattice spacing in x,y,z = 1.07457 1.86121 1.07457
region		box block 0 10 0 5 -0.5 0.5

create_box	1 box
Created orthogonal box = (0 0 -0.537285) to (10.7457 9.30605 0.537285)
  4 by 2 by 1 MPI processor grid
create_atoms	1 box
Created 100 atoms
  Time spent = 0.000738747 secs
mass		1 1.0

pair_style	lj/cut 2.5
pair_coeff	1 1 1.0 1.0 2.5
pair_modify     shift yes

neighbor	0.3 bin
neigh_modify	delay 0 every 1 check yes

variable        e equal pe

# run 0 to get energy of perfect lattice
# emin = minimum energy

run             0
WARNING: No fixes defined, atoms won't move (../verlet.cpp:55)
Neighbor list info ...
  update every 1 steps, delay 0 steps, check yes
  max neighbors/atom: 2000, page size: 100000
  master list distance cutoff = 2.8
  ghost atom cutoff = 2.8
  binsize = 1.4, bins = 8 7 1
  1 neighbor lists, perpetual/occasional/extra = 1 0 0
  (1) pair lj/cut, perpetual
      attributes: half, newton on
      pair build: half/bin/atomonly/newton
      stencil: half/bin/2d/newton
      bin: standard
Per MPI rank memory allocation (min/avg/max) = 2.933 | 2.933 | 2.933 Mbytes
Step Temp E_pair E_mol TotEng Press 
       0            0   -2.9871562            0   -2.9871562    5.8100167 
Loop time of 5.87673e-06 on 8 procs for 0 steps with 100 atoms

78.7% CPU use with 8 MPI tasks x no OpenMP threads

MPI task timing breakdown:
Section |  min time  |  avg time  |  max time  |%varavg| %total
---------------------------------------------------------------
Pair    | 0          | 0          | 0          |   0.0 |  0.00
Neigh   | 0          | 0          | 0          |   0.0 |  0.00
Comm    | 0          | 0          | 0          |   0.0 |  0.00
Output  | 0          | 0          | 0          |   0.0 |  0.00
Modify  | 0          | 0          | 0          |   0.0 |  0.00
Other   |            | 5.877e-06  |            |       |100.00

Nlocal:    12.5 ave 13 max 12 min
Histogram: 4 0 0 0 0 0 0 0 0 4
Nghost:    83.5 ave 84 max 83 min
Histogram: 4 0 0 0 0 0 0 0 0 4
Neighs:    112.5 ave 115 max 110 min
Histogram: 2 0 0 0 2 0 2 0 0 2

Total # of neighbors = 900
Ave neighs/atom = 9
Neighbor list builds = 0
Dangerous builds = 0
variable        emin equal $e
variable        emin equal -2.98715616447944

# disorder the system
# estart = initial energy

variable        x atom x+v_deltaperturb*random(-1.0,1.0,${seed})
variable        x atom x+v_deltaperturb*random(-1.0,1.0,582783)
variable        y atom y+v_deltaperturb*random(-1.0,1.0,${seed})
variable        y atom y+v_deltaperturb*random(-1.0,1.0,582783)

set             group all x v_x
  100 settings made for x
set             group all y v_y
  100 settings made for y

#dump		1 all atom 25 dump.mc

#dump		2 all image 25 image.*.jpg type type #		zoom 1.6 adiam 1.0
#dump_modify	2 pad 5

#dump		3 all movie 25 movie.mpg type type #		zoom 1.6 adiam 1.0
#dump_modify	3 pad 5

variable        elast equal $e
variable        elast equal -2.98715616447944
thermo_style    custom step v_emin v_elast pe

run             0
WARNING: No fixes defined, atoms won't move (../verlet.cpp:55)
Per MPI rank memory allocation (min/avg/max) = 2.933 | 2.933 | 2.933 Mbytes
Step v_emin v_elast PotEng 
       0   -2.9871562   -2.9871562    19.199781 
Loop time of 5.16124e-06 on 8 procs for 0 steps with 100 atoms

65.4% CPU use with 8 MPI tasks x no OpenMP threads

MPI task timing breakdown:
Section |  min time  |  avg time  |  max time  |%varavg| %total
---------------------------------------------------------------
Pair    | 0          | 0          | 0          |   0.0 |  0.00
Neigh   | 0          | 0          | 0          |   0.0 |  0.00
Comm    | 0          | 0          | 0          |   0.0 |  0.00
Output  | 0          | 0          | 0          |   0.0 |  0.00
Modify  | 0          | 0          | 0          |   0.0 |  0.00
Other   |            | 5.161e-06  |            |       |100.00

Nlocal:    12.5 ave 14 max 11 min
Histogram: 1 0 0 3 0 0 3 0 0 1
Nghost:    73 ave 75 max 70 min
Histogram: 1 0 0 0 2 0 2 0 1 2
Neighs:    141 ave 159 max 123 min
Histogram: 1 1 1 1 0 0 1 1 1 1

Total # of neighbors = 1128
Ave neighs/atom = 11.28
Neighbor list builds = 0
Dangerous builds = 0

variable        estart equal $e
variable        estart equal 19.1997808254901
variable        elast equal $e
variable        elast equal 19.1997808254901

# loop over Monte Carlo moves

variable        naccept equal 0
variable        increment equal v_naccept+1
variable        irandom equal floor(atoms*random(0.0,1.0,${seed})+1)
variable        irandom equal floor(atoms*random(0.0,1.0,582783)+1)
variable        rn equal random(0.0,1.0,${seed})
variable        rn equal random(0.0,1.0,582783)
variable        boltzfactor equal "exp(atoms*(v_elast - v_e) / v_kT)"
variable        xnew equal x[v_i]+v_deltamove*random(-1.0,1.0,${seed})
variable        xnew equal x[v_i]+v_deltamove*random(-1.0,1.0,582783)
variable        ynew equal y[v_i]+v_deltamove*random(-1.0,1.0,${seed})
variable        ynew equal y[v_i]+v_deltamove*random(-1.0,1.0,582783)
variable        xi equal x[v_i]
variable        yi equal y[v_i]

label           loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.84759294946185
variable        y0 equal ${yi}
variable        y0 equal 6.37423569694987

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.87776957709781
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.28678872124186
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
       0   -2.9871562    19.199781    19.199781 
       1   -2.9871562    19.199781    19.396074 
Loop time of 0.000102554 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.84759294946185
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.37423569694987
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.5720709880047
variable        y0 equal ${yi}
variable        y0 equal 5.55054221098619

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.6657763560467
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.54022269194323
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
       1   -2.9871562    19.199781    19.396074 
       2   -2.9871562    19.199781    18.841843 
Loop time of 5.67719e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 18.8418429588543
variable naccept equal ${increment}
variable naccept equal 1

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.459052677551175
variable        y0 equal ${yi}
variable        y0 equal 8.41986581005153

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.461557538906003
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.46209968246516
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
       2   -2.9871562    18.841843    18.841843 
       3   -2.9871562    18.841843     18.99023 
Loop time of 5.62945e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.459052677551175
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.41986581005153
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.4443687566063
variable        y0 equal ${yi}
variable        y0 equal 3.69860313696992

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.37775198300096
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.66390537781846
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
       3   -2.9871562    18.841843     18.99023 
       4   -2.9871562    18.841843    18.807209 
Loop time of 5.4267e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 18.8072088064515
variable naccept equal ${increment}
variable naccept equal 2

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.23360760847435
variable        y0 equal ${yi}
variable        y0 equal 2.01121212623185

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.17734692732201
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.9904889740712
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
       4   -2.9871562    18.807209    18.807209 
       5   -2.9871562    18.807209    18.706224 
Loop time of 5.39581e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 18.7062241272999
variable naccept equal ${increment}
variable naccept equal 3

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.87135564604884
variable        y0 equal ${yi}
variable        y0 equal 6.55566048161021

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.80586687842494
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.61844325796595
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
       5   -2.9871562    18.706224    18.706224 
       6   -2.9871562    18.706224    18.711661 
Loop time of 5.28488e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.87135564604884
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.55566048161021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.06897214053966
variable        y0 equal ${yi}
variable        y0 equal 8.19967323459681

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.14397334455349
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.22307642616328
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
       6   -2.9871562    18.706224    18.711661 
       7   -2.9871562    18.706224     18.77557 
Loop time of 5.26199e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.06897214053966
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.19967323459681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.50663187900449
variable        y0 equal ${yi}
variable        y0 equal 7.56962687101626

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.57113583484555
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.55018040266299
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
       7   -2.9871562    18.706224     18.77557 
       8   -2.9871562    18.706224    18.738494 
Loop time of 5.31813e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.50663187900449
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.56962687101626
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.21418936847545
variable        y0 equal ${yi}
variable        y0 equal 6.3494564248704

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.29130173324444
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.39447173611155
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
       8   -2.9871562    18.706224    18.738494 
       9   -2.9871562    18.706224    21.664238 
Loop time of 5.47835e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.21418936847545
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.3494564248704
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 7.94018488525249
variable        y0 equal ${yi}
variable        y0 equal 0.86350280832085

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 7.88638265727855
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.805514188516467
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
       9   -2.9871562    18.706224    21.664238 
      10   -2.9871562    18.706224    18.851438 
Loop time of 5.19004e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 7.94018488525249
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.86350280832085
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.16834633070976
variable        y0 equal ${yi}
variable        y0 equal 8.39832626499232

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.07404753882439
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.38382266677912
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      10   -2.9871562    18.706224    18.851438 
      11   -2.9871562    18.706224     18.67662 
Loop time of 5.34207e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 18.6766202698886
variable naccept equal ${increment}
variable naccept equal 4

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.59946205814314
variable        y0 equal ${yi}
variable        y0 equal 2.77839184972146

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.52578410108519
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.79605212184289
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      11   -2.9871562     18.67662     18.67662 
      12   -2.9871562     18.67662    18.727534 
Loop time of 5.21573e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.59946205814314
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.77839184972146
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.71520588596297
variable        y0 equal ${yi}
variable        y0 equal 8.50687137760218

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.63986052473021
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.4647656074911
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      12   -2.9871562     18.67662    18.727534 
      13   -2.9871562     18.67662    18.686333 
Loop time of 5.16813e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.71520588596297
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.50687137760218
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.87135564604884
variable        y0 equal ${yi}
variable        y0 equal 6.55566048161021

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.92992097655421
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.6204145981454
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      13   -2.9871562     18.67662    18.686333 
      14   -2.9871562     18.67662    18.848387 
Loop time of 4.58411e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.87135564604884
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.55566048161021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.352515979209806
variable        y0 equal ${yi}
variable        y0 equal 6.55085324779978

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.387799485126401
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.49517389074793
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      14   -2.9871562     18.67662    18.848387 
      15   -2.9871562     18.67662    18.649875 
Loop time of 4.65914e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 18.6498751248516
variable naccept equal ${increment}
variable naccept equal 5

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.97526077309295
variable        y0 equal ${yi}
variable        y0 equal 8.23448504127559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.88670579472229
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.19218952573832
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      15   -2.9871562    18.649875    18.649875 
      16   -2.9871562    18.649875    18.816118 
Loop time of 4.58894e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.97526077309295
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.23448504127559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.55075164873373
variable        y0 equal ${yi}
variable        y0 equal 5.74215760176378

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.46315569717657
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.81912440006929
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      16   -2.9871562    18.649875    18.816118 
      17   -2.9871562    18.649875    19.240936 
Loop time of 4.36005e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.55075164873373
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.74215760176378
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.71520588596297
variable        y0 equal ${yi}
variable        y0 equal 8.50687137760218

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.75069267948104
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.52270703233774
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      17   -2.9871562    18.649875    19.240936 
      18   -2.9871562    18.649875    18.657284 
Loop time of 4.39049e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.71520588596297
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.50687137760218
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.50663187900449
variable        y0 equal ${yi}
variable        y0 equal 7.56962687101626

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.59114939371015
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.6569728287723
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      18   -2.9871562    18.649875    18.657284 
      19   -2.9871562    18.649875    18.967603 
Loop time of 4.18166e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.50663187900449
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.56962687101626
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.6272473827881
variable        y0 equal ${yi}
variable        y0 equal 7.54194511499667

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.67699492135469
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.62279662218356
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      19   -2.9871562    18.649875    18.967603 
      20   -2.9871562    18.649875    18.869374 
Loop time of 4.35116e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.6272473827881
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.54194511499667
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.72306582251674
variable        y0 equal ${yi}
variable        y0 equal 4.47625692242548

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.6856681994546
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.43579470271036
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      20   -2.9871562    18.649875    18.869374 
      21   -2.9871562    18.649875    18.660467 
Loop time of 4.29307e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.72306582251674
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.47625692242548
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.45465552964632
variable        y0 equal ${yi}
variable        y0 equal 3.67120390696656

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.36835785069887
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.69994463486802
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      21   -2.9871562    18.649875    18.660467 
      22   -2.9871562    18.649875    18.760057 
Loop time of 4.29408e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.45465552964632
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.67120390696656
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 6.04620492417804
variable        y0 equal ${yi}
variable        y0 equal 8.33303295291957

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.02091737945072
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.42499875940379
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      22   -2.9871562    18.649875    18.760057 
      23   -2.9871562    18.649875    18.785572 
Loop time of 4.30196e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 6.04620492417804
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.33303295291957
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.50663187900449
variable        y0 equal ${yi}
variable        y0 equal 7.56962687101626

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.49776528278257
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.4722852620151
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      23   -2.9871562    18.649875    18.785572 
      24   -2.9871562    18.649875    18.613028 
Loop time of 4.34445e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 18.6130280493567
variable naccept equal ${increment}
variable naccept equal 6

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.78632356444484
variable        y0 equal ${yi}
variable        y0 equal 2.7753891822944

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.73503010789042
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.73983592959741
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      24   -2.9871562    18.613028    18.613028 
      25   -2.9871562    18.613028     18.64811 
Loop time of 4.25794e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.78632356444484
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.7753891822944
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.04622503796264
variable        y0 equal ${yi}
variable        y0 equal 0.941362734544604

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.12667885103866
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.93246557306084
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      25   -2.9871562    18.613028     18.64811 
      26   -2.9871562    18.613028    18.878141 
Loop time of 4.32146e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.04622503796264
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.941362734544604
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.04091423152782
variable        y0 equal ${yi}
variable        y0 equal 4.59223661774561

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.0567768156419
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.66208653801843
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      26   -2.9871562    18.613028    18.878141 
      27   -2.9871562    18.613028    18.610122 
Loop time of 4.20566e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 18.6101218871606
variable naccept equal ${increment}
variable naccept equal 7

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.72746811111403
variable        y0 equal ${yi}
variable        y0 equal 6.56291543976298

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.75894133050871
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.50207719341746
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      27   -2.9871562    18.610122    18.610122 
      28   -2.9871562    18.610122    18.420329 
Loop time of 4.21224e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 18.4203294539541
variable naccept equal ${increment}
variable naccept equal 8

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.6955831456053
variable        y0 equal ${yi}
variable        y0 equal 0.0743083238601685

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.74719416378614
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.025791072845459
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      28   -2.9871562    18.420329    18.420329 
      29   -2.9871562    18.420329    18.522363 
Loop time of 4.36996e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 79 x ${x0}
set atom 79 x 9.6955831456053
  1 settings made for x
set atom $i y ${y0}
set atom 79 y ${y0}
set atom 79 y 0.0743083238601685
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.99504664778052
variable        y0 equal ${yi}
variable        y0 equal 2.96102813454965

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 5.02966773151694
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.92187951775888
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      29   -2.9871562    18.420329    18.522363 
      30   -2.9871562    18.420329    19.150246 
Loop time of 4.2652e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.99504664778052
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.96102813454965
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.56271735269796
variable        y0 equal ${yi}
variable        y0 equal 9.27910173642963

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.65711865265142
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.35638247239917
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      30   -2.9871562    18.420329    19.150246 
      31   -2.9871562    18.420329    18.572803 
Loop time of 4.23385e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.56271735269796
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.27910173642963
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 10.6500851233654
variable        y0 equal ${yi}
variable        y0 equal 3.76922581954133

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 10.6846685488873
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.85353443188798
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      31   -2.9871562    18.420329    18.572803 
      32   -2.9871562    18.420329    18.311191 
Loop time of 4.24476e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 18.3111914717818
variable naccept equal ${increment}
variable naccept equal 9

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.74866355538149
variable        y0 equal ${yi}
variable        y0 equal 0.889158554780811

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.79875581145068
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.852812607992023
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      32   -2.9871562    18.311191    18.311191 
      33   -2.9871562    18.311191    18.422704 
Loop time of 4.2479e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.74866355538149
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.889158554780811
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.49776528278257
variable        y0 equal ${yi}
variable        y0 equal 7.4722852620151

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.56215200820829
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.57089860763812
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      33   -2.9871562    18.311191    18.422704 
      34   -2.9871562    18.311191    18.391774 
Loop time of 4.21684e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.49776528278257
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.4722852620151
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.73131323059035
variable        y0 equal ${yi}
variable        y0 equal 4.67710171097681

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.69340100486708
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.72826737517282
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      34   -2.9871562    18.311191    18.391774 
      35   -2.9871562    18.311191    18.372289 
Loop time of 4.20765e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.73131323059035
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.67710171097681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.459052677551175
variable        y0 equal ${yi}
variable        y0 equal 8.41986581005153

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.547714324394132
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.39453185714778
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      35   -2.9871562    18.311191    18.372289 
      36   -2.9871562    18.311191    18.300435 
Loop time of 4.2428e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 18.3004351286541
variable naccept equal ${increment}
variable naccept equal 10

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.1922400359174
variable        y0 equal ${yi}
variable        y0 equal 0.954647608507007

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.1027207259198
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.928481574762195
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      36   -2.9871562    18.300435    18.300435 
      37   -2.9871562    18.300435    18.373732 
Loop time of 4.15127e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.1922400359174
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.954647608507007
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.87135564604884
variable        y0 equal ${yi}
variable        y0 equal 6.55566048161021

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.9387724093545
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.59623282686702
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      37   -2.9871562    18.300435    18.373732 
      38   -2.9871562    18.300435    18.420573 
Loop time of 4.20142e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.87135564604884
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.55566048161021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.78632356444484
variable        y0 equal ${yi}
variable        y0 equal 2.7753891822944

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.74959222594386
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.74107465716699
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      38   -2.9871562    18.300435    18.420573 
      39   -2.9871562    18.300435    18.328507 
Loop time of 3.99999e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.78632356444484
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.7753891822944
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.36975130557138
variable        y0 equal ${yi}
variable        y0 equal 9.17877667653888

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.28843696831781
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.26706319558948
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      39   -2.9871562    18.300435    18.328507 
      40   -2.9871562    18.300435    18.430366 
Loop time of 4.31616e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.36975130557138
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.17877667653888
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.36975130557138
variable        y0 equal ${yi}
variable        y0 equal 9.17877667653888

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.32596215724069
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.1058867524895
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      40   -2.9871562    18.300435    18.430366 
      41   -2.9871562    18.300435    18.545586 
Loop time of 4.35642e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.36975130557138
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.17877667653888
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.40708486794987
variable        y0 equal ${yi}
variable        y0 equal 1.88286055705613

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.48192629575291
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.83248113772935
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      41   -2.9871562    18.300435    18.545586 
      42   -2.9871562    18.300435    18.315792 
Loop time of 4.26299e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.40708486794987
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.88286055705613
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.516645927825834
variable        y0 equal ${yi}
variable        y0 equal 2.91738013001779

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.476136846938993
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.85021170350411
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      42   -2.9871562    18.300435    18.315792 
      43   -2.9871562    18.300435    18.306153 
Loop time of 4.29811e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.516645927825834
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.91738013001779
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.28044283110649
variable        y0 equal ${yi}
variable        y0 equal 2.67400697442391

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.25489055830986
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.6545912859092
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      43   -2.9871562    18.300435    18.306153 
      44   -2.9871562    18.300435    18.304138 
Loop time of 4.18745e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.28044283110649
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.67400697442391
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.72306582251674
variable        y0 equal ${yi}
variable        y0 equal 4.47625692242548

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.786463814174
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.50682874077723
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      44   -2.9871562    18.300435    18.304138 
      45   -2.9871562    18.300435    18.295616 
Loop time of 4.23001e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 18.2956162371738
variable naccept equal ${increment}
variable naccept equal 11

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.40689885138589
variable        y0 equal ${yi}
variable        y0 equal 1.95026988170212

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.39329236268121
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 2.02082310102051
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      45   -2.9871562    18.295616    18.295616 
      46   -2.9871562    18.295616    18.312679 
Loop time of 4.32302e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.40689885138589
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.95026988170212
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.50309296686422
variable        y0 equal ${yi}
variable        y0 equal 3.6237421588434

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.45141068537008
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.56515824360978
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      46   -2.9871562    18.295616    18.312679 
      47   -2.9871562    18.295616    18.417204 
Loop time of 4.19218e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.50309296686422
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.6237421588434
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 6.95917002239868
variable        y0 equal ${yi}
variable        y0 equal 2.87266253205636

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 7.024227991492
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.84312890740731
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      47   -2.9871562    18.295616    18.417204 
      48   -2.9871562    18.295616    18.306537 
Loop time of 4.15095e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 6.95917002239868
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.87266253205636
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 10.6846685488873
variable        y0 equal ${yi}
variable        y0 equal 3.85353443188798

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 10.7767231901341
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.80844516320359
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      48   -2.9871562    18.295616    18.306537 
      49   -2.9871562    18.295616    18.147353 
Loop time of 4.17216e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 18.1473530663571
variable naccept equal ${increment}
variable naccept equal 12

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.71520588596297
variable        y0 equal ${yi}
variable        y0 equal 8.50687137760218

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.77781357963515
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.55931589521464
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      49   -2.9871562    18.147353    18.147353 
      50   -2.9871562    18.147353    18.184788 
Loop time of 4.08497e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.71520588596297
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.50687137760218
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66628361820956
variable        y0 equal ${yi}
variable        y0 equal 8.33030129589137

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.64468072533388
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.34522449888286
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      50   -2.9871562    18.147353    18.184788 
      51   -2.9871562    18.147353    18.147864 
Loop time of 4.28091e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66628361820956
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.33030129589137
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.94295528768836
variable        y0 equal ${yi}
variable        y0 equal 1.1037085492495

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.92978396057426
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 1.00790997337136
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      51   -2.9871562    18.147353    18.147864 
      52   -2.9871562    18.147353    17.310935 
Loop time of 4.11459e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 17.3109345433279
variable naccept equal ${increment}
variable naccept equal 13

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 10.7767231901341
variable        y0 equal ${yi}
variable        y0 equal 3.80844516320359

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 10.8204353769475
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.79125471873414
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      52   -2.9871562    17.310935    17.310935 
      53   -2.9871562    17.310935    17.326205 
Loop time of 6.94373e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 10.7767231901341
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.80844516320359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.50943795323153
variable        y0 equal ${yi}
variable        y0 equal 4.83169741982385

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.55248561978121
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.91601028794214
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      53   -2.9871562    17.310935    17.326205 
      54   -2.9871562    17.310935    17.342575 
Loop time of 6.70069e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.50943795323153
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.83169741982385
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.04622503796264
variable        y0 equal ${yi}
variable        y0 equal 0.941362734544604

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.00735670605346
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 1.01247323344979
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      54   -2.9871562    17.310935    17.342575 
      55   -2.9871562    17.310935    17.318839 
Loop time of 4.22434e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.04622503796264
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.941362734544604
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.57711223203909
variable        y0 equal ${yi}
variable        y0 equal 1.7166861691243

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.4786569936968
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.62874253175324
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      55   -2.9871562    17.310935    17.318839 
      56   -2.9871562    17.310935    17.633433 
Loop time of 4.85934e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.57711223203909
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.7166861691243
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.19426209687749
variable        y0 equal ${yi}
variable        y0 equal 5.42006843035418

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.10837893247166
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.42797319834429
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      56   -2.9871562    17.310935    17.633433 
      57   -2.9871562    17.310935    17.495069 
Loop time of 3.9207e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.19426209687749
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.42006843035418
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.50943795323153
variable        y0 equal ${yi}
variable        y0 equal 4.83169741982385

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.48859311222811
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.80827528590127
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      57   -2.9871562    17.310935    17.495069 
      58   -2.9871562    17.310935    17.308921 
Loop time of 4.0085e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 17.3089206606902
variable naccept equal ${increment}
variable naccept equal 14

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.187410736083984
variable        y0 equal ${yi}
variable        y0 equal 1.7302321829564

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.224698042869568
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.78300419232911
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      58   -2.9871562    17.308921    17.308921 
      59   -2.9871562    17.308921    17.961475 
Loop time of 4.17255e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 6 x ${x0}
set atom 6 x 0.187410736083984
  1 settings made for x
set atom $i y ${y0}
set atom 6 y ${y0}
set atom 6 y 1.7302321829564
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.07404753882439
variable        y0 equal ${yi}
variable        y0 equal 8.38382266677912

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.16867596823723
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.47626823104914
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      59   -2.9871562    17.308921    17.961475 
      60   -2.9871562    17.308921    17.340215 
Loop time of 4.17102e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.07404753882439
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.38382266677912
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.36975130557138
variable        y0 equal ${yi}
variable        y0 equal 9.17877667653888

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.3612679433735
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.12302479255527
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      60   -2.9871562    17.308921    17.340215 
      61   -2.9871562    17.308921    17.418288 
Loop time of 4.09991e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.36975130557138
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.17877667653888
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.70319105862257
variable        y0 equal ${yi}
variable        y0 equal 7.5197192343738

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.76286459444639
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.58744383182787
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      61   -2.9871562    17.308921    17.418288 
      62   -2.9871562    17.308921    17.306436 
Loop time of 4.04735e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 17.3064360995802
variable naccept equal ${increment}
variable naccept equal 15

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.01163879076348
variable        y0 equal ${yi}
variable        y0 equal 9.27794473874896

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 1.92133815924035
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 9.23672804344028
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      62   -2.9871562    17.306436    17.306436 
      63   -2.9871562    17.306436    17.330302 
Loop time of 3.91121e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.01163879076348
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 9.27794473874896
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.258966393462
variable        y0 equal ${yi}
variable        y0 equal 3.90735419554841

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.22860327481347
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.8745394663347
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      63   -2.9871562    17.306436    17.330302 
      64   -2.9871562    17.306436     18.67625 
Loop time of 4.10634e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.258966393462
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.90735419554841
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.37775198300096
variable        y0 equal ${yi}
variable        y0 equal 3.66390537781846

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.38887881119462
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.60140080018174
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      64   -2.9871562    17.306436     18.67625 
      65   -2.9871562    17.306436    17.366402 
Loop time of 4.01379e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.37775198300096
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.66390537781846
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.97526077309295
variable        y0 equal ${yi}
variable        y0 equal 8.23448504127559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 7.05674064436599
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.13671655572948
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      65   -2.9871562    17.306436    17.366402 
      66   -2.9871562    17.306436     19.74835 
Loop time of 4.0795e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.97526077309295
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.23448504127559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.21161605198594
variable        y0 equal ${yi}
variable        y0 equal 5.67831456606585

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.3046985395691
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.75239630882936
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      66   -2.9871562    17.306436     19.74835 
      67   -2.9871562    17.306436    17.409346 
Loop time of 3.97047e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.21161605198594
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.67831456606585
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 0.066135311126709
variable        y0 equal ${yi}
variable        y0 equal 9.23665307271808

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 0.0507727980613709
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.24085442531436
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      67   -2.9871562    17.306436    17.409346 
      68   -2.9871562    17.306436    17.244993 
Loop time of 4.01481e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 17.2449932365391
variable naccept equal ${increment}
variable naccept equal 16

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 0.0231122970581055
variable        y0 equal ${yi}
variable        y0 equal 7.42290238466525

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 0.0318403005599976
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.51229137506747
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      68   -2.9871562    17.244993    17.244993 
      69   -2.9871562    17.244993    17.237177 
Loop time of 4.06156e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 17.2371769494223
variable naccept equal ${increment}
variable naccept equal 17

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.55446753898526
variable        y0 equal ${yi}
variable        y0 equal 1.77595841071671

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.57948047319318
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.74562306783265
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      69   -2.9871562    17.237177    17.237177 
      70   -2.9871562    17.237177    17.281699 
Loop time of 3.96211e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.55446753898526
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.77595841071671
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.34747294266435
variable        y0 equal ${yi}
variable        y0 equal 7.34275282945895

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.35826578219148
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.40391505089068
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      70   -2.9871562    17.237177    17.281699 
      71   -2.9871562    17.237177    17.200202 
Loop time of 3.96816e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 17.2002017587265
variable naccept equal ${increment}
variable naccept equal 18

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.07404753882439
variable        y0 equal ${yi}
variable        y0 equal 8.38382266677912

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.03154995162041
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.4676475397497
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      71   -2.9871562    17.200202    17.200202 
      72   -2.9871562    17.200202    17.179292 
Loop time of 3.85689e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 17.1792915393841
variable naccept equal ${increment}
variable naccept equal 19

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.45465552964632
variable        y0 equal ${yi}
variable        y0 equal 3.67120390696656

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.4120085612816
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.69567955298554
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      72   -2.9871562    17.179292    17.179292 
      73   -2.9871562    17.179292    17.194129 
Loop time of 3.86177e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.45465552964632
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.67120390696656
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.24916743993321
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.090741765499115
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      73   -2.9871562    17.179292    17.194129 
      74   -2.9871562    17.179292    17.181926 
Loop time of 3.95039e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.547714324394132
variable        y0 equal ${yi}
variable        y0 equal 8.39453185714778

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.504707296291257
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.38087454952296
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      74   -2.9871562    17.179292    17.181926 
      75   -2.9871562    17.179292    17.136251 
Loop time of 3.97054e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 17.1362510778002
variable naccept equal ${increment}
variable naccept equal 20

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.17734692732201
variable        y0 equal ${yi}
variable        y0 equal 1.9904889740712

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.15250330606804
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.91628064296311
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      75   -2.9871562    17.136251    17.136251 
      76   -2.9871562    17.136251    17.073343 
Loop time of 3.96764e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 17.0733426034459
variable naccept equal ${increment}
variable naccept equal 21

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 0.0507727980613709
variable        y0 equal ${yi}
variable        y0 equal 9.24085442531436

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x -0.0101428747177124
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.16062856424182
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      76   -2.9871562    17.073343    17.073343 
      77   -2.9871562    17.073343    17.017293 
Loop time of 3.98129e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 17.0172933912398
variable naccept equal ${increment}
variable naccept equal 22

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.6272473827881
variable        y0 equal ${yi}
variable        y0 equal 7.54194511499667

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.56327402749483
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.57519884434008
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      77   -2.9871562    17.017293    17.017293 
      78   -2.9871562    17.017293    17.338114 
Loop time of 4.00843e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.6272473827881
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.54194511499667
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.39391056378098
variable        y0 equal ${yi}
variable        y0 equal 9.18249467122882

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.47945046503755
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.25402225959628
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      78   -2.9871562    17.017293    17.338114 
      79   -2.9871562    17.017293    16.904453 
Loop time of 4.00236e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 16.9044525158325
variable naccept equal ${increment}
variable naccept equal 23

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.45465552964632
variable        y0 equal ${yi}
variable        y0 equal 3.67120390696656

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.41226781764452
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.76710300011765
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      79   -2.9871562    16.904453    16.904453 
      80   -2.9871562    16.904453    16.872511 
Loop time of 3.84622e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 16.872511221466
variable naccept equal ${increment}
variable naccept equal 24

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.24829633830883
variable        y0 equal ${yi}
variable        y0 equal 2.8101769563804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.29875844119884
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.74278149577477
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      80   -2.9871562    16.872511    16.872511 
      81   -2.9871562    16.872511    17.102819 
Loop time of 4.13841e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.24829633830883
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.8101769563804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 0.0318403005599976
variable        y0 equal ${yi}
variable        y0 equal 7.51229137506747

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 0.0923409461975098
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.58626386251712
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      81   -2.9871562    16.872511    17.102819 
      82   -2.9871562    16.872511    16.973823 
Loop time of 8.17236e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 0.0318403005599976
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.51229137506747
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 7.94018488525249
variable        y0 equal ${yi}
variable        y0 equal 0.86350280832085

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 7.87863776086666
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.862640591371387
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      82   -2.9871562    16.872511    16.973823 
      83   -2.9871562    16.872511    17.057153 
Loop time of 3.96396e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 7.94018488525249
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.86350280832085
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 0.0318403005599976
variable        y0 equal ${yi}
variable        y0 equal 7.51229137506747

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 0.124125075340271
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.58163664665484
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      83   -2.9871562    16.872511    17.057153 
      84   -2.9871562    16.872511    17.036095 
Loop time of 4.02409e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 0.0318403005599976
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.51229137506747
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.48859311222811
variable        y0 equal ${yi}
variable        y0 equal 4.80827528590127

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.42620794653673
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.77909685725137
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      84   -2.9871562    16.872511    17.036095 
      85   -2.9871562    16.872511     16.88361 
Loop time of 4.00671e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.48859311222811
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.80827528590127
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0890479449292
variable        y0 equal ${yi}
variable        y0 equal 6.65942348972788

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.0458755616208
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.67569640413752
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      85   -2.9871562    16.872511     16.88361 
      86   -2.9871562    16.872511    16.883081 
Loop time of 3.94531e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.0890479449292
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.65942348972788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.0567768156419
variable        y0 equal ${yi}
variable        y0 equal 4.66208653801843

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.12409512399532
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.70917331332132
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      86   -2.9871562    16.872511    16.883081 
      87   -2.9871562    16.872511    16.910049 
Loop time of 3.93051e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.0567768156419
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.66208653801843
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.21161605198594
variable        y0 equal ${yi}
variable        y0 equal 5.67831456606585

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.2574496277115
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.7291398877402
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      87   -2.9871562    16.872511    16.910049 
      88   -2.9871562    16.872511    16.922373 
Loop time of 3.94712e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.21161605198594
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.67831456606585
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.55446753898526
variable        y0 equal ${yi}
variable        y0 equal 1.77595841071671

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.50025946298505
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.86405157229966
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      88   -2.9871562    16.872511    16.922373 
      89   -2.9871562    16.872511    16.866007 
Loop time of 3.84151e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 16.866006916779
variable naccept equal ${increment}
variable naccept equal 25

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.76286459444639
variable        y0 equal ${yi}
variable        y0 equal 7.58744383182787

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.84085479258177
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.6634385618236
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      89   -2.9871562    16.866007    16.866007 
      90   -2.9871562    16.866007    16.946301 
Loop time of 3.86223e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 99 x ${x0}
set atom 99 x 9.76286459444639
  1 settings made for x
set atom $i y ${y0}
set atom 99 y ${y0}
set atom 99 y 7.58744383182787
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.75894133050871
variable        y0 equal ${yi}
variable        y0 equal 6.50207719341746

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.77088858087492
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.48102166191569
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      90   -2.9871562    16.866007    16.946301 
      91   -2.9871562    16.866007    16.827696 
Loop time of 3.95996e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 16.8276957115369
variable naccept equal ${increment}
variable naccept equal 26

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.0960834002451
variable        y0 equal ${yi}
variable        y0 equal 7.29019924726748

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.15863830804387
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.24493656482958
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      91   -2.9871562    16.827696    16.827696 
      92   -2.9871562    16.827696    16.392682 
Loop time of 4.02625e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 16.3926818160721
variable naccept equal ${increment}
variable naccept equal 27

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.50025946298505
variable        y0 equal ${yi}
variable        y0 equal 1.86405157229966

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.57983246246244
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.89173857352799
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      92   -2.9871562    16.392682    16.392682 
      93   -2.9871562    16.392682    16.700722 
Loop time of 3.83558e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.50025946298505
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.86405157229966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.53368708609659
variable        y0 equal ${yi}
variable        y0 equal 7.39510370817446

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.47168833731729
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.2979036006
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      93   -2.9871562    16.392682    16.700722 
      94   -2.9871562    16.392682    16.283755 
Loop time of 3.9334e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 16.2837553395042
variable naccept equal ${increment}
variable naccept equal 28

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.7355564435177
variable        y0 equal ${yi}
variable        y0 equal 9.16062856424182

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.7591873725109
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.15828376520007
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      94   -2.9871562    16.283755    16.283755 
      95   -2.9871562    16.283755    16.314732 
Loop time of 3.85241e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.7355564435177
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.16062856424182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.73468725640765
variable        y0 equal ${yi}
variable        y0 equal 2.72136272164681

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.72918215949527
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.68203778239587
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      95   -2.9871562    16.283755    16.314732 
      96   -2.9871562    16.283755    16.290321 
Loop time of 3.89612e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.73468725640765
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.72136272164681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.786463814174
variable        y0 equal ${yi}
variable        y0 equal 4.50682874077723

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.71663890401012
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.41491176241801
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      96   -2.9871562    16.283755    16.290321 
      97   -2.9871562    16.283755    16.296372 
Loop time of 4.05864e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.786463814174
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.50682874077723
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3102847699186
variable        y0 equal ${yi}
variable        y0 equal 2.86695545884469

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.3684420589467
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.93156419965127
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      97   -2.9871562    16.283755    16.296372 
      98   -2.9871562    16.283755    16.361994 
Loop time of 4.56127e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3102847699186
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.86695545884469
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.71520588596297
variable        y0 equal ${yi}
variable        y0 equal 8.50687137760218

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.74401889045668
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.41668003715571
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      98   -2.9871562    16.283755    16.361994 
      99   -2.9871562    16.283755    16.271825 
Loop time of 3.87383e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 16.2718247119607
variable naccept equal ${increment}
variable naccept equal 29

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.04622503796264
variable        y0 equal ${yi}
variable        y0 equal 0.941362734544604

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 6.98617518225356
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 1.02865262817177
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
      99   -2.9871562    16.271825    16.271825 
     100   -2.9871562    16.271825    16.287108 
Loop time of 3.83852e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.04622503796264
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.941362734544604
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 0.0318403005599976
variable        y0 equal ${yi}
variable        y0 equal 7.51229137506747

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 0.0957026362419129
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.44550441828036
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     100   -2.9871562    16.271825    16.287108 
     101   -2.9871562    16.271825    16.321421 
Loop time of 3.9183e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 0.0318403005599976
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.51229137506747
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.73468725640765
variable        y0 equal ${yi}
variable        y0 equal 2.72136272164681

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.72003424127093
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.64792735549309
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     101   -2.9871562    16.271825    16.321421 
     102   -2.9871562    16.271825    16.396763 
Loop time of 3.91724e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.73468725640765
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.72136272164681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0890479449292
variable        y0 equal ${yi}
variable        y0 equal 6.65942348972788

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.0780423406621
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.58118958012095
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     102   -2.9871562    16.271825    16.396763 
     103   -2.9871562    16.271825    16.255505 
Loop time of 3.85359e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 16.2555049233435
variable naccept equal ${increment}
variable naccept equal 30

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.41226781764452
variable        y0 equal ${yi}
variable        y0 equal 3.76710300011765

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.37271776357118
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.74590400023591
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     103   -2.9871562    16.255505    16.255505 
     104   -2.9871562    16.255505    16.328055 
Loop time of 3.8766e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.41226781764452
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.76710300011765
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.39874633390676
variable        y0 equal ${yi}
variable        y0 equal 7.53006526556277

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.42605708677541
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.58444184389376
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     104   -2.9871562    16.255505    16.328055 
     105   -2.9871562    16.255505    16.512815 
Loop time of 3.86293e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.39874633390676
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.53006526556277
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.51660840033609
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.32006986465716
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     105   -2.9871562    16.255505    16.512815 
     106   -2.9871562    16.255505    16.293856 
Loop time of 4.00206e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47168833731729
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.2979036006
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.24829633830883
variable        y0 equal ${yi}
variable        y0 equal 2.8101769563804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.27666950820782
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.9071371791015
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     106   -2.9871562    16.255505    16.293856 
     107   -2.9871562    16.255505    16.304834 
Loop time of 3.95185e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.24829633830883
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.8101769563804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.28044283110649
variable        y0 equal ${yi}
variable        y0 equal 2.67400697442391

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.36997049767525
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.61653890582421
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     107   -2.9871562    16.255505    16.304834 
     108   -2.9871562    16.255505    16.278471 
Loop time of 4.01271e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.28044283110649
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.67400697442391
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 7.94018488525249
variable        y0 equal ${yi}
variable        y0 equal 0.86350280832085

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 7.97706047891475
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.828988929498523
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     108   -2.9871562    16.255505    16.278471 
     109   -2.9871562    16.255505    16.212321 
Loop time of 3.84347e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 16.2123206539601
variable naccept equal ${increment}
variable naccept equal 31

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.33779688516961
variable        y0 equal ${yi}
variable        y0 equal 7.44658609953188

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.2609589521061
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.3943307909038
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     109   -2.9871562    16.212321    16.212321 
     110   -2.9871562    16.212321     16.07381 
Loop time of 4.01011e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 16.0738102273825
variable naccept equal ${increment}
variable naccept equal 32

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.4529803554144
variable        y0 equal ${yi}
variable        y0 equal 5.58965725844103

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.43426498571302
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.52978426163393
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     110   -2.9871562     16.07381     16.07381 
     111   -2.9871562     16.07381    15.896394 
Loop time of 3.92885e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 15.8963936444092
variable naccept equal ${increment}
variable naccept equal 33

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 7.97706047891475
variable        y0 equal ${yi}
variable        y0 equal 0.828988929498523

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.04603356717922
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.731875463235706
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     111   -2.9871562    15.896394    15.896394 
     112   -2.9871562    15.896394    16.090382 
Loop time of 7.13856e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 7.97706047891475
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.828988929498523
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6657763560467
variable        y0 equal ${yi}
variable        y0 equal 5.54022269194323

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.6097548683338
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.60470659678179
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     112   -2.9871562    15.896394    16.090382 
     113   -2.9871562    15.896394     15.66944 
Loop time of 3.85655e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 15.6694395067611
variable naccept equal ${increment}
variable naccept equal 34

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.1922400359174
variable        y0 equal ${yi}
variable        y0 equal 0.954647608507007

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.1404105547925
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 1.00595151971611
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     113   -2.9871562     15.66944     15.66944 
     114   -2.9871562     15.66944    16.055916 
Loop time of 5.67073e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.1922400359174
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.954647608507007
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.59946205814314
variable        y0 equal ${yi}
variable        y0 equal 2.77839184972146

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.5196813722415
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.83453483554223
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     114   -2.9871562     15.66944    16.055916 
     115   -2.9871562     15.66944    15.718819 
Loop time of 3.92022e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.59946205814314
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.77839184972146
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.78632356444484
variable        y0 equal ${yi}
variable        y0 equal 2.7753891822944

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.69325080433971
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.81621988984445
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     115   -2.9871562     15.66944    15.718819 
     116   -2.9871562     15.66944    15.683252 
Loop time of 3.87186e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.78632356444484
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.7753891822944
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.24383619467125
variable        y0 equal ${yi}
variable        y0 equal 5.59898714964586

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.17996948400841
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.62720593159395
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     116   -2.9871562     15.66944    15.683252 
     117   -2.9871562     15.66944    15.646699 
Loop time of 3.97096e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 15.6466988281698
variable naccept equal ${increment}
variable naccept equal 35

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.76286459444639
variable        y0 equal ${yi}
variable        y0 equal 7.58744383182787

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.84189608572599
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.54082266416811
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     117   -2.9871562    15.646699    15.646699 
     118   -2.9871562    15.646699    15.687873 
Loop time of 3.76875e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 99 x ${x0}
set atom 99 x 9.76286459444639
  1 settings made for x
set atom $i y ${y0}
set atom 99 y ${y0}
set atom 99 y 7.58744383182787
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.77088858087492
variable        y0 equal ${yi}
variable        y0 equal 6.48102166191569

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.71569595535231
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.41266182199946
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     118   -2.9871562    15.646699    15.687873 
     119   -2.9871562    15.646699    15.538901 
Loop time of 3.89031e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 15.5389005354474
variable naccept equal ${increment}
variable naccept equal 36

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66628361820956
variable        y0 equal ${yi}
variable        y0 equal 8.33030129589137

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.7033906209447
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.24232579387721
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     119   -2.9871562    15.538901    15.538901 
     120   -2.9871562    15.538901    15.544826 
Loop time of 3.85247e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66628361820956
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.33030129589137
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.79328756490175
variable        y0 equal ${yi}
variable        y0 equal 5.75647065584856

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.74726612725679
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.69117066805559
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     120   -2.9871562    15.538901    15.544826 
     121   -2.9871562    15.538901    8.4055603 
Loop time of 3.81767e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 8.40556034100335
variable naccept equal ${increment}
variable naccept equal 37

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.37775198300096
variable        y0 equal ${yi}
variable        y0 equal 3.66390537781846

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.35682232458803
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.62072397036683
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     121   -2.9871562    8.4055603    8.4055603 
     122   -2.9871562    8.4055603    8.4170148 
Loop time of 3.72419e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.37775198300096
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.66390537781846
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.37775198300096
variable        y0 equal ${yi}
variable        y0 equal 3.66390537781846

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.34383112271043
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.64135434193742
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     122   -2.9871562    8.4055603    8.4170148 
     123   -2.9871562    8.4055603    8.3990809 
Loop time of 3.71136e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 8.39908089832426
variable naccept equal ${increment}
variable naccept equal 38

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.04622503796264
variable        y0 equal ${yi}
variable        y0 equal 0.941362734544604

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.02796765843078
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.90793559144768
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     123   -2.9871562    8.3990809    8.3990809 
     124   -2.9871562    8.3990809    8.3837091 
Loop time of 3.74239e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 8.38370914049354
variable naccept equal ${increment}
variable naccept equal 39

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.43426498571302
variable        y0 equal ${yi}
variable        y0 equal 5.52978426163393

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.51510008970167
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.62858374064165
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     124   -2.9871562    8.3837091    8.3837091 
     125   -2.9871562    8.3837091    9.0048116 
Loop time of 3.69671e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.43426498571302
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.52978426163393
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.387799485126401
variable        y0 equal ${yi}
variable        y0 equal 6.49517389074793

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.446721406379605
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.43200858370295
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     125   -2.9871562    8.3837091    9.0048116 
     126   -2.9871562    8.3837091    8.4310793 
Loop time of 3.72906e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.387799485126401
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.49517389074793
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.1922400359174
variable        y0 equal ${yi}
variable        y0 equal 0.954647608507007

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.2212535027524
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.858363576639026
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     126   -2.9871562    8.3837091    8.4310793 
     127   -2.9871562    8.3837091    8.2670631 
Loop time of 3.74932e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 8.26706311025827
variable naccept equal ${increment}
variable naccept equal 40

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.56271735269796
variable        y0 equal ${yi}
variable        y0 equal 9.27910173642963

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.61203926641714
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.23420247543186
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     127   -2.9871562    8.2670631    8.2670631 
     128   -2.9871562    8.2670631    8.2583161 
Loop time of 3.71573e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 8.25831611836094
variable naccept equal ${increment}
variable naccept equal 41

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.453071899810697
variable        y0 equal ${yi}
variable        y0 equal 4.55533845776483

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.52066447297659
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.47188202494547
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     128   -2.9871562    8.2583161    8.2583161 
     129   -2.9871562    8.2583161     8.423318 
Loop time of 3.67015e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.453071899810697
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.55533845776483
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0780423406621
variable        y0 equal ${yi}
variable        y0 equal 6.58118958012095

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 9.97952861824236
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.52966711060038
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     129   -2.9871562    8.2583161     8.423318 
     130   -2.9871562    8.2583161    8.2616915 
Loop time of 3.81648e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.0780423406621
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.58118958012095
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.59946205814314
variable        y0 equal ${yi}
variable        y0 equal 2.77839184972146

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.50252056320143
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.78571028682092
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     130   -2.9871562    8.2583161    8.2616915 
     131   -2.9871562    8.2583161    8.3122093 
Loop time of 3.80632e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.59946205814314
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.77839184972146
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6097548683338
variable        y0 equal ${yi}
variable        y0 equal 5.60470659678179

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.5458345254116
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.66557838862139
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     131   -2.9871562    8.2583161    8.3122093 
     132   -2.9871562    8.2583161    8.1567036 
Loop time of 6.5089e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 8.15670361650537
variable naccept equal ${increment}
variable naccept equal 42

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.92382499495631
variable        y0 equal ${yi}
variable        y0 equal 8.44281891502436

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.91693416157847
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.35231056131419
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     132   -2.9871562    8.1567036    8.1567036 
     133   -2.9871562    8.1567036    8.1417098 
Loop time of 3.73694e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 8.14170984170739
variable naccept equal ${increment}
variable naccept equal 43

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.15863830804387
variable        y0 equal ${yi}
variable        y0 equal 7.24493656482958

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.12569150685826
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.14559104767107
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     133   -2.9871562    8.1417098    8.1417098 
     134   -2.9871562    8.1417098    8.3624385 
Loop time of 4.00963e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.15863830804387
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.24493656482958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.46762627442094
variable        y0 equal ${yi}
variable        y0 equal 1.67842761657303

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.41993123371812
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.77035118720597
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     134   -2.9871562    8.1417098    8.3624385 
     135   -2.9871562    8.1417098    7.8501928 
Loop time of 3.78974e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 7.8501928209893
variable naccept equal ${increment}
variable naccept equal 44

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.48859311222811
variable        y0 equal ${yi}
variable        y0 equal 4.80827528590127

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.57225463270922
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.72659182900353
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     135   -2.9871562    7.8501928    7.8501928 
     136   -2.9871562    7.8501928    7.8442951 
Loop time of 3.80118e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 7.84429506898578
variable naccept equal ${increment}
variable naccept equal 45

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.41226781764452
variable        y0 equal ${yi}
variable        y0 equal 3.76710300011765

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.486701263575
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.75642528100144
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     136   -2.9871562    7.8442951    7.8442951 
     137   -2.9871562    7.8442951    7.7870928 
Loop time of 3.80171e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 7.78709279582762
variable naccept equal ${increment}
variable naccept equal 46

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.258966393462
variable        y0 equal ${yi}
variable        y0 equal 3.90735419554841

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.24204142808038
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.83410765690934
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     137   -2.9871562    7.7870928    7.7870928 
     138   -2.9871562    7.7870928    8.7236325 
Loop time of 3.80915e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.258966393462
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.90735419554841
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.3473493909792
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.060335910320282
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     138   -2.9871562    7.7870928    8.7236325 
     139   -2.9871562    7.7870928    7.8066226 
Loop time of 3.7727e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.61203926641714
variable        y0 equal ${yi}
variable        y0 equal 9.23420247543186

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.58451553423178
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.24099562871784
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     139   -2.9871562    7.7870928    7.8066226 
     140   -2.9871562    7.7870928    7.7828617 
Loop time of 3.82091e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 7.78286172812162
variable naccept equal ${increment}
variable naccept equal 47

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.99504664778052
variable        y0 equal ${yi}
variable        y0 equal 2.96102813454965

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 5.07093878626166
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.9192275759826
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     140   -2.9871562    7.7828617    7.7828617 
     141   -2.9871562    7.7828617    10.046155 
Loop time of 3.81755e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.99504664778052
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.96102813454965
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.02796765843078
variable        y0 equal ${yi}
variable        y0 equal 0.90793559144768

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.01706539669677
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.949684878099291
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     141   -2.9871562    7.7828617    10.046155 
     142   -2.9871562    7.7828617    7.7955909 
Loop time of 3.69122e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.02796765843078
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.90793559144768
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.36975130557138
variable        y0 equal ${yi}
variable        y0 equal 9.17877667653888

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.41153420924264
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.21764095533221
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     142   -2.9871562    7.7828617    7.7955909 
     143   -2.9871562    7.7828617    7.7285379 
Loop time of 3.76872e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 7.72853794141418
variable naccept equal ${increment}
variable naccept equal 48

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.57312639832278
variable        y0 equal ${yi}
variable        y0 equal 6.59234616295328

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.49552230715533
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.58209515348902
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     143   -2.9871562    7.7285379    7.7285379 
     144   -2.9871562    7.7285379    7.7315133 
Loop time of 3.62012e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.57312639832278
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.59234616295328
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 0.0318403005599976
variable        y0 equal ${yi}
variable        y0 equal 7.51229137506747

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 0.118505001068115
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.60446734752917
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     144   -2.9871562    7.7285379    7.7315133 
     145   -2.9871562    7.7285379    7.9160845 
Loop time of 5.53123e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 0.0318403005599976
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.51229137506747
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.504707296291257
variable        y0 equal ${yi}
variable        y0 equal 8.38087454952296

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.509855182567502
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.41719871677455
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     145   -2.9871562    7.7285379    7.9160845 
     146   -2.9871562    7.7285379    7.8069537 
Loop time of 3.81282e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.504707296291257
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.38087454952296
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.73131323059035
variable        y0 equal ${yi}
variable        y0 equal 4.67710171097681

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.66837710340453
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.76125768774912
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     146   -2.9871562    7.7285379    7.8069537 
     147   -2.9871562    7.7285379    7.8314561 
Loop time of 3.6067e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.73131323059035
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.67710171097681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.78446170567152
variable        y0 equal ${yi}
variable        y0 equal 1.70735105655259

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.71565893171904
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.70498170039719
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     147   -2.9871562    7.7285379    7.8314561 
     148   -2.9871562    7.7285379     7.729023 
Loop time of 3.64345e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.78446170567152
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.70735105655259
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.47945046503755
variable        y0 equal ${yi}
variable        y0 equal 9.25402225959628

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.49909994681093
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.18105973708957
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     148   -2.9871562    7.7285379     7.729023 
     149   -2.9871562    7.7285379    8.0733324 
Loop time of 3.63505e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.47945046503755
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.25402225959628
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 0.913902011710932
variable        y0 equal ${yi}
variable        y0 equal 5.64363808577257

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 0.873290208179285
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.71700168793398
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     149   -2.9871562    7.7285379    8.0733324 
     150   -2.9871562    7.7285379    7.7783509 
Loop time of 3.79404e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 0.913902011710932
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.64363808577257
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.85420002896777
variable        y0 equal ${yi}
variable        y0 equal 4.5685921942608

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.90480163056842
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.66367782706186
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     150   -2.9871562    7.7285379    7.7783509 
     151   -2.9871562    7.7285379    7.3544822 
Loop time of 3.6131e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 7.35448220103831
variable naccept equal ${increment}
variable naccept equal 49

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.92469287752448
variable        y0 equal ${yi}
variable        y0 equal 8.50776854671534

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.83571333526908
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.54441221870479
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     151   -2.9871562    7.3544822    7.3544822 
     152   -2.9871562    7.3544822    7.7414731 
Loop time of 3.63129e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.92469287752448
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.50776854671534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.15863830804387
variable        y0 equal ${yi}
variable        y0 equal 7.24493656482958

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.12079446076909
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.33827004757189
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     152   -2.9871562    7.3544822    7.7414731 
     153   -2.9871562    7.3544822    7.4015899 
Loop time of 3.68986e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.15863830804387
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.24493656482958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.90480163056842
variable        y0 equal ${yi}
variable        y0 equal 4.66367782706186

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.85894154269687
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.60140260809824
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     153   -2.9871562    7.3544822    7.4015899 
     154   -2.9871562    7.3544822    7.4797507 
Loop time of 3.65084e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.90480163056842
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.66367782706186
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.34383112271043
variable        y0 equal ${yi}
variable        y0 equal 3.64135434193742

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.36126806814882
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.57152068181169
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     154   -2.9871562    7.3544822    7.4797507 
     155   -2.9871562    7.3544822    7.4319432 
Loop time of 3.85779e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.34383112271043
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.64135434193742
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.15863830804387
variable        y0 equal ${yi}
variable        y0 equal 7.24493656482958

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.09933172225514
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.28128002014422
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     155   -2.9871562    7.3544822    7.4319432 
     156   -2.9871562    7.3544822    7.4747453 
Loop time of 3.70454e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.15863830804387
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.24493656482958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0780423406621
variable        y0 equal ${yi}
variable        y0 equal 6.58118958012095

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.1233392004033
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.49413067833415
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     156   -2.9871562    7.3544822    7.4747453 
     157   -2.9871562    7.3544822    7.3981722 
Loop time of 3.696e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.0780423406621
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.58118958012095
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.84759294946185
variable        y0 equal ${yi}
variable        y0 equal 6.37423569694987

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.75601147372714
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.30709492699137
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     157   -2.9871562    7.3544822    7.3981722 
     158   -2.9871562    7.3544822     8.187116 
Loop time of 3.68795e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.84759294946185
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.37423569694987
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 7.03299039879486
variable        y0 equal ${yi}
variable        y0 equal 6.46040994659891

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.01848869600936
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.44104715124598
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     158   -2.9871562    7.3544822     8.187116 
     159   -2.9871562    7.3544822    7.3655019 
Loop time of 3.63962e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 7.03299039879486
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.46040994659891
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.65813284118605
variable        y0 equal ${yi}
variable        y0 equal 1.00537619184288

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.73087401588393
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.09745431731972
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     159   -2.9871562    7.3544822    7.3655019 
     160   -2.9871562    7.3544822    7.3201238 
Loop time of 3.64319e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 7.32012384311321
variable naccept equal ${increment}
variable naccept equal 50

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 8.96753065306694
variable        y0 equal ${yi}
variable        y0 equal 6.3641386224412

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 8.91999948937447
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.39802815453043
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     160   -2.9871562    7.3201238    7.3201238 
     161   -2.9871562    7.3201238    7.9131817 
Loop time of 3.72531e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 8.96753065306694
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.3641386224412
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.01163879076348
variable        y0 equal ${yi}
variable        y0 equal 9.27794473874896

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 1.96838590542184
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 9.22352658021777
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     161   -2.9871562    7.3201238    7.9131817 
     162   -2.9871562    7.3201238    7.3328331 
Loop time of 3.68719e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.01163879076348
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 9.27794473874896
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 0.913902011710932
variable        y0 equal ${yi}
variable        y0 equal 5.64363808577257

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 0.904720714885523
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.71907544081407
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     162   -2.9871562    7.3201238    7.3328331 
     163   -2.9871562    7.3201238     7.354814 
Loop time of 3.71576e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 0.913902011710932
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.64363808577257
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2943734292051
variable        y0 equal ${yi}
variable        y0 equal 4.84162094944879

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.2795272830983
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.94040506237909
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     163   -2.9871562    7.3201238     7.354814 
     164   -2.9871562    7.3201238    7.9445502 
Loop time of 3.57912e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.2943734292051
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.84162094944879
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.74866355538149
variable        y0 equal ${yi}
variable        y0 equal 0.889158554780811

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.7506712782361
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.968768938291401
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     164   -2.9871562    7.3201238    7.9445502 
     165   -2.9871562    7.3201238    7.3060187 
Loop time of 3.65141e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 7.30601872412905
variable naccept equal ${increment}
variable naccept equal 51

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.39874633390676
variable        y0 equal ${yi}
variable        y0 equal 7.53006526556277

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.43260875780355
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.6294273408916
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     165   -2.9871562    7.3060187    7.3060187 
     166   -2.9871562    7.3060187     8.030288 
Loop time of 3.56204e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.39874633390676
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.53006526556277
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.40708486794987
variable        y0 equal ${yi}
variable        y0 equal 1.88286055705613

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.42530644893208
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.98161359212464
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     166   -2.9871562    7.3060187     8.030288 
     167   -2.9871562    7.3060187    7.4072162 
Loop time of 3.69018e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.40708486794987
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.88286055705613
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.01590631643639
variable        y0 equal ${yi}
variable        y0 equal 3.80516718192231

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 1.94775005022393
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.71553631587159
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     167   -2.9871562    7.3060187    7.4072162 
     168   -2.9871562    7.3060187    7.6456918 
Loop time of 3.71743e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.01590631643639
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.80516718192231
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.97526077309295
variable        y0 equal ${yi}
variable        y0 equal 8.23448504127559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.87894159832641
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.30428651489314
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     168   -2.9871562    7.3060187    7.6456918 
     169   -2.9871562    7.3060187    7.2583611 
Loop time of 3.67379e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 7.25836112641944
variable naccept equal ${increment}
variable naccept equal 52

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.08515262324364
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.39862699426707
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     169   -2.9871562    7.2583611    7.2583611 
     170   -2.9871562    7.2583611    7.2711192 
Loop time of 3.67454e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.03154995162041
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.4676475397497
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.91693416157847
variable        y0 equal ${yi}
variable        y0 equal 8.35231056131419

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.82670623580103
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.44830380596217
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     170   -2.9871562    7.2583611    7.2711192 
     171   -2.9871562    7.2583611    7.2565323 
Loop time of 3.56085e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 7.25653225856457
variable naccept equal ${increment}
variable naccept equal 53

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.82670623580103
variable        y0 equal ${yi}
variable        y0 equal 8.44830380596217

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.87757643977289
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.42466018117961
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     171   -2.9871562    7.2565323    7.2565323 
     172   -2.9871562    7.2565323     7.256143 
Loop time of 3.68171e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 7.25614300827088
variable naccept equal ${increment}
variable naccept equal 54

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.55075164873373
variable        y0 equal ${yi}
variable        y0 equal 5.74215760176378

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.61461596328985
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.76624200289446
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     172   -2.9871562     7.256143     7.256143 
     173   -2.9871562     7.256143    7.3839951 
Loop time of 5.21226e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.55075164873373
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.74215760176378
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.39874633390676
variable        y0 equal ${yi}
variable        y0 equal 7.53006526556277

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.31387896377813
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.43528987493777
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     173   -2.9871562     7.256143    7.3839951 
     174   -2.9871562     7.256143    7.3597356 
Loop time of 3.64847e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.39874633390676
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.53006526556277
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3102847699186
variable        y0 equal ${yi}
variable        y0 equal 2.86695545884469

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.3930022124311
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.91130896779397
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     174   -2.9871562     7.256143    7.3597356 
     175   -2.9871562     7.256143    7.3736962 
Loop time of 3.65617e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3102847699186
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.86695545884469
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.2212535027524
variable        y0 equal ${yi}
variable        y0 equal 0.858363576639026

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.2309244517346
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.818987913835376
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     175   -2.9871562     7.256143    7.3736962 
     176   -2.9871562     7.256143    7.2637091 
Loop time of 3.8141e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.2212535027524
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.858363576639026
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.36829842090169
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.125313067436218
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     176   -2.9871562     7.256143    7.2637091 
     177   -2.9871562     7.256143    7.3445636 
Loop time of 3.57014e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.19426209687749
variable        y0 equal ${yi}
variable        y0 equal 5.42006843035418

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.21963674783269
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.52001365368563
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     177   -2.9871562     7.256143    7.3445636 
     178   -2.9871562     7.256143    7.1637009 
Loop time of 3.59519e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 7.16370085651957
variable naccept equal ${increment}
variable naccept equal 55

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 0.913902011710932
variable        y0 equal ${yi}
variable        y0 equal 5.64363808577257

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 0.911874714690973
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.73342049067217
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     178   -2.9871562    7.1637009    7.1637009 
     179   -2.9871562    7.1637009    7.2058763 
Loop time of 3.60219e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 0.913902011710932
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.64363808577257
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.74401889045668
variable        y0 equal ${yi}
variable        y0 equal 8.41668003715571

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.6951999564929
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.34288747228678
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     179   -2.9871562    7.1637009    7.2058763 
     180   -2.9871562    7.1637009    7.1693269 
Loop time of 3.63002e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.74401889045668
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.41668003715571
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.40708486794987
variable        y0 equal ${yi}
variable        y0 equal 1.88286055705613

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.44910973071614
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.93145369670457
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     180   -2.9871562    7.1637009    7.1693269 
     181   -2.9871562    7.1637009    7.2133876 
Loop time of 3.67071e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.40708486794987
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.88286055705613
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2943734292051
variable        y0 equal ${yi}
variable        y0 equal 4.84162094944879

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.3732190374395
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.84815109127923
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     181   -2.9871562    7.1637009    7.2133876 
     182   -2.9871562    7.1637009    7.3204588 
Loop time of 3.64404e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.2943734292051
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.84162094944879
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.78446170567152
variable        y0 equal ${yi}
variable        y0 equal 1.70735105655259

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.8307700681555
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.7936737098462
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     182   -2.9871562    7.1637009    7.3204588 
     183   -2.9871562    7.1637009     7.141501 
Loop time of 3.67806e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 7.14150099318231
variable naccept equal ${increment}
variable naccept equal 56

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.73087401588393
variable        y0 equal ${yi}
variable        y0 equal 1.09745431731972

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.6868668933673
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.1922778684977
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     183   -2.9871562     7.141501     7.141501 
     184   -2.9871562     7.141501    7.2285575 
Loop time of 6.58761e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.73087401588393
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.09745431731972
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.15863830804387
variable        y0 equal ${yi}
variable        y0 equal 7.24493656482958

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.24042666911641
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.34214617338442
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     184   -2.9871562     7.141501    7.2285575 
     185   -2.9871562     7.141501    7.0519868 
Loop time of 3.88896e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 7.05198679265626
variable naccept equal ${increment}
variable naccept equal 57

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 6.95917002239868
variable        y0 equal ${yi}
variable        y0 equal 2.87266253205636

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.95876546183273
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.86802085610726
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     185   -2.9871562    7.0519868    7.0519868 
     186   -2.9871562    7.0519868     7.048796 
Loop time of 3.61095e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 7.04879599748071
variable naccept equal ${increment}
variable naccept equal 58

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.07268907784978
variable        y0 equal ${yi}
variable        y0 equal 3.57763503356111

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 2.97858257054845
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.60037004513871
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     186   -2.9871562     7.048796     7.048796 
     187   -2.9871562     7.048796    7.0885416 
Loop time of 3.6695e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.07268907784978
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.57763503356111
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.57312639832278
variable        y0 equal ${yi}
variable        y0 equal 6.59234616295328

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.65331982254763
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.51993823782434
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     187   -2.9871562     7.048796    7.0885416 
     188   -2.9871562     7.048796    7.0525093 
Loop time of 3.68964e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.57312639832278
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.59234616295328
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.78632356444484
variable        y0 equal ${yi}
variable        y0 equal 2.7753891822944

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.7045510939706
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.86561435433725
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     188   -2.9871562     7.048796    7.0525093 
     189   -2.9871562     7.048796    7.0692885 
Loop time of 3.57575e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.78632356444484
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.7753891822944
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.187410736083984
variable        y0 equal ${yi}
variable        y0 equal 1.7302321829564

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.124600601196289
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.65739337585038
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     189   -2.9871562     7.048796    7.0692885 
     190   -2.9871562     7.048796    6.6680282 
Loop time of 3.87188e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 6.66802822174846
variable naccept equal ${increment}
variable naccept equal 59

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.86308897375403
variable        y0 equal ${yi}
variable        y0 equal 4.54561560505792

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.77340234159766
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.63816415423319
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     190   -2.9871562    6.6680282    6.6680282 
     191   -2.9871562    6.6680282    6.6734143 
Loop time of 3.7078e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.86308897375403
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.54561560505792
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.61686462044497
variable        y0 equal ${yi}
variable        y0 equal 2.97424355717996

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.53658436417361
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.99112448665002
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     191   -2.9871562    6.6680282    6.6734143 
     192   -2.9871562    6.6680282    6.7122373 
Loop time of 3.70135e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.61686462044497
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.97424355717996
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66628361820956
variable        y0 equal ${yi}
variable        y0 equal 8.33030129589137

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.5761320936658
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.24801273263988
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     192   -2.9871562    6.6680282    6.7122373 
     193   -2.9871562    6.6680282     6.681179 
Loop time of 3.65918e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66628361820956
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.33030129589137
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.61686462044497
variable        y0 equal ${yi}
variable        y0 equal 2.97424355717996

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.52807780384798
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.96817766400674
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     193   -2.9871562    6.6680282     6.681179 
     194   -2.9871562    6.6680282    6.6790581 
Loop time of 3.56978e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.61686462044497
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.97424355717996
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0310238718986788
variable        y0 equal ${yi}
variable        y0 equal 3.80844516320359

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 0.115546405315427
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.86618027253281
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     194   -2.9871562    6.6680282    6.6790581 
     195   -2.9871562    6.6680282    7.2776826 
Loop time of 4.01785e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 0.0310238718986788
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.80844516320359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.86308897375403
variable        y0 equal ${yi}
variable        y0 equal 4.54561560505792

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.79388619303046
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.62871266955301
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     195   -2.9871562    6.6680282    7.2776826 
     196   -2.9871562    6.6680282     6.669067 
Loop time of 3.7336e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.86308897375403
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.54561560505792
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.17996948400841
variable        y0 equal ${yi}
variable        y0 equal 5.62720593159395

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.20969608465538
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.61323879902559
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     196   -2.9871562    6.6680282     6.669067 
     197   -2.9871562    6.6680282    6.6767215 
Loop time of 3.62197e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.17996948400841
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.62720593159395
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.35826578219148
variable        y0 equal ${yi}
variable        y0 equal 7.40391505089068

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.35375455696794
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.35097489681506
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     197   -2.9871562    6.6680282    6.6767215 
     198   -2.9871562    6.6680282    6.6957216 
Loop time of 3.81689e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.35826578219148
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.40391505089068
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0707942370435
variable        y0 equal ${yi}
variable        y0 equal 8.53329213775691

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 9.99463995733463
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.45593430913981
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     198   -2.9871562    6.6680282    6.6957216 
     199   -2.9871562    6.6680282    6.6741284 
Loop time of 3.56706e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.0707942370435
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.53329213775691
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0310238718986788
variable        y0 equal ${yi}
variable        y0 equal 3.80844516320359

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 0.0567112445831576
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.90723664326798
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     199   -2.9871562    6.6680282    6.6741284 
     200   -2.9871562    6.6680282    7.3653331 
Loop time of 3.62053e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 0.0310238718986788
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.80844516320359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 6.04620492417804
variable        y0 equal ${yi}
variable        y0 equal 8.33303295291957

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.14302020032398
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.3972859612852
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     200   -2.9871562    6.6680282    7.3653331 
     201   -2.9871562    6.6680282    7.7480228 
Loop time of 3.69658e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 6.04620492417804
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.33303295291957
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.73468725640765
variable        y0 equal ${yi}
variable        y0 equal 2.72136272164681

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.63799313266269
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.64326385232308
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     201   -2.9871562    6.6680282    7.7480228 
     202   -2.9871562    6.6680282    8.2998242 
Loop time of 3.60529e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.73468725640765
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.72136272164681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 6.95876546183273
variable        y0 equal ${yi}
variable        y0 equal 2.86802085610726

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 7.0264577416484
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.81073501082757
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     202   -2.9871562    6.6680282    8.2998242 
     203   -2.9871562    6.6680282    6.6604608 
Loop time of 3.6709e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 6.6604608017655
variable naccept equal ${increment}
variable naccept equal 60

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.597638221183683
variable        y0 equal ${yi}
variable        y0 equal 0.769967218149036

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.544814355770017
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.844716854799121
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     203   -2.9871562    6.6604608    6.6604608 
     204   -2.9871562    6.6604608    6.6758925 
Loop time of 3.6086e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.597638221183683
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.769967218149036
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.7506712782361
variable        y0 equal ${yi}
variable        y0 equal 0.968768938291401

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.78341420769472
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.90416123460564
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     204   -2.9871562    6.6604608    6.6758925 
     205   -2.9871562    6.6604608    6.6856927 
Loop time of 3.69325e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.7506712782361
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.968768938291401
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.41153420924264
variable        y0 equal ${yi}
variable        y0 equal 9.21764095533221

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.42846596955377
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.23166983831256
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     205   -2.9871562    6.6604608    6.6856927 
     206   -2.9871562    6.6604608    6.6486798 
Loop time of 3.6024e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 6.6486797835341
variable naccept equal ${increment}
variable naccept equal 61

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.87135564604884
variable        y0 equal ${yi}
variable        y0 equal 6.55566048161021

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.80327389756327
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.64091658131114
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     206   -2.9871562    6.6486798    6.6486798 
     207   -2.9871562    6.6486798    6.7046324 
Loop time of 3.45802e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.87135564604884
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.55566048161021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.2212535027524
variable        y0 equal ${yi}
variable        y0 equal 0.858363576639026

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.3005129698773
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.856256540525287
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     207   -2.9871562    6.6486798    6.7046324 
     208   -2.9871562    6.6486798    6.6386142 
Loop time of 3.54315e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 6.63861418438262
variable naccept equal ${increment}
variable naccept equal 62

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.02162012179547
variable        y0 equal ${yi}
variable        y0 equal 3.71439457697999

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.11135249455624
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.66228382153642
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     208   -2.9871562    6.6386142    6.6386142 
     209   -2.9871562    6.6386142    6.8054721 
Loop time of 3.64451e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.02162012179547
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.71439457697999
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.6955831456053
variable        y0 equal ${yi}
variable        y0 equal 0.0743083238601685

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.72768934248564
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.0749064683914185
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     209   -2.9871562    6.6386142    6.8054721 
     210   -2.9871562    6.6386142    6.6593946 
Loop time of 3.68958e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 79 x ${x0}
set atom 79 x 9.6955831456053
  1 settings made for x
set atom $i y ${y0}
set atom 79 y ${y0}
set atom 79 y 0.0743083238601685
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.786463814174
variable        y0 equal ${yi}
variable        y0 equal 4.50682874077723

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.77945200720913
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.49178115481303
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     210   -2.9871562    6.6386142    6.6593946 
     211   -2.9871562    6.6386142    6.6401136 
Loop time of 3.66037e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.786463814174
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.50682874077723
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 7.97706047891475
variable        y0 equal ${yi}
variable        y0 equal 0.828988929498523

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.04367139934398
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.847485883939594
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     211   -2.9871562    6.6386142    6.6401136 
     212   -2.9871562    6.6386142     6.634546 
Loop time of 3.83443e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 6.63454602893568
variable naccept equal ${increment}
variable naccept equal 63

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.8307700681555
variable        y0 equal ${yi}
variable        y0 equal 1.7936737098462

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.84223664282438
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.78513695380753
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     212   -2.9871562     6.634546     6.634546 
     213   -2.9871562     6.634546      6.63606 
Loop time of 3.58182e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.8307700681555
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.7936737098462
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.387799485126401
variable        y0 equal ${yi}
variable        y0 equal 6.49517389074793

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.400912399688626
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.41804554001322
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     213   -2.9871562     6.634546      6.63606 
     214   -2.9871562     6.634546    6.6849059 
Loop time of 3.60077e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.387799485126401
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.49517389074793
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.59946205814314
variable        y0 equal ${yi}
variable        y0 equal 2.77839184972146

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.6591813107295
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.73446601601937
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     214   -2.9871562     6.634546    6.6849059 
     215   -2.9871562     6.634546    6.6214514 
Loop time of 3.57966e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 6.62145144289711
variable naccept equal ${increment}
variable naccept equal 64

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.7355564435177
variable        y0 equal ${yi}
variable        y0 equal 9.16062856424182

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.7723232348614
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.18798244703143
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     215   -2.9871562    6.6214514    6.6214514 
     216   -2.9871562    6.6214514    6.6455213 
Loop time of 3.60457e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.7355564435177
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.16062856424182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.2609589521061
variable        y0 equal ${yi}
variable        y0 equal 7.3943307909038

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.33927447239266
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.4113006624248
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     216   -2.9871562    6.6214514    6.6455213 
     217   -2.9871562    6.6214514    6.6779277 
Loop time of 3.66922e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.2609589521061
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.3943307909038
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.02796765843078
variable        y0 equal ${yi}
variable        y0 equal 0.90793559144768

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 6.98518828430816
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.821967657316058
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     217   -2.9871562    6.6214514    6.6779277 
     218   -2.9871562    6.6214514    6.6547012 
Loop time of 3.63604e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.02796765843078
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.90793559144768
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.5458345254116
variable        y0 equal ${yi}
variable        y0 equal 5.66557838862139

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.5265262563877
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.69825360720354
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     218   -2.9871562    6.6214514    6.6547012 
     219   -2.9871562    6.6214514    6.5861783 
Loop time of 3.62816e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 6.58617825262653
variable naccept equal ${increment}
variable naccept equal 65

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.63595545449678
variable        y0 equal ${yi}
variable        y0 equal 0.131007170677185

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.64712472119753
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.191917955875397
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     219   -2.9871562    6.5861783    6.5861783 
     220   -2.9871562    6.5861783    6.6700945 
Loop time of 3.60653e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.63595545449678
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.131007170677185
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.61686462044497
variable        y0 equal ${yi}
variable        y0 equal 2.97424355717996

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.58319873690386
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 3.00164419385293
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     220   -2.9871562    6.5861783    6.6700945 
     221   -2.9871562    6.5861783    6.6335001 
Loop time of 3.68682e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.61686462044497
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.97424355717996
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.99504664778052
variable        y0 equal ${yi}
variable        y0 equal 2.96102813454965

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 5.02687689899741
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.98162742825845
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     221   -2.9871562    6.5861783    6.6335001 
     222   -2.9871562    6.5861783    6.9582969 
Loop time of 3.63857e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.99504664778052
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.96102813454965
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.43426498571302
variable        y0 equal ${yi}
variable        y0 equal 5.52978426163393

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.40260913768674
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.5414461011191
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     222   -2.9871562    6.5861783    6.9582969 
     223   -2.9871562    6.5861783    6.5620133 
Loop time of 3.78561e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 6.56201327716183
variable naccept equal ${increment}
variable naccept equal 66

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.02162012179547
variable        y0 equal ${yi}
variable        y0 equal 3.71439457697999

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 0.936312535602385
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.77554972930085
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     223   -2.9871562    6.5620133    6.5620133 
     224   -2.9871562    6.5620133    6.6233364 
Loop time of 3.77101e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.02162012179547
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.71439457697999
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 0.95938600619488
variable        y0 equal ${yi}
variable        y0 equal 1.89217485568589

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 0.999787238437464
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.90842210433549
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     224   -2.9871562    6.5620133    6.6233364 
     225   -2.9871562    6.5620133     6.486816 
Loop time of 3.63166e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 6.48681604491202
variable naccept equal ${increment}
variable naccept equal 67

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.0567768156419
variable        y0 equal ${yi}
variable        y0 equal 4.66208653801843

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.11699649690487
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.57969993704721
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     225   -2.9871562     6.486816     6.486816 
     226   -2.9871562     6.486816    6.5865872 
Loop time of 3.55696e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.0567768156419
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.66208653801843
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.74401889045668
variable        y0 equal ${yi}
variable        y0 equal 8.41668003715571

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.81188709934187
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.47334568418559
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     226   -2.9871562     6.486816    6.5865872 
     227   -2.9871562     6.486816    6.5035087 
Loop time of 3.6252e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.74401889045668
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.41668003715571
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.258966393462
variable        y0 equal ${yi}
variable        y0 equal 3.90735419554841

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.2384138297947
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.81685382886064
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     227   -2.9871562     6.486816    6.5035087 
     228   -2.9871562     6.486816     8.062119 
Loop time of 3.6058e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.258966393462
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.90735419554841
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3102847699186
variable        y0 equal ${yi}
variable        y0 equal 2.86695545884469

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.3785588625929
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.9474643942962
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     228   -2.9871562     6.486816     8.062119 
     229   -2.9871562     6.486816    6.5928122 
Loop time of 3.60566e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3102847699186
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.86695545884469
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.02162012179547
variable        y0 equal ${yi}
variable        y0 equal 3.71439457697999

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.01899102051907
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.68833498520982
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     229   -2.9871562     6.486816    6.5928122 
     230   -2.9871562     6.486816    6.5147386 
Loop time of 3.7327e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.02162012179547
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.71439457697999
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.90480163056842
variable        y0 equal ${yi}
variable        y0 equal 4.66367782706186

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.9595272060155
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.60335029715463
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     230   -2.9871562     6.486816    6.5147386 
     231   -2.9871562     6.486816    7.1669352 
Loop time of 3.64916e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.90480163056842
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.66367782706186
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.29837952613393
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.0149887204170227
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     231   -2.9871562     6.486816    7.1669352 
     232   -2.9871562     6.486816    6.4875623 
Loop time of 3.67881e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.24656169175664
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.0319480299949646
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     232   -2.9871562     6.486816    6.4875623 
     233   -2.9871562     6.486816    6.4924967 
Loop time of 3.56131e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.01163879076348
variable        y0 equal ${yi}
variable        y0 equal 9.27794473874896

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.07129489818917
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 9.37050568569034
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     233   -2.9871562     6.486816    6.4924967 
     234   -2.9871562     6.486816    6.4961925 
Loop time of 3.70635e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.01163879076348
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 9.27794473874896
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.47998924969751
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.280201307204
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     234   -2.9871562     6.486816    6.4961925 
     235   -2.9871562     6.486816    6.4903398 
Loop time of 3.52079e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47168833731729
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.2979036006
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.8169515065301
variable        y0 equal ${yi}
variable        y0 equal 0.890143771875232

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.77280388394481
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.846566982972949
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     235   -2.9871562     6.486816    6.4903398 
     236   -2.9871562     6.486816    6.5061667 
Loop time of 3.61592e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.8169515065301
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.890143771875232
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.453071899810697
variable        y0 equal ${yi}
variable        y0 equal 4.55533845776483

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.538029141822721
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.46241877430841
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     236   -2.9871562     6.486816    6.5061667 
     237   -2.9871562     6.486816    6.6573215 
Loop time of 3.7443e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.453071899810697
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.55533845776483
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.09634747464649
variable        y0 equal ${yi}
variable        y0 equal 0.869295545327991

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 6.03698996264926
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.772125514257281
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     237   -2.9871562     6.486816    6.6573215 
     238   -2.9871562     6.486816    6.5567984 
Loop time of 4.28241e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 6.09634747464649
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.869295545327991
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.453071899810697
variable        y0 equal ${yi}
variable        y0 equal 4.55533845776483

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.520989449420835
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.56744662875101
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     238   -2.9871562     6.486816    6.5567984 
     239   -2.9871562     6.486816    6.3824047 
Loop time of 4.32104e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 6.38240471396969
variable naccept equal ${increment}
variable naccept equal 68

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57225463270922
variable        y0 equal ${yi}
variable        y0 equal 4.72659182900353

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.52624918102999
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.66169138306542
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     239   -2.9871562    6.3824047    6.3824047 
     240   -2.9871562    6.3824047    6.3983946 
Loop time of 3.67181e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.57225463270922
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.72659182900353
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.03567137438805
variable        y0 equal ${yi}
variable        y0 equal 4.69114826077386

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.07762095648796
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.66829084509775
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     240   -2.9871562    6.3824047    6.3983946 
     241   -2.9871562    6.3824047     6.369212 
Loop time of 3.5305e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 6.36921199224972
variable naccept equal ${increment}
variable naccept equal 69

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.04367139934398
variable        y0 equal ${yi}
variable        y0 equal 0.847485883939594

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.11814016698695
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.78858882974419
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     241   -2.9871562     6.369212     6.369212 
     242   -2.9871562     6.369212    6.5800657 
Loop time of 3.5557e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.04367139934398
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.847485883939594
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 0.899675980407526
variable        y0 equal ${yi}
variable        y0 equal 9.19352722871631

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 0.831773081619074
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.23994597900241
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     242   -2.9871562     6.369212    6.5800657 
     243   -2.9871562     6.369212    6.5826005 
Loop time of 3.52446e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 0.899675980407526
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.19352722871631
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.57711223203909
variable        y0 equal ${yi}
variable        y0 equal 1.7166861691243

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.60717563469183
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.68322656533783
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     243   -2.9871562     6.369212    6.5826005 
     244   -2.9871562     6.369212    6.4143318 
Loop time of 3.56304e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.57711223203909
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.7166861691243
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.8169515065301
variable        y0 equal ${yi}
variable        y0 equal 0.890143771875232

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.88350899735575
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.828963371026843
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     244   -2.9871562     6.369212    6.4143318 
     245   -2.9871562     6.369212    6.3736809 
Loop time of 3.56481e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.8169515065301
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.890143771875232
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.2609589521061
variable        y0 equal ${yi}
variable        y0 equal 7.3943307909038

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.20564439932213
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.38570181455874
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     245   -2.9871562     6.369212    6.3736809 
     246   -2.9871562     6.369212    6.3616336 
Loop time of 3.55033e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 6.36163359674539
variable naccept equal ${increment}
variable naccept equal 70

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 0.0318403005599976
variable        y0 equal ${yi}
variable        y0 equal 7.51229137506747

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x -0.0305243015289306
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.47761501398349
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     246   -2.9871562    6.3616336    6.3616336 
     247   -2.9871562    6.3616336    6.3544668 
Loop time of 3.48755e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 6.35446675371252
variable naccept equal ${increment}
variable naccept equal 71

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.50309296686422
variable        y0 equal ${yi}
variable        y0 equal 3.6237421588434

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.47882331449758
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.65898613495958
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     247   -2.9871562    6.3544668    6.3544668 
     248   -2.9871562    6.3544668     6.337012 
Loop time of 3.53655e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 6.33701196122703
variable naccept equal ${increment}
variable naccept equal 72

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.74726612725679
variable        y0 equal ${yi}
variable        y0 equal 5.69117066805559

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.74355002799455
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.5961909527083
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     248   -2.9871562     6.337012     6.337012 
     249   -2.9871562     6.337012    4.4571088 
Loop time of 3.45825e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 4.45710882269401
variable naccept equal ${increment}
variable naccept equal 73

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.520989449420835
variable        y0 equal ${yi}
variable        y0 equal 4.56744662875101

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.599939902225401
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.47262595051691
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     249   -2.9871562    4.4571088    4.4571088 
     250   -2.9871562    4.4571088    4.6306072 
Loop time of 6.6276e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.520989449420835
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.56744662875101
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.49776528278257
variable        y0 equal ${yi}
variable        y0 equal 7.4722852620151

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.48297205367948
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.50014316168093
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     250   -2.9871562    4.4571088    4.6306072 
     251   -2.9871562    4.4571088    4.4554665 
Loop time of 3.77289e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 4.45546645809797
variable naccept equal ${increment}
variable naccept equal 74

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.516645927825834
variable        y0 equal ${yi}
variable        y0 equal 2.91738013001779

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.418996103206541
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.88881869288782
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     251   -2.9871562    4.4554665    4.4554665 
     252   -2.9871562    4.4554665    4.5736094 
Loop time of 3.60839e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.516645927825834
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.91738013001779
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.61223844765303
variable        y0 equal ${yi}
variable        y0 equal 5.51154048388201

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.57899256228086
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.47361386959749
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     252   -2.9871562    4.4554665    4.5736094 
     253   -2.9871562    4.4554665     4.533459 
Loop time of 3.65584e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.61223844765303
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.51154048388201
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.40708486794987
variable        y0 equal ${yi}
variable        y0 equal 1.88286055705613

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.37191096305409
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.92667624137467
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     253   -2.9871562    4.4554665     4.533459 
     254   -2.9871562    4.4554665    4.4620963 
Loop time of 3.59173e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.40708486794987
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.88286055705613
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.09634747464649
variable        y0 equal ${yi}
variable        y0 equal 0.869295545327991

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 6.04212040860645
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.854861756074756
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     254   -2.9871562    4.4554665    4.4620963 
     255   -2.9871562    4.4554665    4.4388367 
Loop time of 3.58834e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 4.43883668667885
variable naccept equal ${increment}
variable naccept equal 75

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.02162012179547
variable        y0 equal ${yi}
variable        y0 equal 3.71439457697999

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 0.990600875217253
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.69930454058778
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     255   -2.9871562    4.4388367    4.4388367 
     256   -2.9871562    4.4388367    4.4644747 
Loop time of 3.93476e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.02162012179547
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.71439457697999
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.516645927825834
variable        y0 equal ${yi}
variable        y0 equal 2.91738013001779

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.520060713687803
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.88988070460657
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     256   -2.9871562    4.4388367    4.4644747 
     257   -2.9871562    4.4388367    4.4220373 
Loop time of 3.54376e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 4.42203729921644
variable naccept equal ${increment}
variable naccept equal 76

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0780423406621
variable        y0 equal ${yi}
variable        y0 equal 6.58118958012095

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.1608709100743
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.50570164457789
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     257   -2.9871562    4.4220373    4.4220373 
     258   -2.9871562    4.4220373    4.5224347 
Loop time of 3.58001e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.0780423406621
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.58118958012095
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.50025946298505
variable        y0 equal ${yi}
variable        y0 equal 1.86405157229966

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.52333792844678
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.84317548654145
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     258   -2.9871562    4.4220373    4.5224347 
     259   -2.9871562    4.4220373    4.4297954 
Loop time of 3.5399e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.50025946298505
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.86405157229966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.40689885138589
variable        y0 equal ${yi}
variable        y0 equal 1.95026988170212

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.40143559693414
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.92893741509979
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     259   -2.9871562    4.4220373    4.4297954 
     260   -2.9871562    4.4220373     4.427685 
Loop time of 3.87091e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.40689885138589
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.95026988170212
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3102847699186
variable        y0 equal ${yi}
variable        y0 equal 2.86695545884469

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.4019582394621
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.94095604392388
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     260   -2.9871562    4.4220373     4.427685 
     261   -2.9871562    4.4220373     4.569276 
Loop time of 3.55061e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3102847699186
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.86695545884469
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.24829633830883
variable        y0 equal ${yi}
variable        y0 equal 2.8101769563804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.28262956737377
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.78437615605691
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     261   -2.9871562    4.4220373     4.569276 
     262   -2.9871562    4.4220373    4.4888015 
Loop time of 3.63494e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.24829633830883
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.8101769563804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.44072332778836
variable        y0 equal ${yi}
variable        y0 equal 0.0966708421707153

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.43133534589673
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 0.102701723575592
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     262   -2.9871562    4.4220373    4.4888015 
     263   -2.9871562    4.4220373    4.4241497 
Loop time of 3.55856e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.44072332778836
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 0.0966708421707153
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 0.913902011710932
variable        y0 equal ${yi}
variable        y0 equal 5.64363808577257

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 0.995350006419947
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.68232610171037
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     263   -2.9871562    4.4220373    4.4241497 
     264   -2.9871562    4.4220373    4.4208924 
Loop time of 3.47554e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 4.42089235355084
variable naccept equal ${increment}
variable naccept equal 77

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.56502480903531
variable        y0 equal ${yi}
variable        y0 equal 3.6810828046335

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.62260251441861
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.65342050356996
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     264   -2.9871562    4.4208924    4.4208924 
     265   -2.9871562    4.4208924    6.2919263 
Loop time of 3.55605e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.56502480903531
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.6810828046335
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.07762095648796
variable        y0 equal ${yi}
variable        y0 equal 4.66829084509775

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.02187279183418
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.70316787117884
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     265   -2.9871562    4.4208924    6.2919263 
     266   -2.9871562    4.4208924    4.4635271 
Loop time of 3.54376e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.07762095648796
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.66829084509775
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.99135452150641
variable        y0 equal ${yi}
variable        y0 equal 6.32309140697947

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.96026352285682
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.34972419277659
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     266   -2.9871562    4.4208924    4.4635271 
     267   -2.9871562    4.4208924    4.3032193 
Loop time of 3.65969e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 4.30321931779311
variable naccept equal ${increment}
variable naccept equal 78

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.486701263575
variable        y0 equal ${yi}
variable        y0 equal 3.75642528100144

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.4280906335396
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.72375140948426
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     267   -2.9871562    4.3032193    4.3032193 
     268   -2.9871562    4.3032193    4.3493501 
Loop time of 3.55618e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.486701263575
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.75642528100144
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.40708486794987
variable        y0 equal ${yi}
variable        y0 equal 1.88286055705613

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.36321673154392
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.8523390569455
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     268   -2.9871562    4.3032193    4.3493501 
     269   -2.9871562    4.3032193    4.2958877 
Loop time of 3.64014e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 4.29588771890341
variable naccept equal ${increment}
variable naccept equal 79

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.22238356828252
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.0399542450904846
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     269   -2.9871562    4.2958877    4.2958877 
     270   -2.9871562    4.2958877    4.3067148 
Loop time of 3.48445e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.47882331449758
variable        y0 equal ${yi}
variable        y0 equal 3.65898613495958

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.5581141455866
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.73628432316911
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     270   -2.9871562    4.2958877    4.3067148 
     271   -2.9871562    4.2958877     4.314214 
Loop time of 3.67025e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.47882331449758
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.65898613495958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.61223844765303
variable        y0 equal ${yi}
variable        y0 equal 5.51154048388201

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.67251619576094
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.59485992138582
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     271   -2.9871562    4.2958877     4.314214 
     272   -2.9871562    4.2958877    4.3134477 
Loop time of 3.61837e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.61223844765303
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.51154048388201
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.87757643977289
variable        y0 equal ${yi}
variable        y0 equal 8.42466018117961

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.8645561746705
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.49525530256328
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     272   -2.9871562    4.2958877    4.3134477 
     273   -2.9871562    4.2958877    4.3148739 
Loop time of 3.64171e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.87757643977289
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.42466018117961
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3005129698773
variable        y0 equal ${yi}
variable        y0 equal 0.856256540525287

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.3956647876759
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.829727812517017
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     273   -2.9871562    4.2958877    4.3148739 
     274   -2.9871562    4.2958877     4.329557 
Loop time of 3.51031e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.3005129698773
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.856256540525287
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.00069663245232
variable        y0 equal ${yi}
variable        y0 equal 1.03627063821587

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 8.96913329083473
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.08126383613381
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     274   -2.9871562    4.2958877     4.329557 
     275   -2.9871562    4.2958877    4.3076861 
Loop time of 3.61051e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.00069663245232
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.03627063821587
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.74401889045668
variable        y0 equal ${yi}
variable        y0 equal 8.41668003715571

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.79458178480101
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.47612835086878
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     275   -2.9871562    4.2958877    4.3076861 
     276   -2.9871562    4.2958877    4.3102059 
Loop time of 3.55329e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.74401889045668
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.41668003715571
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.48185687222902
variable        y0 equal ${yi}
variable        y0 equal 1.94388798854416

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.46213057198946
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.92046221873826
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     276   -2.9871562    4.2958877    4.3102059 
     277   -2.9871562    4.2958877    4.2980816 
Loop time of 3.58696e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.48185687222902
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.94388798854416
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.73468725640765
variable        y0 equal ${yi}
variable        y0 equal 2.72136272164681

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.71682330329409
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.66394276591637
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     277   -2.9871562    4.2958877    4.2980816 
     278   -2.9871562    4.2958877    4.4317851 
Loop time of 3.69386e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.73468725640765
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.72136272164681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.84225670376464
variable        y0 equal ${yi}
variable        y0 equal 4.77940864914819

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.8914976266925
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.82204459065363
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     278   -2.9871562    4.2958877    4.4317851 
     279   -2.9871562    4.2958877    4.2712874 
Loop time of 3.63647e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 4.27128735898519
variable naccept equal ${increment}
variable naccept equal 80

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.57312639832278
variable        y0 equal ${yi}
variable        y0 equal 6.59234616295328

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.58319088101168
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.65162711874475
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     279   -2.9871562    4.2712874    4.2712874 
     280   -2.9871562    4.2712874    4.2934052 
Loop time of 3.54006e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.57312639832278
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.59234616295328
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.07762095648796
variable        y0 equal ${yi}
variable        y0 equal 4.66829084509775

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.09006510693581
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.59300016516611
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     280   -2.9871562    4.2712874    4.2934052 
     281   -2.9871562    4.2712874    4.2531189 
Loop time of 3.61077e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 4.25311885372401
variable naccept equal ${increment}
variable naccept equal 81

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.486701263575
variable        y0 equal ${yi}
variable        y0 equal 3.75642528100144

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.58045839229051
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.7060720638765
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     281   -2.9871562    4.2531189    4.2531189 
     282   -2.9871562    4.2531189    4.2432926 
Loop time of 3.57695e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 4.24329257474789
variable naccept equal ${increment}
variable naccept equal 82

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.0264577416484
variable        y0 equal ${yi}
variable        y0 equal 2.81073501082757

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.98790284672424
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.75419310304025
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     282   -2.9871562    4.2432926    4.2432926 
     283   -2.9871562    4.2432926    4.2344709 
Loop time of 3.71663e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 4.23447089804522
variable naccept equal ${increment}
variable naccept equal 83

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.504707296291257
variable        y0 equal ${yi}
variable        y0 equal 8.38087454952296

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.459625037113095
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.35511863149699
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     283   -2.9871562    4.2344709    4.2344709 
     284   -2.9871562    4.2344709    4.2023488 
Loop time of 3.51956e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 4.2023487815605
variable naccept equal ${increment}
variable naccept equal 84

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40260913768674
variable        y0 equal ${yi}
variable        y0 equal 5.5414461011191

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.48664848009015
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.46562200730044
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     284   -2.9871562    4.2023488    4.2023488 
     285   -2.9871562    4.2023488    4.4442875 
Loop time of 3.60427e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.40260913768674
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.5414461011191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.387799485126401
variable        y0 equal ${yi}
variable        y0 equal 6.49517389074793

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.315071363845731
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.48296888605585
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     285   -2.9871562    4.2023488    4.4442875 
     286   -2.9871562    4.2023488    4.2330659 
Loop time of 3.63589e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.387799485126401
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.49517389074793
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.92469287752448
variable        y0 equal ${yi}
variable        y0 equal 8.50776854671534

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.85953580974875
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.40862084545191
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     286   -2.9871562    4.2023488    4.2330659 
     287   -2.9871562    4.2023488    4.1239078 
Loop time of 3.60801e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 4.12390778985987
variable naccept equal ${increment}
variable naccept equal 85

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.42846596955377
variable        y0 equal ${yi}
variable        y0 equal 9.23166983831256

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.36582681655008
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.27031280505985
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     287   -2.9871562    4.1239078    4.1239078 
     288   -2.9871562    4.1239078    4.1695246 
Loop time of 3.45709e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.42846596955377
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.23166983831256
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.04212040860645
variable        y0 equal ${yi}
variable        y0 equal 0.854861756074756

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 6.07943215329639
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.779754515397876
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     288   -2.9871562    4.1239078    4.1695246 
     289   -2.9871562    4.1239078     4.199769 
Loop time of 3.5635e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 6.04212040860645
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.854861756074756
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.96026352285682
variable        y0 equal ${yi}
variable        y0 equal 6.34972419277659

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.99421976446449
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.43438820377818
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     289   -2.9871562    4.1239078     4.199769 
     290   -2.9871562    4.1239078      4.14914 
Loop time of 3.52852e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.96026352285682
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.34972419277659
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.02162012179547
variable        y0 equal ${yi}
variable        y0 equal 3.71439457697999

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.0708308132475
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.66879633231294
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     290   -2.9871562    4.1239078      4.14914 
     291   -2.9871562    4.1239078    4.1997095 
Loop time of 3.56686e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.02162012179547
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.71439457697999
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.06897214053966
variable        y0 equal ${yi}
variable        y0 equal 8.19967323459681

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.0497484505067
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.15603469528254
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     291   -2.9871562    4.1239078    4.1997095 
     292   -2.9871562    4.1239078    4.2209803 
Loop time of 3.55483e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.06897214053966
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.19967323459681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7151750167065
variable        y0 equal ${yi}
variable        y0 equal 7.47761501398349

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.759210189169
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.53634610500598
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     292   -2.9871562    4.1239078    4.2209803 
     293   -2.9871562    4.1239078    4.1493465 
Loop time of 3.65169e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7151750167065
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.47761501398349
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.39874633390676
variable        y0 equal ${yi}
variable        y0 equal 7.53006526556277

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.42271354038488
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.45066014852786
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     293   -2.9871562    4.1239078    4.1493465 
     294   -2.9871562    4.1239078    4.0675557 
Loop time of 3.5974e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 4.06755566059537
variable naccept equal ${increment}
variable naccept equal 86

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.3073891115101
variable        y0 equal ${yi}
variable        y0 equal 5.46609456484514

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.35130489586908
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.43497152273851
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     294   -2.9871562    4.0675557    4.0675557 
     295   -2.9871562    4.0675557    4.2286693 
Loop time of 3.58363e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.3073891115101
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.46609456484514
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.92978396057426
variable        y0 equal ${yi}
variable        y0 equal 1.00790997337136

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.99879463552772
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 1.06120080541405
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     295   -2.9871562    4.0675557    4.2286693 
     296   -2.9871562    4.0675557    4.0987007 
Loop time of 3.67413e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.92978396057426
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 1.00790997337136
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.6272473827881
variable        y0 equal ${yi}
variable        y0 equal 7.54194511499667

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.71272399583284
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.50542391863131
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     296   -2.9871562    4.0675557    4.0987007 
     297   -2.9871562    4.0675557     3.952514 
Loop time of 3.50379e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 3.95251400703764
variable naccept equal ${increment}
variable naccept equal 87

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.61686462044497
variable        y0 equal ${yi}
variable        y0 equal 2.97424355717996

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.64981808542986
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 3.06511266204217
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     297   -2.9871562     3.952514     3.952514 
     298   -2.9871562     3.952514     4.228819 
Loop time of 3.48769e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.61686462044497
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.97424355717996
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.74401889045668
variable        y0 equal ${yi}
variable        y0 equal 8.41668003715571

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.69060533245039
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.34579481996592
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     298   -2.9871562     3.952514     4.228819 
     299   -2.9871562     3.952514    3.9568349 
Loop time of 3.55835e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.74401889045668
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.41668003715571
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.55075164873373
variable        y0 equal ${yi}
variable        y0 equal 5.74215760176378

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.45661249000799
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.82575739567476
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     299   -2.9871562     3.952514    3.9568349 
     300   -2.9871562     3.952514    4.6651088 
Loop time of 3.51859e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.55075164873373
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.74215760176378
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.09006510693581
variable        y0 equal ${yi}
variable        y0 equal 4.59300016516611

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.15524310786278
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.68067452067301
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     300   -2.9871562     3.952514    4.6651088 
     301   -2.9871562     3.952514    3.9770899 
Loop time of 3.49648e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.09006510693581
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.59300016516611
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.01590631643639
variable        y0 equal ${yi}
variable        y0 equal 3.80516718192231

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.07967942396508
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.7242755250467
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     301   -2.9871562     3.952514    3.9770899 
     302   -2.9871562     3.952514    4.0009734 
Loop time of 3.54879e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.01590631643639
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.80516718192231
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.3073891115101
variable        y0 equal ${yi}
variable        y0 equal 5.46609456484514

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.34711069583017
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.40019200985628
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     302   -2.9871562     3.952514    4.0009734 
     303   -2.9871562     3.952514      4.34026 
Loop time of 3.66214e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.3073891115101
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.46609456484514
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.8307700681555
variable        y0 equal ${yi}
variable        y0 equal 1.7936737098462

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.88406697987196
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.76876639506883
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     303   -2.9871562     3.952514      4.34026 
     304   -2.9871562     3.952514    3.9663902 
Loop time of 3.62134e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.8307700681555
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.7936737098462
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.85953580974875
variable        y0 equal ${yi}
variable        y0 equal 8.40862084545191

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.92899314998923
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.48198492445048
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     304   -2.9871562     3.952514    3.9663902 
     305   -2.9871562     3.952514    3.9813565 
Loop time of 3.63387e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.85953580974875
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.40862084545191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.85119799851057
variable        y0 equal ${yi}
variable        y0 equal 3.81704555316102

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.93524605511305
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.72625889344346
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     305   -2.9871562     3.952514    3.9813565 
     306   -2.9871562     3.952514    4.1425784 
Loop time of 3.6166e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.85119799851057
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.81704555316102
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.87757643977289
variable        y0 equal ${yi}
variable        y0 equal 8.42466018117961

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.85629137078409
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.45065544761714
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     306   -2.9871562     3.952514    4.1425784 
     307   -2.9871562     3.952514    3.9502015 
Loop time of 3.61749e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 3.95020147301421
variable naccept equal ${increment}
variable naccept equal 88

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.21418936847545
variable        y0 equal ${yi}
variable        y0 equal 6.3494564248704

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.17055683730937
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.38234023586741
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     307   -2.9871562    3.9502015    3.9502015 
     308   -2.9871562    3.9502015    3.4029481 
Loop time of 3.62846e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 3.4029480674088
variable naccept equal ${increment}
variable naccept equal 89

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.01590631643639
variable        y0 equal ${yi}
variable        y0 equal 3.80516718192231

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 1.99785717169152
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.87768581671845
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     308   -2.9871562    3.4029481    3.4029481 
     309   -2.9871562    3.4029481    3.3952267 
Loop time of 3.49224e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 3.39522674094847
variable naccept equal ${increment}
variable naccept equal 90

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.35312636851827
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.0183089137077331
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     309   -2.9871562    3.3952267    3.3952267 
     310   -2.9871562    3.3952267    3.4109598 
Loop time of 3.5631e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.50025946298505
variable        y0 equal ${yi}
variable        y0 equal 1.86405157229966

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.50349426666166
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.89073812148637
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     310   -2.9871562    3.3952267    3.4109598 
     311   -2.9871562    3.3952267    3.4550008 
Loop time of 3.53994e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.50025946298505
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.86405157229966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.01163879076348
variable        y0 equal ${yi}
variable        y0 equal 9.27794473874896

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.06753070989953
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 9.28944804179996
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     311   -2.9871562    3.3952267    3.4550008 
     312   -2.9871562    3.3952267    3.3887195 
Loop time of 3.52857e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 3.38871951716667
variable naccept equal ${increment}
variable naccept equal 91

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.09006510693581
variable        y0 equal ${yi}
variable        y0 equal 4.59300016516611

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.13920948226006
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.51336059922144
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     312   -2.9871562    3.3887195    3.3887195 
     313   -2.9871562    3.3887195    3.4014981 
Loop time of 6.08449e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.09006510693581
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.59300016516611
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.0567768156419
variable        y0 equal ${yi}
variable        y0 equal 4.66208653801843

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.04262927173473
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.62224207276269
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     313   -2.9871562    3.3887195    3.4014981 
     314   -2.9871562    3.3887195    3.3898721 
Loop time of 3.51516e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.0567768156419
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.66208653801843
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.06897214053966
variable        y0 equal ${yi}
variable        y0 equal 8.19967323459681

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.03148551582195
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.25080559171732
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     314   -2.9871562    3.3887195    3.3898721 
     315   -2.9871562    3.3887195    3.3552931 
Loop time of 3.6479e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 3.35529305824231
variable naccept equal ${increment}
variable naccept equal 92

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.73131323059035
variable        y0 equal ${yi}
variable        y0 equal 4.67710171097681

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.80142506559325
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.64370380991861
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     315   -2.9871562    3.3552931    3.3552931 
     316   -2.9871562    3.3552931    3.3678391 
Loop time of 3.50411e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.73131323059035
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.67710171097681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.8169515065301
variable        y0 equal ${yi}
variable        y0 equal 0.890143771875232

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.73621929207926
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.929682608354419
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     316   -2.9871562    3.3552931    3.3678391 
     317   -2.9871562    3.3552931    3.3739307 
Loop time of 3.64008e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.8169515065301
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.890143771875232
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.74401889045668
variable        y0 equal ${yi}
variable        y0 equal 8.41668003715571

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.65808878143263
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.50701395191248
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     317   -2.9871562    3.3552931    3.3739307 
     318   -2.9871562    3.3552931    3.3855263 
Loop time of 3.58641e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.74401889045668
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.41668003715571
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.48185687222902
variable        y0 equal ${yi}
variable        y0 equal 1.94388798854416

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.45046121039812
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 2.03577225587433
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     318   -2.9871562    3.3552931    3.3855263 
     319   -2.9871562    3.3552931    3.7155097 
Loop time of 3.65633e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.48185687222902
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.94388798854416
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.44072332778836
variable        y0 equal ${yi}
variable        y0 equal 0.0966708421707153

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.48322149911786
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 0.0199005961418151
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     319   -2.9871562    3.3552931    3.7155097 
     320   -2.9871562    3.3552931    3.3492273 
Loop time of 3.6589e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 3.34922732545967
variable naccept equal ${increment}
variable naccept equal 93

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.19252239226857
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.00639301538467403
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     320   -2.9871562    3.3492273    3.3492273 
     321   -2.9871562    3.3492273    3.3523466 
Loop time of 3.64495e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.597638221183683
variable        y0 equal ${yi}
variable        y0 equal 0.769967218149036

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.6302324012908
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.804496832597583
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     321   -2.9871562    3.3492273    3.3523466 
     322   -2.9871562    3.3492273    3.3344166 
Loop time of 3.58785e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 3.33441662468351
variable naccept equal ${increment}
variable naccept equal 94

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.86308897375403
variable        y0 equal ${yi}
variable        y0 equal 4.54561560505792

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.92869656919776
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.5198671614544
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     322   -2.9871562    3.3344166    3.3344166 
     323   -2.9871562    3.3344166    3.3459413 
Loop time of 3.70727e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.86308897375403
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.54561560505792
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.6955831456053
variable        y0 equal ${yi}
variable        y0 equal 0.0743083238601685

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.68869359968779
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.1279620885849
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     323   -2.9871562    3.3344166    3.3459413 
     324   -2.9871562    3.3344166    3.3192123 
Loop time of 3.53505e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 3.31921230791418
variable naccept equal ${increment}
variable naccept equal 95

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2943734292051
variable        y0 equal ${yi}
variable        y0 equal 4.84162094944879

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.2110269073507
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.90926219576761
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     324   -2.9871562    3.3192123    3.3192123 
     325   -2.9871562    3.3192123    3.5632936 
Loop time of 3.56892e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.2943734292051
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.84162094944879
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.74355002799455
variable        y0 equal ${yi}
variable        y0 equal 5.5961909527083

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.82405435004655
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.5151563996573
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     325   -2.9871562    3.3192123    3.5632936 
     326   -2.9871562    3.3192123    3.4526628 
Loop time of 3.63469e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.74355002799455
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.5961909527083
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.124600601196289
variable        y0 equal ${yi}
variable        y0 equal 1.65739337585038

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.213477754592895
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.64986744306153
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     326   -2.9871562    3.3192123    3.4526628 
     327   -2.9871562    3.3192123    3.5379498 
Loop time of 3.53456e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 6 x ${x0}
set atom 6 x 0.124600601196289
  1 settings made for x
set atom $i y ${y0}
set atom 6 y ${y0}
set atom 6 y 1.65739337585038
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.74401889045668
variable        y0 equal ${yi}
variable        y0 equal 8.41668003715571

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.7911317010684
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.37118543304499
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     327   -2.9871562    3.3192123    3.5379498 
     328   -2.9871562    3.3192123    3.3182217 
Loop time of 3.49345e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 3.31822169659297
variable naccept equal ${increment}
variable naccept equal 96

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.21161605198594
variable        y0 equal ${yi}
variable        y0 equal 5.67831456606585

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.29989098389359
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.72776091044146
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     328   -2.9871562    3.3182217    3.3182217 
     329   -2.9871562    3.3182217    3.3748583 
Loop time of 3.51588e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.21161605198594
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.67831456606585
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.57711223203909
variable        y0 equal ${yi}
variable        y0 equal 1.7166861691243

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.61205859024298
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.63770842931336
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     329   -2.9871562    3.3182217    3.3748583 
     330   -2.9871562    3.3182217    3.4162628 
Loop time of 3.68329e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.57711223203909
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.7166861691243
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.0567768156419
variable        y0 equal ${yi}
variable        y0 equal 4.66208653801843

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.0369942605386
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.6132219230549
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     330   -2.9871562    3.3182217    3.4162628 
     331   -2.9871562    3.3182217    3.3196747 
Loop time of 3.57615e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.0567768156419
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.66208653801843
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.786463814174
variable        y0 equal ${yi}
variable        y0 equal 4.50682874077723

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.83858691969997
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.4871469175236
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     331   -2.9871562    3.3182217    3.3196747 
     332   -2.9871562    3.3182217    3.3318879 
Loop time of 3.54276e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.786463814174
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.50682874077723
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.42271354038488
variable        y0 equal ${yi}
variable        y0 equal 7.45066014852786

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.34323152143728
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.4833332213428
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     332   -2.9871562    3.3182217    3.3318879 
     333   -2.9871562    3.3182217    3.4097382 
Loop time of 3.57607e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.42271354038488
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.45066014852786
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.68869359968779
variable        y0 equal ${yi}
variable        y0 equal 0.1279620885849

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.62581338165877
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.0827957153320313
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     333   -2.9871562    3.3182217    3.4097382 
     334   -2.9871562    3.3182217    3.3096365 
Loop time of 3.78658e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 3.30963654511316
variable naccept equal ${increment}
variable naccept equal 97

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 1.99785717169152
variable        y0 equal ${yi}
variable        y0 equal 3.87768581671845

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.06690257231103
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.79156183762681
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     334   -2.9871562    3.3096365    3.3096365 
     335   -2.9871562    3.3096365    3.2995547 
Loop time of 3.56735e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 3.29955466162915
variable naccept equal ${increment}
variable naccept equal 98

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.58451553423178
variable        y0 equal ${yi}
variable        y0 equal 9.24099562871784

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.58617153007757
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.144875676516
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     335   -2.9871562    3.2995547    3.2995547 
     336   -2.9871562    3.2995547     3.303551 
Loop time of 3.66332e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.58451553423178
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.24099562871784
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.92978396057426
variable        y0 equal ${yi}
variable        y0 equal 1.00790997337136

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.99645732282936
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 1.05039479326043
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     336   -2.9871562    3.2995547     3.303551 
     337   -2.9871562    3.2995547    3.3187765 
Loop time of 3.56725e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.92978396057426
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 1.00790997337136
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.56502480903531
variable        y0 equal ${yi}
variable        y0 equal 3.6810828046335

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.49132942357922
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.63162182135713
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     337   -2.9871562    3.2995547    3.3187765 
     338   -2.9871562    3.2995547    2.3411649 
Loop time of 3.49696e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 2.34116488029093
variable naccept equal ${increment}
variable naccept equal 99

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 6.04620492417804
variable        y0 equal ${yi}
variable        y0 equal 8.33303295291957

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.02990794141284
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.29363690532741
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     338   -2.9871562    2.3411649    2.3411649 
     339   -2.9871562    2.3411649    2.2848826 
Loop time of 3.60733e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 2.28488257576975
variable naccept equal ${increment}
variable naccept equal 100

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.02162012179547
variable        y0 equal ${yi}
variable        y0 equal 3.71439457697999

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 0.955127325851256
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.71532922549378
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     339   -2.9871562    2.2848826    2.2848826 
     340   -2.9871562    2.2848826    2.3305721 
Loop time of 3.5879e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.02162012179547
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.71439457697999
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2943734292051
variable        y0 equal ${yi}
variable        y0 equal 4.84162094944879

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.3565030340215
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.75199741476938
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     340   -2.9871562    2.2848826    2.3305721 
     341   -2.9871562    2.2848826      2.23202 
Loop time of 3.63329e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 2.23202002023241
variable naccept equal ${increment}
variable naccept equal 101

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.00028690417462
variable        y0 equal ${yi}
variable        y0 equal 7.4731605443027

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.03629819472485
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.54285924759173
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     341   -2.9871562      2.23202      2.23202 
     342   -2.9871562      2.23202    2.2421275 
Loop time of 3.58999e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.00028690417462
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4731605443027
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.24829633830883
variable        y0 equal ${yi}
variable        y0 equal 2.8101769563804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.17226861118175
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.81804441186288
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     342   -2.9871562      2.23202    2.2421275 
     343   -2.9871562      2.23202    2.1827039 
Loop time of 3.59054e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 2.1827039251808
variable naccept equal ${increment}
variable naccept equal 102

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.21963674783269
variable        y0 equal ${yi}
variable        y0 equal 5.52001365368563

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.1967699146227
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.58315908854204
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     343   -2.9871562    2.1827039    2.1827039 
     344   -2.9871562    2.1827039    2.1915561 
Loop time of 3.65896e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.21963674783269
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.52001365368563
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.41993123371812
variable        y0 equal ${yi}
variable        y0 equal 1.77035118720597

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.35915150721284
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.80079861066407
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     344   -2.9871562    2.1827039    2.1915561 
     345   -2.9871562    2.1827039    2.1523436 
Loop time of 3.55186e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 2.15234362235816
variable naccept equal ${increment}
variable naccept equal 103

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.85953580974875
variable        y0 equal ${yi}
variable        y0 equal 8.40862084545191

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.79672591327963
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.36334333337839
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     345   -2.9871562    2.1523436    2.1523436 
     346   -2.9871562    2.1523436    2.1663776 
Loop time of 3.71639e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.85953580974875
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.40862084545191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.36321673154392
variable        y0 equal ${yi}
variable        y0 equal 1.8523390569455

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.37729761361637
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.94115337512558
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     346   -2.9871562    2.1523436    2.1663776 
     347   -2.9871562    2.1523436    2.1785461 
Loop time of 3.60194e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.36321673154392
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.8523390569455
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.520989449420835
variable        y0 equal ${yi}
variable        y0 equal 4.56744662875101

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.507592184940244
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.58122632855341
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     347   -2.9871562    2.1523436    2.1785461 
     348   -2.9871562    2.1523436    2.1564425 
Loop time of 3.60805e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.520989449420835
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.56744662875101
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.39882474659997
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.39241191473269
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     348   -2.9871562    2.1523436    2.1564425 
     349   -2.9871562    2.1523436    2.1914723 
Loop time of 3.51184e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47168833731729
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.2979036006
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.85629137078409
variable        y0 equal ${yi}
variable        y0 equal 8.45065544761714

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.83017104188089
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.48041423477229
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     349   -2.9871562    2.1523436    2.1914723 
     350   -2.9871562    2.1523436    2.1567834 
Loop time of 3.57384e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.85629137078409
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.45065544761714
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.74355002799455
variable        y0 equal ${yi}
variable        y0 equal 5.5961909527083

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.70814781346742
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.57438946907717
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     350   -2.9871562    2.1523436    2.1567834 
     351   -2.9871562    2.1523436    1.9134523 
Loop time of 3.60495e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.91345229877358
variable naccept equal ${increment}
variable naccept equal 104

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.00028690417462
variable        y0 equal ${yi}
variable        y0 equal 7.4731605443027

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.03926513512784
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.4691895755794
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     351   -2.9871562    1.9134523    1.9134523 
     352   -2.9871562    1.9134523    1.9109871 
Loop time of 3.56367e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.91098708507899
variable naccept equal ${increment}
variable naccept equal 105

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.06753070989953
variable        y0 equal ${yi}
variable        y0 equal 9.28944804179996

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.11292983929025
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 9.24421996581882
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     352   -2.9871562    1.9109871    1.9109871 
     353   -2.9871562    1.9109871    1.9106407 
Loop time of 3.6618e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.91064068102192
variable naccept equal ${increment}
variable naccept equal 106

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.85953580974875
variable        y0 equal ${yi}
variable        y0 equal 8.40862084545191

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.95935798525153
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.33042802728708
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     353   -2.9871562    1.9106407    1.9106407 
     354   -2.9871562    1.9106407    1.8740448 
Loop time of 3.64325e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.87404483005926
variable naccept equal ${increment}
variable naccept equal 107

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 6.02990794141284
variable        y0 equal ${yi}
variable        y0 equal 8.29363690532741

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.07210488278857
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.34585292257366
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     354   -2.9871562    1.8740448    1.8740448 
     355   -2.9871562    1.8740448    2.0702452 
Loop time of 3.65217e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 6.02990794141284
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.29363690532741
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3005129698773
variable        y0 equal ${yi}
variable        y0 equal 0.856256540525287

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.2418087724705
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.798901816118091
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     355   -2.9871562    1.8740448    2.0702452 
     356   -2.9871562    1.8740448    1.8856033 
Loop time of 3.55739e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.3005129698773
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.856256540525287
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.04212040860645
variable        y0 equal ${yi}
variable        y0 equal 0.854861756074756

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 6.13176341016285
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.86154763292107
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     356   -2.9871562    1.8740448    1.8856033 
     357   -2.9871562    1.8740448    1.9411966 
Loop time of 3.6553e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 6.04212040860645
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.854861756074756
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.459625037113095
variable        y0 equal ${yi}
variable        y0 equal 8.35511863149699

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.54169821302023
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.41637049831447
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     357   -2.9871562    1.8740448    1.9411966 
     358   -2.9871562    1.8740448    2.0064014 
Loop time of 3.66746e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.459625037113095
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.35511863149699
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.8169515065301
variable        y0 equal ${yi}
variable        y0 equal 0.890143771875232

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.7858813814271
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.898821707475513
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     358   -2.9871562    1.8740448    2.0064014 
     359   -2.9871562    1.8740448    1.8782281 
Loop time of 3.60611e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.8169515065301
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.890143771875232
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.73468725640765
variable        y0 equal ${yi}
variable        y0 equal 2.72136272164681

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.64870165545932
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.75666401358941
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     359   -2.9871562    1.8740448    1.8782281 
     360   -2.9871562    1.8740448    4.6354583 
Loop time of 3.5796e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.73468725640765
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.72136272164681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.48185687222902
variable        y0 equal ${yi}
variable        y0 equal 1.94388798854416

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.42096427836839
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 2.03490505597656
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     360   -2.9871562    1.8740448    4.6354583 
     361   -2.9871562    1.8740448    2.1625828 
Loop time of 3.74304e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.48185687222902
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.94388798854416
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.17996948400841
variable        y0 equal ${yi}
variable        y0 equal 5.62720593159395

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.14502597490654
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.53364494984346
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     361   -2.9871562    1.8740448    2.1625828 
     362   -2.9871562    1.8740448    1.8617982 
Loop time of 3.58861e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.86179816736602
variable naccept equal ${increment}
variable naccept equal 108

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03148551582195
variable        y0 equal ${yi}
variable        y0 equal 8.25080559171732

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.09325066207744
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.34185184158381
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     362   -2.9871562    1.8617982    1.8617982 
     363   -2.9871562    1.8617982    1.8769382 
Loop time of 3.58127e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03148551582195
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.25080559171732
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.35915150721284
variable        y0 equal ${yi}
variable        y0 equal 1.80079861066407

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.41299231131288
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.80218074700898
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     363   -2.9871562    1.8617982    1.8769382 
     364   -2.9871562    1.8617982     1.866072 
Loop time of 3.57747e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.35915150721284
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.80079861066407
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.6302324012908
variable        y0 equal ${yi}
variable        y0 equal 0.804496832597583

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.616629739204313
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.744235976446002
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     364   -2.9871562    1.8617982     1.866072 
     365   -2.9871562    1.8617982    1.9020598 
Loop time of 3.64691e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.6302324012908
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.804496832597583
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 7.03299039879486
variable        y0 equal ${yi}
variable        y0 equal 6.46040994659891

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.06044206896469
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.51616222397318
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     365   -2.9871562    1.8617982    1.9020598 
     366   -2.9871562    1.8617982    1.8375708 
Loop time of 3.70325e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.83757084520317
variable naccept equal ${increment}
variable naccept equal 109

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.09006510693581
variable        y0 equal ${yi}
variable        y0 equal 4.59300016516611

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.10939047057183
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.60961571091577
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     366   -2.9871562    1.8375708    1.8375708 
     367   -2.9871562    1.8375708     1.835434 
Loop time of 3.59875e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.83543397058131
variable naccept equal ${increment}
variable naccept equal 110

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.14502597490654
variable        y0 equal ${yi}
variable        y0 equal 5.53364494984346

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.20860423485146
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.48299548571306
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     367   -2.9871562     1.835434     1.835434 
     368   -2.9871562     1.835434    1.8648408 
Loop time of 3.4586e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.14502597490654
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.53364494984346
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.63595545449678
variable        y0 equal ${yi}
variable        y0 equal 0.131007170677185

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.59484791913454
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.135441219806671
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     368   -2.9871562     1.835434    1.8648408 
     369   -2.9871562     1.835434    1.8567313 
Loop time of 3.52819e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.63595545449678
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.131007170677185
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.7506712782361
variable        y0 equal ${yi}
variable        y0 equal 0.968768938291401

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.84699796318788
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.998236437547535
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     369   -2.9871562     1.835434    1.8567313 
     370   -2.9871562     1.835434    1.9344799 
Loop time of 3.73469e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.7506712782361
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.968768938291401
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.87135564604884
variable        y0 equal ${yi}
variable        y0 equal 6.55566048161021

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.88975222626811
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.49677963987819
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     370   -2.9871562     1.835434    1.9344799 
     371   -2.9871562     1.835434    1.8928979 
Loop time of 3.71094e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.87135564604884
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.55566048161021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.90480163056842
variable        y0 equal ${yi}
variable        y0 equal 4.66367782706186

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.93302334506503
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.71217333430215
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     371   -2.9871562     1.835434    1.8928979 
     372   -2.9871562     1.835434    1.8812152 
Loop time of 3.76301e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.90480163056842
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.66367782706186
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.78632356444484
variable        y0 equal ${yi}
variable        y0 equal 2.7753891822944

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.74608667412883
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.79483514996866
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     372   -2.9871562     1.835434    1.8812152 
     373   -2.9871562     1.835434    1.8393104 
Loop time of 3.57843e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.78632356444484
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.7753891822944
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.6591813107295
variable        y0 equal ${yi}
variable        y0 equal 2.73446601601937

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.61809576948118
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.66532459231713
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     373   -2.9871562     1.835434    1.8393104 
     374   -2.9871562     1.835434    1.8900334 
Loop time of 3.58604e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.6591813107295
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.73446601601937
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.04212040860645
variable        y0 equal ${yi}
variable        y0 equal 0.854861756074756

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 5.99054194648258
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.841647489774555
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     374   -2.9871562     1.835434    1.8900334 
     375   -2.9871562     1.835434    1.8376206 
Loop time of 3.67034e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 6.04212040860645
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.854861756074756
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57225463270922
variable        y0 equal ${yi}
variable        y0 equal 4.72659182900353

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.64943960785647
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.82604291790886
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     375   -2.9871562     1.835434    1.8376206 
     376   -2.9871562     1.835434    1.9683212 
Loop time of 3.56003e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.57225463270922
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.72659182900353
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.7911317010684
variable        y0 equal ${yi}
variable        y0 equal 8.37118543304499

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.70976040561628
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.28874858535822
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     376   -2.9871562     1.835434    1.9683212 
     377   -2.9871562     1.835434    1.8419068 
Loop time of 3.63534e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.7911317010684
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.37118543304499
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.10939047057183
variable        y0 equal ${yi}
variable        y0 equal 4.60961571091577

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.17070888001473
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.68602787608072
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     377   -2.9871562     1.835434    1.8419068 
     378   -2.9871562     1.835434    1.8696969 
Loop time of 6.32685e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.10939047057183
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.60961571091577
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7151750167065
variable        y0 equal ${yi}
variable        y0 equal 7.47761501398349

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.666915961092
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.38727078762317
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     378   -2.9871562     1.835434    1.8696969 
     379   -2.9871562     1.835434    1.8668004 
Loop time of 3.60113e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7151750167065
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.47761501398349
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.520060713687803
variable        y0 equal ${yi}
variable        y0 equal 2.88988070460657

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.436288161674406
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.9070917245994
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     379   -2.9871562     1.835434    1.8668004 
     380   -2.9871562     1.835434    1.9321557 
Loop time of 3.84422e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.520060713687803
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.88988070460657
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.87135564604884
variable        y0 equal ${yi}
variable        y0 equal 6.55566048161021

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.91461881915217
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.49674593941203
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     380   -2.9871562     1.835434    1.9321557 
     381   -2.9871562     1.835434    1.9148684 
Loop time of 3.68036e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.87135564604884
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.55566048161021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.50025946298505
variable        y0 equal ${yi}
variable        y0 equal 1.86405157229966

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.46111556688215
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.83501274964875
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     381   -2.9871562     1.835434    1.9148684 
     382   -2.9871562     1.835434    1.7633791 
Loop time of 3.68083e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.76337910671936
variable naccept equal ${increment}
variable naccept equal 111

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.8169515065301
variable        y0 equal ${yi}
variable        y0 equal 0.890143771875232

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.82254123011714
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.966656931150287
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     382   -2.9871562    1.7633791    1.7633791 
     383   -2.9871562    1.7633791    1.7778964 
Loop time of 3.50837e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.8169515065301
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.890143771875232
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.85629137078409
variable        y0 equal ${yi}
variable        y0 equal 8.45065544761714

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.79902222672586
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.45315378822383
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     383   -2.9871562    1.7633791    1.7778964 
     384   -2.9871562    1.7633791    1.7698066 
Loop time of 3.56961e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.85629137078409
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.45065544761714
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.786463814174
variable        y0 equal ${yi}
variable        y0 equal 4.50682874077723

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.73748982468731
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.55758550518916
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     384   -2.9871562    1.7633791    1.7698066 
     385   -2.9871562    1.7633791    1.7638232 
Loop time of 3.58346e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.76382323090863
variable naccept equal ${increment}
variable naccept equal 112

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7151750167065
variable        y0 equal ${yi}
variable        y0 equal 7.47761501398349

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.6479147513562
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.43258213129306
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     385   -2.9871562    1.7638232    1.7638232 
     386   -2.9871562    1.7638232    1.8144596 
Loop time of 3.4553e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7151750167065
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.47761501398349
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 7.06044206896469
variable        y0 equal ${yi}
variable        y0 equal 6.51616222397318

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 6.99400134363815
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.59644997850886
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     386   -2.9871562    1.7638232    1.8144596 
     387   -2.9871562    1.7638232    1.8345794 
Loop time of 3.4737e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 7.06044206896469
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.51616222397318
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.57711223203909
variable        y0 equal ${yi}
variable        y0 equal 1.7166861691243

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.66932824690115
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.71616243503159
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     387   -2.9871562    1.7638232    1.8345794 
     388   -2.9871562    1.7638232    1.9361078 
Loop time of 3.61415e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.57711223203909
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.7166861691243
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.8169515065301
variable        y0 equal ${yi}
variable        y0 equal 0.890143771875232

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.89710387507563
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.893060239065021
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     388   -2.9871562    1.7638232    1.9361078 
     389   -2.9871562    1.7638232     1.765664 
Loop time of 3.50697e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.8169515065301
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.890143771875232
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.5265262563877
variable        y0 equal ${yi}
variable        y0 equal 5.69825360720354

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.5697014172726
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.77922322695452
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     389   -2.9871562    1.7638232     1.765664 
     390   -2.9871562    1.7638232    1.7887774 
Loop time of 3.58618e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.5265262563877
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.69825360720354
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.48322149911786
variable        y0 equal ${yi}
variable        y0 equal 0.0199005961418151

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.58215939203168
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y -0.0131149291992188
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     390   -2.9871562    1.7638232    1.7887774 
     391   -2.9871562    1.7638232     1.922629 
Loop time of 3.54312e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.48322149911786
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 0.0199005961418151
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.61686462044497
variable        y0 equal ${yi}
variable        y0 equal 2.97424355717996

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.62846250414629
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 3.05203980180124
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     391   -2.9871562    1.7638232     1.922629 
     392   -2.9871562    1.7638232    1.9297395 
Loop time of 3.50135e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.61686462044497
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.97424355717996
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.8914976266925
variable        y0 equal ${yi}
variable        y0 equal 4.82204459065363

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.87762415686294
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.77079314345286
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     392   -2.9871562    1.7638232    1.9297395 
     393   -2.9871562    1.7638232    1.7173494 
Loop time of 3.52284e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.71734938088787
variable naccept equal ${increment}
variable naccept equal 113

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.87894159832641
variable        y0 equal ${yi}
variable        y0 equal 8.30428651489314

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.97784195223495
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.32680290855464
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     393   -2.9871562    1.7173494    1.7173494 
     394   -2.9871562    1.7173494     1.566312 
Loop time of 3.65307e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.56631203726645
variable naccept equal ${increment}
variable naccept equal 114

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.87135564604884
variable        y0 equal ${yi}
variable        y0 equal 6.55566048161021

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.91574336806422
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.56656817928782
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     394   -2.9871562     1.566312     1.566312 
     395   -2.9871562     1.566312    1.5840229 
Loop time of 3.53558e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.87135564604884
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.55566048161021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.90480163056842
variable        y0 equal ${yi}
variable        y0 equal 4.66367782706186

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.91092514951221
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.66123783940241
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     395   -2.9871562     1.566312    1.5840229 
     396   -2.9871562     1.566312    1.5885811 
Loop time of 3.62318e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.90480163056842
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.66367782706186
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.10939047057183
variable        y0 equal ${yi}
variable        y0 equal 4.60961571091577

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.17113715130837
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.60592613572046
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     396   -2.9871562     1.566312    1.5885811 
     397   -2.9871562     1.566312    1.5657124 
Loop time of 3.54804e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.56571238729969
variable naccept equal ${increment}
variable naccept equal 115

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.11292983929025
variable        y0 equal ${yi}
variable        y0 equal 9.24421996581882

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.10450782219278
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 9.19905437934726
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     397   -2.9871562    1.5657124    1.5657124 
     398   -2.9871562    1.5657124    1.5789583 
Loop time of 3.5237e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.11292983929025
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 9.24421996581882
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.21963674783269
variable        y0 equal ${yi}
variable        y0 equal 5.52001365368563

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.20891928433934
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.56093283837038
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     398   -2.9871562    1.5657124    1.5789583 
     399   -2.9871562    1.5657124    1.5643478 
Loop time of 3.55798e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.56434775227594
variable naccept equal ${increment}
variable naccept equal 116

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 6.98790284672424
variable        y0 equal ${yi}
variable        y0 equal 2.75419310304025

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.97642637768432
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.69445910426477
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     399   -2.9871562    1.5643478    1.5643478 
     400   -2.9871562    1.5643478    1.5860548 
Loop time of 3.6104e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 6.98790284672424
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.75419310304025
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.95935798525153
variable        y0 equal ${yi}
variable        y0 equal 8.33042802728708

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 5.03441286920844
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.24887866891916
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     400   -2.9871562    1.5643478    1.5860548 
     401   -2.9871562    1.5643478    1.6813555 
Loop time of 3.718e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.95935798525153
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.33042802728708
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.42271354038488
variable        y0 equal ${yi}
variable        y0 equal 7.45066014852786

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.36637852031957
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.42138128605151
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     401   -2.9871562    1.5643478    1.6813555 
     402   -2.9871562    1.5643478    1.6238192 
Loop time of 3.56324e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.42271354038488
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.45066014852786
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.49132942357922
variable        y0 equal ${yi}
variable        y0 equal 3.63162182135713

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.56277708211804
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.61680875582826
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     402   -2.9871562    1.5643478    1.6238192 
     403   -2.9871562    1.5643478    2.1209506 
Loop time of 3.58193e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.49132942357922
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.63162182135713
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66628361820956
variable        y0 equal ${yi}
variable        y0 equal 8.33030129589137

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.6312115776517
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.26106995262202
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     403   -2.9871562    1.5643478    2.1209506 
     404   -2.9871562    1.5643478    1.5720421 
Loop time of 3.57269e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66628361820956
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.33030129589137
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20891928433934
variable        y0 equal ${yi}
variable        y0 equal 5.56093283837038

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.28192436456242
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.56574441139894
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     404   -2.9871562    1.5643478    1.5720421 
     405   -2.9871562    1.5643478    1.5786695 
Loop time of 3.46458e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20891928433934
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56093283837038
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.95935798525153
variable        y0 equal ${yi}
variable        y0 equal 8.33042802728708

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.96772496342002
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.23241872705515
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     405   -2.9871562    1.5643478    1.5786695 
     406   -2.9871562    1.5643478    1.6350161 
Loop time of 3.6759e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.95935798525153
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.33042802728708
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.85629137078409
variable        y0 equal ${yi}
variable        y0 equal 8.45065544761714

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.79430689135675
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.46936724103984
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     406   -2.9871562    1.5643478    1.6350161 
     407   -2.9871562    1.5643478    1.5762623 
Loop time of 3.64222e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.85629137078409
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.45065544761714
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 0.899675980407526
variable        y0 equal ${yi}
variable        y0 equal 9.19352722871631

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 0.902489951450159
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.16719992864459
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     407   -2.9871562    1.5643478    1.5762623 
     408   -2.9871562    1.5643478    1.5672672 
Loop time of 3.61449e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 0.899675980407526
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.19352722871631
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40260913768674
variable        y0 equal ${yi}
variable        y0 equal 5.5414461011191

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.4301039258566
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.53071504776674
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     408   -2.9871562    1.5643478    1.5672672 
     409   -2.9871562    1.5643478    1.5980798 
Loop time of 3.64649e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.40260913768674
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.5414461011191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.35826578219148
variable        y0 equal ${yi}
variable        y0 equal 7.40391505089068

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.28159687597963
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.4978555950191
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     409   -2.9871562    1.5643478    1.5980798 
     410   -2.9871562    1.5643478    1.5622606 
Loop time of 3.6161e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.5622606379719
variable naccept equal ${increment}
variable naccept equal 117

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.62581338165877
variable        y0 equal ${yi}
variable        y0 equal 0.0827957153320313

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.60189408539412
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.164266347885132
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     410   -2.9871562    1.5622606    1.5622606 
     411   -2.9871562    1.5622606    1.5631349 
Loop time of 3.63952e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.56313485005628
variable naccept equal ${increment}
variable naccept equal 118

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.520060713687803
variable        y0 equal ${yi}
variable        y0 equal 2.88988070460657

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.468465288082029
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.90584467622141
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     411   -2.9871562    1.5631349    1.5631349 
     412   -2.9871562    1.5631349    1.6064296 
Loop time of 3.72259e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.520060713687803
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.88988070460657
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.60189408539412
variable        y0 equal ${yi}
variable        y0 equal 0.164266347885132

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.5918520736563
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.0918658018112184
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     412   -2.9871562    1.5631349    1.6064296 
     413   -2.9871562    1.5631349    1.5654613 
Loop time of 3.59141e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 79 x ${x0}
set atom 79 x 9.60189408539412
  1 settings made for x
set atom $i y ${y0}
set atom 79 y ${y0}
set atom 79 y 0.164266347885132
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.8307700681555
variable        y0 equal ${yi}
variable        y0 equal 1.7936737098462

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.77959260223982
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.80438243529862
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     413   -2.9871562    1.5631349    1.5654613 
     414   -2.9871562    1.5631349     1.564179 
Loop time of 3.69017e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.8307700681555
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.7936737098462
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.14502597490654
variable        y0 equal ${yi}
variable        y0 equal 5.53364494984346

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.04699133077965
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.48886756842332
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     414   -2.9871562    1.5631349     1.564179 
     415   -2.9871562    1.5631349     1.624556 
Loop time of 3.5136e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.14502597490654
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.53364494984346
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.28044283110649
variable        y0 equal ${yi}
variable        y0 equal 2.67400697442391

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.28845272976906
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.75579466792443
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     415   -2.9871562    1.5631349     1.624556 
     416   -2.9871562    1.5631349    1.5584116 
Loop time of 3.69294e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.55841162159314
variable naccept equal ${increment}
variable naccept equal 119

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.34383112271043
variable        y0 equal ${yi}
variable        y0 equal 3.64135434193742

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.30488829691621
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.72380816502702
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     416   -2.9871562    1.5584116    1.5584116 
     417   -2.9871562    1.5584116    1.5411621 
Loop time of 3.68541e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.54116209761192
variable naccept equal ${increment}
variable naccept equal 120

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 7.06044206896469
variable        y0 equal ${yi}
variable        y0 equal 6.51616222397318

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.08603041449234
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.53742138878336
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     417   -2.9871562    1.5411621    1.5411621 
     418   -2.9871562    1.5411621    1.5470104 
Loop time of 3.68339e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 7.06044206896469
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.51616222397318
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66628361820956
variable        y0 equal ${yi}
variable        y0 equal 8.33030129589137

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.73555084347506
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.28282771028575
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     418   -2.9871562    1.5411621    1.5470104 
     419   -2.9871562    1.5411621    1.5503165 
Loop time of 3.55335e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66628361820956
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.33030129589137
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.04212040860645
variable        y0 equal ${yi}
variable        y0 equal 0.854861756074756

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 5.95462453324787
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.790458055246204
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     419   -2.9871562    1.5411621    1.5503165 
     420   -2.9871562    1.5411621     1.601195 
Loop time of 3.58358e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 6.04212040860645
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.854861756074756
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.7506712782361
variable        y0 equal ${yi}
variable        y0 equal 0.968768938291401

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.77868833422441
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 1.03901606391701
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     420   -2.9871562    1.5411621     1.601195 
     421   -2.9871562    1.5411621    1.5789805 
Loop time of 3.737e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.7506712782361
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.968768938291401
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 6.98790284672424
variable        y0 equal ${yi}
variable        y0 equal 2.75419310304025

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.9320023683612
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.82359918328622
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     421   -2.9871562    1.5411621    1.5789805 
     422   -2.9871562    1.5411621    1.5410596 
Loop time of 3.57835e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.54105964095209
variable naccept equal ${increment}
variable naccept equal 121

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.3565030340215
variable        y0 equal ${yi}
variable        y0 equal 4.75199741476938

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.3791622523328
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.71766387576029
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     422   -2.9871562    1.5410596    1.5410596 
     423   -2.9871562    1.5410596    1.5693377 
Loop time of 3.6657e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.3565030340215
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.75199741476938
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.28845272976906
variable        y0 equal ${yi}
variable        y0 equal 2.75579466792443

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.29281390625984
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.81548961373666
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     423   -2.9871562    1.5410596    1.5693377 
     424   -2.9871562    1.5410596    1.5416644 
Loop time of 3.61964e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.28845272976906
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.75579466792443
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.96026352285682
variable        y0 equal ${yi}
variable        y0 equal 6.34972419277659

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.87403288721382
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.25285101667872
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     424   -2.9871562    1.5410596    1.5416644 
     425   -2.9871562    1.5410596    1.6201631 
Loop time of 3.6303e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.96026352285682
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.34972419277659
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.520989449420835
variable        y0 equal ${yi}
variable        y0 equal 4.56744662875101

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.507097609439756
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.56671496981546
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     425   -2.9871562    1.5410596    1.6201631 
     426   -2.9871562    1.5410596    1.5627596 
Loop time of 3.66975e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.520989449420835
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.56744662875101
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.40689885138589
variable        y0 equal ${yi}
variable        y0 equal 1.95026988170212

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.33030006407815
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.87248324534958
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     426   -2.9871562    1.5410596    1.5627596 
     427   -2.9871562    1.5410596    1.6376936 
Loop time of 3.49859e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.40689885138589
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.95026988170212
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.87135564604884
variable        y0 equal ${yi}
variable        y0 equal 6.55566048161021

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.91474539557582
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.51542738214961
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     427   -2.9871562    1.5410596    1.6376936 
     428   -2.9871562    1.5410596    1.5931699 
Loop time of 3.52176e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.87135564604884
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.55566048161021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 7.06044206896469
variable        y0 equal ${yi}
variable        y0 equal 6.51616222397318

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.085977616698
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.4297259523057
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     428   -2.9871562    1.5410596    1.5931699 
     429   -2.9871562    1.5410596    1.7226818 
Loop time of 3.75674e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 7.06044206896469
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.51616222397318
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.17055683730937
variable        y0 equal ${yi}
variable        y0 equal 6.38234023586741

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.21557635663844
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.45888218418589
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     429   -2.9871562    1.5410596    1.7226818 
     430   -2.9871562    1.5410596    1.9046234 
Loop time of 3.4586e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.17055683730937
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.38234023586741
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.520989449420835
variable        y0 equal ${yi}
variable        y0 equal 4.56744662875101

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.537436564365293
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.5394646083729
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     430   -2.9871562    1.5410596    1.9046234 
     431   -2.9871562    1.5410596      1.56094 
Loop time of 3.52745e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.520989449420835
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.56744662875101
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.02796765843078
variable        y0 equal ${yi}
variable        y0 equal 0.90793559144768

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.01834789791747
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.992886694181292
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     431   -2.9871562    1.5410596      1.56094 
     432   -2.9871562    1.5410596    1.5818404 
Loop time of 3.53821e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.02796765843078
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.90793559144768
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.71272399583284
variable        y0 equal ${yi}
variable        y0 equal 7.50542391863131

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.65211558499757
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.51075175133013
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     432   -2.9871562    1.5410596    1.5818404 
     433   -2.9871562    1.5410596     1.548753 
Loop time of 3.58707e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.71272399583284
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.50542391863131
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.90480163056842
variable        y0 equal ${yi}
variable        y0 equal 4.66367782706186

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.99830827672473
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.58633422011301
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     433   -2.9871562    1.5410596     1.548753 
     434   -2.9871562    1.5410596    2.8822993 
Loop time of 3.66137e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.90480163056842
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.66367782706186
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.40689885138589
variable        y0 equal ${yi}
variable        y0 equal 1.95026988170212

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.34336682080346
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.99645606658524
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     434   -2.9871562    1.5410596    2.8822993 
     435   -2.9871562    1.5410596    1.6239261 
Loop time of 3.60928e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.40689885138589
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.95026988170212
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.35915150721284
variable        y0 equal ${yi}
variable        y0 equal 1.80079861066407

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.27108347494813
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.85012233636445
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     435   -2.9871562    1.5410596    1.6239261 
     436   -2.9871562    1.5410596     1.584289 
Loop time of 3.59104e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.35915150721284
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.80079861066407
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.04367139934398
variable        y0 equal ${yi}
variable        y0 equal 0.847485883939594

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.04032180904247
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.814143725145191
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     436   -2.9871562    1.5410596     1.584289 
     437   -2.9871562    1.5410596    1.5622263 
Loop time of 3.59587e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.04367139934398
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.847485883939594
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.78632356444484
variable        y0 equal ${yi}
variable        y0 equal 2.7753891822944

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.74575917044765
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.79918503733972
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     437   -2.9871562    1.5410596    1.5622263 
     438   -2.9871562    1.5410596    1.5456266 
Loop time of 3.55454e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.78632356444484
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.7753891822944
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 6.9320023683612
variable        y0 equal ${yi}
variable        y0 equal 2.82359918328622

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.96972704210922
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.72406321736673
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     438   -2.9871562    1.5410596    1.5456266 
     439   -2.9871562    1.5410596    1.5514606 
Loop time of 3.57914e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 6.9320023683612
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.82359918328622
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.73468725640765
variable        y0 equal ${yi}
variable        y0 equal 2.72136272164681

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.8091578241109
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.75739406319954
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     439   -2.9871562    1.5410596    1.5514606 
     440   -2.9871562    1.5410596    1.0943513 
Loop time of 3.49936e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 1.09435129826488
variable naccept equal ${increment}
variable naccept equal 122

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 8.94868864733727
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.52761803783472
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     440   -2.9871562    1.0943513    1.0943513 
     441   -2.9871562    1.0943513    1.1278569 
Loop time of 3.66492e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.03154995162041
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.4676475397497
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 8.9332001419738
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.43242098011072
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     441   -2.9871562    1.0943513    1.1278569 
     442   -2.9871562    1.0943513    1.1613445 
Loop time of 3.55161e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.03154995162041
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.4676475397497
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.85629137078409
variable        y0 equal ${yi}
variable        y0 equal 8.45065544761714

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.89868882218485
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.47161971248683
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     442   -2.9871562    1.0943513    1.1613445 
     443   -2.9871562    1.0943513    1.1055167 
Loop time of 3.7082e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.85629137078409
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.45065544761714
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.17055683730937
variable        y0 equal ${yi}
variable        y0 equal 6.38234023586741

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.16249499915935
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.43196247354975
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     443   -2.9871562    1.0943513    1.1055167 
     444   -2.9871562    1.0943513   0.96312914 
Loop time of 3.55639e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.963129135164766
variable naccept equal ${increment}
variable naccept equal 123

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.258966393462
variable        y0 equal ${yi}
variable        y0 equal 3.90735419554841

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.34452852725106
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.90099815888535
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     444   -2.9871562   0.96312914   0.96312914 
     445   -2.9871562   0.96312914   0.58404597 
Loop time of 3.63733e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.58404596545432
variable naccept equal ${increment}
variable naccept equal 124

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.55075164873373
variable        y0 equal ${yi}
variable        y0 equal 5.74215760176378

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.55792419750463
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.79088512604433
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     445   -2.9871562   0.58404597   0.58404597 
     446   -2.9871562   0.58404597   0.69575764 
Loop time of 3.52908e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.55075164873373
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.74215760176378
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.58045839229051
variable        y0 equal ${yi}
variable        y0 equal 3.7060720638765

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.49991772332612
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.778730578853
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     446   -2.9871562   0.58404597   0.69575764 
     447   -2.9871562   0.58404597   0.59621319 
Loop time of 3.61199e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.58045839229051
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7060720638765
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.85629137078409
variable        y0 equal ${yi}
variable        y0 equal 8.45065544761714

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.86732061425333
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.43319919027385
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     447   -2.9871562   0.58404597   0.59621319 
     448   -2.9871562   0.58404597   0.58357328 
Loop time of 3.556e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.583573276538062
variable naccept equal ${increment}
variable naccept equal 125

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 8.98291936833412
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.38861938633021
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     448   -2.9871562   0.58357328   0.58357328 
     449   -2.9871562   0.58357328    0.6400955 
Loop time of 3.5849e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.03154995162041
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.4676475397497
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.73131323059035
variable        y0 equal ${yi}
variable        y0 equal 4.67710171097681

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.66879590948058
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.68696838969156
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     449   -2.9871562   0.58357328    0.6400955 
     450   -2.9871562   0.58357328   0.58176434 
Loop time of 3.60833e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.581764344057091
variable naccept equal ${increment}
variable naccept equal 126

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.07268907784978
variable        y0 equal ${yi}
variable        y0 equal 3.57763503356111

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.17181414126912
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.63301749987733
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     450   -2.9871562   0.58176434   0.58176434 
     451   -2.9871562   0.58176434   0.54373074 
Loop time of 3.59929e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.54373073933006
variable naccept equal ${increment}
variable naccept equal 127

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.459625037113095
variable        y0 equal ${yi}
variable        y0 equal 8.35511863149699

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.526374812522794
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.40881200946864
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     451   -2.9871562   0.54373074   0.54373074 
     452   -2.9871562   0.54373074   0.64378639 
Loop time of 3.67467e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.459625037113095
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.35511863149699
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.96026352285682
variable        y0 equal ${yi}
variable        y0 equal 6.34972419277659

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.88226810335456
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.2568466378831
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     452   -2.9871562   0.54373074   0.64378639 
     453   -2.9871562   0.54373074   0.61146788 
Loop time of 3.56221e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.96026352285682
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.34972419277659
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.55149480818826
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.30114215936923
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     453   -2.9871562   0.54373074   0.61146788 
     454   -2.9871562   0.54373074   0.63832073 
Loop time of 3.72681e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47168833731729
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.2979036006
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.48322149911786
variable        y0 equal ${yi}
variable        y0 equal 0.0199005961418151

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.49687319198514
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 0.0200155973434447
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     454   -2.9871562   0.54373074   0.63832073 
     455   -2.9871562   0.54373074   0.55198596 
Loop time of 3.56732e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.48322149911786
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 0.0199005961418151
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.8169515065301
variable        y0 equal ${yi}
variable        y0 equal 0.890143771875232

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.84628117600566
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.954261310804218
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     455   -2.9871562   0.54373074   0.55198596 
     456   -2.9871562   0.54373074   0.55402808 
Loop time of 3.60545e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.8169515065301
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.890143771875232
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.35915150721284
variable        y0 equal ${yi}
variable        y0 equal 1.80079861066407

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.3573738344452
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.76061611554688
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     456   -2.9871562   0.54373074   0.55402808 
     457   -2.9871562   0.54373074   0.56345812 
Loop time of 3.63574e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.35915150721284
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.80079861066407
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.20564439932213
variable        y0 equal ${yi}
variable        y0 equal 7.38570181455874

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.17184378544197
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.3747372898128
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     457   -2.9871562   0.54373074   0.56345812 
     458   -2.9871562   0.54373074   0.54830848 
Loop time of 3.5975e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.20564439932213
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.38570181455874
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.17113715130837
variable        y0 equal ${yi}
variable        y0 equal 4.60592613572046

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.13380500990899
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.57058556431696
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     458   -2.9871562   0.54373074   0.54830848 
     459   -2.9871562   0.54373074   0.54286051 
Loop time of 3.62715e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.542860510665415
variable naccept equal ${increment}
variable naccept equal 128

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.3565030340215
variable        y0 equal ${yi}
variable        y0 equal 4.75199741476938

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.4355737689992
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.6644579803364
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     459   -2.9871562   0.54286051   0.54286051 
     460   -2.9871562   0.54286051   0.76177379 
Loop time of 3.59979e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.3565030340215
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.75199741476938
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.13380500990899
variable        y0 equal ${yi}
variable        y0 equal 4.57058556431696

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.10886161047967
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.52547369355127
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     460   -2.9871562   0.54286051   0.76177379 
     461   -2.9871562   0.54286051   0.55669533 
Loop time of 6.27347e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.13380500990899
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.57058556431696
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7151750167065
variable        y0 equal ${yi}
variable        y0 equal 7.47761501398349

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.6460391123944
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.544310120013
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     461   -2.9871562   0.54286051   0.55669533 
     462   -2.9871562   0.54286051    0.6205513 
Loop time of 3.70326e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7151750167065
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.47761501398349
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.71272399583284
variable        y0 equal ${yi}
variable        y0 equal 7.50542391863131

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.67742036738817
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.49725764122271
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     462   -2.9871562   0.54286051    0.6205513 
     463   -2.9871562   0.54286051   0.54107338 
Loop time of 3.62945e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.541073382100302
variable naccept equal ${increment}
variable naccept equal 129

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 6.02990794141284
variable        y0 equal ${yi}
variable        y0 equal 8.29363690532741

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.00514463145724
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.39348559297618
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     463   -2.9871562   0.54107338   0.54107338 
     464   -2.9871562   0.54107338   0.54321031 
Loop time of 3.56009e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 6.02990794141284
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.29363690532741
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.46111556688215
variable        y0 equal ${yi}
variable        y0 equal 1.83501274964875

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.38950794139768
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.91415946862763
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     464   -2.9871562   0.54107338   0.54321031 
     465   -2.9871562   0.54107338   0.53623924 
Loop time of 3.66075e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.536239244822847
variable naccept equal ${increment}
variable naccept equal 130

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03148551582195
variable        y0 equal ${yi}
variable        y0 equal 8.25080559171732

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.12537782787182
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.24411989368494
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     465   -2.9871562   0.53623924   0.53623924 
     466   -2.9871562   0.53623924   0.59460401 
Loop time of 3.68683e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03148551582195
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.25080559171732
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.58451553423178
variable        y0 equal ${yi}
variable        y0 equal 9.24099562871784

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.52583153087866
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.2737044881615
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     466   -2.9871562   0.53623924   0.59460401 
     467   -2.9871562   0.53623924   0.53635385 
Loop time of 3.60263e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.536353849574954
variable naccept equal ${increment}
variable naccept equal 131

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.21161605198594
variable        y0 equal ${yi}
variable        y0 equal 5.67831456606585

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.12201070864411
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.68489750569064
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     467   -2.9871562   0.53635385   0.53635385 
     468   -2.9871562   0.53635385   0.60722657 
Loop time of 4.08701e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.21161605198594
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.67831456606585
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.61686462044497
variable        y0 equal ${yi}
variable        y0 equal 2.97424355717996

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.64307676434298
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.93201261731485
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     468   -2.9871562   0.53635385   0.60722657 
     469   -2.9871562   0.53635385   0.50212453 
Loop time of 3.66377e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.502124532185567
variable naccept equal ${increment}
variable naccept equal 132

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.58045839229051
variable        y0 equal ${yi}
variable        y0 equal 3.7060720638765

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.59997006812516
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.73997877402436
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     469   -2.9871562   0.50212453   0.50212453 
     470   -2.9871562   0.50212453   0.50083036 
Loop time of 3.62395e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.500830362546703
variable naccept equal ${increment}
variable naccept equal 133

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.40689885138589
variable        y0 equal ${yi}
variable        y0 equal 1.95026988170212

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.40723561762887
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 2.02369878671234
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     470   -2.9871562   0.50083036   0.50083036 
     471   -2.9871562   0.50083036   0.54535306 
Loop time of 3.6116e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.40689885138589
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.95026988170212
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.87762415686294
variable        y0 equal ${yi}
variable        y0 equal 4.77079314345286

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.88052521029159
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.76031438464091
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     471   -2.9871562   0.50083036   0.54535306 
     472   -2.9871562   0.50083036   0.48849447 
Loop time of 3.60225e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.488494469929146
variable naccept equal ${increment}
variable naccept equal 134

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.12701019961388
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.38509505905207
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     472   -2.9871562   0.48849447   0.48849447 
     473   -2.9871562   0.48849447   0.51778939 
Loop time of 3.77213e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.03154995162041
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.4676475397497
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.40689885138589
variable        y0 equal ${yi}
variable        y0 equal 1.95026988170212

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.44703354357797
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 2.002840677715
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     473   -2.9871562   0.48849447   0.51778939 
     474   -2.9871562   0.48849447    0.5107958 
Loop time of 3.61798e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.40689885138589
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.95026988170212
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.17226861118175
variable        y0 equal ${yi}
variable        y0 equal 2.81804441186288

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.23366500734187
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.72685755463937
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     474   -2.9871562   0.48849447    0.5107958 
     475   -2.9871562   0.48849447   0.74347537 
Loop time of 3.59815e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.17226861118175
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.81804441186288
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40260913768674
variable        y0 equal ${yi}
variable        y0 equal 5.5414461011191

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.4604710260954
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.5619644517203
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     475   -2.9871562   0.48849447   0.74347537 
     476   -2.9871562   0.48849447   0.63694512 
Loop time of 3.6875e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.40260913768674
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.5414461011191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.70814781346742
variable        y0 equal ${yi}
variable        y0 equal 5.57438946907717

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.68636270919267
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.50392006581026
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     476   -2.9871562   0.48849447   0.63694512 
     477   -2.9871562   0.48849447   0.28168253 
Loop time of 3.64923e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.281682526590605
variable naccept equal ${increment}
variable naccept equal 135

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.8307700681555
variable        y0 equal ${yi}
variable        y0 equal 1.7936737098462

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.84290997265455
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.77562597177094
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     477   -2.9871562   0.28168253   0.28168253 
     478   -2.9871562   0.28168253   0.28584095 
Loop time of 3.58064e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.8307700681555
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.7936737098462
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.00069663245232
variable        y0 equal ${yi}
variable        y0 equal 1.03627063821587

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 8.9314004154876
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.02894386838707
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     478   -2.9871562   0.28168253   0.28584095 
     479   -2.9871562   0.28168253   0.35100156 
Loop time of 3.62836e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.00069663245232
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.03627063821587
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66628361820956
variable        y0 equal ${yi}
variable        y0 equal 8.33030129589137

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.66585860132952
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.32581171907481
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     479   -2.9871562   0.28168253   0.35100156 
     480   -2.9871562   0.28168253    0.2813574 
Loop time of 3.60156e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.281357396582991
variable naccept equal ${increment}
variable naccept equal 136

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 0.999787238437464
variable        y0 equal ${yi}
variable        y0 equal 1.90842210433549

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.06580039580517
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.89073654792375
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     480   -2.9871562    0.2813574    0.2813574 
     481   -2.9871562    0.2813574   0.23698948 
Loop time of 3.67357e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.236989479127406
variable naccept equal ${increment}
variable naccept equal 137

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.8169515065301
variable        y0 equal ${yi}
variable        y0 equal 0.890143771875232

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.82264807740336
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.958740826356738
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     481   -2.9871562   0.23698948   0.23698948 
     482   -2.9871562   0.23698948   0.24815258 
Loop time of 3.68411e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.8169515065301
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.890143771875232
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.28845272976906
variable        y0 equal ${yi}
variable        y0 equal 2.75579466792443

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.37843893487007
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.66737669679024
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     482   -2.9871562   0.23698948   0.24815258 
     483   -2.9871562   0.23698948   0.27934439 
Loop time of 3.53326e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.28845272976906
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.75579466792443
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.3565030340215
variable        y0 equal ${yi}
variable        y0 equal 4.75199741476938

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.2971436027547
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.75506552809641
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     483   -2.9871562   0.23698948   0.27934439 
     484   -2.9871562   0.23698948   0.20424306 
Loop time of 3.68019e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.204243064357698
variable naccept equal ${increment}
variable naccept equal 138

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40260913768674
variable        y0 equal ${yi}
variable        y0 equal 5.5414461011191

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.30495149293805
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.62222276871401
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     484   -2.9871562   0.20424306   0.20424306 
     485   -2.9871562   0.20424306   0.50162762 
Loop time of 3.65068e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.40260913768674
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.5414461011191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.64307676434298
variable        y0 equal ${yi}
variable        y0 equal 2.93201261731485

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.63480706095477
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.83259171220163
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     485   -2.9871562   0.20424306   0.50162762 
     486   -2.9871562   0.20424306   0.17476602 
Loop time of 3.6951e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.174766017307176
variable naccept equal ${increment}
variable naccept equal 139

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.48297205367948
variable        y0 equal ${yi}
variable        y0 equal 7.50014316168093

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.51162417331602
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.48157359686159
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     486   -2.9871562   0.17476602   0.17476602 
     487   -2.9871562   0.17476602   0.17574865 
Loop time of 3.6703e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.48297205367948
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.50014316168093
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.73748982468731
variable        y0 equal ${yi}
variable        y0 equal 4.55758550518916

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.78567172804958
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.64188341254161
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     487   -2.9871562   0.17476602   0.17574865 
     488   -2.9871562   0.17476602   0.16771659 
Loop time of 3.64211e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.167716588767212
variable naccept equal ${increment}
variable naccept equal 140

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2971436027547
variable        y0 equal ${yi}
variable        y0 equal 4.75506552809641

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.3030105475446
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.78844142311976
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     488   -2.9871562   0.16771659   0.16771659 
     489   -2.9871562   0.16771659   0.18681859 
Loop time of 3.51108e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.2971436027547
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.75506552809641
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.24042666911641
variable        y0 equal ${yi}
variable        y0 equal 7.34214617338442

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.27741039752522
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.34604293432497
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     489   -2.9871562   0.16771659   0.18681859 
     490   -2.9871562   0.16771659   0.17302155 
Loop time of 3.57475e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.24042666911641
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.34214617338442
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.16249499915935
variable        y0 equal ${yi}
variable        y0 equal 6.43196247354975

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.20846326946117
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.46824260488978
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     490   -2.9871562   0.16771659   0.17302155 
     491   -2.9871562   0.16771659   0.53767906 
Loop time of 3.68049e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.16249499915935
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.43196247354975
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0780423406621
variable        y0 equal ${yi}
variable        y0 equal 6.58118958012095

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 9.98400547542772
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.5680043174409
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     491   -2.9871562   0.16771659   0.53767906 
     492   -2.9871562   0.16771659   0.16270437 
Loop time of 3.66615e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.162704367995658
variable naccept equal ${increment}
variable naccept equal 141

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.06580039580517
variable        y0 equal ${yi}
variable        y0 equal 1.89073654792375

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 0.970897129375269
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.80583476207322
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     492   -2.9871562   0.16270437   0.16270437 
     493   -2.9871562   0.16270437   0.30398901 
Loop time of 3.56769e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.06580039580517
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.89073654792375
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.66879590948058
variable        y0 equal ${yi}
variable        y0 equal 4.68696838969156

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.75469153125716
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.60578846091196
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     493   -2.9871562   0.16270437   0.30398901 
     494   -2.9871562   0.16270437   0.15541686 
Loop time of 3.56459e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.155416858664796
variable naccept equal ${increment}
variable naccept equal 142

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7151750167065
variable        y0 equal ${yi}
variable        y0 equal 7.47761501398349

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.7380775292569
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.41298324194217
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     494   -2.9871562   0.15541686   0.15541686 
     495   -2.9871562   0.15541686   0.14797854 
Loop time of 3.62982e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.147978538435313
variable naccept equal ${increment}
variable naccept equal 143

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.92978396057426
variable        y0 equal ${yi}
variable        y0 equal 1.00790997337136

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.90921692489921
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.999725504625175
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     495   -2.9871562   0.14797854   0.14797854 
     496   -2.9871562   0.14797854   0.14767857 
Loop time of 3.57482e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.147678571112535
variable naccept equal ${increment}
variable naccept equal 144

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.17226861118175
variable        y0 equal ${yi}
variable        y0 equal 2.81804441186288

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.15983539222576
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.72893139096597
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     496   -2.9871562   0.14767857   0.14767857 
     497   -2.9871562   0.14767857   0.28284909 
Loop time of 3.58863e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.17226861118175
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.81804441186288
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20891928433934
variable        y0 equal ${yi}
variable        y0 equal 5.56093283837038

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.27297086476842
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.46147673075396
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     497   -2.9871562   0.14767857   0.28284909 
     498   -2.9871562   0.14767857   0.17638558 
Loop time of 3.57143e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20891928433934
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56093283837038
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.124600601196289
variable        y0 equal ${yi}
variable        y0 equal 1.65739337585038

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.0416810750961303
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.60789935967988
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     498   -2.9871562   0.14767857   0.17638558 
     499   -2.9871562   0.14767857   0.21316208 
Loop time of 3.60126e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 6 x ${x0}
set atom 6 x 0.124600601196289
  1 settings made for x
set atom $i y ${y0}
set atom 6 y ${y0}
set atom 6 y 1.65739337585038
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.37939815043527
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.34653258648181
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     499   -2.9871562   0.14767857   0.21316208 
     500   -2.9871562   0.14767857   0.17590059 
Loop time of 3.57169e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47168833731729
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.2979036006
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.17226861118175
variable        y0 equal ${yi}
variable        y0 equal 2.81804441186288

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.17199829219676
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.84892342063287
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     500   -2.9871562   0.14767857   0.17590059 
     501   -2.9871562   0.14767857   0.13559675 
Loop time of 3.55659e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.135596754338973
variable naccept equal ${increment}
variable naccept equal 145

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.67742036738817
variable        y0 equal ${yi}
variable        y0 equal 7.49725764122271

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.73354203858797
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.50265548553728
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     501   -2.9871562   0.13559675   0.13559675 
     502   -2.9871562   0.13559675   0.13769013 
Loop time of 3.59784e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.67742036738817
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.49725764122271
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 7.06044206896469
variable        y0 equal ${yi}
variable        y0 equal 6.51616222397318

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.01844290772125
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.41745296255579
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     502   -2.9871562   0.13559675   0.13769013 
     503   -2.9871562   0.13559675   0.20920235 
Loop time of 3.56975e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 7.06044206896469
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.51616222397318
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 9.98400547542772
variable        y0 equal ${yi}
variable        y0 equal 6.5680043174409

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 9.9797257188817
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.49382116333476
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     503   -2.9871562   0.13559675   0.20920235 
     504   -2.9871562   0.13559675   0.15445297 
Loop time of 3.5894e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 9.98400547542772
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.5680043174409
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.66138973116656
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.4159049979597
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     504   -2.9871562   0.13559675   0.15445297 
     505   -2.9871562   0.13559675   0.16197528 
Loop time of 3.72551e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0707942370435
variable        y0 equal ${yi}
variable        y0 equal 8.53329213775691

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.0888815526029
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.55971763052043
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     505   -2.9871562   0.13559675   0.16197528 
     506   -2.9871562   0.13559675   0.17445412 
Loop time of 3.67888e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.0707942370435
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.53329213775691
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.459625037113095
variable        y0 equal ${yi}
variable        y0 equal 8.35511863149699

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.407478077808285
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.38573962368068
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     506   -2.9871562   0.13559675   0.17445412 
     507   -2.9871562   0.13559675   0.20227173 
Loop time of 3.64385e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.459625037113095
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.35511863149699
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.48297205367948
variable        y0 equal ${yi}
variable        y0 equal 7.50014316168093

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.55718231597806
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.45237067070269
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     507   -2.9871562   0.13559675   0.20227173 
     508   -2.9871562   0.13559675   0.15978457 
Loop time of 3.67351e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.48297205367948
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.50014316168093
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.76356770872851
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.31098055757579
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     508   -2.9871562   0.13559675   0.15978457 
     509   -2.9871562   0.13559675   0.15217262 
Loop time of 3.61204e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.87135564604884
variable        y0 equal ${yi}
variable        y0 equal 6.55566048161021

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.88760837832576
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.56175305382243
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     509   -2.9871562   0.13559675   0.15217262 
     510   -2.9871562   0.13559675   0.13723242 
Loop time of 3.66093e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.87135564604884
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.55566048161021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.35915150721284
variable        y0 equal ${yi}
variable        y0 equal 1.80079861066407

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.41967655499192
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.81013465306824
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     510   -2.9871562   0.13559675   0.13723242 
     511   -2.9871562   0.13559675    0.1509323 
Loop time of 3.65933e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.35915150721284
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.80079861066407
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20891928433934
variable        y0 equal ${yi}
variable        y0 equal 5.56093283837038

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.27107258796254
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.51733844225603
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     511   -2.9871562   0.13559675    0.1509323 
     512   -2.9871562   0.13559675   0.14838817 
Loop time of 3.59418e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20891928433934
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56093283837038
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.5265262563877
variable        y0 equal ${yi}
variable        y0 equal 5.69825360720354

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.486388643568
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.77907041256624
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     512   -2.9871562   0.13559675   0.14838817 
     513   -2.9871562   0.13559675   0.18553146 
Loop time of 3.66114e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.5265262563877
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.69825360720354
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.24042666911641
variable        y0 equal ${yi}
variable        y0 equal 7.34214617338442

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.31604666471043
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.3835992249515
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     513   -2.9871562   0.13559675   0.18553146 
     514   -2.9871562   0.13559675   0.14823598 
Loop time of 3.60426e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.24042666911641
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.34214617338442
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.36321673154392
variable        y0 equal ${yi}
variable        y0 equal 1.8523390569455

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.40927301406421
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.84353478334015
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     514   -2.9871562   0.13559675   0.14823598 
     515   -2.9871562   0.13559675   0.15357645 
Loop time of 3.5486e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.36321673154392
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.8523390569455
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.8307700681555
variable        y0 equal ${yi}
variable        y0 equal 1.7936737098462

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.8409528303015
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.7124023833043
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     515   -2.9871562   0.13559675   0.15357645 
     516   -2.9871562   0.13559675   0.15658569 
Loop time of 3.68814e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.8307700681555
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.7936737098462
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.61223844765303
variable        y0 equal ${yi}
variable        y0 equal 5.51154048388201

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.57532680510161
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.57984679882723
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     516   -2.9871562   0.13559675   0.15658569 
     517   -2.9871562   0.13559675   0.16441975 
Loop time of 3.62023e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.61223844765303
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.51154048388201
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.61223844765303
variable        y0 equal ${yi}
variable        y0 equal 5.51154048388201

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.69248719690916
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.4418504351874
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     517   -2.9871562   0.13559675   0.16441975 
     518   -2.9871562   0.13559675   0.23348063 
Loop time of 4.05282e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.61223844765303
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.51154048388201
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.7911317010684
variable        y0 equal ${yi}
variable        y0 equal 8.37118543304499

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.71409361560774
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.40300849594172
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     518   -2.9871562   0.13559675   0.23348063 
     519   -2.9871562   0.13559675   0.14197216 
Loop time of 3.61586e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.7911317010684
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.37118543304499
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3102847699186
variable        y0 equal ${yi}
variable        y0 equal 2.86695545884469

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.2306964043638
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.91160944672921
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     519   -2.9871562   0.13559675   0.14197216 
     520   -2.9871562   0.13559675   0.14997262 
Loop time of 3.58565e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3102847699186
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.86695545884469
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.0567768156419
variable        y0 equal ${yi}
variable        y0 equal 4.66208653801843

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 7.96228054164745
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.70049043053552
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     520   -2.9871562   0.13559675   0.14997262 
     521   -2.9871562   0.13559675    0.1316653 
Loop time of 3.5896e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.131665300071552
variable naccept equal ${increment}
variable naccept equal 146

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 0.995350006419947
variable        y0 equal ${yi}
variable        y0 equal 5.68232610171037

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 1.03084906657391
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.64538028185563
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     521   -2.9871562    0.1316653    0.1316653 
     522   -2.9871562    0.1316653   0.12717804 
Loop time of 3.52543e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.127178036606281
variable naccept equal ${increment}
variable naccept equal 147

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.02796765843078
variable        y0 equal ${yi}
variable        y0 equal 0.90793559144768

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.04322490969345
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.840176923978655
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     522   -2.9871562   0.12717804   0.12717804 
     523   -2.9871562   0.12717804   0.12592396 
Loop time of 3.63316e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal 0.125923962593359
variable naccept equal ${increment}
variable naccept equal 148

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.28159687597963
variable        y0 equal ${yi}
variable        y0 equal 7.4978555950191

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.2124745615265
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.58138563957476
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     523   -2.9871562   0.12592396   0.12592396 
     524   -2.9871562   0.12592396   0.18130749 
Loop time of 3.72266e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.28159687597963
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.4978555950191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.00069663245232
variable        y0 equal ${yi}
variable        y0 equal 1.03627063821587

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.06696871239693
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 0.947883542287678
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     524   -2.9871562   0.12592396   0.18130749 
     525   -2.9871562   0.12592396   0.17025585 
Loop time of 3.6383e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.00069663245232
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.03627063821587
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.04367139934398
variable        y0 equal ${yi}
variable        y0 equal 0.847485883939594

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.13835930227138
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.866527553308338
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     525   -2.9871562   0.12592396   0.17025585 
     526   -2.9871562   0.12592396    0.2471949 
Loop time of 3.5465e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.04367139934398
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.847485883939594
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.13380500990899
variable        y0 equal ${yi}
variable        y0 equal 4.57058556431696

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.07103619296105
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.49827829951212
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     526   -2.9871562   0.12592396    0.2471949 
     527   -2.9871562   0.12592396   0.19623355 
Loop time of 3.61116e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.13380500990899
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.57058556431696
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.16249499915935
variable        y0 equal ${yi}
variable        y0 equal 6.43196247354975

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.12387865184642
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.51902153030863
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     527   -2.9871562   0.12592396   0.19623355 
     528   -2.9871562   0.12592396  -0.12741274 
Loop time of 3.52829e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.127412744264151
variable naccept equal ${increment}
variable naccept equal 149

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 0.899675980407526
variable        y0 equal ${yi}
variable        y0 equal 9.19352722871631

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 0.919852259952356
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.16016710508197
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     528   -2.9871562  -0.12741274  -0.12741274 
     529   -2.9871562  -0.12741274  -0.14731192 
Loop time of 3.57276e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.147311915303588
variable naccept equal ${increment}
variable naccept equal 150

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.48185687222902
variable        y0 equal ${yi}
variable        y0 equal 1.94388798854416

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.42197798648302
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.98083526275223
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     529   -2.9871562  -0.14731192  -0.14731192 
     530   -2.9871562  -0.14731192 -0.044643772 
Loop time of 3.65604e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.48185687222902
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.94388798854416
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.95935798525153
variable        y0 equal ${yi}
variable        y0 equal 8.33042802728708

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.91887720465003
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.32393774904306
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     530   -2.9871562  -0.14731192 -0.044643772 
     531   -2.9871562  -0.14731192   -0.1477092 
Loop time of 3.62956e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.147709195233657
variable naccept equal ${increment}
variable naccept equal 151

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.13380500990899
variable        y0 equal ${yi}
variable        y0 equal 4.57058556431696

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.06494713742287
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.59435745829508
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     531   -2.9871562   -0.1477092   -0.1477092 
     532   -2.9871562   -0.1477092  -0.13550508 
Loop time of 3.5154e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.13380500990899
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.57058556431696
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.14502597490654
variable        y0 equal ${yi}
variable        y0 equal 5.53364494984346

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.12230678240166
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.48569248860078
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     532   -2.9871562   -0.1477092  -0.13550508 
     533   -2.9871562   -0.1477092  -0.12478441 
Loop time of 3.69358e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.14502597490654
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.53364494984346
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.17181414126912
variable        y0 equal ${yi}
variable        y0 equal 3.63301749987733

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.1002936100916
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.69890974326264
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     533   -2.9871562   -0.1477092  -0.12478441 
     534   -2.9871562   -0.1477092  -0.12989761 
Loop time of 3.72958e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.17181414126912
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.63301749987733
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.36321673154392
variable        y0 equal ${yi}
variable        y0 equal 1.8523390569455

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.46120824574985
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.8917407192952
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     534   -2.9871562   -0.1477092  -0.12989761 
     535   -2.9871562   -0.1477092 -0.068451348 
Loop time of 3.62425e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.36321673154392
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.8523390569455
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.49132942357922
variable        y0 equal ${yi}
variable        y0 equal 3.63162182135713

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.53268796602154
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.57816341681611
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     535   -2.9871562   -0.1477092 -0.068451348 
     536   -2.9871562   -0.1477092  0.064118078 
Loop time of 3.64315e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.49132942357922
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.63162182135713
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.90480163056842
variable        y0 equal ${yi}
variable        y0 equal 4.66367782706186

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.89023764092914
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.66609920615122
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     536   -2.9871562   -0.1477092  0.064118078 
     537   -2.9871562   -0.1477092  -0.17167482 
Loop time of 3.53949e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.171674817073665
variable naccept equal ${increment}
variable naccept equal 152

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.28159687597963
variable        y0 equal ${yi}
variable        y0 equal 7.4978555950191

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.33479744274828
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.59009148206973
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     537   -2.9871562  -0.17167482  -0.17167482 
     538   -2.9871562  -0.17167482  -0.12761017 
Loop time of 3.56962e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.28159687597963
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.4978555950191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.13380500990899
variable        y0 equal ${yi}
variable        y0 equal 4.57058556431696

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.23293024022134
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.57251385802195
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     538   -2.9871562  -0.17167482  -0.12761017 
     539   -2.9871562  -0.17167482  -0.16448217 
Loop time of 3.59779e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.13380500990899
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.57058556431696
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.68636270919267
variable        y0 equal ${yi}
variable        y0 equal 5.50392006581026

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.70966960349504
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.50147887413698
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     539   -2.9871562  -0.17167482  -0.16448217 
     540   -2.9871562  -0.17167482  -0.13827534 
Loop time of 3.5597e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.68636270919267
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.50392006581026
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.33182571887532
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.0765301704406739
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     540   -2.9871562  -0.17167482  -0.13827534 
     541   -2.9871562  -0.17167482  -0.14890457 
Loop time of 3.5492e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.67742036738817
variable        y0 equal ${yi}
variable        y0 equal 7.49725764122271

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.61310833850328
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.4074543150928
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     541   -2.9871562  -0.17167482  -0.14890457 
     542   -2.9871562  -0.17167482  -0.17723921 
Loop time of 3.57223e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.177239206004158
variable naccept equal ${increment}
variable naccept equal 153

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.49132942357922
variable        y0 equal ${yi}
variable        y0 equal 3.63162182135713

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.45687854686642
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.62555331750047
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     542   -2.9871562  -0.17723921  -0.17723921 
     543   -2.9871562  -0.17723921 -0.091187971 
Loop time of 3.76565e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.49132942357922
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.63162182135713
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.52583153087866
variable        y0 equal ${yi}
variable        y0 equal 9.2737044881615

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.48242723781836
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.30063560712665
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     543   -2.9871562  -0.17723921 -0.091187971 
     544   -2.9871562  -0.17723921  -0.15739018 
Loop time of 3.57985e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.52583153087866
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.2737044881615
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20891928433934
variable        y0 equal ${yi}
variable        y0 equal 5.56093283837038

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.12885608434239
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.59649734442431
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     544   -2.9871562  -0.17723921  -0.15739018 
     545   -2.9871562  -0.17723921  -0.12851604 
Loop time of 3.48553e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20891928433934
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56093283837038
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.17181414126912
variable        y0 equal ${yi}
variable        y0 equal 3.63301749987733

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.07904746293584
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.68667097849977
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     545   -2.9871562  -0.17723921  -0.12851604 
     546   -2.9871562  -0.17723921  -0.15580254 
Loop time of 3.6549e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.17181414126912
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.63301749987733
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.61223844765303
variable        y0 equal ${yi}
variable        y0 equal 5.51154048388201

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.70371013163206
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.43681349699694
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     546   -2.9871562  -0.17723921  -0.15580254 
     547   -2.9871562  -0.17723921 -0.046457334 
Loop time of 3.58976e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.61223844765303
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.51154048388201
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.38950794139768
variable        y0 equal ${yi}
variable        y0 equal 1.91415946862763

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.44109301963712
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.85579359910554
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     547   -2.9871562  -0.17723921 -0.046457334 
     548   -2.9871562  -0.17723921   -0.1805566 
Loop time of 3.62921e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.180556600313748
variable naccept equal ${increment}
variable naccept equal 154

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.57312639832278
variable        y0 equal ${yi}
variable        y0 equal 6.59234616295328

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.63440697073718
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.61466061607828
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     548   -2.9871562   -0.1805566   -0.1805566 
     549   -2.9871562   -0.1805566  -0.16412047 
Loop time of 3.67576e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.57312639832278
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.59234616295328
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.48322149911786
variable        y0 equal ${yi}
variable        y0 equal 0.0199005961418151

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.52481931844617
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 0.119486713409424
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     549   -2.9871562   -0.1805566  -0.16412047 
     550   -2.9871562   -0.1805566 -0.095167666 
Loop time of 3.70066e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.48322149911786
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 0.0199005961418151
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.8091578241109
variable        y0 equal ${yi}
variable        y0 equal 2.75739406319954

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.78412929732791
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.76655925484993
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     550   -2.9871562   -0.1805566 -0.095167666 
     551   -2.9871562   -0.1805566 -0.038216792 
Loop time of 3.62727e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.8091578241109
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.75739406319954
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.20564439932213
variable        y0 equal ${yi}
variable        y0 equal 7.38570181455874

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.13085464874611
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.32753542986178
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     551   -2.9871562   -0.1805566 -0.038216792 
     552   -2.9871562   -0.1805566   -0.1399059 
Loop time of 3.65815e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.20564439932213
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.38570181455874
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.02162012179547
variable        y0 equal ${yi}
variable        y0 equal 3.71439457697999

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.05080023129635
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.79416375918519
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     552   -2.9871562   -0.1805566   -0.1399059 
     553   -2.9871562   -0.1805566  -0.17559007 
Loop time of 3.65836e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.02162012179547
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.71439457697999
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.6302324012908
variable        y0 equal ${yi}
variable        y0 equal 0.804496832597583

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.722736092010405
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.898674841630786
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     553   -2.9871562   -0.1805566  -0.17559007 
     554   -2.9871562   -0.1805566  -0.17283124 
Loop time of 3.587e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.6302324012908
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.804496832597583
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.00069663245232
variable        y0 equal ${yi}
variable        y0 equal 1.03627063821587

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.08412291724236
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.01486168693337
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     554   -2.9871562   -0.1805566  -0.17283124 
     555   -2.9871562   -0.1805566  -0.19495113 
Loop time of 3.64967e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.194951130254433
variable naccept equal ${increment}
variable naccept equal 155

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.6591813107295
variable        y0 equal ${yi}
variable        y0 equal 2.73446601601937

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.58749472101164
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.80558005544045
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     555   -2.9871562  -0.19495113  -0.19495113 
     556   -2.9871562  -0.19495113  -0.17738043 
Loop time of 3.60881e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.6591813107295
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.73446601601937
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.02162012179547
variable        y0 equal ${yi}
variable        y0 equal 3.71439457697999

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.02855122407132
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.67214816374909
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     556   -2.9871562  -0.19495113  -0.17738043 
     557   -2.9871562  -0.19495113  -0.18273825 
Loop time of 3.55354e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.02162012179547
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.71439457697999
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.88052521029159
variable        y0 equal ${yi}
variable        y0 equal 4.76031438464091

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.78709147253677
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.66414099091456
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     557   -2.9871562  -0.19495113  -0.18273825 
     558   -2.9871562  -0.19495113 -0.050246663 
Loop time of 3.53764e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.88052521029159
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.76031438464091
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.47945046503755
variable        y0 equal ${yi}
variable        y0 equal 9.25402225959628

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.50097684939119
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.26305651176303
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     558   -2.9871562  -0.19495113 -0.050246663 
     559   -2.9871562  -0.19495113   -0.1910531 
Loop time of 3.69541e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.47945046503755
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.25402225959628
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.85119799851057
variable        y0 equal ${yi}
variable        y0 equal 3.81704555316102

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.94058498619673
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.82541955275666
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     559   -2.9871562  -0.19495113   -0.1910531 
     560   -2.9871562  -0.19495113 0.0017318213 
Loop time of 3.66296e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.85119799851057
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.81704555316102
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.19708939551869
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.0317733526229858
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     560   -2.9871562  -0.19495113 0.0017318213 
     561   -2.9871562  -0.19495113  -0.18790329 
Loop time of 3.62331e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.86308897375403
variable        y0 equal ${yi}
variable        y0 equal 4.54561560505792

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.93966022371588
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.61637136095926
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     561   -2.9871562  -0.19495113  -0.18790329 
     562   -2.9871562  -0.19495113  -0.17936875 
Loop time of 3.57687e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.86308897375403
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.54561560505792
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 7.96228054164745
variable        y0 equal ${yi}
variable        y0 equal 4.70049043053552

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 7.91367704271175
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.69087884777948
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     562   -2.9871562  -0.19495113  -0.17936875 
     563   -2.9871562  -0.19495113  -0.19116025 
Loop time of 3.58563e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 7.96228054164745
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.70049043053552
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.84759294946185
variable        y0 equal ${yi}
variable        y0 equal 6.37423569694987

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.81238148171893
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.36623068586817
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     563   -2.9871562  -0.19495113  -0.19116025 
     564   -2.9871562  -0.19495113 -0.094336055 
Loop time of 3.60788e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.84759294946185
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.37423569694987
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.13178624232465
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.54318392601275
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     564   -2.9871562  -0.19495113 -0.094336055 
     565   -2.9871562  -0.19495113  -0.16770584 
Loop time of 3.6305e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.48322149911786
variable        y0 equal ${yi}
variable        y0 equal 0.0199005961418151

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.45700465837384
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 0.0121884107589721
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     565   -2.9871562  -0.19495113  -0.16770584 
     566   -2.9871562  -0.19495113  -0.20355889 
Loop time of 3.63886e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.203558893027337
variable naccept equal ${increment}
variable naccept equal 156

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.7911317010684
variable        y0 equal ${yi}
variable        y0 equal 8.37118543304499

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.78579938610029
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.27193396009501
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     566   -2.9871562  -0.20355889  -0.20355889 
     567   -2.9871562  -0.20355889   -0.1983145 
Loop time of 3.6531e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.7911317010684
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.37118543304499
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.63480706095477
variable        y0 equal ${yi}
variable        y0 equal 2.83259171220163

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.72057427048465
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.84151422950128
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     567   -2.9871562  -0.20355889   -0.1983145 
     568   -2.9871562  -0.20355889  -0.16643642 
Loop time of 6.32667e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.63480706095477
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.83259171220163
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.59997006812516
variable        y0 equal ${yi}
variable        y0 equal 3.73997877402436

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.65351329007569
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.6654220299257
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     568   -2.9871562  -0.20355889  -0.16643642 
     569   -2.9871562  -0.20355889  -0.19366265 
Loop time of 3.7606e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.59997006812516
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.73997877402436
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.13380500990899
variable        y0 equal ${yi}
variable        y0 equal 4.57058556431696

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.14751921612771
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.64353142136499
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     569   -2.9871562  -0.20355889  -0.19366265 
     570   -2.9871562  -0.20355889  -0.19270616 
Loop time of 3.7711e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.13380500990899
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.57058556431696
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0707942370435
variable        y0 equal ${yi}
variable        y0 equal 8.53329213775691

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.0792487625142
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.49438857950267
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     570   -2.9871562  -0.20355889  -0.19270616 
     571   -2.9871562  -0.20355889  -0.21394822 
Loop time of 3.66366e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.213948224107082
variable naccept equal ${increment}
variable naccept equal 157

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03084906657391
variable        y0 equal ${yi}
variable        y0 equal 5.64538028185563

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 1.0912711890524
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.64305448477464
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     571   -2.9871562  -0.21394822  -0.21394822 
     572   -2.9871562  -0.21394822  -0.20778907 
Loop time of 3.57371e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03084906657391
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.64538028185563
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.45700465837384
variable        y0 equal ${yi}
variable        y0 equal 0.0121884107589721

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.40561812320615
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y -0.00772984027862556
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     572   -2.9871562  -0.21394822  -0.20778907 
     573   -2.9871562  -0.21394822  -0.19966659 
Loop time of 3.55804e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.45700465837384
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 0.0121884107589721
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.97784195223495
variable        y0 equal ${yi}
variable        y0 equal 8.32680290855464

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 7.05963371077224
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.27325421489772
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     573   -2.9871562  -0.21394822  -0.19966659 
     574   -2.9871562  -0.21394822  -0.16225999 
Loop time of 3.66113e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.97784195223495
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.32680290855464
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.28159687597963
variable        y0 equal ${yi}
variable        y0 equal 7.4978555950191

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.19039895613405
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.55689593878054
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     574   -2.9871562  -0.21394822  -0.16225999 
     575   -2.9871562  -0.21394822  -0.16351267 
Loop time of 3.59957e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.28159687597963
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.4978555950191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.56912841319162
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.30557818737292
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     575   -2.9871562  -0.21394822  -0.16351267 
     576   -2.9871562  -0.21394822 -0.076427254 
Loop time of 3.65709e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47168833731729
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.2979036006
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 7.06044206896469
variable        y0 equal ${yi}
variable        y0 equal 6.51616222397318

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.05380506792709
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.46833037868967
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     576   -2.9871562  -0.21394822 -0.076427254 
     577   -2.9871562  -0.21394822  -0.17896869 
Loop time of 3.5791e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 7.06044206896469
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.51616222397318
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.17199829219676
variable        y0 equal ${yi}
variable        y0 equal 2.84892342063287

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.12182472347117
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.89803315373758
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     577   -2.9871562  -0.21394822  -0.17896869 
     578   -2.9871562  -0.21394822  -0.21695371 
Loop time of 3.66678e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.216953707940488
variable naccept equal ${increment}
variable naccept equal 158

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.99504664778052
variable        y0 equal ${yi}
variable        y0 equal 2.96102813454965

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 5.05337972282706
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.87817181321481
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     578   -2.9871562  -0.21695371  -0.21695371 
     579   -2.9871562  -0.21695371   0.23946596 
Loop time of 3.60967e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.99504664778052
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.96102813454965
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.60189408539412
variable        y0 equal ${yi}
variable        y0 equal 0.164266347885132

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.68921686886427
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.196412169933319
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     579   -2.9871562  -0.21695371   0.23946596 
     580   -2.9871562  -0.21695371   -0.1774901 
Loop time of 3.74432e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 79 x ${x0}
set atom 79 x 9.60189408539412
  1 settings made for x
set atom $i y ${y0}
set atom 79 y ${y0}
set atom 79 y 0.164266347885132
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40260913768674
variable        y0 equal ${yi}
variable        y0 equal 5.5414461011191

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.45041728416349
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.46185989325243
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     580   -2.9871562  -0.21695371   -0.1774901 
     581   -2.9871562  -0.21695371   -0.1293477 
Loop time of 3.54302e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.40260913768674
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.5414461011191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75469153125716
variable        y0 equal ${yi}
variable        y0 equal 4.60578846091196

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.77634543378783
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.53033906573221
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     581   -2.9871562  -0.21695371   -0.1293477 
     582   -2.9871562  -0.21695371  -0.19724166 
Loop time of 3.55126e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.75469153125716
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.60578846091196
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.12387865184642
variable        y0 equal ${yi}
variable        y0 equal 6.51902153030863

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.1747808515916
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.60585507885447
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     582   -2.9871562  -0.21695371  -0.19724166 
     583   -2.9871562  -0.21695371 -0.080237063 
Loop time of 3.70377e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.12387865184642
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.51902153030863
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3005129698773
variable        y0 equal ${yi}
variable        y0 equal 0.856256540525287

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.3762231353779
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.764285584199756
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     583   -2.9871562  -0.21695371 -0.080237063 
     584   -2.9871562  -0.21695371  -0.20049913 
Loop time of 3.671e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.3005129698773
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.856256540525287
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.7911317010684
variable        y0 equal ${yi}
variable        y0 equal 8.37118543304499

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.7362883706851
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.45156934179362
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     584   -2.9871562  -0.21695371  -0.20049913 
     585   -2.9871562  -0.21695371  -0.20345251 
Loop time of 3.76926e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.7911317010684
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.37118543304499
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.61310833850328
variable        y0 equal ${yi}
variable        y0 equal 7.4074543150928

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.54805468478624
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.36365213718676
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     585   -2.9871562  -0.21695371  -0.20345251 
     586   -2.9871562  -0.21695371   -0.1896466 
Loop time of 3.67784e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.61310833850328
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.4074543150928
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.21161605198594
variable        y0 equal ${yi}
variable        y0 equal 5.67831456606585

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.26632247050019
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.73006771748263
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     586   -2.9871562  -0.21695371   -0.1896466 
     587   -2.9871562  -0.21695371   -0.1663489 
Loop time of 3.60454e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.21161605198594
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.67831456606585
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03148551582195
variable        y0 equal ${yi}
variable        y0 equal 8.25080559171732

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.03852441905834
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.15818823494013
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     587   -2.9871562  -0.21695371   -0.1663489 
     588   -2.9871562  -0.21695371  -0.16163642 
Loop time of 3.66976e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03148551582195
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.25080559171732
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.520989449420835
variable        y0 equal ${yi}
variable        y0 equal 4.56744662875101

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.533120890060331
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.48093705529138
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     588   -2.9871562  -0.21695371  -0.16163642 
     589   -2.9871562  -0.21695371 -0.018955298 
Loop time of 3.54217e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.520989449420835
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.56744662875101
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.8307700681555
variable        y0 equal ${yi}
variable        y0 equal 1.7936737098462

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.7916060018408
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.78030420920915
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     589   -2.9871562  -0.21695371 -0.018955298 
     590   -2.9871562  -0.21695371  -0.21718506 
Loop time of 3.64042e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.217185061494722
variable naccept equal ${increment}
variable naccept equal 159

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.36321673154392
variable        y0 equal ${yi}
variable        y0 equal 1.8523390569455

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.44090472220936
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.75410437963074
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     590   -2.9871562  -0.21718506  -0.21718506 
     591   -2.9871562  -0.21718506  -0.13695157 
Loop time of 3.67507e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.36321673154392
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.8523390569455
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.01600132901222
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.48154278911646
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     591   -2.9871562  -0.21718506  -0.13695157 
     592   -2.9871562  -0.21718506  -0.21393693 
Loop time of 4.10812e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.03154995162041
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.4676475397497
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.78632356444484
variable        y0 equal ${yi}
variable        y0 equal 2.7753891822944

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.70505483666545
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.73103659125665
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     592   -2.9871562  -0.21718506  -0.21393693 
     593   -2.9871562  -0.21718506  -0.18490689 
Loop time of 3.5361e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.78632356444484
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.7753891822944
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.124600601196289
variable        y0 equal ${yi}
variable        y0 equal 1.65739337585038

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.118773663043976
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.59258966825074
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     593   -2.9871562  -0.21718506  -0.18490689 
     594   -2.9871562  -0.21718506  -0.16781462 
Loop time of 3.63371e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 6 x ${x0}
set atom 6 x 0.124600601196289
  1 settings made for x
set atom $i y ${y0}
set atom 6 y ${y0}
set atom 6 y 1.65739337585038
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.42846596955377
variable        y0 equal ${yi}
variable        y0 equal 9.23166983831256

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.37111687182504
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.18519298541873
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     594   -2.9871562  -0.21718506  -0.16781462 
     595   -2.9871562  -0.21718506   -0.1679099 
Loop time of 3.73866e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.42846596955377
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.23166983831256
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.76286459444639
variable        y0 equal ${yi}
variable        y0 equal 7.58744383182787

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.71003035782453
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.4907858523395
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     595   -2.9871562  -0.21718506   -0.1679099 
     596   -2.9871562  -0.21718506  -0.22896196 
Loop time of 3.60989e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.228961961651723
variable naccept equal ${increment}
variable naccept equal 160

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.63595545449678
variable        y0 equal ${yi}
variable        y0 equal 0.131007170677185

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.60445083537523
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.222389495372772
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     596   -2.9871562  -0.22896196  -0.22896196 
     597   -2.9871562  -0.22896196 -0.029990125 
Loop time of 3.69235e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.63595545449678
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.131007170677185
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.13380500990899
variable        y0 equal ${yi}
variable        y0 equal 4.57058556431696

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.1493705244735
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.58995101803705
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     597   -2.9871562  -0.22896196 -0.029990125 
     598   -2.9871562  -0.22896196  -0.23162758 
Loop time of 3.65157e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.231627582681613
variable naccept equal ${increment}
variable naccept equal 161

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.42846596955377
variable        y0 equal ${yi}
variable        y0 equal 9.23166983831256

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.36941315650064
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.27226007688373
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     598   -2.9871562  -0.23162758  -0.23162758 
     599   -2.9871562  -0.23162758  -0.17092814 
Loop time of 3.68904e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.42846596955377
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.23166983831256
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.86732061425333
variable        y0 equal ${yi}
variable        y0 equal 8.43319919027385

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.78110160151606
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.41175454773006
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     599   -2.9871562  -0.23162758  -0.17092814 
     600   -2.9871562  -0.23162758  -0.22882378 
Loop time of 3.6141e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.86732061425333
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.43319919027385
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.7506712782361
variable        y0 equal ${yi}
variable        y0 equal 0.968768938291401

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.76630756735582
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 1.05104806016716
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     600   -2.9871562  -0.23162758  -0.22882378 
     601   -2.9871562  -0.23162758  -0.19532332 
Loop time of 3.58293e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.7506712782361
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.968768938291401
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.7355564435177
variable        y0 equal ${yi}
variable        y0 equal 9.16062856424182

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.7663984616451
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.18897468555301
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     601   -2.9871562  -0.23162758  -0.19532332 
     602   -2.9871562  -0.23162758   -0.2275042 
Loop time of 3.6375e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.7355564435177
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.16062856424182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.96026352285682
variable        y0 equal ${yi}
variable        y0 equal 6.34972419277659

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.99953915714561
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.41183045641413
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     602   -2.9871562  -0.23162758   -0.2275042 
     603   -2.9871562  -0.23162758  -0.17538641 
Loop time of 3.68184e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.96026352285682
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.34972419277659
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.40689885138589
variable        y0 equal ${yi}
variable        y0 equal 1.95026988170212

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.39082376479226
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 2.03846066377228
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     603   -2.9871562  -0.23162758  -0.17538641 
     604   -2.9871562  -0.23162758  -0.16576863 
Loop time of 3.71494e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.40689885138589
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.95026988170212
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.48185687222902
variable        y0 equal ${yi}
variable        y0 equal 1.94388798854416

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.50993915954057
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.85850640914505
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     604   -2.9871562  -0.23162758  -0.16576863 
     605   -2.9871562  -0.23162758  -0.24030966 
Loop time of 3.70723e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.240309656776366
variable naccept equal ${increment}
variable naccept equal 162

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.73087401588393
variable        y0 equal ${yi}
variable        y0 equal 1.09745431731972

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.78804708917571
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.04433018754753
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     605   -2.9871562  -0.24030966  -0.24030966 
     606   -2.9871562  -0.24030966  -0.25890181 
Loop time of 3.58895e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.258901809683786
variable naccept equal ${increment}
variable naccept equal 163

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.459625037113095
variable        y0 equal ${yi}
variable        y0 equal 8.35511863149699

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.465849562087918
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.39330973543223
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     606   -2.9871562  -0.25890181  -0.25890181 
     607   -2.9871562  -0.25890181  -0.18807038 
Loop time of 3.68806e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.459625037113095
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.35511863149699
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.42271354038488
variable        y0 equal ${yi}
variable        y0 equal 7.45066014852786

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.37975622255575
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.35799701538348
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     607   -2.9871562  -0.25890181  -0.18807038 
     608   -2.9871562  -0.25890181  -0.17242661 
Loop time of 3.72005e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.42271354038488
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.45066014852786
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.04212040860645
variable        y0 equal ${yi}
variable        y0 equal 0.854861756074756

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 6.07710559327594
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.761804362047046
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     608   -2.9871562  -0.25890181  -0.17242661 
     609   -2.9871562  -0.25890181  -0.17260049 
Loop time of 3.67931e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 6.04212040860645
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.854861756074756
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.61223844765303
variable        y0 equal ${yi}
variable        y0 equal 5.51154048388201

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.63029257534621
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.47097952311236
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     609   -2.9871562  -0.25890181  -0.17260049 
     610   -2.9871562  -0.25890181    -0.251729 
Loop time of 3.5799e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.61223844765303
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.51154048388201
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.52583153087866
variable        y0 equal ${yi}
variable        y0 equal 9.2737044881615

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.62012595970404
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.33640138614505
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     610   -2.9871562  -0.25890181    -0.251729 
     611   -2.9871562  -0.25890181  -0.20421315 
Loop time of 3.51656e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.52583153087866
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.2737044881615
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 6.02990794141284
variable        y0 equal ${yi}
variable        y0 equal 8.29363690532741

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.0321084852933
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.24870762743053
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     611   -2.9871562  -0.25890181  -0.20421315 
     612   -2.9871562  -0.25890181  -0.23790666 
Loop time of 3.6066e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 6.02990794141284
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.29363690532741
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.90921692489921
variable        y0 equal ${yi}
variable        y0 equal 0.999725504625175

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 5.00553148626625
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.993754549730155
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     612   -2.9871562  -0.25890181  -0.23790666 
     613   -2.9871562  -0.25890181  -0.25623288 
Loop time of 3.72631e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.90921692489921
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.999725504625175
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03084906657391
variable        y0 equal ${yi}
variable        y0 equal 5.64538028185563

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 1.07571211178952
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.65777299349503
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     613   -2.9871562  -0.25890181  -0.25623288 
     614   -2.9871562  -0.25890181  -0.25496829 
Loop time of 3.60425e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03084906657391
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.64538028185563
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.21161605198594
variable        y0 equal ${yi}
variable        y0 equal 5.67831456606585

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.21192237217637
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.74161645119387
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     614   -2.9871562  -0.25890181  -0.25496829 
     615   -2.9871562  -0.25890181  -0.17617223 
Loop time of 3.58545e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.21161605198594
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.67831456606585
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.71569595535231
variable        y0 equal ${yi}
variable        y0 equal 6.41266182199946

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.70583290059996
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.50101393000117
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     615   -2.9871562  -0.25890181  -0.17617223 
     616   -2.9871562  -0.25890181  -0.25847443 
Loop time of 3.78441e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.71569595535231
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.41266182199946
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.86732061425333
variable        y0 equal ${yi}
variable        y0 equal 8.43319919027385

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.80038117686396
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.51535864986476
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     616   -2.9871562  -0.25890181  -0.25847443 
     617   -2.9871562  -0.25890181  -0.23587445 
Loop time of 3.63839e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.86732061425333
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.43319919027385
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.387799485126401
variable        y0 equal ${yi}
variable        y0 equal 6.49517389074793

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.471242232719327
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.49353084103098
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     617   -2.9871562  -0.25890181  -0.23587445 
     618   -2.9871562  -0.25890181  -0.26675427 
Loop time of 3.61789e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.266754270191201
variable naccept equal ${increment}
variable naccept equal 164

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.87135564604884
variable        y0 equal ${yi}
variable        y0 equal 6.55566048161021

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.84424841920024
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.62774709002009
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     618   -2.9871562  -0.26675427  -0.26675427 
     619   -2.9871562  -0.26675427   -0.2504368 
Loop time of 3.58767e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.87135564604884
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.55566048161021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.89023764092914
variable        y0 equal ${yi}
variable        y0 equal 4.66609920615122

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.84793349463931
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.76595867031977
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     619   -2.9871562  -0.26675427   -0.2504368 
     620   -2.9871562  -0.26675427  -0.11861418 
Loop time of 3.66302e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.89023764092914
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.66609920615122
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.63480706095477
variable        y0 equal ${yi}
variable        y0 equal 2.83259171220163

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.6057202923276
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.87377845021585
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     620   -2.9871562  -0.26675427  -0.11861418 
     621   -2.9871562  -0.26675427  -0.26456248 
Loop time of 3.73837e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.63480706095477
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.83259171220163
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.24042666911641
variable        y0 equal ${yi}
variable        y0 equal 7.34214617338442

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.16051933526555
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.24248009052538
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     621   -2.9871562  -0.26675427  -0.26456248 
     622   -2.9871562  -0.26675427  -0.20961794 
Loop time of 3.61859e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.24042666911641
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.34214617338442
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.59921502947588
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.38590156950053
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     622   -2.9871562  -0.26675427  -0.20961794 
     623   -2.9871562  -0.26675427  -0.25908313 
Loop time of 3.57984e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.8169515065301
variable        y0 equal ${yi}
variable        y0 equal 0.890143771875232

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.84639275590068
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.946412988412708
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     623   -2.9871562  -0.26675427  -0.25908313 
     624   -2.9871562  -0.26675427  -0.26027568 
Loop time of 3.72667e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.8169515065301
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.890143771875232
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 8.96753065306694
variable        y0 equal ${yi}
variable        y0 equal 6.3641386224412

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 8.89802207667381
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.30909802452555
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     624   -2.9871562  -0.26675427  -0.26027568 
     625   -2.9871562  -0.26675427    0.1727203 
Loop time of 3.68795e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 8.96753065306694
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.3641386224412
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.99504664778052
variable        y0 equal ${yi}
variable        y0 equal 2.96102813454965

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.91486918567954
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 3.03624315234521
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     625   -2.9871562  -0.26675427    0.1727203 
     626   -2.9871562  -0.26675427  -0.37706899 
Loop time of 3.65683e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.377068988602875
variable naccept equal ${increment}
variable naccept equal 165

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.459625037113095
variable        y0 equal ${yi}
variable        y0 equal 8.35511863149699

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.471591897407437
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.40089113630351
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     626   -2.9871562  -0.37706899  -0.37706899 
     627   -2.9871562  -0.37706899  -0.28556402 
Loop time of 3.64704e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.459625037113095
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.35511863149699
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.68636270919267
variable        y0 equal ${yi}
variable        y0 equal 5.50392006581026

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.78603100934449
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.48183519785601
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     627   -2.9871562  -0.37706899  -0.28556402 
     628   -2.9871562  -0.37706899   -0.1221096 
Loop time of 3.79111e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.68636270919267
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.50392006581026
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.21161605198594
variable        y0 equal ${yi}
variable        y0 equal 5.67831456606585

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.29747077305528
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.67492594664294
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     628   -2.9871562  -0.37706899   -0.1221096 
     629   -2.9871562  -0.37706899  -0.38195109 
Loop time of 3.69398e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.381951092734855
variable naccept equal ${increment}
variable naccept equal 166

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.14502597490654
variable        y0 equal ${yi}
variable        y0 equal 5.53364494984346

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.18580605427132
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.55704977457719
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     629   -2.9871562  -0.38195109  -0.38195109 
     630   -2.9871562  -0.38195109  -0.38008551 
Loop time of 3.72778e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.14502597490654
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.53364494984346
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.71569595535231
variable        y0 equal ${yi}
variable        y0 equal 6.41266182199946

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.64482000072432
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.43445450798503
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     630   -2.9871562  -0.38195109  -0.38008551 
     631   -2.9871562  -0.38195109  -0.38751669 
Loop time of 3.5739e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.387516686909323
variable naccept equal ${increment}
variable naccept equal 167

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.12182472347117
variable        y0 equal ${yi}
variable        y0 equal 2.89803315373758

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.0832990586648
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.88667256804804
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     631   -2.9871562  -0.38751669  -0.38751669 
     632   -2.9871562  -0.38751669  -0.39314977 
Loop time of 3.65885e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.393149768155685
variable naccept equal ${increment}
variable naccept equal 168

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40260913768674
variable        y0 equal ${yi}
variable        y0 equal 5.5414461011191

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.46366261640454
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.47717411463457
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     632   -2.9871562  -0.39314977  -0.39314977 
     633   -2.9871562  -0.39314977  -0.26488667 
Loop time of 3.62598e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.40260913768674
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.5414461011191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 9.98400547542772
variable        y0 equal ${yi}
variable        y0 equal 6.5680043174409

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 9.88538781442842
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.52210437790385
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     633   -2.9871562  -0.39314977  -0.26488667 
     634   -2.9871562  -0.39314977  -0.35964677 
Loop time of 3.61349e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 9.98400547542772
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.5680043174409
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 8.96753065306694
variable        y0 equal ${yi}
variable        y0 equal 6.3641386224412

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.02579118926079
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.37822083965769
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     634   -2.9871562  -0.39314977  -0.35964677 
     635   -2.9871562  -0.39314977   -0.5124858 
Loop time of 3.66264e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.512485803602374
variable naccept equal ${increment}
variable naccept equal 169

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.12387865184642
variable        y0 equal ${yi}
variable        y0 equal 6.51902153030863

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.16827264427043
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.53969800011149
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     635   -2.9871562   -0.5124858   -0.5124858 
     636   -2.9871562   -0.5124858  -0.45259165 
Loop time of 3.70444e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.12387865184642
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.51902153030863
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.42271354038488
variable        y0 equal ${yi}
variable        y0 equal 7.45066014852786

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.39532217819463
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.41649500456119
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     636   -2.9871562   -0.5124858  -0.45259165 
     637   -2.9871562   -0.5124858  -0.48921182 
Loop time of 3.60321e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.42271354038488
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.45066014852786
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.11292983929025
variable        y0 equal ${yi}
variable        y0 equal 9.24421996581882

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.03891026417123
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 9.24684340465396
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     637   -2.9871562   -0.5124858  -0.48921182 
     638   -2.9871562   -0.5124858  -0.50450495 
Loop time of 3.58875e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.11292983929025
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 9.24421996581882
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.7911317010684
variable        y0 equal ${yi}
variable        y0 equal 8.37118543304499

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.86805122096968
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.47061341919001
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     638   -2.9871562   -0.5124858  -0.50450495 
     639   -2.9871562   -0.5124858  -0.47331951 
Loop time of 3.59512e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.7911317010684
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.37118543304499
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.05522481798029
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.92872233363489
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     639   -2.9871562   -0.5124858  -0.47331951 
     640   -2.9871562   -0.5124858   -0.4769438 
Loop time of 3.66807e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.45700465837384
variable        y0 equal ${yi}
variable        y0 equal 0.0121884107589721

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.38531076112653
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y -0.0565804958343507
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     640   -2.9871562   -0.5124858   -0.4769438 
     641   -2.9871562   -0.5124858  -0.47589119 
Loop time of 3.51556e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.45700465837384
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 0.0121884107589721
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.64482000072432
variable        y0 equal ${yi}
variable        y0 equal 6.43445450798503

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.6435375352664
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.50962585941783
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     641   -2.9871562   -0.5124858  -0.47589119 
     642   -2.9871562   -0.5124858  -0.50143993 
Loop time of 3.7793e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.64482000072432
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.43445450798503
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.59997006812516
variable        y0 equal ${yi}
variable        y0 equal 3.73997877402436

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.60324263730469
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.6603208498491
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     642   -2.9871562   -0.5124858  -0.50143993 
     643   -2.9871562   -0.5124858  -0.48734085 
Loop time of 3.59864e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.59997006812516
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.73997877402436
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.520989449420835
variable        y0 equal ${yi}
variable        y0 equal 4.56744662875101

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.587646217742826
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.54803736561701
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     643   -2.9871562   -0.5124858  -0.48734085 
     644   -2.9871562   -0.5124858  -0.51587405 
Loop time of 3.61898e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.515874049986589
variable naccept equal ${increment}
variable naccept equal 170

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.68636270919267
variable        y0 equal ${yi}
variable        y0 equal 5.50392006581026

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.60553795257036
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.53007482235628
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     644   -2.9871562  -0.51587405  -0.51587405 
     645   -2.9871562  -0.51587405  -0.56284891 
Loop time of 3.55632e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.562848912113662
variable naccept equal ${increment}
variable naccept equal 171

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3005129698773
variable        y0 equal ${yi}
variable        y0 equal 0.856256540525287

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.3884569887181
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.902980502355426
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     645   -2.9871562  -0.56284891  -0.56284891 
     646   -2.9871562  -0.56284891  -0.49585539 
Loop time of 3.57072e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.3005129698773
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.856256540525287
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.6591813107295
variable        y0 equal ${yi}
variable        y0 equal 2.73446601601937

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.68854066331815
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.82532094689706
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     646   -2.9871562  -0.56284891  -0.49585539 
     647   -2.9871562  -0.56284891  -0.55530052 
Loop time of 3.49509e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.6591813107295
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.73446601601937
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.04367139934398
variable        y0 equal ${yi}
variable        y0 equal 0.847485883939594

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.09039217828609
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.754326124894947
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     647   -2.9871562  -0.56284891  -0.55530052 
     648   -2.9871562  -0.56284891  -0.34106184 
Loop time of 3.58651e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.04367139934398
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.847485883939594
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 7.96228054164745
variable        y0 equal ${yi}
variable        y0 equal 4.70049043053552

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.04462984203197
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.64526479596063
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     648   -2.9871562  -0.56284891  -0.34106184 
     649   -2.9871562  -0.56284891  -0.56104128 
Loop time of 3.62729e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 7.96228054164745
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.70049043053552
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03148551582195
variable        y0 equal ${yi}
variable        y0 equal 8.25080559171732

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.08572488426067
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.19859377063807
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     649   -2.9871562  -0.56284891  -0.56104128 
     650   -2.9871562  -0.56284891  -0.52887694 
Loop time of 3.51875e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03148551582195
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.25080559171732
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.06580039580517
variable        y0 equal ${yi}
variable        y0 equal 1.89073654792375

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.04213614781552
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.95328226468629
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     650   -2.9871562  -0.56284891  -0.52887694 
     651   -2.9871562  -0.56284891  -0.55637383 
Loop time of 3.81785e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.06580039580517
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.89073654792375
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.6591813107295
variable        y0 equal ${yi}
variable        y0 equal 2.73446601601937

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.74466399152708
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.74569092961648
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     651   -2.9871562  -0.56284891  -0.55637383 
     652   -2.9871562  -0.56284891  -0.56966751 
Loop time of 3.62612e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.569667509219926
variable naccept equal ${increment}
variable naccept equal 172

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.02579118926079
variable        y0 equal ${yi}
variable        y0 equal 6.37822083965769

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 8.93084345776589
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.29439136520853
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     652   -2.9871562  -0.56966751  -0.56966751 
     653   -2.9871562  -0.56966751  -0.18786675 
Loop time of 3.68233e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.02579118926079
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.37822083965769
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.91887720465003
variable        y0 equal ${yi}
variable        y0 equal 8.32393774904306

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.91711939215003
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.25918798364694
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     653   -2.9871562  -0.56966751  -0.18786675 
     654   -2.9871562  -0.56966751  -0.54329752 
Loop time of 3.68019e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.91887720465003
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.32393774904306
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.14502597490654
variable        y0 equal ${yi}
variable        y0 equal 5.53364494984346

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.18284537235603
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.55002372210222
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     654   -2.9871562  -0.56966751  -0.54329752 
     655   -2.9871562  -0.56966751  -0.56707005 
Loop time of 3.69915e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.14502597490654
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.53364494984346
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.520060713687803
variable        y0 equal ${yi}
variable        y0 equal 2.88988070460657

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.501289709010984
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.91464834185938
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     655   -2.9871562  -0.56966751  -0.56707005 
     656   -2.9871562  -0.56966751  -0.54787438 
Loop time of 3.62674e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.520060713687803
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.88988070460657
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78804708917571
variable        y0 equal ${yi}
variable        y0 equal 1.04433018754753

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.8783095379634
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.14128176759514
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     656   -2.9871562  -0.56966751  -0.54787438 
     657   -2.9871562  -0.56966751  -0.41283932 
Loop time of 6.31065e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.78804708917571
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.04433018754753
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.57312639832278
variable        y0 equal ${yi}
variable        y0 equal 6.59234616295328

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.47409359097262
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.6377294851922
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     657   -2.9871562  -0.56966751  -0.41283932 
     658   -2.9871562  -0.56966751  -0.53237812 
Loop time of 3.63026e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.57312639832278
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.59234616295328
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.57711223203909
variable        y0 equal ${yi}
variable        y0 equal 1.7166861691243

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.54014339287054
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.74339536807602
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     658   -2.9871562  -0.56966751  -0.53237812 
     659   -2.9871562  -0.56966751  -0.59741532 
Loop time of 3.58089e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.59741531866216
variable naccept equal ${increment}
variable naccept equal 173

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.11292983929025
variable        y0 equal ${yi}
variable        y0 equal 9.24421996581882

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.13628898302423
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 9.32685000408023
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     659   -2.9871562  -0.59741532  -0.59741532 
     660   -2.9871562  -0.59741532  -0.59936238 
Loop time of 3.57843e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.599362378440923
variable naccept equal ${increment}
variable naccept equal 174

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.6302324012908
variable        y0 equal ${yi}
variable        y0 equal 0.804496832597583

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.655973048606779
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.861963148820728
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     660   -2.9871562  -0.59936238  -0.59936238 
     661   -2.9871562  -0.59936238  -0.59379411 
Loop time of 3.55411e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.6302324012908
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.804496832597583
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.61223844765303
variable        y0 equal ${yi}
variable        y0 equal 5.51154048388201

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.53345007179854
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.50920685475069
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     661   -2.9871562  -0.59936238  -0.59379411 
     662   -2.9871562  -0.59936238  -0.58873276 
Loop time of 3.53523e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.61223844765303
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.51154048388201
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.6302324012908
variable        y0 equal ${yi}
variable        y0 equal 0.804496832597583

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.562561567226316
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.851799853551715
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     662   -2.9871562  -0.59936238  -0.58873276 
     663   -2.9871562  -0.59936238  -0.55724888 
Loop time of 3.71499e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.6302324012908
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.804496832597583
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.28845272976906
variable        y0 equal ${yi}
variable        y0 equal 2.75579466792443

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.36682274062187
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.84790621968606
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     663   -2.9871562  -0.59936238  -0.55724888 
     664   -2.9871562  -0.59936238  -0.56764091 
Loop time of 3.55072e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.28845272976906
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.75579466792443
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.87135564604884
variable        y0 equal ${yi}
variable        y0 equal 6.55566048161021

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.91447170296794
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.49419892565242
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     664   -2.9871562  -0.59936238  -0.56764091 
     665   -2.9871562  -0.59936238  -0.55432259 
Loop time of 3.63642e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.87135564604884
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.55566048161021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20891928433934
variable        y0 equal ${yi}
variable        y0 equal 5.56093283837038

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.23164621352711
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.49417573158937
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     665   -2.9871562  -0.59936238  -0.55432259 
     666   -2.9871562  -0.59936238  -0.58984566 
Loop time of 4.15785e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20891928433934
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56093283837038
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.89023764092914
variable        y0 equal ${yi}
variable        y0 equal 4.66609920615122

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.88767145831577
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.57754190319941
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     666   -2.9871562  -0.59936238  -0.58984566 
     667   -2.9871562  -0.59936238  -0.42407705 
Loop time of 3.59751e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.89023764092914
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.66609920615122
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.85119799851057
variable        y0 equal ${yi}
variable        y0 equal 3.81704555316102

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.77121166466352
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.72175073189866
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     667   -2.9871562  -0.59936238  -0.42407705 
     668   -2.9871562  -0.59936238  -0.63970788 
Loop time of 3.6656e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.639707878626642
variable naccept equal ${increment}
variable naccept equal 175

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.40689885138589
variable        y0 equal ${yi}
variable        y0 equal 1.95026988170212

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.37039762257653
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.90494084737366
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     668   -2.9871562  -0.63970788  -0.63970788 
     669   -2.9871562  -0.63970788  -0.62452889 
Loop time of 3.70207e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.40689885138589
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.95026988170212
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.52583153087866
variable        y0 equal ${yi}
variable        y0 equal 9.2737044881615

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.55870154936087
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.25253196466296
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     669   -2.9871562  -0.63970788  -0.62452889 
     670   -2.9871562  -0.63970788  -0.64634297 
Loop time of 3.7102e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.646342968834782
variable naccept equal ${increment}
variable naccept equal 176

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.59997006812516
variable        y0 equal ${yi}
variable        y0 equal 3.73997877402436

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.59297168412629
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.83524177832734
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     670   -2.9871562  -0.64634297  -0.64634297 
     671   -2.9871562  -0.64634297  -0.62306897 
Loop time of 3.70232e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.59997006812516
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.73997877402436
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.30548830985585
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.0119012117385865
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     671   -2.9871562  -0.64634297  -0.62306897 
     672   -2.9871562  -0.64634297  -0.64493063 
Loop time of 3.73373e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.40689885138589
variable        y0 equal ${yi}
variable        y0 equal 1.95026988170212

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.50615108727532
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 2.04895848414963
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     672   -2.9871562  -0.64634297  -0.64493063 
     673   -2.9871562  -0.64634297  -0.56296437 
Loop time of 3.77187e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.40689885138589
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.95026988170212
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40260913768674
variable        y0 equal ${yi}
variable        y0 equal 5.5414461011191

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.47476196685697
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.60575511400896
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     673   -2.9871562  -0.64634297  -0.56296437 
     674   -2.9871562  -0.64634297  -0.35255127 
Loop time of 3.59659e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.40260913768674
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.5414461011191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.08412291724236
variable        y0 equal ${yi}
variable        y0 equal 1.01486168693337

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.08931784350426
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 0.926579244840474
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     674   -2.9871562  -0.64634297  -0.35255127 
     675   -2.9871562  -0.64634297  -0.56694616 
Loop time of 3.57025e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.08412291724236
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.01486168693337
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.42271354038488
variable        y0 equal ${yi}
variable        y0 equal 7.45066014852786

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.37543418247472
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.39755385246539
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     675   -2.9871562  -0.64634297  -0.56694616 
     676   -2.9871562  -0.64634297  -0.58951279 
Loop time of 3.65274e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.42271354038488
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.45066014852786
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.42846596955377
variable        y0 equal ${yi}
variable        y0 equal 9.23166983831256

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.39562483548242
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.2234489034447
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     676   -2.9871562  -0.64634297  -0.58951279 
     677   -2.9871562  -0.64634297  -0.62559008 
Loop time of 3.6037e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.42846596955377
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.23166983831256
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.02579118926079
variable        y0 equal ${yi}
variable        y0 equal 6.37822083965769

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.02148798424751
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.28522154823771
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     677   -2.9871562  -0.64634297  -0.62559008 
     678   -2.9871562  -0.64634297  -0.53322031 
Loop time of 3.70665e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.02579118926079
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.37822083965769
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.49132942357922
variable        y0 equal ${yi}
variable        y0 equal 3.63162182135713

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.50259725252057
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.61251451535356
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     678   -2.9871562  -0.64634297  -0.53322031 
     679   -2.9871562  -0.64634297  -0.58967458 
Loop time of 3.6118e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.49132942357922
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.63162182135713
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.04322490969345
variable        y0 equal ${yi}
variable        y0 equal 0.840176923978655

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.07948799410507
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.798687763917772
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     679   -2.9871562  -0.64634297  -0.58967458 
     680   -2.9871562  -0.64634297  -0.62939952 
Loop time of 3.75862e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.04322490969345
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.840176923978655
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.88052521029159
variable        y0 equal ${yi}
variable        y0 equal 4.76031438464091

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.79255947151824
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.74791627282069
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     680   -2.9871562  -0.64634297  -0.62939952 
     681   -2.9871562  -0.64634297  -0.49614504 
Loop time of 3.64831e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.88052521029159
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.76031438464091
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.15250330606804
variable        y0 equal ${yi}
variable        y0 equal 1.91628064296311

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.25064342657433
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 2.00500193021363
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     681   -2.9871562  -0.64634297  -0.49614504 
     682   -2.9871562  -0.64634297  -0.56587434 
Loop time of 3.52866e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.15250330606804
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.91628064296311
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.24042666911641
variable        y0 equal ${yi}
variable        y0 equal 7.34214617338442

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.26681135654012
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.27351664629244
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     682   -2.9871562  -0.64634297  -0.56587434 
     683   -2.9871562  -0.64634297  -0.61444029 
Loop time of 3.55611e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.24042666911641
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.34214617338442
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40260913768674
variable        y0 equal ${yi}
variable        y0 equal 5.5414461011191

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.48228491941358
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.55234136526781
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     683   -2.9871562  -0.64634297  -0.61444029 
     684   -2.9871562  -0.64634297  -0.41934301 
Loop time of 3.57725e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.40260913768674
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.5414461011191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 6.9320023683612
variable        y0 equal ${yi}
variable        y0 equal 2.82359918328622

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 7.02396835365936
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.9046416756759
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     684   -2.9871562  -0.64634297  -0.41934301 
     685   -2.9871562  -0.64634297  -0.55170681 
Loop time of 3.70003e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 6.9320023683612
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.82359918328622
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.06580039580517
variable        y0 equal ${yi}
variable        y0 equal 1.89073654792375

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.07785165627651
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.86409153125352
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     685   -2.9871562  -0.64634297  -0.55170681 
     686   -2.9871562  -0.64634297  -0.64839336 
Loop time of 3.55838e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.648393357587295
variable naccept equal ${increment}
variable naccept equal 177

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.45700465837384
variable        y0 equal ${yi}
variable        y0 equal 0.0121884107589721

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.50605466762448
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y -0.00586678981781013
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     686   -2.9871562  -0.64839336  -0.64839336 
     687   -2.9871562  -0.64839336  -0.62700325 
Loop time of 3.53825e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.45700465837384
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 0.0121884107589721
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.13628898302423
variable        y0 equal ${yi}
variable        y0 equal 9.32685000408023

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.03976981083261
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 9.33679538476794
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     687   -2.9871562  -0.64839336  -0.62700325 
     688   -2.9871562  -0.64839336  -0.63571655 
Loop time of 3.64256e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.13628898302423
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 9.32685000408023
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3005129698773
variable        y0 equal ${yi}
variable        y0 equal 0.856256540525287

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.3595150355359
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.853789492357105
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     688   -2.9871562  -0.64839336  -0.63571655 
     689   -2.9871562  -0.64839336   -0.6380548 
Loop time of 3.56817e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.3005129698773
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.856256540525287
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.520060713687803
variable        y0 equal ${yi}
variable        y0 equal 2.88988070460657

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.44823662797537
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.80794713469843
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     689   -2.9871562  -0.64839336   -0.6380548 
     690   -2.9871562  -0.64839336  -0.60117438 
Loop time of 3.54724e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.520060713687803
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.88988070460657
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75469153125716
variable        y0 equal ${yi}
variable        y0 equal 4.60578846091196

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.75591478546096
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.61056455725595
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     690   -2.9871562  -0.64839336  -0.60117438 
     691   -2.9871562  -0.64839336  -0.64829681 
Loop time of 3.74199e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.648296813940514
variable naccept equal ${increment}
variable naccept equal 178

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7380775292569
variable        y0 equal ${yi}
variable        y0 equal 7.41298324194217

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.8129844744855
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.32202244129443
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     691   -2.9871562  -0.64829681  -0.64829681 
     692   -2.9871562  -0.64829681  -0.59341912 
Loop time of 3.56512e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7380775292569
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41298324194217
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.77121166466352
variable        y0 equal ${yi}
variable        y0 equal 3.72175073189866

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.82254872797605
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.8030103401674
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     692   -2.9871562  -0.64829681  -0.59341912 
     693   -2.9871562  -0.64829681   -0.6304573 
Loop time of 3.5999e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.77121166466352
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.72175073189866
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3005129698773
variable        y0 equal ${yi}
variable        y0 equal 0.856256540525287

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.3545004610081
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.909820838678211
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     693   -2.9871562  -0.64829681   -0.6304573 
     694   -2.9871562  -0.64829681  -0.60351894 
Loop time of 3.66966e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.3005129698773
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.856256540525287
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.45700465837384
variable        y0 equal ${yi}
variable        y0 equal 0.0121884107589721

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.46746646562482
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y -0.0414414882659913
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     694   -2.9871562  -0.64829681  -0.60351894 
     695   -2.9871562  -0.64829681  -0.64842588 
Loop time of 3.5747e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.648425883657589
variable naccept equal ${increment}
variable naccept equal 179

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.89023764092914
variable        y0 equal ${yi}
variable        y0 equal 4.66609920615122

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.98877036530963
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.68616083020136
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     695   -2.9871562  -0.64842588  -0.64842588 
     696   -2.9871562  -0.64842588  -0.38935866 
Loop time of 3.73981e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.89023764092914
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.66609920615122
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.7911317010684
variable        y0 equal ${yi}
variable        y0 equal 8.37118543304499

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.82833671768141
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.35087125219401
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     696   -2.9871562  -0.64842588  -0.38935866 
     697   -2.9871562  -0.64842588  -0.64483099 
Loop time of 3.64545e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.7911317010684
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.37118543304499
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.97784195223495
variable        y0 equal ${yi}
variable        y0 equal 8.32680290855464

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 7.06157044449493
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.28116476453837
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     697   -2.9871562  -0.64842588  -0.64483099 
     698   -2.9871562  -0.64842588  -0.60461091 
Loop time of 3.7849e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.97784195223495
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.32680290855464
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.28845272976906
variable        y0 equal ${yi}
variable        y0 equal 2.75579466792443

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.30125987250359
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.81474125357964
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     698   -2.9871562  -0.64842588  -0.60461091 
     699   -2.9871562  -0.64842588   -0.6399459 
Loop time of 3.66969e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.28845272976906
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.75579466792443
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 7.96228054164745
variable        y0 equal ${yi}
variable        y0 equal 4.70049043053552

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.01594173311092
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.65203656310007
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     699   -2.9871562  -0.64842588   -0.6399459 
     700   -2.9871562  -0.64842588  -0.64927298 
Loop time of 3.71043e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.649272977286453
variable naccept equal ${increment}
variable naccept equal 180

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.02162012179547
variable        y0 equal ${yi}
variable        y0 equal 3.71439457697999

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.10567082484418
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.7027230934633
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     700   -2.9871562  -0.64927298  -0.64927298 
     701   -2.9871562  -0.64927298  -0.67155011 
Loop time of 3.72918e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.671550114859429
variable naccept equal ${increment}
variable naccept equal 181

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.47882331449758
variable        y0 equal ${yi}
variable        y0 equal 3.65898613495958

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.54731318790685
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.75024119181764
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     701   -2.9871562  -0.67155011  -0.67155011 
     702   -2.9871562  -0.67155011   -0.6818929 
Loop time of 3.76753e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.681892897477311
variable naccept equal ${increment}
variable naccept equal 182

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.12387865184642
variable        y0 equal ${yi}
variable        y0 equal 6.51902153030863

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.11147080062724
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.42885595098963
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     702   -2.9871562   -0.6818929   -0.6818929 
     703   -2.9871562   -0.6818929  -0.60911436 
Loop time of 3.63032e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.12387865184642
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.51902153030863
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0310238718986788
variable        y0 equal ${yi}
variable        y0 equal 3.80844516320359

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x -0.0321395635604582
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.86208486123215
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     703   -2.9871562   -0.6818929  -0.60911436 
     704   -2.9871562   -0.6818929  -0.65383076 
Loop time of 3.58651e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 0.0310238718986788
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.80844516320359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.64482000072432
variable        y0 equal ${yi}
variable        y0 equal 6.43445450798503

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.57099532087279
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.43010357157222
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     704   -2.9871562   -0.6818929  -0.65383076 
     705   -2.9871562   -0.6818929  -0.66608558 
Loop time of 3.60596e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.64482000072432
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.43445450798503
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.90921692489921
variable        y0 equal ${yi}
variable        y0 equal 0.999725504625175

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.81721263765632
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 1.02294437478814
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     705   -2.9871562   -0.6818929  -0.66608558 
     706   -2.9871562   -0.6818929  -0.62221209 
Loop time of 3.68147e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.90921692489921
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.999725504625175
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.71003035782453
variable        y0 equal ${yi}
variable        y0 equal 7.4907858523395

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.797047870146
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.39519510593676
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     706   -2.9871562   -0.6818929  -0.62221209 
     707   -2.9871562   -0.6818929  -0.48131522 
Loop time of 3.63369e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 99 x ${x0}
set atom 99 x 9.71003035782453
  1 settings made for x
set atom $i y ${y0}
set atom 99 y ${y0}
set atom 99 y 7.4907858523395
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.03374064286405
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.50698196020388
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     707   -2.9871562   -0.6818929  -0.48131522 
     708   -2.9871562   -0.6818929  -0.67877768 
Loop time of 3.66256e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.459625037113095
variable        y0 equal ${yi}
variable        y0 equal 8.35511863149699

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.444242735305691
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.30422124780711
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     708   -2.9871562   -0.6818929  -0.67877768 
     709   -2.9871562   -0.6818929  -0.72211806 
Loop time of 3.62569e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.722118062886096
variable naccept equal ${increment}
variable naccept equal 183

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.63480706095477
variable        y0 equal ${yi}
variable        y0 equal 2.83259171220163

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.61315977453967
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.75866485806802
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     709   -2.9871562  -0.72211806  -0.72211806 
     710   -2.9871562  -0.72211806  -0.71864296 
Loop time of 3.65855e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.63480706095477
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.83259171220163
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.20564439932213
variable        y0 equal ${yi}
variable        y0 equal 7.38570181455874

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.21192652622566
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.38165299024844
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     710   -2.9871562  -0.72211806  -0.71864296 
     711   -2.9871562  -0.72211806  -0.72092864 
Loop time of 3.6209e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.20564439932213
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.38570181455874
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.24042666911641
variable        y0 equal ${yi}
variable        y0 equal 7.34214617338442

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.28278804778615
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.29470926847719
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     711   -2.9871562  -0.72211806  -0.72092864 
     712   -2.9871562  -0.72211806  -0.69503294 
Loop time of 3.54749e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.24042666911641
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.34214617338442
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20891928433934
variable        y0 equal ${yi}
variable        y0 equal 5.56093283837038

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.25857398271123
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.52703098004061
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     712   -2.9871562  -0.72211806  -0.69503294 
     713   -2.9871562  -0.72211806    -0.719692 
Loop time of 3.67824e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20891928433934
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56093283837038
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.3073891115101
variable        y0 equal ${yi}
variable        y0 equal 5.46609456484514

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.24094513176996
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.36807242577272
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     713   -2.9871562  -0.72211806    -0.719692 
     714   -2.9871562  -0.72211806 -0.085058865 
Loop time of 3.66241e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.3073891115101
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.46609456484514
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.90921692489921
variable        y0 equal ${yi}
variable        y0 equal 0.999725504625175

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.87082346319496
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.983593209493492
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     714   -2.9871562  -0.72211806 -0.085058865 
     715   -2.9871562  -0.72211806  -0.72168401 
Loop time of 4.14675e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.721684009289683
variable naccept equal ${increment}
variable naccept equal 184

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.36321673154392
variable        y0 equal ${yi}
variable        y0 equal 1.8523390569455

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.45228423833408
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.8148829855687
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     715   -2.9871562  -0.72168401  -0.72168401 
     716   -2.9871562  -0.72168401  -0.65918541 
Loop time of 3.69647e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.36321673154392
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.8523390569455
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.60553795257036
variable        y0 equal ${yi}
variable        y0 equal 5.53007482235628

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.65315091767732
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.62708901112276
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     716   -2.9871562  -0.72168401  -0.65918541 
     717   -2.9871562  -0.72168401  -0.51386499 
Loop time of 3.6227e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.60553795257036
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.53007482235628
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.48297205367948
variable        y0 equal ${yi}
variable        y0 equal 7.50014316168093

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.42738548913862
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.45820632305407
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     717   -2.9871562  -0.72168401  -0.51386499 
     718   -2.9871562  -0.72168401  -0.74943969 
Loop time of 3.48902e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.749439686923201
variable naccept equal ${increment}
variable naccept equal 185

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2971436027547
variable        y0 equal ${yi}
variable        y0 equal 4.75506552809641

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.3963077787419
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.75067938918039
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     718   -2.9871562  -0.74943969  -0.74943969 
     719   -2.9871562  -0.74943969  -0.71792202 
Loop time of 3.55088e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.2971436027547
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.75506552809641
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.72307140151149
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.59792137497829
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     719   -2.9871562  -0.74943969  -0.71792202 
     720   -2.9871562  -0.74943969  -0.73284317 
Loop time of 3.67959e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7380775292569
variable        y0 equal ${yi}
variable        y0 equal 7.41298324194217

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.7833730776959
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.32231045093799
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     720   -2.9871562  -0.74943969  -0.73284317 
     721   -2.9871562  -0.74943969  -0.71964145 
Loop time of 3.65562e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7380775292569
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41298324194217
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.6302324012908
variable        y0 equal ${yi}
variable        y0 equal 0.804496832597583

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.602409358421232
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.791764386403888
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     721   -2.9871562  -0.74943969  -0.71964145 
     722   -2.9871562  -0.74943969  -0.74544195 
Loop time of 3.65633e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.6302324012908
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.804496832597583
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03148551582195
variable        y0 equal ${yi}
variable        y0 equal 8.25080559171732

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.10250355600216
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.33475932992991
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     722   -2.9871562  -0.74943969  -0.74544195 
     723   -2.9871562  -0.74943969  -0.73312583 
Loop time of 3.61471e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03148551582195
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.25080559171732
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.20564439932213
variable        y0 equal ${yi}
variable        y0 equal 7.38570181455874

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.29854891935692
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.44766614761614
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     723   -2.9871562  -0.74943969  -0.73312583 
     724   -2.9871562  -0.74943969  -0.72633527 
Loop time of 3.52884e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.20564439932213
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.38570181455874
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.42738548913862
variable        y0 equal ${yi}
variable        y0 equal 7.45820632305407

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.46994961896803
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.37816305485033
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     724   -2.9871562  -0.74943969  -0.72633527 
     725   -2.9871562  -0.74943969  -0.75442437 
Loop time of 3.73983e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.754424370935741
variable naccept equal ${increment}
variable naccept equal 186

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.34452852725106
variable        y0 equal ${yi}
variable        y0 equal 3.90099815888535

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.30785986899453
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.94461702866684
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     725   -2.9871562  -0.75442437  -0.75442437 
     726   -2.9871562  -0.75442437  -0.55808478 
Loop time of 3.54344e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.34452852725106
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.90099815888535
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.89023764092914
variable        y0 equal ${yi}
variable        y0 equal 4.66609920615122

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.83038856942645
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.62046405428812
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     726   -2.9871562  -0.75442437  -0.55808478 
     727   -2.9871562  -0.75442437  -0.79320721 
Loop time of 3.64755e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.793207211795567
variable naccept equal ${increment}
variable naccept equal 187

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.42271354038488
variable        y0 equal ${yi}
variable        y0 equal 7.45066014852786

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.45505593855154
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.39650682535434
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     727   -2.9871562  -0.79320721  -0.79320721 
     728   -2.9871562  -0.79320721  -0.80741829 
Loop time of 3.53288e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.807418291986778
variable naccept equal ${increment}
variable naccept equal 188

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.50993915954057
variable        y0 equal ${yi}
variable        y0 equal 1.85850640914505

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.50628010192338
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.936454562164
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     728   -2.9871562  -0.80741829  -0.80741829 
     729   -2.9871562  -0.80741829  -0.81227877 
Loop time of 3.48073e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.812278767794069
variable naccept equal ${increment}
variable naccept equal 189

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.96026352285682
variable        y0 equal ${yi}
variable        y0 equal 6.34972419277659

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.96714340090095
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.29090753332606
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     729   -2.9871562  -0.81227877  -0.81227877 
     730   -2.9871562  -0.81227877  -0.68691769 
Loop time of 3.56808e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.96026352285682
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.34972419277659
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 9.98400547542772
variable        y0 equal ${yi}
variable        y0 equal 6.5680043174409

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 9.93682994880876
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.54530114666453
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     730   -2.9871562  -0.81227877  -0.68691769 
     731   -2.9871562  -0.81227877  -0.78559905 
Loop time of 3.6409e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 9.98400547542772
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.5680043174409
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.40689885138589
variable        y0 equal ${yi}
variable        y0 equal 1.95026988170212

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.36354865550119
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.96192784688538
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     731   -2.9871562  -0.81227877  -0.78559905 
     732   -2.9871562  -0.81227877  -0.77654789 
Loop time of 3.58291e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.40689885138589
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.95026988170212
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.73072572270519
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.63569530600474
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     732   -2.9871562  -0.81227877  -0.77654789 
     733   -2.9871562  -0.81227877  -0.80002997 
Loop time of 3.64224e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.12387865184642
variable        y0 equal ${yi}
variable        y0 equal 6.51902153030863

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.07640730737544
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.5061425043725
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     733   -2.9871562  -0.81227877  -0.80002997 
     734   -2.9871562  -0.81227877  -0.82195929 
Loop time of 3.6676e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.821959288544281
variable naccept equal ${increment}
variable naccept equal 190

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.87082346319496
variable        y0 equal ${yi}
variable        y0 equal 0.983593209493492

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.86053182720482
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.889302774179314
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     734   -2.9871562  -0.82195929  -0.82195929 
     735   -2.9871562  -0.82195929  -0.83675261 
Loop time of 3.52785e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.836752606193241
variable naccept equal ${increment}
variable naccept equal 191

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.02579118926079
variable        y0 equal ${yi}
variable        y0 equal 6.37822083965769

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 8.97132245022804
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.47151776091089
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     735   -2.9871562  -0.83675261  -0.83675261 
     736   -2.9871562  -0.83675261  -0.80756437 
Loop time of 3.55603e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.02579118926079
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.37822083965769
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.17181414126912
variable        y0 equal ${yi}
variable        y0 equal 3.63301749987733

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.1971442794756
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.55529106421601
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     736   -2.9871562  -0.83675261  -0.80756437 
     737   -2.9871562  -0.83675261  -0.79069457 
Loop time of 3.64792e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.17181414126912
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.63301749987733
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.59997006812516
variable        y0 equal ${yi}
variable        y0 equal 3.73997877402436

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.67839514174882
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.73824497027528
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     737   -2.9871562  -0.83675261  -0.79069457 
     738   -2.9871562  -0.83675261  -0.83688663 
Loop time of 3.52768e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.836886629452944
variable naccept equal ${increment}
variable naccept equal 192

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.7355564435177
variable        y0 equal ${yi}
variable        y0 equal 9.16062856424182

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.8183473070316
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.06649109828799
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     738   -2.9871562  -0.83688663  -0.83688663 
     739   -2.9871562  -0.83688663  -0.52718904 
Loop time of 3.73164e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.7355564435177
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.16062856424182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.28159687597963
variable        y0 equal ${yi}
variable        y0 equal 7.4978555950191

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.23440743763658
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.41649253692889
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     739   -2.9871562  -0.83688663  -0.52718904 
     740   -2.9871562  -0.83688663  -0.80079632 
Loop time of 3.45938e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.28159687597963
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.4978555950191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75591478546096
variable        y0 equal ${yi}
variable        y0 equal 4.61056455725595

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.79489089448882
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.68787734860345
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     740   -2.9871562  -0.83688663  -0.80079632 
     741   -2.9871562  -0.83688663  -0.81076491 
Loop time of 3.61077e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.75591478546096
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.61056455725595
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.84759294946185
variable        y0 equal ${yi}
variable        y0 equal 6.37423569694987

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.8674810047864
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.36184206739894
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     741   -2.9871562  -0.83688663  -0.81076491 
     742   -2.9871562  -0.83688663  -0.86152869 
Loop time of 3.67506e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.861528688214128
variable naccept equal ${increment}
variable naccept equal 193

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 9.98400547542772
variable        y0 equal ${yi}
variable        y0 equal 6.5680043174409

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.007643103983
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.663717324891
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     742   -2.9871562  -0.86152869  -0.86152869 
     743   -2.9871562  -0.86152869  -0.78562501 
Loop time of 3.78198e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 9.98400547542772
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.5680043174409
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.61223844765303
variable        y0 equal ${yi}
variable        y0 equal 5.51154048388201

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.5415570902693
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.57699845974642
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     743   -2.9871562  -0.86152869  -0.78562501 
     744   -2.9871562  -0.86152869   -0.8443393 
Loop time of 3.7053e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.61223844765303
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.51154048388201
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.587646217742826
variable        y0 equal ${yi}
variable        y0 equal 4.54803736561701

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.578324051299955
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.57125561589167
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     744   -2.9871562  -0.86152869   -0.8443393 
     745   -2.9871562  -0.86152869  -0.87830607 
Loop time of 3.60887e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.878306067397213
variable naccept equal ${increment}
variable naccept equal 194

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.8091578241109
variable        y0 equal ${yi}
variable        y0 equal 2.75739406319954

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.74290262420169
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.78184069367745
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     745   -2.9871562  -0.87830607  -0.87830607 
     746   -2.9871562  -0.87830607  -0.73004544 
Loop time of 3.60064e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.8091578241109
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.75739406319954
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 7.06044206896469
variable        y0 equal ${yi}
variable        y0 equal 6.51616222397318

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 6.97703101912186
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.5944516255044
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     746   -2.9871562  -0.87830607  -0.73004544 
     747   -2.9871562  -0.87830607  -0.79542239 
Loop time of 3.50816e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 7.06044206896469
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.51616222397318
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.444242735305691
variable        y0 equal ${yi}
variable        y0 equal 8.30422124780711

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.353394992748165
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.40122522033747
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     747   -2.9871562  -0.87830607  -0.79542239 
     748   -2.9871562  -0.87830607  -0.67556094 
Loop time of 3.69631e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.444242735305691
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.30422124780711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.63480706095477
variable        y0 equal ${yi}
variable        y0 equal 2.83259171220163

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.71592892288943
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.84816629859308
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     748   -2.9871562  -0.87830607  -0.67556094 
     749   -2.9871562  -0.87830607  -0.86818005 
Loop time of 3.68613e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.63480706095477
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.83259171220163
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.61310833850328
variable        y0 equal ${yi}
variable        y0 equal 7.4074543150928

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.68400031485979
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.40458581772113
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     749   -2.9871562  -0.87830607  -0.86818005 
     750   -2.9871562  -0.87830607  -0.87839493 
Loop time of 3.6715e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.878394927351056
variable naccept equal ${increment}
variable naccept equal 195

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.86308897375403
variable        y0 equal ${yi}
variable        y0 equal 4.54561560505792

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.91740828394232
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.63780476206705
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     750   -2.9871562  -0.87839493  -0.87839493 
     751   -2.9871562  -0.87839493  -0.84604465 
Loop time of 3.58339e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.86308897375403
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.54561560505792
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 0.919852259952356
variable        y0 equal ${yi}
variable        y0 equal 9.16016710508197

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 0.921325591403772
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.13441501367419
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     751   -2.9871562  -0.87839493  -0.84604465 
     752   -2.9871562  -0.87839493  -0.87546743 
Loop time of 3.60593e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 0.919852259952356
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.16016710508197
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.78632356444484
variable        y0 equal ${yi}
variable        y0 equal 2.7753891822944

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.79833471099025
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.75330324145654
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     752   -2.9871562  -0.87839493  -0.87546743 
     753   -2.9871562  -0.87839493  -0.87812632 
Loop time of 3.57125e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.878126318447391
variable naccept equal ${increment}
variable naccept equal 196

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.86308897375403
variable        y0 equal ${yi}
variable        y0 equal 4.54561560505792

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.79544342397986
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.56401381844446
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     753   -2.9871562  -0.87812632  -0.87812632 
     754   -2.9871562  -0.87812632  -0.88048812 
Loop time of 3.68215e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.880488116244461
variable naccept equal ${increment}
variable naccept equal 197

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.7355564435177
variable        y0 equal ${yi}
variable        y0 equal 9.16062856424182

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.7549893816166
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.06106489408343
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     754   -2.9871562  -0.88048812  -0.88048812 
     755   -2.9871562  -0.88048812  -0.69453009 
Loop time of 3.59219e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.7355564435177
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.16062856424182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.578324051299955
variable        y0 equal ${yi}
variable        y0 equal 4.57125561589167

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.652843602100278
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.58024310225413
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     755   -2.9871562  -0.88048812  -0.69453009 
     756   -2.9871562  -0.88048812  -0.86707997 
Loop time of 3.44657e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.578324051299955
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.57125561589167
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.91887720465003
variable        y0 equal ${yi}
variable        y0 equal 8.32393774904306

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.88561328291236
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.33791131891305
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     756   -2.9871562  -0.88048812  -0.86707997 
     757   -2.9871562  -0.88048812  -0.87132659 
Loop time of 3.63796e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.91887720465003
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.32393774904306
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.15250330606804
variable        y0 equal ${yi}
variable        y0 equal 1.91628064296311

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.16948064009056
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.84239873073166
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     757   -2.9871562  -0.88048812  -0.87132659 
     758   -2.9871562  -0.88048812  -0.86610902 
Loop time of 3.65271e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.15250330606804
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.91628064296311
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.08412291724236
variable        y0 equal ${yi}
variable        y0 equal 1.01486168693337

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.07293406445534
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 0.960823472249837
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     758   -2.9871562  -0.88048812  -0.86610902 
     759   -2.9871562  -0.88048812  -0.84145788 
Loop time of 3.59804e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.08412291724236
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.01486168693337
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 0.919852259952356
variable        y0 equal ${yi}
variable        y0 equal 9.16016710508197

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 0.933177629310419
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.1395004700455
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     759   -2.9871562  -0.88048812  -0.84145788 
     760   -2.9871562  -0.88048812   -0.8911058 
Loop time of 3.77096e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.891105796544393
variable naccept equal ${increment}
variable naccept equal 198

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.76093413710375
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.36534814752635
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     760   -2.9871562   -0.8911058   -0.8911058 
     761   -2.9871562   -0.8911058  -0.88151404 
Loop time of 3.57941e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.61223844765303
variable        y0 equal ${yi}
variable        y0 equal 5.51154048388201

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.57222292898772
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.48064044659334
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     761   -2.9871562   -0.8911058  -0.88151404 
     762   -2.9871562   -0.8911058  -0.89550749 
Loop time of 3.5802e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.895507488920585
variable naccept equal ${increment}
variable naccept equal 199

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 6.9320023683612
variable        y0 equal ${yi}
variable        y0 equal 2.82359918328622

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.94331956186935
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.73706269236901
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     762   -2.9871562  -0.89550749  -0.89550749 
     763   -2.9871562  -0.89550749  -0.87252789 
Loop time of 3.59128e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 6.9320023683612
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.82359918328622
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 6.02990794141284
variable        y0 equal ${yi}
variable        y0 equal 8.29363690532741

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.0912247296094
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.26275631107387
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     763   -2.9871562  -0.89550749  -0.87252789 
     764   -2.9871562  -0.89550749   -0.8299905 
Loop time of 3.51224e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 6.02990794141284
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.29363690532741
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.79833471099025
variable        y0 equal ${yi}
variable        y0 equal 2.75330324145654

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.74352434197551
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.66470490666726
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     764   -2.9871562  -0.89550749   -0.8299905 
     765   -2.9871562  -0.89550749  -0.81442412 
Loop time of 3.73314e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.79833471099025
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.75330324145654
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.13628898302423
variable        y0 equal ${yi}
variable        y0 equal 9.32685000408023

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.05425347725259
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 9.38058647621005
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     765   -2.9871562  -0.89550749  -0.81442412 
     766   -2.9871562  -0.89550749  -0.86618516 
Loop time of 3.68269e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.13628898302423
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 9.32685000408023
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.13628898302423
variable        y0 equal ${yi}
variable        y0 equal 9.32685000408023

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.06577138344156
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 9.39162204969256
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     766   -2.9871562  -0.89550749  -0.86618516 
     767   -2.9871562  -0.89550749  -0.86189879 
Loop time of 6.41803e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.13628898302423
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 9.32685000408023
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.60553795257036
variable        y0 equal ${yi}
variable        y0 equal 5.53007482235628

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.59045673766557
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.62913839762407
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     767   -2.9871562  -0.89550749  -0.86189879 
     768   -2.9871562  -0.89550749  -0.79022305 
Loop time of 6.10672e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.60553795257036
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.53007482235628
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0792487625142
variable        y0 equal ${yi}
variable        y0 equal 8.49438857950267

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.1260053876897
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.43344125665721
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     768   -2.9871562  -0.89550749  -0.79022305 
     769   -2.9871562  -0.89550749  -0.90437787 
Loop time of 3.73536e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.90437786728004
variable naccept equal ${increment}
variable naccept equal 200

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.06690257231103
variable        y0 equal ${yi}
variable        y0 equal 3.79156183762681

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.0748247806202
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.76523935361039
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     769   -2.9871562  -0.90437787  -0.90437787 
     770   -2.9871562  -0.90437787  -0.90710419 
Loop time of 3.59278e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.907104193980351
variable naccept equal ${increment}
variable naccept equal 201

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.04212040860645
variable        y0 equal ${yi}
variable        y0 equal 0.854861756074756

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 6.12855427224628
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.855967207658618
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     770   -2.9871562  -0.90710419  -0.90710419 
     771   -2.9871562  -0.90710419   -0.8495992 
Loop time of 3.60319e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 6.04212040860645
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.854861756074756
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.04367139934398
variable        y0 equal ${yi}
variable        y0 equal 0.847485883939594

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 7.9753815710435
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.898160131681293
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     771   -2.9871562  -0.90710419   -0.8495992 
     772   -2.9871562  -0.90710419  -0.89309136 
Loop time of 3.6713e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.04367139934398
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.847485883939594
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.20564439932213
variable        y0 equal ${yi}
variable        y0 equal 7.38570181455874

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.30052802006111
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.39147000637316
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     772   -2.9871562  -0.90710419  -0.89309136 
     773   -2.9871562  -0.90710419  -0.87662796 
Loop time of 3.74958e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.20564439932213
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.38570181455874
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.34452852725106
variable        y0 equal ${yi}
variable        y0 equal 3.90099815888535

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.28083096264916
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.87886062426697
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     773   -2.9871562  -0.90710419  -0.87662796 
     774   -2.9871562  -0.90710419  -0.68793831 
Loop time of 3.60516e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.34452852725106
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.90099815888535
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.29747077305528
variable        y0 equal ${yi}
variable        y0 equal 5.67492594664294

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.37499551851961
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.68343353216845
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     774   -2.9871562  -0.90710419  -0.68793831 
     775   -2.9871562  -0.90710419  -0.84658074 
Loop time of 3.61714e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.29747077305528
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.67492594664294
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.5265262563877
variable        y0 equal ${yi}
variable        y0 equal 5.69825360720354

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.5395588834934
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.71024687235552
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     775   -2.9871562  -0.90710419  -0.84658074 
     776   -2.9871562  -0.90710419  -0.91525106 
Loop time of 3.70137e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.91525105900376
variable naccept equal ${increment}
variable naccept equal 202

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.3073891115101
variable        y0 equal ${yi}
variable        y0 equal 5.46609456484514

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.36907261132318
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.55776917879778
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     776   -2.9871562  -0.91525106  -0.91525106 
     777   -2.9871562  -0.91525106  -0.99556332 
Loop time of 3.56117e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.995563319011819
variable naccept equal ${increment}
variable naccept equal 203

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.28159687597963
variable        y0 equal ${yi}
variable        y0 equal 7.4978555950191

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.21182146151277
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.54474647369647
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     777   -2.9871562  -0.99556332  -0.99556332 
     778   -2.9871562  -0.99556332  -0.96352409 
Loop time of 3.59266e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.28159687597963
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.4978555950191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.444242735305691
variable        y0 equal ${yi}
variable        y0 equal 8.30422124780711

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.441471190849209
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.39284392513331
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     778   -2.9871562  -0.99556332  -0.96352409 
     779   -2.9871562  -0.99556332  -0.87446502 
Loop time of 3.6289e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.444242735305691
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.30422124780711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.74466399152708
variable        y0 equal ${yi}
variable        y0 equal 2.74569092961648

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.83403908212614
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.78081728192666
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     779   -2.9871562  -0.99556332  -0.87446502 
     780   -2.9871562  -0.99556332  -0.93759322 
Loop time of 3.51069e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.74466399152708
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.74569092961648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.15250330606804
variable        y0 equal ${yi}
variable        y0 equal 1.91628064296311

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.1253779474865
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.93679951808518
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     780   -2.9871562  -0.99556332  -0.93759322 
     781   -2.9871562  -0.99556332  -0.99148094 
Loop time of 3.74421e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.15250330606804
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.91628064296311
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.87699012080318
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.60829086655543
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     781   -2.9871562  -0.99556332  -0.99148094 
     782   -2.9871562  -0.99556332  -0.94118295 
Loop time of 3.76921e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.24042666911641
variable        y0 equal ${yi}
variable        y0 equal 7.34214617338442

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.32962341069737
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.33623478737139
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     782   -2.9871562  -0.99556332  -0.94118295 
     783   -2.9871562  -0.99556332  -0.95962032 
Loop time of 3.66691e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.24042666911641
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.34214617338442
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.7916060018408
variable        y0 equal ${yi}
variable        y0 equal 1.78030420920915

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.72728868006346
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.79494979760713
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     783   -2.9871562  -0.99556332  -0.95962032 
     784   -2.9871562  -0.99556332  -0.99257488 
Loop time of 3.61496e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.7916060018408
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.78030420920915
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.7916060018408
variable        y0 equal ${yi}
variable        y0 equal 1.78030420920915

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.70863327263471
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.8455588617093
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     784   -2.9871562  -0.99556332  -0.99257488 
     785   -2.9871562  -0.99556332  -0.98992933 
Loop time of 3.47844e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.7916060018408
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.78030420920915
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79544342397986
variable        y0 equal ${yi}
variable        y0 equal 4.56401381844446

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.7260972106391
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.61955509537622
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     785   -2.9871562  -0.99556332  -0.98992933 
     786   -2.9871562  -0.99556332  -0.97582176 
Loop time of 3.58205e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79544342397986
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.56401381844446
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.23798024415532
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.119954383373261
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     786   -2.9871562  -0.99556332  -0.97582176 
     787   -2.9871562  -0.99556332  -0.97542886 
Loop time of 3.69895e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.40760077952463
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.38911068763995
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     787   -2.9871562  -0.99556332  -0.97542886 
     788   -2.9871562  -0.99556332  -0.97722887 
Loop time of 3.70073e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47168833731729
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.2979036006
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.7911317010684
variable        y0 equal ${yi}
variable        y0 equal 8.37118543304499

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.7578687568469
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.39387903131541
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     788   -2.9871562  -0.99556332  -0.97722887 
     789   -2.9871562  -0.99556332  -0.99569035 
Loop time of 3.6771e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.995690348711485
variable naccept equal ${increment}
variable naccept equal 204

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75591478546096
variable        y0 equal ${yi}
variable        y0 equal 4.61056455725595

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.83013777931167
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.60740683430597
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     789   -2.9871562  -0.99569035  -0.99569035 
     790   -2.9871562  -0.99569035  -0.96732888 
Loop time of 3.55568e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.75591478546096
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.61056455725595
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03084906657391
variable        y0 equal ${yi}
variable        y0 equal 5.64538028185563

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 1.0960209401434
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.73421448414521
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     790   -2.9871562  -0.99569035  -0.96732888 
     791   -2.9871562  -0.99569035  -0.96925442 
Loop time of 3.53627e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03084906657391
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.64538028185563
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.40689885138589
variable        y0 equal ${yi}
variable        y0 equal 1.95026988170212

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.33773022412377
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.93099596879547
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     791   -2.9871562  -0.99569035  -0.96925442 
     792   -2.9871562  -0.99569035    -0.935873 
Loop time of 3.59548e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.40689885138589
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.95026988170212
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.17181414126912
variable        y0 equal ${yi}
variable        y0 equal 3.63301749987733

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.19891665935078
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.55148232741487
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     792   -2.9871562  -0.99569035    -0.935873 
     793   -2.9871562  -0.99569035  -0.95250538 
Loop time of 3.66737e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.17181414126912
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.63301749987733
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.15250330606804
variable        y0 equal ${yi}
variable        y0 equal 1.91628064296311

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.16610246340141
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.90517050406998
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     793   -2.9871562  -0.99569035  -0.95250538 
     794   -2.9871562  -0.99569035  -0.99619172 
Loop time of 3.68575e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -0.996191722563386
variable naccept equal ${increment}
variable naccept equal 205

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.01594173311092
variable        y0 equal ${yi}
variable        y0 equal 4.65203656310007

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 7.94988389610149
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.73998791331217
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     794   -2.9871562  -0.99619172  -0.99619172 
     795   -2.9871562  -0.99619172  -0.99455898 
Loop time of 3.66131e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.01594173311092
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.65203656310007
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 0.964478460151491
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.49540052738451
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     795   -2.9871562  -0.99619172  -0.99455898 
     796   -2.9871562  -0.99619172  -0.96754152 
Loop time of 3.69522e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.87135564604884
variable        y0 equal ${yi}
variable        y0 equal 6.55566048161021

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.81246043959742
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.62017238871089
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     796   -2.9871562  -0.99619172  -0.96754152 
     797   -2.9871562  -0.99619172  -0.96118372 
Loop time of 3.67875e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.87135564604884
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.55566048161021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.02579118926079
variable        y0 equal ${yi}
variable        y0 equal 6.37822083965769

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.09822706896813
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.33564282194605
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     797   -2.9871562  -0.99619172  -0.96118372 
     798   -2.9871562  -0.99619172  -0.96230152 
Loop time of 3.65146e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.02579118926079
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.37822083965769
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.91486918567954
variable        y0 equal ${yi}
variable        y0 equal 3.03624315234521

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.89555294155417
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 3.03869023295739
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     798   -2.9871562  -0.99619172  -0.96230152 
     799   -2.9871562  -0.99619172    -1.041318 
Loop time of 3.55735e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.04131801809516
variable naccept equal ${increment}
variable naccept equal 206

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.42846596955377
variable        y0 equal ${yi}
variable        y0 equal 9.23166983831256

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.46553996323663
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.20163835990756
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     799   -2.9871562    -1.041318    -1.041318 
     800   -2.9871562    -1.041318   -1.0529931 
Loop time of 3.6127e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.05299307298069
variable naccept equal ${increment}
variable naccept equal 207

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.88052521029159
variable        y0 equal ${yi}
variable        y0 equal 4.76031438464091

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.81605811396285
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.81006588095591
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     800   -2.9871562   -1.0529931   -1.0529931 
     801   -2.9871562   -1.0529931  -0.94846785 
Loop time of 3.74515e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.88052521029159
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.76031438464091
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75591478546096
variable        y0 equal ${yi}
variable        y0 equal 4.61056455725595

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.76364876230193
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.64057087057992
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     801   -2.9871562   -1.0529931  -0.94846785 
     802   -2.9871562   -1.0529931   -1.0494262 
Loop time of 4.06129e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.75591478546096
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.61056455725595
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3102847699186
variable        y0 equal ${yi}
variable        y0 equal 2.86695545884469

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.2812402490637
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.88736656876901
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     802   -2.9871562   -1.0529931   -1.0494262 
     803   -2.9871562   -1.0529931    -1.050218 
Loop time of 3.65575e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3102847699186
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.86695545884469
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 7.06044206896469
variable        y0 equal ${yi}
variable        y0 equal 6.51616222397318

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.06747253218338
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.46930045620432
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     803   -2.9871562   -1.0529931    -1.050218 
     804   -2.9871562   -1.0529931   -1.0088686 
Loop time of 3.52653e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 7.06044206896469
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.51616222397318
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.8091578241109
variable        y0 equal ${yi}
variable        y0 equal 2.75739406319954

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.8608382340192
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.70200465890266
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     804   -2.9871562   -1.0529931   -1.0088686 
     805   -2.9871562   -1.0529931   -1.0552866 
Loop time of 3.55588e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.05528663855748
variable naccept equal ${increment}
variable naccept equal 208

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.20564439932213
variable        y0 equal ${yi}
variable        y0 equal 7.38570181455874

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.24659141937599
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.32356796589159
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     805   -2.9871562   -1.0552866   -1.0552866 
     806   -2.9871562   -1.0552866    -1.026615 
Loop time of 3.58372e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.20564439932213
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.38570181455874
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.46746646562482
variable        y0 equal ${yi}
variable        y0 equal 9.264607102755

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.43464517990018
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.33144942033618
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     806   -2.9871562   -1.0552866    -1.026615 
     807   -2.9871562   -1.0552866    -1.042308 
Loop time of 3.66477e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.46746646562482
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.264607102755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.83038856942645
variable        y0 equal ${yi}
variable        y0 equal 4.62046405428812

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.81734974343768
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.6230520998852
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     807   -2.9871562   -1.0552866    -1.042308 
     808   -2.9871562   -1.0552866    -1.069065 
Loop time of 3.63443e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.06906500970169
variable naccept equal ${increment}
variable naccept equal 209

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.29747077305528
variable        y0 equal ${yi}
variable        y0 equal 5.67492594664294

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.24974109013292
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.75846054499346
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     808   -2.9871562    -1.069065    -1.069065 
     809   -2.9871562    -1.069065  -0.95929758 
Loop time of 3.59563e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.29747077305528
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.67492594664294
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3102847699186
variable        y0 equal ${yi}
variable        y0 equal 2.86695545884469

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.2354211334249
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.89478276940682
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     809   -2.9871562    -1.069065  -0.95929758 
     810   -2.9871562    -1.069065   -1.0470201 
Loop time of 3.58137e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3102847699186
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.86695545884469
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.444242735305691
variable        y0 equal ${yi}
variable        y0 equal 8.30422124780711

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.404719813266659
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.32394843019541
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     810   -2.9871562    -1.069065   -1.0470201 
     811   -2.9871562    -1.069065   -1.0496136 
Loop time of 3.76999e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.444242735305691
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.30422124780711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.86053182720482
variable        y0 equal ${yi}
variable        y0 equal 0.889302774179314

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.78587727188408
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.907560952413414
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     811   -2.9871562    -1.069065   -1.0496136 
     812   -2.9871562    -1.069065    -1.039095 
Loop time of 3.70771e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.86053182720482
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.889302774179314
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.13628898302423
variable        y0 equal ${yi}
variable        y0 equal 0.0208014130592336

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.13227767387735
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 0.0556135416030873
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     812   -2.9871562    -1.069065    -1.039095 
     813   -2.9871562    -1.069065   -1.0622515 
Loop time of 3.56357e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.13628898302423
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.0208014130592336
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.8608382340192
variable        y0 equal ${yi}
variable        y0 equal 2.70200465890266

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.82762308080188
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.60275520058967
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     813   -2.9871562    -1.069065   -1.0622515 
     814   -2.9871562    -1.069065  -0.81481101 
Loop time of 6.36299e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.8608382340192
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.70200465890266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.10567082484418
variable        y0 equal ${yi}
variable        y0 equal 3.7027230934633

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.18955771048719
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.75241027636659
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     814   -2.9871562    -1.069065  -0.81481101 
     815   -2.9871562    -1.069065  -0.99726495 
Loop time of 3.59219e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.10567082484418
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.7027230934633
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.96026352285682
variable        y0 equal ${yi}
variable        y0 equal 6.34972419277659

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.89262209772407
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.29890985027781
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     815   -2.9871562    -1.069065  -0.99726495 
     816   -2.9871562    -1.069065  -0.98930339 
Loop time of 3.68568e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.96026352285682
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.34972419277659
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.124600601196289
variable        y0 equal ${yi}
variable        y0 equal 1.65739337585038

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.145095777511597
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.72663672349519
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     816   -2.9871562    -1.069065  -0.98930339 
     817   -2.9871562    -1.069065   -1.0770045 
Loop time of 3.53666e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.07700445414868
variable naccept equal ${increment}
variable naccept equal 210

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 0.993867781955538
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.50318948354983
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     817   -2.9871562   -1.0770045   -1.0770045 
     818   -2.9871562   -1.0770045   -1.0605602 
Loop time of 3.54416e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.11935729383326
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.85060728761057
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     818   -2.9871562   -1.0770045   -1.0605602 
     819   -2.9871562   -1.0770045   -1.0753356 
Loop time of 3.55209e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.49132942357922
variable        y0 equal ${yi}
variable        y0 equal 3.63162182135713

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.58191340366269
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.55834942622316
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     819   -2.9871562   -1.0770045   -1.0753356 
     820   -2.9871562   -1.0770045  -0.92372832 
Loop time of 3.78067e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.49132942357922
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.63162182135713
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.50628010192338
variable        y0 equal ${yi}
variable        y0 equal 1.936454562164

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.4891350165886
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.94759384772842
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     820   -2.9871562   -1.0770045  -0.92372832 
     821   -2.9871562   -1.0770045    -1.069466 
Loop time of 3.70174e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.50628010192338
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.936454562164
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.20564439932213
variable        y0 equal ${yi}
variable        y0 equal 7.38570181455874

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.13740766683922
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.29849799003863
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     821   -2.9871562   -1.0770045    -1.069466 
     822   -2.9871562   -1.0770045   -1.0086156 
Loop time of 3.65904e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.20564439932213
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.38570181455874
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.57222292898772
variable        y0 equal ${yi}
variable        y0 equal 5.48064044659334

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.65659552096007
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.5478769654532
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     822   -2.9871562   -1.0770045   -1.0086156 
     823   -2.9871562   -1.0770045   -1.0377873 
Loop time of 3.62674e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.57222292898772
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.48064044659334
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.86732061425333
variable        y0 equal ${yi}
variable        y0 equal 8.43319919027385

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.83084403792505
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.48331345237789
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     823   -2.9871562   -1.0770045   -1.0377873 
     824   -2.9871562   -1.0770045   -1.0725232 
Loop time of 3.53591e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.86732061425333
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.43319919027385
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 0.933177629310419
variable        y0 equal ${yi}
variable        y0 equal 9.1395004700455

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 0.871666601497461
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.10146719920962
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     824   -2.9871562   -1.0770045   -1.0725232 
     825   -2.9871562   -1.0770045  -0.95992516 
Loop time of 3.66391e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 0.933177629310419
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.1395004700455
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.88504674950725
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.73705901259349
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     825   -2.9871562   -1.0770045  -0.95992516 
     826   -2.9871562   -1.0770045   -1.0355379 
Loop time of 3.6057e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.14502597490654
variable        y0 equal ${yi}
variable        y0 equal 5.53364494984346

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.16462363640175
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.49260635321336
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     826   -2.9871562   -1.0770045   -1.0355379 
     827   -2.9871562   -1.0770045   -1.0682287 
Loop time of 3.59952e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.14502597490654
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.53364494984346
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0310238718986788
variable        y0 equal ${yi}
variable        y0 equal 3.80844516320359

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 0.0192462682724276
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.86827208562028
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     827   -2.9871562   -1.0770045   -1.0682287 
     828   -2.9871562   -1.0770045   -1.0322032 
Loop time of 3.55049e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 0.0310238718986788
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.80844516320359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.55075164873373
variable        y0 equal ${yi}
variable        y0 equal 5.74215760176378

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.49922783214819
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.80742725079256
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     828   -2.9871562   -1.0770045   -1.0322032 
     829   -2.9871562   -1.0770045  -0.86493028 
Loop time of 3.60043e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.55075164873373
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.74215760176378
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.68400031485979
variable        y0 equal ${yi}
variable        y0 equal 7.40458581772113

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.75542079368059
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.47740601625705
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     829   -2.9871562   -1.0770045  -0.86493028 
     830   -2.9871562   -1.0770045   -1.0481865 
Loop time of 3.69428e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.68400031485979
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.40458581772113
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.1493705244735
variable        y0 equal ${yi}
variable        y0 equal 4.58995101803705

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.13461420256646
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.65451947802469
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     830   -2.9871562   -1.0770045   -1.0481865 
     831   -2.9871562   -1.0770045   -1.0600103 
Loop time of 3.63908e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.1493705244735
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.58995101803705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.96026352285682
variable        y0 equal ${yi}
variable        y0 equal 6.34972419277659

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.93050993322669
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.34705883995524
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     831   -2.9871562   -1.0770045   -1.0600103 
     832   -2.9871562   -1.0770045   -1.0981841 
Loop time of 3.56807e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.09818413890444
variable naccept equal ${increment}
variable naccept equal 211

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3005129698773
variable        y0 equal ${yi}
variable        y0 equal 0.856256540525287

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.2502878550549
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.816722055185169
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     832   -2.9871562   -1.0981841   -1.0981841 
     833   -2.9871562   -1.0981841   -1.0644705 
Loop time of 3.68417e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.3005129698773
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.856256540525287
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 7.06044206896469
variable        y0 equal ${yi}
variable        y0 equal 6.51616222397318

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.00564221420929
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.58254001871576
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     833   -2.9871562   -1.0981841   -1.0644705 
     834   -2.9871562   -1.0981841   -1.0586023 
Loop time of 3.7289e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 7.06044206896469
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.51616222397318
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.46994961896803
variable        y0 equal ${yi}
variable        y0 equal 7.37816305485033

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.39474039474394
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.46836681690477
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     834   -2.9871562   -1.0981841   -1.0586023 
     835   -2.9871562   -1.0981841   -1.0876391 
Loop time of 3.68914e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.46994961896803
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.37816305485033
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.77554164448864
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.69632823819087
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     835   -2.9871562   -1.0981841   -1.0876391 
     836   -2.9871562   -1.0981841   -1.0974038 
Loop time of 3.55225e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.04322490969345
variable        y0 equal ${yi}
variable        y0 equal 0.840176923978655

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.05742265263244
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.914156409013598
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     836   -2.9871562   -1.0981841   -1.0974038 
     837   -2.9871562   -1.0981841   -1.0828811 
Loop time of 3.55886e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.04322490969345
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.840176923978655
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 7.06044206896469
variable        y0 equal ${yi}
variable        y0 equal 6.51616222397318

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.03900916853592
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.58173864618769
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     837   -2.9871562   -1.0981841   -1.0828811 
     838   -2.9871562   -1.0981841   -1.0635068 
Loop time of 3.68339e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 7.06044206896469
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.51616222397318
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.79833471099025
variable        y0 equal ${yi}
variable        y0 equal 2.75330324145654

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.87348716775066
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.68151926967004
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     838   -2.9871562   -1.0981841   -1.0635068 
     839   -2.9871562   -1.0981841   -1.0833667 
Loop time of 3.58605e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.79833471099025
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.75330324145654
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.08412291724236
variable        y0 equal ${yi}
variable        y0 equal 1.01486168693337

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.01135254818947
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 0.918397124517293
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     839   -2.9871562   -1.0981841   -1.0833667 
     840   -2.9871562   -1.0981841  -0.95564207 
Loop time of 3.59255e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.08412291724236
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.01486168693337
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.57312639832278
variable        y0 equal ${yi}
variable        y0 equal 6.59234616295328

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.55586392760058
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.63701478973856
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     840   -2.9871562   -1.0981841  -0.95564207 
     841   -2.9871562   -1.0981841   -1.0816309 
Loop time of 3.61197e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.57312639832278
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.59234616295328
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20891928433934
variable        y0 equal ${yi}
variable        y0 equal 5.56093283837038

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.2989979362444
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.50923532192903
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     841   -2.9871562   -1.0981841   -1.0816309 
     842   -2.9871562   -1.0981841   -1.0846564 
Loop time of 3.62361e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20891928433934
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56093283837038
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.01594173311092
variable        y0 equal ${yi}
variable        y0 equal 4.65203656310007

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.01394880412914
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.70269989127085
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     842   -2.9871562   -1.0981841   -1.0846564 
     843   -2.9871562   -1.0981841    -1.098849 
Loop time of 3.53514e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.09884902717647
variable naccept equal ${increment}
variable naccept equal 212

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78804708917571
variable        y0 equal ${yi}
variable        y0 equal 1.04433018754753

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.83944294650985
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 0.949097104776229
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     843   -2.9871562    -1.098849    -1.098849 
     844   -2.9871562    -1.098849   -1.0949369 
Loop time of 3.61217e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.78804708917571
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.04433018754753
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.46553996323663
variable        y0 equal ${yi}
variable        y0 equal 9.20163835990756

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.43296188830453
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.25720965373843
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     844   -2.9871562    -1.098849   -1.0949369 
     845   -2.9871562    -1.098849   -1.0869364 
Loop time of 3.58899e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.46553996323663
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.20163835990756
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 6.02990794141284
variable        y0 equal ${yi}
variable        y0 equal 8.29363690532741

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.09129841287128
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.36962209857997
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     845   -2.9871562    -1.098849   -1.0869364 
     846   -2.9871562    -1.098849   -0.9816483 
Loop time of 3.6409e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 6.02990794141284
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.29363690532741
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.79833471099025
variable        y0 equal ${yi}
variable        y0 equal 2.75330324145654

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.78051648656017
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.67612467976907
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     846   -2.9871562    -1.098849   -0.9816483 
     847   -2.9871562    -1.098849   -1.0554867 
Loop time of 3.61655e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.79833471099025
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.75330324145654
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.49132942357922
variable        y0 equal ${yi}
variable        y0 equal 3.63162182135713

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.43214940229321
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.60830506844652
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     847   -2.9871562    -1.098849   -1.0554867 
     848   -2.9871562    -1.098849    -0.785666 
Loop time of 3.78419e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.49132942357922
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.63162182135713
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 9.98400547542772
variable        y0 equal ${yi}
variable        y0 equal 6.5680043174409

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.0265902999898
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.65374482408992
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     848   -2.9871562    -1.098849    -0.785666 
     849   -2.9871562    -1.098849   -1.0515537 
Loop time of 3.59411e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 9.98400547542772
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.5680043174409
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 9.98400547542772
variable        y0 equal ${yi}
variable        y0 equal 6.5680043174409

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.0074291352292
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.63849679962626
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     849   -2.9871562    -1.098849   -1.0515537 
     850   -2.9871562    -1.098849   -1.0613351 
Loop time of 3.63926e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 9.98400547542772
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.5680043174409
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.145095777511597
variable        y0 equal ${yi}
variable        y0 equal 1.72663672349519

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.16318541765213
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.79891386411256
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     850   -2.9871562    -1.098849   -1.0613351 
     851   -2.9871562    -1.098849    -1.085256 
Loop time of 3.75791e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 6 x ${x0}
set atom 6 x 0.145095777511597
  1 settings made for x
set atom $i y ${y0}
set atom 6 y ${y0}
set atom 6 y 1.72663672349519
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.68400031485979
variable        y0 equal ${yi}
variable        y0 equal 7.40458581772113

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.70824613728945
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.35762933817172
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     851   -2.9871562    -1.098849    -1.085256 
     852   -2.9871562    -1.098849   -1.0914449 
Loop time of 3.697e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.68400031485979
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.40458581772113
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.35915150721284
variable        y0 equal ${yi}
variable        y0 equal 1.80079861066407

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.39397816736909
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.7419923105008
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     852   -2.9871562    -1.098849   -1.0914449 
     853   -2.9871562    -1.098849   -1.0845542 
Loop time of 3.55938e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.35915150721284
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.80079861066407
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.145095777511597
variable        y0 equal ${yi}
variable        y0 equal 1.72663672349519

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.112628924846649
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.75601954839296
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     853   -2.9871562    -1.098849   -1.0845542 
     854   -2.9871562    -1.098849   -1.1171499 
Loop time of 3.68251e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.11714994763679
variable naccept equal ${increment}
variable naccept equal 213

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.57799885153551
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.34358396448192
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     854   -2.9871562   -1.1171499   -1.1171499 
     855   -2.9871562   -1.1171499   -1.1104311 
Loop time of 3.54666e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.45505593855154
variable        y0 equal ${yi}
variable        y0 equal 7.39650682535434

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.44025573570501
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.3160576137569
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     855   -2.9871562   -1.1171499   -1.1104311 
     856   -2.9871562   -1.1171499    -1.035935 
Loop time of 3.58104e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.45505593855154
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.39650682535434
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.67839514174882
variable        y0 equal ${yi}
variable        y0 equal 3.73824497027528

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.59171490827027
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.6867305235399
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     856   -2.9871562   -1.1171499    -1.035935 
     857   -2.9871562   -1.1171499   -1.1032432 
Loop time of 4.28721e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.67839514174882
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.73824497027528
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.57222292898772
variable        y0 equal ${yi}
variable        y0 equal 5.48064044659334

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.62075649975417
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.40204758589464
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     857   -2.9871562   -1.1171499   -1.1032432 
     858   -2.9871562   -1.1171499    -1.068134 
Loop time of 4.34009e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.57222292898772
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.48064044659334
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.50628010192338
variable        y0 equal ${yi}
variable        y0 equal 1.936454562164

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.49656952777329
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.88621024272507
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     858   -2.9871562   -1.1171499    -1.068134 
     859   -2.9871562   -1.1171499   -1.1113039 
Loop time of 3.63159e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.50628010192338
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.936454562164
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.46553996323663
variable        y0 equal ${yi}
variable        y0 equal 9.20163835990756

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.42515351294595
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.25242620218127
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     859   -2.9871562   -1.1171499   -1.1113039 
     860   -2.9871562   -1.1171499    -1.101407 
Loop time of 3.63931e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.46553996323663
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.20163835990756
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.8169515065301
variable        y0 equal ${yi}
variable        y0 equal 0.890143771875232

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.86593469897395
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.843550940263599
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     860   -2.9871562   -1.1171499    -1.101407 
     861   -2.9871562   -1.1171499    -1.111927 
Loop time of 3.61909e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.8169515065301
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.890143771875232
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.47945046503755
variable        y0 equal ${yi}
variable        y0 equal 9.25402225959628

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.38134199459764
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.18407176244586
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     861   -2.9871562   -1.1171499    -1.111927 
     862   -2.9871562   -1.1171499   -1.0770826 
Loop time of 3.57005e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.47945046503755
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.25402225959628
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.28159687597963
variable        y0 equal ${yi}
variable        y0 equal 7.4978555950191

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.34037064392778
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.53812233534121
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     862   -2.9871562   -1.1171499   -1.0770826 
     863   -2.9871562   -1.1171499   -1.1084955 
Loop time of 3.73979e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.28159687597963
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.4978555950191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.07640730737544
variable        y0 equal ${yi}
variable        y0 equal 6.5061425043725

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.06081770061351
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.59912495151987
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     863   -2.9871562   -1.1171499   -1.1084955 
     864   -2.9871562   -1.1171499   -1.1468947 
Loop time of 3.58471e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.14689465693565
variable naccept equal ${increment}
variable naccept equal 214

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.34452852725106
variable        y0 equal ${yi}
variable        y0 equal 3.90099815888535

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.37391455887871
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.80258712334763
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     864   -2.9871562   -1.1468947   -1.1468947 
     865   -2.9871562   -1.1468947   -1.2365313 
Loop time of 3.72239e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.23653133965525
variable naccept equal ${increment}
variable naccept equal 215

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75591478546096
variable        y0 equal ${yi}
variable        y0 equal 4.61056455725595

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.79554624755813
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.5882462536709
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     865   -2.9871562   -1.2365313   -1.2365313 
     866   -2.9871562   -1.2365313   -1.2250254 
Loop time of 3.57935e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.75591478546096
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.61056455725595
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.7355564435177
variable        y0 equal ${yi}
variable        y0 equal 9.16062856424182

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.8136220892124
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.2487870763573
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     866   -2.9871562   -1.2365313   -1.2250254 
     867   -2.9871562   -1.2365313   -1.1784781 
Loop time of 3.74442e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.7355564435177
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.16062856424182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.88052521029159
variable        y0 equal ${yi}
variable        y0 equal 4.76031438464091

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.78811935463592
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.74642358178065
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     867   -2.9871562   -1.2365313   -1.1784781 
     868   -2.9871562   -1.2365313   -1.1849961 
Loop time of 3.65946e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.88052521029159
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.76031438464091
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.97784195223495
variable        y0 equal ${yi}
variable        y0 equal 8.32680290855464

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.92541783133194
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.28928664840755
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     868   -2.9871562   -1.2365313   -1.1849961 
     869   -2.9871562   -1.2365313   -1.1867145 
Loop time of 3.72889e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.97784195223495
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.32680290855464
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.71164085188991
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.73676301592753
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     869   -2.9871562   -1.2365313   -1.1867145 
     870   -2.9871562   -1.2365313   -1.2054869 
Loop time of 3.66613e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.578324051299955
variable        y0 equal ${yi}
variable        y0 equal 4.57125561589167

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.586605925956632
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.58906858319208
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     870   -2.9871562   -1.2365313   -1.2054869 
     871   -2.9871562   -1.2365313   -1.2483014 
Loop time of 3.72446e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.24830140823745
variable naccept equal ${increment}
variable naccept equal 216

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.46994961896803
variable        y0 equal ${yi}
variable        y0 equal 7.37816305485033

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.52780090967085
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.36200553503298
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     871   -2.9871562   -1.2483014   -1.2483014 
     872   -2.9871562   -1.2483014   -1.2214957 
Loop time of 3.72234e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.46994961896803
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.37816305485033
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57225463270922
variable        y0 equal ${yi}
variable        y0 equal 4.72659182900353

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.52441205858965
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.78134334439202
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     872   -2.9871562   -1.2483014   -1.2214957 
     873   -2.9871562   -1.2483014    -1.218084 
Loop time of 3.59562e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.57225463270922
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.72659182900353
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.35915150721284
variable        y0 equal ${yi}
variable        y0 equal 1.80079861066407

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.42793486197206
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.83933557651109
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     873   -2.9871562   -1.2483014    -1.218084 
     874   -2.9871562   -1.2483014   -1.2545075 
Loop time of 3.64416e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.25450750586
variable naccept equal ${increment}
variable naccept equal 217

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.13628898302423
variable        y0 equal ${yi}
variable        y0 equal 0.0208014130592336

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.1395422999035
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y -0.0367939710617076
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     874   -2.9871562   -1.2545075   -1.2545075 
     875   -2.9871562   -1.2545075   -1.2552339 
Loop time of 3.50409e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.25523389739909
variable naccept equal ${increment}
variable naccept equal 218

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3005129698773
variable        y0 equal ${yi}
variable        y0 equal 0.856256540525287

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.3210734848042
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.84316247295174
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     875   -2.9871562   -1.2552339   -1.2552339 
     876   -2.9871562   -1.2552339   -1.2559743 
Loop time of 3.5451e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.25597433482844
variable naccept equal ${increment}
variable naccept equal 219

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 7.06044206896469
variable        y0 equal ${yi}
variable        y0 equal 6.51616222397318

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.15192390957519
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.47396543756952
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     876   -2.9871562   -1.2559743   -1.2559743 
     877   -2.9871562   -1.2559743   -1.0352066 
Loop time of 3.67602e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 7.06044206896469
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.51616222397318
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3210734848042
variable        y0 equal ${yi}
variable        y0 equal 0.84316247295174

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.3654194716473
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.806736906278461
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     877   -2.9871562   -1.2559743   -1.0352066 
     878   -2.9871562   -1.2559743   -1.2485568 
Loop time of 3.6299e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.3210734848042
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.84316247295174
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.37391455887871
variable        y0 equal ${yi}
variable        y0 equal 3.80258712334763

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.46293977021294
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.74090495867859
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     878   -2.9871562   -1.2559743   -1.2485568 
     879   -2.9871562   -1.2559743   -1.3248985 
Loop time of 6.2864e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.32489851070741
variable naccept equal ${increment}
variable naccept equal 220

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.7916060018408
variable        y0 equal ${yi}
variable        y0 equal 1.78030420920915

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.77895602463362
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.81722146651811
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     879   -2.9871562   -1.3248985   -1.3248985 
     880   -2.9871562   -1.3248985   -1.3270955 
Loop time of 3.61627e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.32709553024296
variable naccept equal ${increment}
variable naccept equal 221

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.1395422999035
variable        y0 equal ${yi}
variable        y0 equal 9.26925461995929

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.0474003736149
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 9.21108343112796
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     880   -2.9871562   -1.3270955   -1.3270955 
     881   -2.9871562   -1.3270955   -1.3055467 
Loop time of 3.65725e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.1395422999035
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 9.26925461995929
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.1493705244735
variable        y0 equal ${yi}
variable        y0 equal 4.58995101803705

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.15536142308266
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.68212617987558
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     881   -2.9871562   -1.3270955   -1.3055467 
     882   -2.9871562   -1.3270955   -1.2764353 
Loop time of 3.65082e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.1493705244735
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.58995101803705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.55075164873373
variable        y0 equal ${yi}
variable        y0 equal 5.74215760176378

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.47955639202368
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.68945287411409
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     882   -2.9871562   -1.3270955   -1.2764353 
     883   -2.9871562   -1.3270955   -1.3494096 
Loop time of 3.60619e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.34940957970155
variable naccept equal ${increment}
variable naccept equal 222

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.17181414126912
variable        y0 equal ${yi}
variable        y0 equal 3.63301749987733

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.26462735890904
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.68544435067308
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     883   -2.9871562   -1.3494096   -1.3494096 
     884   -2.9871562   -1.3494096   -1.3582641 
Loop time of 3.60355e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.35826412727446
variable naccept equal ${increment}
variable naccept equal 223

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.44109301963712
variable        y0 equal ${yi}
variable        y0 equal 1.85579359910554

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.4768748442259
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.85539166114396
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     884   -2.9871562   -1.3582641   -1.3582641 
     885   -2.9871562   -1.3582641   -1.3313014 
Loop time of 3.54755e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.44109301963712
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.85579359910554
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.471242232719327
variable        y0 equal ${yi}
variable        y0 equal 6.49353084103098

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.406094367900754
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.40018727318277
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     885   -2.9871562   -1.3582641   -1.3313014 
     886   -2.9871562   -1.3582641   -1.3046923 
Loop time of 3.6103e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.471242232719327
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.49353084103098
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.64482000072432
variable        y0 equal ${yi}
variable        y0 equal 6.43445450798503

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.62241094310713
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.44860517517558
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     886   -2.9871562   -1.3582641   -1.3046923 
     887   -2.9871562   -1.3582641   -1.3562514 
Loop time of 3.58901e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.64482000072432
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.43445450798503
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.04322490969345
variable        y0 equal ${yi}
variable        y0 equal 0.840176923978655

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.12449258843109
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.758029957521288
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     887   -2.9871562   -1.3582641   -1.3562514 
     888   -2.9871562   -1.3582641   -1.2810375 
Loop time of 3.56093e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.04322490969345
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.840176923978655
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.14272395967341
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.88408720465998
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     888   -2.9871562   -1.3582641   -1.2810375 
     889   -2.9871562   -1.3582641   -1.3538104 
Loop time of 3.69221e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7380775292569
variable        y0 equal ${yi}
variable        y0 equal 7.41298324194217

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.7182274182492
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.3335405143764
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     889   -2.9871562   -1.3582641   -1.3538104 
     890   -2.9871562   -1.3582641   -1.3519312 
Loop time of 3.58378e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7380775292569
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41298324194217
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.471242232719327
variable        y0 equal ${yi}
variable        y0 equal 6.49353084103098

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.518748016754056
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.56016401783457
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     890   -2.9871562   -1.3582641   -1.3519312 
     891   -2.9871562   -1.3582641   -1.3548963 
Loop time of 3.69773e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.471242232719327
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.49353084103098
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.68400031485979
variable        y0 equal ${yi}
variable        y0 equal 7.40458581772113

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.72433849730913
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.37565397348666
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     891   -2.9871562   -1.3582641   -1.3548963 
     892   -2.9871562   -1.3582641   -1.3495208 
Loop time of 3.73672e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.68400031485979
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.40458581772113
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54731318790685
variable        y0 equal ${yi}
variable        y0 equal 3.75024119181764

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.61489307720434
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.6604432062639
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     892   -2.9871562   -1.3582641   -1.3495208 
     893   -2.9871562   -1.3582641   -1.2920679 
Loop time of 3.64717e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54731318790685
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75024119181764
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.63595545449678
variable        y0 equal ${yi}
variable        y0 equal 0.131007170677185

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.67219225326006
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.136653912067413
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     893   -2.9871562   -1.3582641   -1.2920679 
     894   -2.9871562   -1.3582641    -1.341397 
Loop time of 3.63095e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.63595545449678
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.131007170677185
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.27660374720308
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.69168437285554
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     894   -2.9871562   -1.3582641    -1.341397 
     895   -2.9871562   -1.3582641    -1.357611 
Loop time of 3.57733e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 0.933177629310419
variable        y0 equal ${yi}
variable        y0 equal 9.1395004700455

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 0.974881544906427
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.14707976091235
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     895   -2.9871562   -1.3582641    -1.357611 
     896   -2.9871562   -1.3582641   -1.3887182 
Loop time of 3.73989e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.38871819760241
variable naccept equal ${increment}
variable naccept equal 224

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40260913768674
variable        y0 equal ${yi}
variable        y0 equal 5.5414461011191

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.4255084435072
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.44424623196322
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     896   -2.9871562   -1.3887182   -1.3887182 
     897   -2.9871562   -1.3887182   -1.3886118 
Loop time of 3.61599e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.40260913768674
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.5414461011191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.47955639202368
variable        y0 equal ${yi}
variable        y0 equal 5.68945287411409

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.44328098137152
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.60752732699113
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     897   -2.9871562   -1.3887182   -1.3886118 
     898   -2.9871562   -1.3887182    -1.412428 
Loop time of 6.10835e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.41242798568167
variable naccept equal ${increment}
variable naccept equal 225

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.71003035782453
variable        y0 equal ${yi}
variable        y0 equal 7.4907858523395

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.76022679089185
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.4271339448955
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     898   -2.9871562    -1.412428    -1.412428 
     899   -2.9871562    -1.412428   -1.3342789 
Loop time of 3.60367e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 99 x ${x0}
set atom 99 x 9.71003035782453
  1 settings made for x
set atom $i y ${y0}
set atom 99 y ${y0}
set atom 99 y 7.4907858523395
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.28845272976906
variable        y0 equal ${yi}
variable        y0 equal 2.75579466792443

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.22285979706795
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.74353152486184
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     899   -2.9871562    -1.412428   -1.3342789 
     900   -2.9871562    -1.412428   -1.4194108 
Loop time of 3.68242e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.4194107878061
variable naccept equal ${increment}
variable naccept equal 226

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.7506712782361
variable        y0 equal ${yi}
variable        y0 equal 0.968768938291401

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.77169399142046
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 1.02102751325402
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     900   -2.9871562   -1.4194108   -1.4194108 
     901   -2.9871562   -1.4194108   -1.4004404 
Loop time of 3.59014e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.7506712782361
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.968768938291401
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.40689885138589
variable        y0 equal ${yi}
variable        y0 equal 1.95026988170212

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.38571890114862
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.93968546769684
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     901   -2.9871562   -1.4194108   -1.4004404 
     902   -2.9871562   -1.4194108    -1.407699 
Loop time of 3.66522e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.40689885138589
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.95026988170212
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.47973042248804
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.29410369720721
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     902   -2.9871562   -1.4194108    -1.407699 
     903   -2.9871562   -1.4194108   -1.4158264 
Loop time of 3.49809e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47168833731729
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.2979036006
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.07785165627651
variable        y0 equal ${yi}
variable        y0 equal 1.86409153125352

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.06826570351772
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.86881992003984
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     903   -2.9871562   -1.4194108   -1.4158264 
     904   -2.9871562   -1.4194108   -1.4157998 
Loop time of 3.70876e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.07785165627651
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.86409153125352
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.112628924846649
variable        y0 equal ${yi}
variable        y0 equal 1.75601954839296

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.0427202701568602
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.660774830795
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     904   -2.9871562   -1.4194108   -1.4157998 
     905   -2.9871562   -1.4194108   -1.3914822 
Loop time of 3.6476e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 6 x ${x0}
set atom 6 x 0.112628924846649
  1 settings made for x
set atom $i y ${y0}
set atom 6 y ${y0}
set atom 6 y 1.75601954839296
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0310238718986788
variable        y0 equal ${yi}
variable        y0 equal 3.80844516320359

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 0.0128975868225374
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.77990783019196
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     905   -2.9871562   -1.4194108   -1.3914822 
     906   -2.9871562   -1.4194108    -1.422596 
Loop time of 3.66307e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.42259604980845
variable naccept equal ${increment}
variable naccept equal 227

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.1260053876897
variable        y0 equal ${yi}
variable        y0 equal 8.43344125665721

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.2256060842534
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.44985064186153
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     906   -2.9871562    -1.422596    -1.422596 
     907   -2.9871562    -1.422596   -1.3200747 
Loop time of 3.65075e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.1260053876897
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.43344125665721
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78804708917571
variable        y0 equal ${yi}
variable        y0 equal 1.04433018754753

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.83035717208816
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.1313826520327
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     907   -2.9871562    -1.422596   -1.3200747 
     908   -2.9871562    -1.422596   -1.3461458 
Loop time of 3.55624e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.78804708917571
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.04433018754753
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.8169515065301
variable        y0 equal ${yi}
variable        y0 equal 0.890143771875232

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.82797947445994
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.89721691201958
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     908   -2.9871562    -1.422596   -1.3461458 
     909   -2.9871562    -1.422596   -1.4241092 
Loop time of 3.51704e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.42410917440787
variable naccept equal ${increment}
variable naccept equal 228

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 0.974881544906427
variable        y0 equal ${yi}
variable        y0 equal 9.14707976091235

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 0.900259259540369
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.24482509601443
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     909   -2.9871562   -1.4241092   -1.4241092 
     910   -2.9871562   -1.4241092   -1.3252471 
Loop time of 3.62537e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 0.974881544906427
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.14707976091235
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.54014339287054
variable        y0 equal ${yi}
variable        y0 equal 1.74339536807602

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.52269270260107
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.7492563404805
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     910   -2.9871562   -1.4241092   -1.3252471 
     911   -2.9871562   -1.4241092   -1.4301168 
Loop time of 3.60521e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.43011679666604
variable naccept equal ${increment}
variable naccept equal 229

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.36321673154392
variable        y0 equal ${yi}
variable        y0 equal 1.8523390569455

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.42576701402225
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.76362674615448
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     911   -2.9871562   -1.4301168   -1.4301168 
     912   -2.9871562   -1.4301168    -1.392386 
Loop time of 3.56872e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.36321673154392
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.8523390569455
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.7355564435177
variable        y0 equal ${yi}
variable        y0 equal 9.16062856424182

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.6882154663258
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.13688908326953
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     912   -2.9871562   -1.4301168    -1.392386 
     913   -2.9871562   -1.4301168   -1.3958553 
Loop time of 3.71673e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.7355564435177
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.16062856424182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.38655892689439
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.75643561644685
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     913   -2.9871562   -1.4301168   -1.3958553 
     914   -2.9871562   -1.4301168   -1.3449753 
Loop time of 3.63755e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.7506712782361
variable        y0 equal ${yi}
variable        y0 equal 0.968768938291401

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.82510768055696
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.934965904462666
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     914   -2.9871562   -1.4301168   -1.3449753 
     915   -2.9871562   -1.4301168   -1.4069213 
Loop time of 3.66649e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.7506712782361
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.968768938291401
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.8608382340192
variable        y0 equal ${yi}
variable        y0 equal 2.70200465890266

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.78886814076893
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.80012571784355
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     915   -2.9871562   -1.4301168   -1.4069213 
     916   -2.9871562   -1.4301168   -1.3621305 
Loop time of 3.56161e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.8608382340192
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.70200465890266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.6302324012908
variable        y0 equal ${yi}
variable        y0 equal 0.804496832597583

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.598681707778837
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.860469933259814
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     916   -2.9871562   -1.4301168   -1.3621305 
     917   -2.9871562   -1.4301168   -1.4253347 
Loop time of 3.53864e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.6302324012908
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.804496832597583
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03148551582195
variable        y0 equal ${yi}
variable        y0 equal 8.25080559171732

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 7.94933566449978
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.26920076526697
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     917   -2.9871562   -1.4301168   -1.4253347 
     918   -2.9871562   -1.4301168   -1.4133775 
Loop time of 3.47247e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03148551582195
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.25080559171732
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.28159687597963
variable        y0 equal ${yi}
variable        y0 equal 7.4978555950191

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.381353176429
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.53594180670047
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     918   -2.9871562   -1.4301168   -1.4133775 
     919   -2.9871562   -1.4301168   -1.4151278 
Loop time of 3.59403e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.28159687597963
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.4978555950191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.46293977021294
variable        y0 equal ${yi}
variable        y0 equal 3.74090495867859

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.38971678732949
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.65703361792694
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     919   -2.9871562   -1.4301168   -1.4151278 
     920   -2.9871562   -1.4301168   -1.3623305 
Loop time of 3.66111e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.46293977021294
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.74090495867859
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.04322490969345
variable        y0 equal ${yi}
variable        y0 equal 0.840176923978655

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 6.95875395813629
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.865050192582933
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     920   -2.9871562   -1.4301168   -1.3623305 
     921   -2.9871562   -1.4301168   -1.4005487 
Loop time of 3.60351e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.04322490969345
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.840176923978655
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.55870154936087
variable        y0 equal ${yi}
variable        y0 equal 9.25253196466296

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.60752267677557
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.30706016528933
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     921   -2.9871562   -1.4301168   -1.4005487 
     922   -2.9871562   -1.4301168   -1.4008142 
Loop time of 3.59614e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.55870154936087
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.25253196466296
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.23493712901631
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.061136543750763
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     922   -2.9871562   -1.4301168   -1.4008142 
     923   -2.9871562   -1.4301168   -1.4294839 
Loop time of 3.56969e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.57222292898772
variable        y0 equal ${yi}
variable        y0 equal 5.48064044659334

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.59935610769866
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.43782788460451
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     923   -2.9871562   -1.4301168   -1.4294839 
     924   -2.9871562   -1.4301168   -1.4147564 
Loop time of 3.52772e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.57222292898772
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.48064044659334
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.8608382340192
variable        y0 equal ${yi}
variable        y0 equal 2.70200465890266

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.9318645473241
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.66796987029411
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     924   -2.9871562   -1.4301168   -1.4147564 
     925   -2.9871562   -1.4301168   -1.3305969 
Loop time of 3.5765e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.8608382340192
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.70200465890266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79544342397986
variable        y0 equal ${yi}
variable        y0 equal 4.56401381844446

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.79829481481848
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.66341626995966
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     925   -2.9871562   -1.4301168   -1.3305969 
     926   -2.9871562   -1.4301168   -1.4446656 
Loop time of 3.72656e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.44466561834418
variable naccept equal ${increment}
variable naccept equal 230

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.42793486197206
variable        y0 equal ${yi}
variable        y0 equal 1.83933557651109

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.35387750942918
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.85945996425218
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     926   -2.9871562   -1.4446656   -1.4446656 
     927   -2.9871562   -1.4446656   -1.4403386 
Loop time of 3.50871e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.42793486197206
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.83933557651109
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.68400031485979
variable        y0 equal ${yi}
variable        y0 equal 7.40458581772113

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.66915581384127
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.39339096870685
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     927   -2.9871562   -1.4446656   -1.4403386 
     928   -2.9871562   -1.4446656   -1.4428903 
Loop time of 3.56696e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.68400031485979
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.40458581772113
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.01394880412914
variable        y0 equal ${yi}
variable        y0 equal 4.70269989127085

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.07809895871975
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.65553936118052
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     928   -2.9871562   -1.4446656   -1.4428903 
     929   -2.9871562   -1.4446656    -1.443869 
Loop time of 3.625e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.01394880412914
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.70269989127085
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03148551582195
variable        y0 equal ${yi}
variable        y0 equal 8.25080559171732

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.02622429727413
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.30461697496469
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     929   -2.9871562   -1.4446656    -1.443869 
     930   -2.9871562   -1.4446656   -1.4469315 
Loop time of 3.62632e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.44693148352682
variable naccept equal ${increment}
variable naccept equal 231

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06081770061351
variable        y0 equal ${yi}
variable        y0 equal 6.59912495151987

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.02269224523402
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.54095271364679
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     930   -2.9871562   -1.4469315   -1.4469315 
     931   -2.9871562   -1.4469315   -1.4504292 
Loop time of 3.6259e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.45042916242854
variable naccept equal ${increment}
variable naccept equal 232

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.586605925956632
variable        y0 equal ${yi}
variable        y0 equal 4.58906858319208

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.598599274555112
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.53373321646616
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     931   -2.9871562   -1.4504292   -1.4504292 
     932   -2.9871562   -1.4504292   -1.4218086 
Loop time of 3.49804e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.586605925956632
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.58906858319208
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.24042666911641
variable        y0 equal ${yi}
variable        y0 equal 7.34214617338442

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.25279456138173
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.38214940157198
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     932   -2.9871562   -1.4504292   -1.4218086 
     933   -2.9871562   -1.4504292   -1.4554372 
Loop time of 3.59625e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.45543715564806
variable naccept equal ${increment}
variable naccept equal 233

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.40689885138589
variable        y0 equal ${yi}
variable        y0 equal 1.95026988170212

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.30942922352868
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 2.04244977614945
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     933   -2.9871562   -1.4554372   -1.4554372 
     934   -2.9871562   -1.4554372  -0.95799566 
Loop time of 3.54931e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.40689885138589
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.95026988170212
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.02622429727413
variable        y0 equal ${yi}
variable        y0 equal 8.30461697496469

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.04726209043361
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.29240513958032
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     934   -2.9871562   -1.4554372  -0.95799566 
     935   -2.9871562   -1.4554372   -1.4539072 
Loop time of 3.56044e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.02622429727413
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.30461697496469
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.28159687597963
variable        y0 equal ${yi}
variable        y0 equal 7.4978555950191

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.24356772978517
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.54733134832644
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     935   -2.9871562   -1.4554372   -1.4539072 
     936   -2.9871562   -1.4554372   -1.4324462 
Loop time of 3.63866e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.28159687597963
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.4978555950191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 0.940420153934297
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.5577940138843
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     936   -2.9871562   -1.4554372   -1.4324462 
     937   -2.9871562   -1.4554372   -1.3593272 
Loop time of 3.70181e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.39729921340066
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.2775690349605
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     937   -2.9871562   -1.4554372   -1.3593272 
     938   -2.9871562   -1.4554372   -1.4401012 
Loop time of 3.54878e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47168833731729
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.2979036006
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54731318790685
variable        y0 equal ${yi}
variable        y0 equal 3.75024119181764

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.57871951896917
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.72293282313478
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     938   -2.9871562   -1.4554372   -1.4401012 
     939   -2.9871562   -1.4554372   -1.4450875 
Loop time of 3.58074e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54731318790685
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75024119181764
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.04212040860645
variable        y0 equal ${yi}
variable        y0 equal 0.854861756074756

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 6.02497799355976
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.911451740968555
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     939   -2.9871562   -1.4554372   -1.4450875 
     940   -2.9871562   -1.4554372   -1.4638446 
Loop time of 3.57293e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.46384460999957
variable naccept equal ${increment}
variable naccept equal 234

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82797947445994
variable        y0 equal ${yi}
variable        y0 equal 0.89721691201958

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.8597981862176
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.980748351323932
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     940   -2.9871562   -1.4638446   -1.4638446 
     941   -2.9871562   -1.4638446      -1.4524 
Loop time of 3.5963e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82797947445994
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.89721691201958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.04367139934398
variable        y0 equal ${yi}
variable        y0 equal 0.847485883939594

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.05018270610667
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.883626898038715
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     941   -2.9871562   -1.4638446      -1.4524 
     942   -2.9871562   -1.4638446   -1.4813224 
Loop time of 3.65583e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.48132243969199
variable naccept equal ${increment}
variable naccept equal 235

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 0.974881544906427
variable        y0 equal ${yi}
variable        y0 equal 9.14707976091235

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 1.06971333344631
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.07952703941195
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     942   -2.9871562   -1.4813224   -1.4813224 
     943   -2.9871562   -1.4813224   -1.4775901 
Loop time of 3.52115e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 0.974881544906427
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.14707976091235
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.7355564435177
variable        y0 equal ${yi}
variable        y0 equal 9.16062856424182

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.6621885736637
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.18153402316898
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     943   -2.9871562   -1.4813224   -1.4775901 
     944   -2.9871562   -1.4813224   -1.4819523 
Loop time of 3.55801e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.48195231111357
variable naccept equal ${increment}
variable naccept equal 236

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2971436027547
variable        y0 equal ${yi}
variable        y0 equal 4.75506552809641

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.20469412842
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.80468764656946
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     944   -2.9871562   -1.4819523   -1.4819523 
     945   -2.9871562   -1.4819523   -1.4343416 
Loop time of 3.67875e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.2971436027547
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.75506552809641
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0128975868225374
variable        y0 equal ${yi}
variable        y0 equal 3.77990783019196

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x -0.0267288684844694
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.83343025012146
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     945   -2.9871562   -1.4819523   -1.4343416 
     946   -2.9871562   -1.4819523   -1.4644272 
Loop time of 3.54179e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 0.0128975868225374
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.77990783019196
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.89555294155417
variable        y0 equal ${yi}
variable        y0 equal 3.03869023295739

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.98520919918356
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 3.07488280507424
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     946   -2.9871562   -1.4819523   -1.4644272 
     947   -2.9871562   -1.4819523  -0.70438063 
Loop time of 3.63197e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.89555294155417
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 3.03869023295739
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.47945046503755
variable        y0 equal ${yi}
variable        y0 equal 9.25402225959628

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.56158988554689
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.2918301414284
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     947   -2.9871562   -1.4819523  -0.70438063 
     948   -2.9871562   -1.4819523   -1.4091045 
Loop time of 3.5122e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.47945046503755
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.25402225959628
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 9.98400547542772
variable        y0 equal ${yi}
variable        y0 equal 6.5680043174409

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 9.98025505581102
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.66747937933436
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     948   -2.9871562   -1.4819523   -1.4091045 
     949   -2.9871562   -1.4819523   -1.3747987 
Loop time of 3.71413e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 9.98400547542772
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.5680043174409
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.86053182720482
variable        y0 equal ${yi}
variable        y0 equal 0.889302774179314

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.79883126854241
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.923244209993218
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     949   -2.9871562   -1.4819523   -1.3747987 
     950   -2.9871562   -1.4819523   -1.4569768 
Loop time of 3.53539e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.86053182720482
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.889302774179314
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.01394880412914
variable        y0 equal ${yi}
variable        y0 equal 4.70269989127085

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.00851837991573
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.61388506049082
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     950   -2.9871562   -1.4819523   -1.4569768 
     951   -2.9871562   -1.4819523    -1.475003 
Loop time of 3.66544e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.01394880412914
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.70269989127085
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.02269224523402
variable        y0 equal ${yi}
variable        y0 equal 6.54095271364679

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.03516697286464
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.55468170181741
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     951   -2.9871562   -1.4819523    -1.475003 
     952   -2.9871562   -1.4819523   -1.4842256 
Loop time of 3.55493e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.48422556703503
variable naccept equal ${increment}
variable naccept equal 237

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.56930645584841
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.35740113176402
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     952   -2.9871562   -1.4842256   -1.4842256 
     953   -2.9871562   -1.4842256   -1.4720116 
Loop time of 3.60121e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.07785165627651
variable        y0 equal ${yi}
variable        y0 equal 1.86409153125352

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.00601321776562
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.78667992732591
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     953   -2.9871562   -1.4842256   -1.4720116 
     954   -2.9871562   -1.4842256    -1.413726 
Loop time of 3.48286e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.07785165627651
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.86409153125352
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3210734848042
variable        y0 equal ${yi}
variable        y0 equal 0.84316247295174

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.3219509963055
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.846012469041675
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     954   -2.9871562   -1.4842256    -1.413726 
     955   -2.9871562   -1.4842256   -1.4850136 
Loop time of 3.77981e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.48501357627387
variable naccept equal ${increment}
variable naccept equal 238

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.26462735890904
variable        y0 equal ${yi}
variable        y0 equal 3.68544435067308

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.32159135102788
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.63044341368806
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     955   -2.9871562   -1.4850136   -1.4850136 
     956   -2.9871562   -1.4850136   -1.4656273 
Loop time of 3.69569e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.26462735890904
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.68544435067308
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.01394880412914
variable        y0 equal ${yi}
variable        y0 equal 4.70269989127085

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.10512567161419
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.65693239325449
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     956   -2.9871562   -1.4850136   -1.4656273 
     957   -2.9871562   -1.4850136   -1.4796673 
Loop time of 3.51306e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.01394880412914
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.70269989127085
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.60189408539412
variable        y0 equal ${yi}
variable        y0 equal 0.164266347885132

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.57918032883284
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.0850776791572572
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     957   -2.9871562   -1.4850136   -1.4796673 
     958   -2.9871562   -1.4850136   -1.4919232 
Loop time of 3.46891e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.491923156679
variable naccept equal ${increment}
variable naccept equal 239

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78804708917571
variable        y0 equal ${yi}
variable        y0 equal 1.04433018754753

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.86795213420821
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 0.947475190866317
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     958   -2.9871562   -1.4919232   -1.4919232 
     959   -2.9871562   -1.4919232   -1.4759658 
Loop time of 3.56705e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.78804708917571
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.04433018754753
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.7506712782361
variable        y0 equal ${yi}
variable        y0 equal 0.968768938291401

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.81910476565141
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.919455297696919
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     959   -2.9871562   -1.4919232   -1.4759658 
     960   -2.9871562   -1.4919232    -1.471648 
Loop time of 3.53474e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.7506712782361
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.968768938291401
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.87135564604884
variable        y0 equal ${yi}
variable        y0 equal 6.55566048161021

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.78247871914988
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.57109596268168
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     960   -2.9871562   -1.4919232    -1.471648 
     961   -2.9871562   -1.4919232   -1.4934029 
Loop time of 3.69332e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.49340285365173
variable naccept equal ${increment}
variable naccept equal 240

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.89555294155417
variable        y0 equal ${yi}
variable        y0 equal 3.03869023295739

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.96362549900351
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.95737274857858
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     961   -2.9871562   -1.4934029   -1.4934029 
     962   -2.9871562   -1.4934029   -1.5745752 
Loop time of 3.85359e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.57457516097695
variable naccept equal ${increment}
variable naccept equal 241

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.02497799355976
variable        y0 equal ${yi}
variable        y0 equal 0.911451740968555

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 5.93871539790623
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.858981331098407
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     962   -2.9871562   -1.5745752   -1.5745752 
     963   -2.9871562   -1.5745752   -1.5726013 
Loop time of 3.72579e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 6.02497799355976
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.911451740968555
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.11791221498346
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.95092853280405
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     963   -2.9871562   -1.5745752   -1.5726013 
     964   -2.9871562   -1.5745752   -1.5494051 
Loop time of 3.64625e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.45505593855154
variable        y0 equal ${yi}
variable        y0 equal 7.39650682535434

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.43694574672949
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.38742323246265
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     964   -2.9871562   -1.5745752   -1.5494051 
     965   -2.9871562   -1.5745752   -1.5603278 
Loop time of 3.65531e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.45505593855154
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.39650682535434
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.46746646562482
variable        y0 equal ${yi}
variable        y0 equal 9.264607102755

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.55744259754087
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.36272786367266
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     965   -2.9871562   -1.5745752   -1.5603278 
     966   -2.9871562   -1.5745752   -1.5270938 
Loop time of 3.70279e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.46746646562482
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.264607102755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78804708917571
variable        y0 equal ${yi}
variable        y0 equal 1.04433018754753

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.78581515748931
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.04153251241478
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     966   -2.9871562   -1.5745752   -1.5270938 
     967   -2.9871562   -1.5745752   -1.5755609 
Loop time of 3.65297e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.57556093664701
variable naccept equal ${increment}
variable naccept equal 242

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.78247871914988
variable        y0 equal ${yi}
variable        y0 equal 6.57109596268168

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.77135444203501
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.58268436924449
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     967   -2.9871562   -1.5755609   -1.5755609 
     968   -2.9871562   -1.5755609   -1.5688016 
Loop time of 3.49659e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.78247871914988
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.57109596268168
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 9.98400547542772
variable        y0 equal ${yi}
variable        y0 equal 6.5680043174409

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 9.99236583748064
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.62297387854091
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     968   -2.9871562   -1.5755609   -1.5688016 
     969   -2.9871562   -1.5755609   -1.5470213 
Loop time of 3.5681e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 9.98400547542772
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.5680043174409
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.26734591801377
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.76747332377565
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     969   -2.9871562   -1.5755609   -1.5470213 
     970   -2.9871562   -1.5755609   -1.5660835 
Loop time of 3.68563e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.12617372869349
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.90716690989832
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     970   -2.9871562   -1.5755609   -1.5660835 
     971   -2.9871562   -1.5755609   -1.5682993 
Loop time of 3.56618e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.91887720465003
variable        y0 equal ${yi}
variable        y0 equal 8.32393774904306

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 5.01752247452079
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.42363653101022
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     971   -2.9871562   -1.5755609   -1.5682993 
     972   -2.9871562   -1.5755609   -1.5394125 
Loop time of 3.52507e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.91887720465003
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.32393774904306
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.85618775406963
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.66830582970546
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     972   -2.9871562   -1.5755609   -1.5394125 
     973   -2.9871562   -1.5755609   -1.5527028 
Loop time of 3.56222e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.04322490969345
variable        y0 equal ${yi}
variable        y0 equal 0.840176923978655

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.0000481871669
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.784034033525316
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     973   -2.9871562   -1.5755609   -1.5527028 
     974   -2.9871562   -1.5755609   -1.5693564 
Loop time of 3.98296e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.04322490969345
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.840176923978655
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.84113851427374
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.59162378662989
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     974   -2.9871562   -1.5755609   -1.5693564 
     975   -2.9871562   -1.5755609   -1.5672801 
Loop time of 3.57773e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.29747077305528
variable        y0 equal ${yi}
variable        y0 equal 5.67492594664294

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.28353248913499
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.60404488985736
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     975   -2.9871562   -1.5755609   -1.5672801 
     976   -2.9871562   -1.5755609   -1.6128046 
Loop time of 3.58698e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.61280459671928
variable naccept equal ${increment}
variable naccept equal 243

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20891928433934
variable        y0 equal ${yi}
variable        y0 equal 5.56093283837038

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.29215829133549
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.48455140536028
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     976   -2.9871562   -1.6128046   -1.6128046 
     977   -2.9871562   -1.6128046   -1.5879464 
Loop time of 3.49055e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20891928433934
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56093283837038
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.112628924846649
variable        y0 equal ${yi}
variable        y0 equal 1.75601954839296

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.194551134109497
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.66424557349748
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     977   -2.9871562   -1.6128046   -1.5879464 
     978   -2.9871562   -1.6128046    -1.534438 
Loop time of 3.65449e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 6 x ${x0}
set atom 6 x 0.112628924846649
  1 settings made for x
set atom $i y ${y0}
set atom 6 y ${y0}
set atom 6 y 1.75601954839296
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.1395422999035
variable        y0 equal ${yi}
variable        y0 equal 9.26925461995929

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.07223591247903
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 9.33390876758426
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     978   -2.9871562   -1.6128046    -1.534438 
     979   -2.9871562   -1.6128046   -1.6043062 
Loop time of 3.53722e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.1395422999035
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 9.26925461995929
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0128975868225374
variable        y0 equal ${yi}
variable        y0 equal 3.77990783019196

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x -0.0604982972144804
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.72810977263581
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     979   -2.9871562   -1.6128046   -1.6043062 
     980   -2.9871562   -1.6128046   -1.5475963 
Loop time of 3.61834e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 0.0128975868225374
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.77990783019196
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.03516697286464
variable        y0 equal ${yi}
variable        y0 equal 6.55468170181741

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.11414918302394
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.51079396740426
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     980   -2.9871562   -1.6128046   -1.5475963 
     981   -2.9871562   -1.6128046   -1.5904134 
Loop time of 3.70461e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.03516697286464
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.55468170181741
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.50628010192338
variable        y0 equal ${yi}
variable        y0 equal 1.936454562164

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.42201675334397
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.93096880099838
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     981   -2.9871562   -1.6128046   -1.5904134 
     982   -2.9871562   -1.6128046   -1.5632084 
Loop time of 3.61875e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.50628010192338
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.936454562164
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.16758816877708
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.87477440021103
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     982   -2.9871562   -1.6128046   -1.5632084 
     983   -2.9871562   -1.6128046   -1.6093698 
Loop time of 3.6404e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.77895602463362
variable        y0 equal ${yi}
variable        y0 equal 1.81722146651811

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.77997144936201
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.76716828725404
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     983   -2.9871562   -1.6128046   -1.6093698 
     984   -2.9871562   -1.6128046   -1.6075825 
Loop time of 3.49954e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.77895602463362
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.81722146651811
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.46293977021294
variable        y0 equal ${yi}
variable        y0 equal 3.74090495867859

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.51757102727013
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.74784597916733
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     984   -2.9871562   -1.6128046   -1.6075825 
     985   -2.9871562   -1.6128046   -1.6171687 
Loop time of 3.60043e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.61716873146723
variable naccept equal ${increment}
variable naccept equal 244

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7380775292569
variable        y0 equal ${yi}
variable        y0 equal 7.41298324194217

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.6605692346745
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.38338889208103
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     985   -2.9871562   -1.6171687   -1.6171687 
     986   -2.9871562   -1.6171687   -1.6066612 
Loop time of 3.53035e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7380775292569
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41298324194217
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.78247871914988
variable        y0 equal ${yi}
variable        y0 equal 6.57109596268168

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.77633171597605
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.59052471653452
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     986   -2.9871562   -1.6171687   -1.6066612 
     987   -2.9871562   -1.6171687   -1.6058638 
Loop time of 3.55273e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.78247871914988
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.57109596268168
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.64482000072432
variable        y0 equal ${yi}
variable        y0 equal 6.43445450798503

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.69741722543669
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.48545577064982
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     987   -2.9871562   -1.6171687   -1.6058638 
     988   -2.9871562   -1.6171687   -1.6186229 
Loop time of 3.74494e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.61862288404956
variable naccept equal ${increment}
variable naccept equal 245

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.49132942357922
variable        y0 equal ${yi}
variable        y0 equal 3.63162182135713

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.41120611825848
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.71720311207902
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     988   -2.9871562   -1.6186229   -1.6186229 
     989   -2.9871562   -1.6186229   -1.6865328 
Loop time of 3.52929e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.68653280245735
variable naccept equal ${increment}
variable naccept equal 246

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75591478546096
variable        y0 equal ${yi}
variable        y0 equal 4.61056455725595

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.76620992620422
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.6772339498417
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     989   -2.9871562   -1.6865328   -1.6865328 
     990   -2.9871562   -1.6865328   -1.6745899 
Loop time of 3.50995e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.75591478546096
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.61056455725595
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.60553795257036
variable        y0 equal ${yi}
variable        y0 equal 5.53007482235628

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.62435978808824
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.47372263615328
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     990   -2.9871562   -1.6865328   -1.6745899 
     991   -2.9871562   -1.6865328    -1.680911 
Loop time of 3.68645e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.60553795257036
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.53007482235628
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.1260053876897
variable        y0 equal ${yi}
variable        y0 equal 8.43344125665721

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.1646980408689
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.51741399683055
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     991   -2.9871562   -1.6865328    -1.680911 
     992   -2.9871562   -1.6865328   -1.4762661 
Loop time of 3.69348e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.1260053876897
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.43344125665721
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.40689885138589
variable        y0 equal ${yi}
variable        y0 equal 1.95026988170212

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.36728318451959
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.85709767720764
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     992   -2.9871562   -1.6865328   -1.4762661 
     993   -2.9871562   -1.6865328   -1.6878509 
Loop time of 3.59391e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.68785085517659
variable naccept equal ${increment}
variable naccept equal 247

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 0.974881544906427
variable        y0 equal ${yi}
variable        y0 equal 9.14707976091235

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 0.923406043845941
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.12350818622439
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     993   -2.9871562   -1.6878509   -1.6878509 
     994   -2.9871562   -1.6878509    -1.662309 
Loop time of 3.59801e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 0.974881544906427
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.14707976091235
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.44328098137152
variable        y0 equal ${yi}
variable        y0 equal 5.60752732699113

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.44231471855414
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.5160907620688
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     994   -2.9871562   -1.6878509    -1.662309 
     995   -2.9871562   -1.6878509   -1.6607479 
Loop time of 3.55384e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.44328098137152
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.60752732699113
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.69184740662356
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.23816124118861
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     995   -2.9871562   -1.6878509   -1.6607479 
     996   -2.9871562   -1.6878509    -1.672631 
Loop time of 3.58151e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.68400031485979
variable        y0 equal ${yi}
variable        y0 equal 7.40458581772113

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.67830637851183
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.38870193090701
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     996   -2.9871562   -1.6878509    -1.672631 
     997   -2.9871562   -1.6878509   -1.6872888 
Loop time of 3.59471e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.68400031485979
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.40458581772113
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.91887720465003
variable        y0 equal ${yi}
variable        y0 equal 8.32393774904306

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.93805575012504
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.32736837781961
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     997   -2.9871562   -1.6878509   -1.6872888 
     998   -2.9871562   -1.6878509   -1.6899587 
Loop time of 3.59189e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.68995873629221
variable naccept equal ${increment}
variable naccept equal 248

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.22937239169637
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.0951451539993287
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     998   -2.9871562   -1.6899587   -1.6899587 
     999   -2.9871562   -1.6899587   -1.6826804 
Loop time of 3.489e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.86732061425333
variable        y0 equal ${yi}
variable        y0 equal 8.43319919027385

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.81659465352182
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.49460998691615
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
     999   -2.9871562   -1.6899587   -1.6826804 
    1000   -2.9871562   -1.6899587    -1.680295 
Loop time of 3.5971e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.86732061425333
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.43319919027385
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.81734974343768
variable        y0 equal ${yi}
variable        y0 equal 4.6230520998852

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.77563576657763
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.66855532282755
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1000   -2.9871562   -1.6899587    -1.680295 
    1001   -2.9871562   -1.6899587   -1.6630049 
Loop time of 3.58708e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.81734974343768
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.6230520998852
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.8608382340192
variable        y0 equal ${yi}
variable        y0 equal 2.70200465890266

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.76216716725818
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.74951912137367
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1001   -2.9871562   -1.6899587   -1.6630049 
    1002   -2.9871562   -1.6899587   -1.4588674 
Loop time of 3.55556e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.8608382340192
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.70200465890266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.1260053876897
variable        y0 equal ${yi}
variable        y0 equal 8.43344125665721

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.1908290390035
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.43970131792125
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1002   -2.9871562   -1.6899587   -1.4588674 
    1003   -2.9871562   -1.6899587   -1.6275027 
Loop time of 3.60066e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.1260053876897
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.43344125665721
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.63480706095477
variable        y0 equal ${yi}
variable        y0 equal 2.83259171220163

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.64295322775622
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.89437136622766
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1003   -2.9871562   -1.6899587   -1.6275027 
    1004   -2.9871562   -1.6899587   -1.6631902 
Loop time of 3.49878e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.63480706095477
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.83259171220163
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.36907261132318
variable        y0 equal ${yi}
variable        y0 equal 5.55776917879778

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.27039842127878
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.65179220383364
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1004   -2.9871562   -1.6899587   -1.6631902 
    1005   -2.9871562   -1.6899587   -1.3237254 
Loop time of 3.66234e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.36907261132318
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.55776917879778
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.44109301963712
variable        y0 equal ${yi}
variable        y0 equal 1.85579359910554

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.42371865907575
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.7675963201291
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1005   -2.9871562   -1.6899587   -1.3237254 
    1006   -2.9871562   -1.6899587   -1.7239907 
Loop time of 3.60694e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.72399069499009
variable naccept equal ${increment}
variable naccept equal 249

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.69741722543669
variable        y0 equal ${yi}
variable        y0 equal 6.48545577064982

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.66282268960905
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.47586878077021
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1006   -2.9871562   -1.7239907   -1.7239907 
    1007   -2.9871562   -1.7239907   -1.7242878 
Loop time of 3.56391e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.72428776805177
variable naccept equal ${increment}
variable naccept equal 250

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.07785165627651
variable        y0 equal ${yi}
variable        y0 equal 1.86409153125352

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.01093614419155
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.94635230681962
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1007   -2.9871562   -1.7242878   -1.7242878 
    1008   -2.9871562   -1.7242878   -1.6851997 
Loop time of 3.56109e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.07785165627651
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.86409153125352
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.5395588834934
variable        y0 equal ${yi}
variable        y0 equal 5.71024687235552

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.5310840447597
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.61111056750017
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1008   -2.9871562   -1.7242878   -1.6851997 
    1009   -2.9871562   -1.7242878   -1.6440516 
Loop time of 3.59171e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.5395588834934
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.71024687235552
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.8674810047864
variable        y0 equal ${yi}
variable        y0 equal 6.36184206739894

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.83942999799242
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.35194695726863
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1009   -2.9871562   -1.7242878   -1.6440516 
    1010   -2.9871562   -1.7242878   -1.6828329 
Loop time of 3.53315e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.8674810047864
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.36184206739894
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.8608382340192
variable        y0 equal ${yi}
variable        y0 equal 2.70200465890266

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.84937839467517
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.78537006350853
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1010   -2.9871562   -1.7242878   -1.6828329 
    1011   -2.9871562   -1.7242878   -1.7062527 
Loop time of 3.58925e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.8608382340192
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.70200465890266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.520060713687803
variable        y0 equal ${yi}
variable        y0 equal 2.88988070460657

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.430616171756651
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.83406510325769
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1011   -2.9871562   -1.7242878   -1.7062527 
    1012   -2.9871562   -1.7242878   -1.6230995 
Loop time of 3.56111e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.520060713687803
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.88988070460657
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.46553996323663
variable        y0 equal ${yi}
variable        y0 equal 9.20163835990756

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.53458543538171
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.2437810014519
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1012   -2.9871562   -1.7242878   -1.6230995 
    1013   -2.9871562   -1.7242878   -1.7324227 
Loop time of 3.63666e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.73242265445855
variable naccept equal ${increment}
variable naccept equal 251

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.46994961896803
variable        y0 equal ${yi}
variable        y0 equal 7.37816305485033

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.40635736385252
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.41152420368456
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1013   -2.9871562   -1.7324227   -1.7324227 
    1014   -2.9871562   -1.7324227   -1.7372438 
Loop time of 3.644e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.73724382417537
variable naccept equal ${increment}
variable naccept equal 252

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6621885736637
variable        y0 equal ${yi}
variable        y0 equal 9.18153402316898

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.6291183312588
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.2346125077042
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1014   -2.9871562   -1.7372438   -1.7372438 
    1015   -2.9871562   -1.7372438   -1.7470106 
Loop time of 3.67131e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.74701060200186
variable naccept equal ${increment}
variable naccept equal 253

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.6302324012908
variable        y0 equal ${yi}
variable        y0 equal 0.804496832597583

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.591862769523527
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.729623480546802
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1015   -2.9871562   -1.7470106   -1.7470106 
    1016   -2.9871562   -1.7470106   -1.7257305 
Loop time of 3.53757e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.6302324012908
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.804496832597583
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75591478546096
variable        y0 equal ${yi}
variable        y0 equal 4.61056455725595

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.73925473888351
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.66080088967248
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1016   -2.9871562   -1.7470106   -1.7257305 
    1017   -2.9871562   -1.7470106   -1.7450215 
Loop time of 3.52744e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.75591478546096
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.61056455725595
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.14502597490654
variable        y0 equal ${yi}
variable        y0 equal 5.53364494984346

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.05478261152611
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.47058982794481
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1017   -2.9871562   -1.7470106   -1.7450215 
    1018   -2.9871562   -1.7470106   -1.6607541 
Loop time of 3.65639e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.14502597490654
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.53364494984346
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.18211348692283
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.94071571013993
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1018   -2.9871562   -1.7470106   -1.6607541 
    1019   -2.9871562   -1.7470106   -1.7417622 
Loop time of 3.61986e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 7.06044206896469
variable        y0 equal ${yi}
variable        y0 equal 6.51616222397318

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.04089255610153
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.55091043249598
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1019   -2.9871562   -1.7470106   -1.7417622 
    1020   -2.9871562   -1.7470106   -1.7282144 
Loop time of 3.58261e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 7.06044206896469
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.51616222397318
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.24109790086308
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.0750358700752259
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1020   -2.9871562   -1.7470106   -1.7282144 
    1021   -2.9871562   -1.7470106   -1.7438912 
Loop time of 3.66291e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.05018270610667
variable        y0 equal ${yi}
variable        y0 equal 0.883626898038715

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.01602202056742
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.923290832746357
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1021   -2.9871562   -1.7470106   -1.7438912 
    1022   -2.9871562   -1.7470106   -1.7441213 
Loop time of 3.55677e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.05018270610667
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.883626898038715
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.08412291724236
variable        y0 equal ${yi}
variable        y0 equal 1.01486168693337

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.12239968497307
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.09747809957299
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1022   -2.9871562   -1.7470106   -1.7441213 
    1023   -2.9871562   -1.7470106   -1.7452633 
Loop time of 3.80678e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.74526334031462
variable naccept equal ${increment}
variable naccept equal 254

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.586605925956632
variable        y0 equal ${yi}
variable        y0 equal 4.58906858319208

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.538762040534879
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.52424564713403
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1023   -2.9871562   -1.7452633   -1.7452633 
    1024   -2.9871562   -1.7452633   -1.6928254 
Loop time of 3.71942e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.586605925956632
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.58906858319208
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.22285979706795
variable        y0 equal ${yi}
variable        y0 equal 2.74353152486184

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.15474003273995
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.66475260230401
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1024   -2.9871562   -1.7452633   -1.6928254 
    1025   -2.9871562   -1.7452633    -1.724678 
Loop time of 6.51453e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.22285979706795
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.74353152486184
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.5395588834934
variable        y0 equal ${yi}
variable        y0 equal 5.71024687235552

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.5938358386211
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.70117394869524
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1025   -2.9871562   -1.7452633    -1.724678 
    1026   -2.9871562   -1.7452633   -1.7569882 
Loop time of 4.67356e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.75698816895123
variable naccept equal ${increment}
variable naccept equal 255

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.19016076405259
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.70074641649921
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1026   -2.9871562   -1.7569882   -1.7569882 
    1027   -2.9871562   -1.7569882   -1.7205107 
Loop time of 3.59321e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.86732061425333
variable        y0 equal ${yi}
variable        y0 equal 8.43319919027385

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.87088133612757
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.50471277154979
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1027   -2.9871562   -1.7569882   -1.7205107 
    1028   -2.9871562   -1.7569882    -1.738775 
Loop time of 3.56396e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.86732061425333
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.43319919027385
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.0748247806202
variable        y0 equal ${yi}
variable        y0 equal 3.76523935361039

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.05719277302132
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.79958184523713
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1028   -2.9871562   -1.7569882    -1.738775 
    1029   -2.9871562   -1.7569882   -1.7485056 
Loop time of 3.5412e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.0748247806202
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.76523935361039
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.52269270260107
variable        y0 equal ${yi}
variable        y0 equal 1.7492563404805

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.44468214351904
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.838471952892
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1029   -2.9871562   -1.7569882   -1.7485056 
    1030   -2.9871562   -1.7569882   -1.7784776 
Loop time of 3.64172e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.77847764995241
variable naccept equal ${increment}
variable naccept equal 256

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.02497799355976
variable        y0 equal ${yi}
variable        y0 equal 0.911451740968555

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 6.11156067807667
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.963629742372364
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1030   -2.9871562   -1.7784776   -1.7784776 
    1031   -2.9871562   -1.7784776   -1.7114711 
Loop time of 3.51495e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 6.02497799355976
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.911451740968555
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.77121166466352
variable        y0 equal ${yi}
variable        y0 equal 3.72175073189866

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.86112827538129
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.81270834965836
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1031   -2.9871562   -1.7784776   -1.7114711 
    1032   -2.9871562   -1.7784776   -1.7112883 
Loop time of 3.70471e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.77121166466352
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.72175073189866
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.1493705244735
variable        y0 equal ${yi}
variable        y0 equal 4.58995101803705

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.15950039345772
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.49664146059915
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1032   -2.9871562   -1.7784776   -1.7112883 
    1033   -2.9871562   -1.7784776   -1.7179134 
Loop time of 3.63918e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.1493705244735
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.58995101803705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.822478743785
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.70610267275736
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1033   -2.9871562   -1.7784776   -1.7179134 
    1034   -2.9871562   -1.7784776   -1.7725422 
Loop time of 3.49624e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.40635736385252
variable        y0 equal ${yi}
variable        y0 equal 7.41152420368456

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.42474775710966
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.43509661283754
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1034   -2.9871562   -1.7784776   -1.7725422 
    1035   -2.9871562   -1.7784776   -1.7731057 
Loop time of 3.62469e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.40635736385252
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.41152420368456
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.63595545449678
variable        y0 equal ${yi}
variable        y0 equal 0.131007170677185

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.70018819728319
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.0890159964561462
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1035   -2.9871562   -1.7784776   -1.7731057 
    1036   -2.9871562   -1.7784776   -1.7118666 
Loop time of 3.60231e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.63595545449678
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.131007170677185
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03084906657391
variable        y0 equal ${yi}
variable        y0 equal 5.64538028185563

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 1.1264802606886
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.73927500193314
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1036   -2.9871562   -1.7784776   -1.7118666 
    1037   -2.9871562   -1.7784776   -1.7457688 
Loop time of 3.63534e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03084906657391
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.64538028185563
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.93805575012504
variable        y0 equal ${yi}
variable        y0 equal 8.32736837781961

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.98399006962119
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.38522428192194
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1037   -2.9871562   -1.7784776   -1.7457688 
    1038   -2.9871562   -1.7784776   -1.7691008 
Loop time of 3.65231e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.93805575012504
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.32736837781961
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.04322490969345
variable        y0 equal ${yi}
variable        y0 equal 0.840176923978655

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.02537268677399
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.926061685788958
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1038   -2.9871562   -1.7784776   -1.7691008 
    1039   -2.9871562   -1.7784776   -1.7788102 
Loop time of 3.62445e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.77881019104213
variable naccept equal ${increment}
variable naccept equal 257

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.1395422999035
variable        y0 equal ${yi}
variable        y0 equal 9.26925461995929

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.2168075386654
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 9.27377691972583
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1039   -2.9871562   -1.7788102   -1.7788102 
    1040   -2.9871562   -1.7788102   -1.7763243 
Loop time of 3.66166e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.1395422999035
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 9.26925461995929
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 0.974881544906427
variable        y0 equal ${yi}
variable        y0 equal 9.14707976091235

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 0.89373178799801
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.07009595144122
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1040   -2.9871562   -1.7788102   -1.7763243 
    1041   -2.9871562   -1.7788102   -1.6916886 
Loop time of 3.62903e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 0.974881544906427
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.14707976091235
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.586605925956632
variable        y0 equal ${yi}
variable        y0 equal 4.58906858319208

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.512087364593412
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.50006326788828
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1041   -2.9871562   -1.7788102   -1.6916886 
    1042   -2.9871562   -1.7788102   -1.6668728 
Loop time of 3.63189e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.586605925956632
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.58906858319208
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.22678570190773
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.80666753432816
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1042   -2.9871562   -1.7788102   -1.6668728 
    1043   -2.9871562   -1.7788102      -1.7388 
Loop time of 3.56076e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.03516697286464
variable        y0 equal ${yi}
variable        y0 equal 6.55468170181741

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 7.99699617027141
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.50796243683328
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1043   -2.9871562   -1.7788102      -1.7388 
    1044   -2.9871562   -1.7788102   -1.7645664 
Loop time of 3.58556e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.03516697286464
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.55468170181741
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40260913768674
variable        y0 equal ${yi}
variable        y0 equal 5.5414461011191

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.40921907821561
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.57548137848574
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1044   -2.9871562   -1.7788102   -1.7645664 
    1045   -2.9871562   -1.7788102   -1.7266477 
Loop time of 3.59822e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.40260913768674
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.5414461011191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75591478546096
variable        y0 equal ${yi}
variable        y0 equal 4.61056455725595

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.79442298610641
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.56086813563272
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1045   -2.9871562   -1.7788102   -1.7266477 
    1046   -2.9871562   -1.7788102   -1.7622837 
Loop time of 3.59244e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.75591478546096
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.61056455725595
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.01394880412914
variable        y0 equal ${yi}
variable        y0 equal 4.70269989127085

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.04387097953655
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.80057568901942
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1046   -2.9871562   -1.7788102   -1.7622837 
    1047   -2.9871562   -1.7788102   -1.7255889 
Loop time of 3.54951e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.01394880412914
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.70269989127085
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.36728318451959
variable        y0 equal ${yi}
variable        y0 equal 1.85709767720764

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.43551569699365
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.89214071414535
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1047   -2.9871562   -1.7788102   -1.7255889 
    1048   -2.9871562   -1.7788102   -1.8042084 
Loop time of 4.00485e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.80420841789194
variable naccept equal ${increment}
variable naccept equal 258

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.44468214351904
variable        y0 equal ${yi}
variable        y0 equal 1.838471952892

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.42002098400366
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.78894172093933
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1048   -2.9871562   -1.8042084   -1.8042084 
    1049   -2.9871562   -1.8042084   -1.7778507 
Loop time of 3.56744e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.44468214351904
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.838471952892
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 6.9320023683612
variable        y0 equal ${yi}
variable        y0 equal 2.82359918328622

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.88608111420318
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.89773024293283
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1049   -2.9871562   -1.8042084   -1.7778507 
    1050   -2.9871562   -1.8042084   -1.7621357 
Loop time of 3.58461e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 6.9320023683612
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.82359918328622
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.44328098137152
variable        y0 equal ${yi}
variable        y0 equal 5.60752732699113

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.38858401615393
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.5759879702826
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1050   -2.9871562   -1.8042084   -1.7621357 
    1051   -2.9871562   -1.8042084   -1.7832432 
Loop time of 3.63475e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.44328098137152
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.60752732699113
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6291183312588
variable        y0 equal ${yi}
variable        y0 equal 9.2346125077042

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.5701796372586
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.24773352849811
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1051   -2.9871562   -1.8042084   -1.7832432 
    1052   -2.9871562   -1.8042084   -1.7656088 
Loop time of 3.55213e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6291183312588
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.2346125077042
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.51757102727013
variable        y0 equal ${yi}
variable        y0 equal 3.74784597916733

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.53134179829674
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.7513208345903
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1052   -2.9871562   -1.8042084   -1.7656088 
    1053   -2.9871562   -1.8042084   -1.8011115 
Loop time of 3.57778e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.51757102727013
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.74784597916733
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 7.06044206896469
variable        y0 equal ${yi}
variable        y0 equal 6.51616222397318

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.13949365893051
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.50303375259867
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1053   -2.9871562   -1.8042084   -1.8011115 
    1054   -2.9871562   -1.8042084   -1.7239978 
Loop time of 3.53547e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 7.06044206896469
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.51616222397318
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.88638629555044
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.57020581120417
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1054   -2.9871562   -1.8042084   -1.7239978 
    1055   -2.9871562   -1.8042084   -1.7640038 
Loop time of 3.5299e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.22285979706795
variable        y0 equal ${yi}
variable        y0 equal 2.74353152486184

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.3103120179847
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.82841100665429
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1055   -2.9871562   -1.8042084   -1.7640038 
    1056   -2.9871562   -1.8042084   -1.7846341 
Loop time of 6.12766e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.22285979706795
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.74353152486184
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.03616969306023
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.54195239461954
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1056   -2.9871562   -1.8042084   -1.7846341 
    1057   -2.9871562   -1.8042084   -1.7846667 
Loop time of 3.57405e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.03154995162041
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.4676475397497
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.53458543538171
variable        y0 equal ${yi}
variable        y0 equal 9.2437810014519

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.52172473191339
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.28439741838305
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1057   -2.9871562   -1.8042084   -1.7846667 
    1058   -2.9871562   -1.8042084   -1.8079449 
Loop time of 3.53492e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.80794490373946
variable naccept equal ${increment}
variable naccept equal 259

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.78247871914988
variable        y0 equal ${yi}
variable        y0 equal 6.57109596268168

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.82206190148478
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.63689008490077
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1058   -2.9871562   -1.8079449   -1.8079449 
    1059   -2.9871562   -1.8079449   -1.7742238 
Loop time of 3.50965e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.78247871914988
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.57109596268168
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.63480706095477
variable        y0 equal ${yi}
variable        y0 equal 2.83259171220163

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.73409250855227
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.78248417350153
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1059   -2.9871562   -1.8079449   -1.7742238 
    1060   -2.9871562   -1.8079449   -1.7909359 
Loop time of 3.60085e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.63480706095477
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.83259171220163
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.45505593855154
variable        y0 equal ${yi}
variable        y0 equal 7.39650682535434

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.45608463127386
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.32319032278323
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1060   -2.9871562   -1.8079449   -1.7909359 
    1061   -2.9871562   -1.8079449   -1.7370294 
Loop time of 3.52875e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.45505593855154
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.39650682535434
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.7506712782361
variable        y0 equal ${yi}
variable        y0 equal 0.968768938291401

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.74083279251833
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.982814689386219
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1061   -2.9871562   -1.8079449   -1.7370294 
    1062   -2.9871562   -1.8079449   -1.8077105 
Loop time of 3.55553e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.7506712782361
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.968768938291401
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78581515748931
variable        y0 equal ${yi}
variable        y0 equal 1.04153251241478

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.75083885391189
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.04175704311165
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1062   -2.9871562   -1.8079449   -1.8077105 
    1063   -2.9871562   -1.8079449   -1.8071064 
Loop time of 3.61363e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.78581515748931
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.04153251241478
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.52172473191339
variable        y0 equal ${yi}
variable        y0 equal 9.28439741838305

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.54204332350809
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.19271418559878
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1063   -2.9871562   -1.8079449   -1.8071064 
    1064   -2.9871562   -1.8079449   -1.7871073 
Loop time of 3.6847e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.52172473191339
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.28439741838305
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.09498575328684
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.80714600058893
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1064   -2.9871562   -1.8079449   -1.7871073 
    1065   -2.9871562   -1.8079449   -1.7993074 
Loop time of 3.68076e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2971436027547
variable        y0 equal ${yi}
variable        y0 equal 4.75506552809641

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.3048718694707
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.85425978058741
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1065   -2.9871562   -1.8079449   -1.7993074 
    1066   -2.9871562   -1.8079449   -1.7184366 
Loop time of 3.5789e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.2971436027547
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.75506552809641
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.02579118926079
variable        y0 equal ${yi}
variable        y0 equal 6.37822083965769

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.04304151255638
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.44874846474161
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1066   -2.9871562   -1.8079449   -1.7184366 
    1067   -2.9871562   -1.8079449   -1.8194041 
Loop time of 3.53229e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.81940407863904
variable naccept equal ${increment}
variable naccept equal 260

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.586605925956632
variable        y0 equal ${yi}
variable        y0 equal 4.58906858319208

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.64114514152136
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.62995809668466
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1067   -2.9871562   -1.8194041   -1.8194041 
    1068   -2.9871562   -1.8194041   -1.8052326 
Loop time of 3.46088e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.586605925956632
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.58906858319208
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.26462735890904
variable        y0 equal ${yi}
variable        y0 equal 3.68544435067308

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.24597583770314
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.61097474856508
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1068   -2.9871562   -1.8194041   -1.8052326 
    1069   -2.9871562   -1.8194041   -1.8094459 
Loop time of 3.68446e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.26462735890904
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.68544435067308
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.7506712782361
variable        y0 equal ${yi}
variable        y0 equal 0.968768938291401

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.76486470579881
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.881972785699696
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1069   -2.9871562   -1.8194041   -1.8094459 
    1070   -2.9871562   -1.8194041   -1.8129783 
Loop time of 3.75162e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.7506712782361
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.968768938291401
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57225463270922
variable        y0 equal ${yi}
variable        y0 equal 4.72659182900353

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.57543257355471
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.67648406380578
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1070   -2.9871562   -1.8194041   -1.8129783 
    1071   -2.9871562   -1.8194041   -1.8246216 
Loop time of 3.5797e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.8246216360082
variable naccept equal ${increment}
variable naccept equal 261

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.520060713687803
variable        y0 equal ${yi}
variable        y0 equal 2.88988070460657

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.528748662868406
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.90965737077097
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1071   -2.9871562   -1.8246216   -1.8246216 
    1072   -2.9871562   -1.8246216   -1.8204027 
Loop time of 3.55755e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.520060713687803
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.88988070460657
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.17139503399238
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.96350466392105
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1072   -2.9871562   -1.8246216   -1.8204027 
    1073   -2.9871562   -1.8246216   -1.8126826 
Loop time of 3.62217e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.7162687623435
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.72452661150858
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1073   -2.9871562   -1.8246216   -1.8126826 
    1074   -2.9871562   -1.8246216   -1.7825073 
Loop time of 3.61831e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.12224470694715
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.41543135967516
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1074   -2.9871562   -1.8246216   -1.7825073 
    1075   -2.9871562   -1.8246216   -1.8000788 
Loop time of 3.6008e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.10567082484418
variable        y0 equal ${yi}
variable        y0 equal 3.7027230934633

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.17352785189801
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.62889561219346
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1075   -2.9871562   -1.8246216   -1.8000788 
    1076   -2.9871562   -1.8246216   -1.7371078 
Loop time of 3.65894e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.10567082484418
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.7027230934633
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.586605925956632
variable        y0 equal ${yi}
variable        y0 equal 4.58906858319208

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.565379925170804
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.68124908560678
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1076   -2.9871562   -1.8246216   -1.7371078 
    1077   -2.9871562   -1.8246216   -1.8404585 
Loop time of 3.60464e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.84045851929374
variable naccept equal ${increment}
variable naccept equal 262

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.10567082484418
variable        y0 equal ${yi}
variable        y0 equal 3.7027230934633

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.03529732545072
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.66674024624955
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1077   -2.9871562   -1.8404585   -1.8404585 
    1078   -2.9871562   -1.8404585   -1.8219641 
Loop time of 3.57209e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.10567082484418
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.7027230934633
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.50628010192338
variable        y0 equal ${yi}
variable        y0 equal 1.936454562164

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.42672990718308
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.87637236497467
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1078   -2.9871562   -1.8404585   -1.8219641 
    1079   -2.9871562   -1.8404585   -1.8268835 
Loop time of 3.55605e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.50628010192338
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.936454562164
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.78981167911825
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.6916680490391
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1079   -2.9871562   -1.8404585   -1.8268835 
    1080   -2.9871562   -1.8404585    -1.837921 
Loop time of 3.81547e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.28689625342103
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.71090118451249
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1080   -2.9871562   -1.8404585    -1.837921 
    1081   -2.9871562   -1.8404585   -1.8391449 
Loop time of 3.54532e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 8.96521227080376
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.47667761959131
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1081   -2.9871562   -1.8404585   -1.8391449 
    1082   -2.9871562   -1.8404585   -1.8155133 
Loop time of 3.69183e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.03154995162041
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.4676475397497
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.12334904988461
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.45858100977206
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1082   -2.9871562   -1.8404585   -1.8155133 
    1083   -2.9871562   -1.8404585   -1.8310824 
Loop time of 3.5757e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.96362549900351
variable        y0 equal ${yi}
variable        y0 equal 2.95737274857858

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.94325743555365
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 3.01261335584024
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1083   -2.9871562   -1.8404585   -1.8310824 
    1084   -2.9871562   -1.8404585   -1.7479199 
Loop time of 3.61851e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.96362549900351
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.95737274857858
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.04304151255638
variable        y0 equal ${yi}
variable        y0 equal 6.44874846474161

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 8.95310978610069
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.34995239511957
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1084   -2.9871562   -1.8404585   -1.7479199 
    1085   -2.9871562   -1.8404585   -1.7581669 
Loop time of 3.5483e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.04304151255638
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.44874846474161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 6.9320023683612
variable        y0 equal ${yi}
variable        y0 equal 2.82359918328622

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.96153754273101
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.86360311480859
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1085   -2.9871562   -1.8404585   -1.7581669 
    1086   -2.9871562   -1.8404585   -1.8362069 
Loop time of 3.54064e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 6.9320023683612
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.82359918328622
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.51757102727013
variable        y0 equal ${yi}
variable        y0 equal 3.74784597916733

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.56183176755028
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.64937539858948
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1086   -2.9871562   -1.8404585   -1.8362069 
    1087   -2.9871562   -1.8404585   -1.7703258 
Loop time of 3.60914e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.51757102727013
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.74784597916733
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 0.974881544906427
variable        y0 equal ${yi}
variable        y0 equal 9.14707976091235

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 1.04256149848156
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.12870747554629
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1087   -2.9871562   -1.8404585   -1.7703258 
    1088   -2.9871562   -1.8404585   -1.8441716 
Loop time of 3.60147e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.8441715517984
variable naccept equal ${increment}
variable naccept equal 263

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.67839514174882
variable        y0 equal ${yi}
variable        y0 equal 3.73824497027528

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.59562623658601
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.83191344304216
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1088   -2.9871562   -1.8441716   -1.8441716 
    1089   -2.9871562   -1.8441716   -1.8211239 
Loop time of 3.60153e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.67839514174882
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.73824497027528
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.40635736385252
variable        y0 equal ${yi}
variable        y0 equal 7.41152420368456

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.39977147975828
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.33912527885698
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1089   -2.9871562   -1.8441716   -1.8211239 
    1090   -2.9871562   -1.8441716   -1.8490096 
Loop time of 3.6471e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.84900957275712
variable naccept equal ${increment}
variable naccept equal 264

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 9.98400547542772
variable        y0 equal ${yi}
variable        y0 equal 6.5680043174409

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.0128297571202
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.50182060734263
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1090   -2.9871562   -1.8490096   -1.8490096 
    1091   -2.9871562   -1.8490096   -1.8685176 
Loop time of 3.56902e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.86851758333353
variable naccept equal ${increment}
variable naccept equal 265

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.44328098137152
variable        y0 equal ${yi}
variable        y0 equal 5.60752732699113

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.52627091247809
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.62449314539628
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1091   -2.9871562   -1.8685176   -1.8685176 
    1092   -2.9871562   -1.8685176   -1.8762907 
Loop time of 3.60926e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.87629071543963
variable naccept equal ${increment}
variable naccept equal 266

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.57312639832278
variable        y0 equal ${yi}
variable        y0 equal 6.59234616295328

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.56331699967166
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.51610798374643
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1092   -2.9871562   -1.8762907   -1.8762907 
    1093   -2.9871562   -1.8762907   -1.8823503 
Loop time of 3.52337e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.88235029136234
variable naccept equal ${increment}
variable naccept equal 267

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.86732061425333
variable        y0 equal ${yi}
variable        y0 equal 8.43319919027385

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.83027569571619
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.49510998643932
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1093   -2.9871562   -1.8823503   -1.8823503 
    1094   -2.9871562   -1.8823503   -1.8728616 
Loop time of 3.61045e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.86732061425333
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.43319919027385
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.86053182720482
variable        y0 equal ${yi}
variable        y0 equal 0.889302774179314

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.92188998102486
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.869733079183434
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1094   -2.9871562   -1.8823503   -1.8728616 
    1095   -2.9871562   -1.8823503   -1.8870161 
Loop time of 3.53486e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.88701611473236
variable naccept equal ${increment}
variable naccept equal 268

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.7506712782361
variable        y0 equal ${yi}
variable        y0 equal 0.968768938291401

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.67264876246233
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.871292896974415
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1095   -2.9871562   -1.8870161   -1.8870161 
    1096   -2.9871562   -1.8870161   -1.8902228 
Loop time of 3.62605e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.89022275849958
variable naccept equal ${increment}
variable naccept equal 269

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.565379925170804
variable        y0 equal ${yi}
variable        y0 equal 4.68124908560678

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.476119883457089
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.72873064631387
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1096   -2.9871562   -1.8902228   -1.8902228 
    1097   -2.9871562   -1.8902228   -1.8570795 
Loop time of 6.09325e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.565379925170804
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.68124908560678
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.97784195223495
variable        y0 equal ${yi}
variable        y0 equal 8.32680290855464

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.91584168949768
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.33792208351192
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1097   -2.9871562   -1.8902228   -1.8570795 
    1098   -2.9871562   -1.8902228   -1.8261214 
Loop time of 3.71164e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.97784195223495
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.32680290855464
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3219509963055
variable        y0 equal ${yi}
variable        y0 equal 0.846012469041675

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.4044547919293
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.936135156858295
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1098   -2.9871562   -1.8902228   -1.8261214 
    1099   -2.9871562   -1.8902228   -1.8553169 
Loop time of 3.67426e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.3219509963055
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.846012469041675
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.7578687568469
variable        y0 equal ${yi}
variable        y0 equal 8.39387903131541

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.8316435237689
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.33618075765666
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1099   -2.9871562   -1.8902228   -1.8553169 
    1100   -2.9871562   -1.8902228   -1.8853848 
Loop time of 3.52286e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.7578687568469
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.39387903131541
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7380775292569
variable        y0 equal ${yi}
variable        y0 equal 7.41298324194217

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.8326046069318
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.49199136820102
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1100   -2.9871562   -1.8902228   -1.8853848 
    1101   -2.9871562   -1.8902228   -1.7838462 
Loop time of 3.67973e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7380775292569
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41298324194217
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.52172473191339
variable        y0 equal ${yi}
variable        y0 equal 9.28439741838305

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.60781994580347
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.27249764907687
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1101   -2.9871562   -1.8902228   -1.7838462 
    1102   -2.9871562   -1.8902228   -1.8620454 
Loop time of 3.46869e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.52172473191339
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.28439741838305
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.52627091247809
variable        y0 equal ${yi}
variable        y0 equal 5.62449314539628

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.50875395376456
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.60411881153779
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1102   -2.9871562   -1.8902228   -1.8620454 
    1103   -2.9871562   -1.8902228   -1.8913476 
Loop time of 3.6108e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.89134759709822
variable naccept equal ${increment}
variable naccept equal 270

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.36907261132318
variable        y0 equal ${yi}
variable        y0 equal 5.55776917879778

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.42239316224176
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.58969682400423
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1103   -2.9871562   -1.8913476   -1.8913476 
    1104   -2.9871562   -1.8913476   -1.9091866 
Loop time of 3.60096e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.90918662386608
variable naccept equal ${increment}
variable naccept equal 271

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40260913768674
variable        y0 equal ${yi}
variable        y0 equal 5.5414461011191

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.45573695102597
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.45798114483553
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1104   -2.9871562   -1.9091866   -1.9091866 
    1105   -2.9871562   -1.9091866   -1.8977468 
Loop time of 3.58801e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.40260913768674
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.5414461011191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.96362549900351
variable        y0 equal ${yi}
variable        y0 equal 2.95737274857858

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.98257599710761
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.99833892556527
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1105   -2.9871562   -1.9091866   -1.8977468 
    1106   -2.9871562   -1.9091866   -1.7716376 
Loop time of 3.69562e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.96362549900351
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.95737274857858
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.86732061425333
variable        y0 equal ${yi}
variable        y0 equal 8.43319919027385

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.89377521792536
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.46831390775737
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1106   -2.9871562   -1.9091866   -1.7716376 
    1107   -2.9871562   -1.9091866   -1.8984139 
Loop time of 3.52931e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.86732061425333
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.43319919027385
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.36379778464051
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.81367214484346
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1107   -2.9871562   -1.9091866   -1.8984139 
    1108   -2.9871562   -1.9091866   -1.8832503 
Loop time of 3.6845e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.96362549900351
variable        y0 equal ${yi}
variable        y0 equal 2.95737274857858

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.977072950595
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.88160681697229
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1108   -2.9871562   -1.9091866   -1.8832503 
    1109   -2.9871562   -1.9091866   -1.9573287 
Loop time of 3.52307e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.95732866986252
variable naccept equal ${increment}
variable naccept equal 272

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.05018270610667
variable        y0 equal ${yi}
variable        y0 equal 0.883626898038715

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.14395782350398
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.891646965253681
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1109   -2.9871562   -1.9573287   -1.9573287 
    1110   -2.9871562   -1.9573287   -1.9130287 
Loop time of 3.54826e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.05018270610667
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.883626898038715
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.97784195223495
variable        y0 equal ${yi}
variable        y0 equal 8.32680290855464

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.91088468113586
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.30079013027247
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1110   -2.9871562   -1.9573287   -1.9130287 
    1111   -2.9871562   -1.9573287   -1.8837938 
Loop time of 3.59767e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.97784195223495
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.32680290855464
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.1395422999035
variable        y0 equal ${yi}
variable        y0 equal 9.26925461995929

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.18714699188577
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 9.21009571063846
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1111   -2.9871562   -1.9573287   -1.8837938 
    1112   -2.9871562   -1.9573287   -1.9491925 
Loop time of 3.58286e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.1395422999035
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 9.26925461995929
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.7002414429122
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.67365230673716
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1112   -2.9871562   -1.9573287   -1.9491925 
    1113   -2.9871562   -1.9573287   -1.9052154 
Loop time of 3.61867e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 8.95150462109596
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.50359674610193
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1113   -2.9871562   -1.9573287   -1.9052154 
    1114   -2.9871562   -1.9573287   -1.9193497 
Loop time of 3.69099e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.03154995162041
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.4676475397497
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.92188998102486
variable        y0 equal ${yi}
variable        y0 equal 0.869733079183434

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.96933804392159
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.861062403428887
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1114   -2.9871562   -1.9573287   -1.9193497 
    1115   -2.9871562   -1.9573287   -1.9528435 
Loop time of 3.65709e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.92188998102486
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.869733079183434
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.47945046503755
variable        y0 equal ${yi}
variable        y0 equal 9.25402225959628

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.43142861206743
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.20189911830752
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1115   -2.9871562   -1.9573287   -1.9528435 
    1116   -2.9871562   -1.9573287   -1.9469237 
Loop time of 3.62381e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.47945046503755
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.25402225959628
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6291183312588
variable        y0 equal ${yi}
variable        y0 equal 9.2346125077042

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.5882198413067
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.13932036865086
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1116   -2.9871562   -1.9573287   -1.9469237 
    1117   -2.9871562   -1.9573287   -1.7926927 
Loop time of 3.58614e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6291183312588
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.2346125077042
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.444242735305691
variable        y0 equal ${yi}
variable        y0 equal 8.30422124780711

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.394595296779537
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.23746160186824
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1117   -2.9871562   -1.9573287   -1.7926927 
    1118   -2.9871562   -1.9573287   -1.9104624 
Loop time of 3.56428e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.444242735305691
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.30422124780711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.471242232719327
variable        y0 equal ${yi}
variable        y0 equal 6.49353084103098

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.431884725490476
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.53101284042826
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1118   -2.9871562   -1.9573287   -1.9104624 
    1119   -2.9871562   -1.9573287   -1.9549924 
Loop time of 3.56121e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.471242232719327
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.49353084103098
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.63595545449678
variable        y0 equal ${yi}
variable        y0 equal 0.131007170677185

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.58464017072145
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.181575858592987
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1119   -2.9871562   -1.9573287   -1.9549924 
    1120   -2.9871562   -1.9573287   -1.9023285 
Loop time of 3.64475e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.63595545449678
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.131007170677185
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.55870154936087
variable        y0 equal ${yi}
variable        y0 equal 9.25253196466296

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.49973816711676
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.17757205474704
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1120   -2.9871562   -1.9573287   -1.9023285 
    1121   -2.9871562   -1.9573287   -1.9335186 
Loop time of 3.55125e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.55870154936087
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.25253196466296
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.977072950595
variable        y0 equal ${yi}
variable        y0 equal 2.88160681697229

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.97122610449133
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.87912948104242
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1121   -2.9871562   -1.9573287   -1.9335186 
    1122   -2.9871562   -1.9573287    -1.967405 
Loop time of 3.57932e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.96740497339814
variable naccept equal ${increment}
variable naccept equal 273

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.78247871914988
variable        y0 equal ${yi}
variable        y0 equal 6.57109596268168

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.75350688019877
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.49352085129252
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1122   -2.9871562    -1.967405    -1.967405 
    1123   -2.9871562    -1.967405   -1.9791889 
Loop time of 3.50872e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.9791888936836
variable naccept equal ${increment}
variable naccept equal 274

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.93805575012504
variable        y0 equal ${yi}
variable        y0 equal 8.32736837781961

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.89759506820976
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.30636266387994
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1123   -2.9871562   -1.9791889   -1.9791889 
    1124   -2.9871562   -1.9791889   -1.9728762 
Loop time of 3.5949e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.93805575012504
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.32736837781961
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.14502597490654
variable        y0 equal ${yi}
variable        y0 equal 5.53364494984346

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.14566361347542
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.60219994728761
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1124   -2.9871562   -1.9791889   -1.9728762 
    1125   -2.9871562   -1.9791889   -1.9766267 
Loop time of 3.69331e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.14502597490654
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.53364494984346
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.20564439932213
variable        y0 equal ${yi}
variable        y0 equal 7.38570181455874

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.19470320383415
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.41677955713534
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1125   -2.9871562   -1.9791889   -1.9766267 
    1126   -2.9871562   -1.9791889   -1.9831058 
Loop time of 3.58914e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.9831057615596
variable naccept equal ${increment}
variable naccept equal 275

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.7578687568469
variable        y0 equal ${yi}
variable        y0 equal 8.39387903131541

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.81646621425581
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.381368362084
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1126   -2.9871562   -1.9831058   -1.9831058 
    1127   -2.9871562   -1.9831058   -1.9807809 
Loop time of 3.46897e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.7578687568469
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.39387903131541
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.47945046503755
variable        y0 equal ${yi}
variable        y0 equal 9.25402225959628

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.40183663447114
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.26865103948443
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1127   -2.9871562   -1.9831058   -1.9807809 
    1128   -2.9871562   -1.9831058    -1.995411 
Loop time of 3.5439e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.99541103200575
variable naccept equal ${increment}
variable naccept equal 276

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.18104984163141
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.97752848836283
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1128   -2.9871562    -1.995411    -1.995411 
    1129   -2.9871562    -1.995411   -1.9277205 
Loop time of 3.52068e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.444242735305691
variable        y0 equal ${yi}
variable        y0 equal 8.30422124780711

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.400680656829739
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.21996908105906
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1129   -2.9871562    -1.995411   -1.9277205 
    1130   -2.9871562    -1.995411    -1.930166 
Loop time of 3.56135e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.444242735305691
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.30422124780711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.42239316224176
variable        y0 equal ${yi}
variable        y0 equal 5.58969682400423

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.39151010035593
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.55357420389849
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1130   -2.9871562    -1.995411    -1.930166 
    1131   -2.9871562    -1.995411   -1.9834917 
Loop time of 3.53677e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.42239316224176
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.58969682400423
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.88052521029159
variable        y0 equal ${yi}
variable        y0 equal 4.76031438464091

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.93114805498764
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.78696730488703
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1131   -2.9871562    -1.995411   -1.9834917 
    1132   -2.9871562    -1.995411   -1.9909998 
Loop time of 3.595e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.88052521029159
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.76031438464091
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.8608382340192
variable        y0 equal ${yi}
variable        y0 equal 2.70200465890266

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.81152559478275
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.76030372353889
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1132   -2.9871562    -1.995411   -1.9909998 
    1133   -2.9871562    -1.995411    -1.884298 
Loop time of 3.48006e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.8608382340192
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.70200465890266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.7578687568469
variable        y0 equal ${yi}
variable        y0 equal 8.39387903131541

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.7673339625163
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.40072963155803
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1133   -2.9871562    -1.995411    -1.884298 
    1134   -2.9871562    -1.995411   -1.9949033 
Loop time of 3.57311e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.7578687568469
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.39387903131541
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.02497799355976
variable        y0 equal ${yi}
variable        y0 equal 0.911451740968555

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 6.00392820794575
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.864141031015247
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1134   -2.9871562    -1.995411   -1.9949033 
    1135   -2.9871562    -1.995411   -1.9971355 
Loop time of 3.61017e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -1.99713550607419
variable naccept equal ${increment}
variable naccept equal 277

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.02622429727413
variable        y0 equal ${yi}
variable        y0 equal 8.30461697496469

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.12160456775524
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.38838374532754
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1135   -2.9871562   -1.9971355   -1.9971355 
    1136   -2.9871562   -1.9971355   -1.9461867 
Loop time of 3.64685e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.02622429727413
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.30461697496469
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.40183663447114
variable        y0 equal ${yi}
variable        y0 equal 9.26865103948443

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.35056147654267
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.20379765737384
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1136   -2.9871562   -1.9971355   -1.9461867 
    1137   -2.9871562   -1.9971355   -1.9472306 
Loop time of 3.6142e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.40183663447114
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.26865103948443
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0128975868225374
variable        y0 equal ${yi}
variable        y0 equal 3.77990783019196

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x -0.0658611774444304
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.86835093064438
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1137   -2.9871562   -1.9971355   -1.9472306 
    1138   -2.9871562   -1.9971355   -1.9445278 
Loop time of 3.56126e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 0.0128975868225374
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.77990783019196
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.5938358386211
variable        y0 equal ${yi}
variable        y0 equal 5.70117394869524

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.522169586008
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.77965760176378
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1138   -2.9871562   -1.9971355   -1.9445278 
    1139   -2.9871562   -1.9971355   -1.9031622 
Loop time of 3.61408e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.5938358386211
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.70117394869524
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.77121166466352
variable        y0 equal ${yi}
variable        y0 equal 3.72175073189866

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.68858192442533
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.63603604598176
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1139   -2.9871562   -1.9971355   -1.9031622 
    1140   -2.9871562   -1.9971355   -1.9874575 
Loop time of 3.57211e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.77121166466352
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.72175073189866
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.5938358386211
variable        y0 equal ${yi}
variable        y0 equal 5.70117394869524

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.6742867310695
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.79287453835207
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1140   -2.9871562   -1.9971355   -1.9874575 
    1141   -2.9871562   -1.9971355   -1.9156287 
Loop time of 3.54691e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.5938358386211
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.70117394869524
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.41120611825848
variable        y0 equal ${yi}
variable        y0 equal 3.71720311207902

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.40737680593396
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.73942260308396
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1141   -2.9871562   -1.9971355   -1.9156287 
    1142   -2.9871562   -1.9971355   -2.0006752 
Loop time of 3.52057e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.0006752281591
variable naccept equal ${increment}
variable naccept equal 278

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82797947445994
variable        y0 equal ${yi}
variable        y0 equal 0.89721691201958

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.82182325640803
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.899742563474506
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1142   -2.9871562   -2.0006752   -2.0006752 
    1143   -2.9871562   -2.0006752   -1.9998318 
Loop time of 3.67703e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82797947445994
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.89721691201958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7380775292569
variable        y0 equal ${yi}
variable        y0 equal 7.41298324194217

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.7796016534024
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.50579228725696
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1143   -2.9871562   -2.0006752   -1.9998318 
    1144   -2.9871562   -2.0006752   -1.9308201 
Loop time of 3.66493e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7380775292569
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41298324194217
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.42371865907575
variable        y0 equal ${yi}
variable        y0 equal 1.7675963201291

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.49688249030973
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.78238482854432
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1144   -2.9871562   -2.0006752   -1.9308201 
    1145   -2.9871562   -2.0006752   -1.9770501 
Loop time of 3.51569e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.42371865907575
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.7675963201291
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.520060713687803
variable        y0 equal ${yi}
variable        y0 equal 2.88988070460657

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.43191434899893
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.80282083722452
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1145   -2.9871562   -2.0006752   -1.9770501 
    1146   -2.9871562   -2.0006752   -1.9095296 
Loop time of 3.60309e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.520060713687803
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.88988070460657
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.63480706095477
variable        y0 equal ${yi}
variable        y0 equal 2.83259171220163

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.62547737240573
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.83778620931009
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1146   -2.9871562   -2.0006752   -1.9095296 
    1147   -2.9871562   -2.0006752   -1.9992678 
Loop time of 4.0423e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.63480706095477
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.83259171220163
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.09708896001035
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.39305869665408
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1147   -2.9871562   -2.0006752   -1.9992678 
    1148   -2.9871562   -2.0006752   -1.9980713 
Loop time of 3.66741e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.00392820794575
variable        y0 equal ${yi}
variable        y0 equal 0.864141031015247

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 6.016895305705
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.870142837274402
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1148   -2.9871562   -2.0006752   -1.9980713 
    1149   -2.9871562   -2.0006752   -1.9993714 
Loop time of 3.52578e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 6.00392820794575
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.864141031015247
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.6302324012908
variable        y0 equal ${yi}
variable        y0 equal 0.804496832597583

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.578193898597624
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.726695605028003
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1149   -2.9871562   -2.0006752   -1.9993714 
    1150   -2.9871562   -2.0006752   -1.9895902 
Loop time of 3.51832e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.6302324012908
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.804496832597583
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.20436143318519
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.31911999311709
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1150   -2.9871562   -2.0006752   -1.9895902 
    1151   -2.9871562   -2.0006752    -1.974238 
Loop time of 3.64217e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.50628010192338
variable        y0 equal ${yi}
variable        y0 equal 1.936454562164

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.60461410441819
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.95453172109192
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1151   -2.9871562   -2.0006752    -1.974238 
    1152   -2.9871562   -2.0006752   -1.9894752 
Loop time of 3.65252e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.50628010192338
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.936454562164
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.5938358386211
variable        y0 equal ${yi}
variable        y0 equal 5.70117394869524

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.650485213583
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.67973738854128
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1152   -2.9871562   -2.0006752   -1.9894752 
    1153   -2.9871562   -2.0006752   -2.0100372 
Loop time of 3.52125e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.01003717620357
variable naccept equal ${increment}
variable naccept equal 279

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75591478546096
variable        y0 equal ${yi}
variable        y0 equal 4.61056455725595

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.76012865503265
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.69902127140924
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1153   -2.9871562   -2.0100372   -2.0100372 
    1154   -2.9871562   -2.0100372   -1.9914297 
Loop time of 3.64944e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.75591478546096
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.61056455725595
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.0748247806202
variable        y0 equal ${yi}
variable        y0 equal 3.76523935361039

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.15449824968682
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.83953256173264
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1154   -2.9871562   -2.0100372   -1.9914297 
    1155   -2.9871562   -2.0100372   -2.0131714 
Loop time of 3.53406e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.01317143236807
variable naccept equal ${increment}
variable naccept equal 280

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.40737680593396
variable        y0 equal ${yi}
variable        y0 equal 3.73942260308396

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.49588650861646
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.67805612845551
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1155   -2.9871562   -2.0131714   -2.0131714 
    1156   -2.9871562   -2.0131714    -2.006232 
Loop time of 3.47555e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.40737680593396
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.73942260308396
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.71365280667431
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.64998724812434
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1156   -2.9871562   -2.0131714    -2.006232 
    1157   -2.9871562   -2.0131714   -1.9982217 
Loop time of 3.48673e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.40183663447114
variable        y0 equal ${yi}
variable        y0 equal 9.26865103948443

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.39706934769364
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.33193389880984
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1157   -2.9871562   -2.0131714   -1.9982217 
    1158   -2.9871562   -2.0131714   -2.0112284 
Loop time of 3.6338e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.40183663447114
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.26865103948443
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.49434810399133
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.24612338867449
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1158   -2.9871562   -2.0131714   -2.0112284 
    1159   -2.9871562   -2.0131714   -1.9749975 
Loop time of 3.65927e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47168833731729
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.2979036006
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3219509963055
variable        y0 equal ${yi}
variable        y0 equal 0.846012469041675

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.3403910283108
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.807549484479755
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1159   -2.9871562   -2.0131714   -1.9749975 
    1160   -2.9871562   -2.0131714   -1.9838035 
Loop time of 3.64921e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.3219509963055
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.846012469041675
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.75350688019877
variable        y0 equal ${yi}
variable        y0 equal 6.49352085129252

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.71406083623057
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.39451940790644
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1160   -2.9871562   -2.0131714   -1.9838035 
    1161   -2.9871562   -2.0131714   -1.9835526 
Loop time of 6.20784e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.75350688019877
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.49352085129252
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3219509963055
variable        y0 equal ${yi}
variable        y0 equal 0.846012469041675

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.3403497818966
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.945441253888935
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1161   -2.9871562   -2.0131714   -1.9835526 
    1162   -2.9871562   -2.0131714   -2.0072124 
Loop time of 3.63055e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.3219509963055
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.846012469041675
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82797947445994
variable        y0 equal ${yi}
variable        y0 equal 0.89721691201958

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.7373522333253
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.965796657312244
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1162   -2.9871562   -2.0131714   -2.0072124 
    1163   -2.9871562   -2.0131714   -1.9673539 
Loop time of 3.5786e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82797947445994
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.89721691201958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.444242735305691
variable        y0 equal ${yi}
variable        y0 equal 8.30422124780711

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.530149836936856
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.3636522761732
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1163   -2.9871562   -2.0131714   -1.9673539 
    1164   -2.9871562   -2.0131714   -1.9799669 
Loop time of 3.57336e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.444242735305691
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.30422124780711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.22285979706795
variable        y0 equal ${yi}
variable        y0 equal 2.74353152486184

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.3066303106025
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.76427937718728
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1164   -2.9871562   -2.0131714   -1.9799669 
    1165   -2.9871562   -2.0131714   -2.0016504 
Loop time of 3.5568e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.22285979706795
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.74353152486184
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.63480706095477
variable        y0 equal ${yi}
variable        y0 equal 2.83259171220163

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.66544155955096
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.92848974439005
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1165   -2.9871562   -2.0131714   -2.0016504 
    1166   -2.9871562   -2.0131714   -1.9884912 
Loop time of 3.57144e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.63480706095477
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.83259171220163
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.1493705244735
variable        y0 equal ${yi}
variable        y0 equal 4.58995101803705

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.17273776251824
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.55392747277185
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1166   -2.9871562   -2.0131714   -1.9884912 
    1167   -2.9871562   -2.0131714   -2.0062875 
Loop time of 3.53959e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.1493705244735
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.58995101803705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.64779524683733
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.25504087127742
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1167   -2.9871562   -2.0131714   -2.0062875 
    1168   -2.9871562   -2.0131714    -2.003648 
Loop time of 3.59323e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.36321673154392
variable        y0 equal ${yi}
variable        y0 equal 1.8523390569455

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.27499524116077
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.86645225665635
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1168   -2.9871562   -2.0131714    -2.003648 
    1169   -2.9871562   -2.0131714   -2.0040417 
Loop time of 3.6363e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.36321673154392
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.8523390569455
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54731318790685
variable        y0 equal ${yi}
variable        y0 equal 3.75024119181764

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.47222158748876
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.70434735579622
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1169   -2.9871562   -2.0131714   -2.0040417 
    1170   -2.9871562   -2.0131714    -1.988311 
Loop time of 3.64677e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54731318790685
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75024119181764
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.28159687597963
variable        y0 equal ${yi}
variable        y0 equal 7.4978555950191

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.37309358198854
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.47418843832278
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1170   -2.9871562   -2.0131714    -1.988311 
    1171   -2.9871562   -2.0131714   -2.0156408 
Loop time of 3.6658e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.01564083208766
variable naccept equal ${increment}
variable naccept equal 281

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.79833471099025
variable        y0 equal ${yi}
variable        y0 equal 2.75330324145654

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.78951489249355
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.71340123387674
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1171   -2.9871562   -2.0156408   -2.0156408 
    1172   -2.9871562   -2.0156408   -2.0013107 
Loop time of 3.47624e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.79833471099025
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.75330324145654
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.42793486197206
variable        y0 equal ${yi}
variable        y0 equal 1.83933557651109

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.37491308529588
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.76059159419603
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1172   -2.9871562   -2.0156408   -2.0013107 
    1173   -2.9871562   -2.0156408   -2.0077716 
Loop time of 3.56416e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.42793486197206
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.83933557651109
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.81734974343768
variable        y0 equal ${yi}
variable        y0 equal 4.6230520998852

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.77796752412311
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.53915511721537
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1173   -2.9871562   -2.0156408   -2.0077716 
    1174   -2.9871562   -2.0156408   -1.9257937 
Loop time of 3.57456e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.81734974343768
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.6230520998852
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 6.9320023683612
variable        y0 equal ${yi}
variable        y0 equal 2.82359918328622

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.91334146538421
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.86240864964822
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1174   -2.9871562   -2.0156408   -1.9257937 
    1175   -2.9871562   -2.0156408   -2.0032288 
Loop time of 3.6948e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 6.9320023683612
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.82359918328622
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.74466399152708
variable        y0 equal ${yi}
variable        y0 equal 2.74569092961648

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.75930469234419
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.65835893126824
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1175   -2.9871562   -2.0156408   -2.0032288 
    1176   -2.9871562   -2.0156408   -1.9871443 
Loop time of 3.5377e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.74466399152708
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.74569092961648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.77121166466352
variable        y0 equal ${yi}
variable        y0 equal 3.72175073189866

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.70109274862882
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.70061683220994
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1176   -2.9871562   -2.0156408   -1.9871443 
    1177   -2.9871562   -2.0156408   -2.0213749 
Loop time of 3.6388e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.02137491111784
variable naccept equal ${increment}
variable naccept equal 282

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3219509963055
variable        y0 equal ${yi}
variable        y0 equal 0.846012469041675

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.3452798966427
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.803210588205188
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1177   -2.9871562   -2.0213749   -2.0213749 
    1178   -2.9871562   -2.0213749   -1.9859538 
Loop time of 3.59521e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.3219509963055
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.846012469041675
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.88052521029159
variable        y0 equal ${yi}
variable        y0 equal 4.76031438464091

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.80114808359786
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.84610122794078
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1178   -2.9871562   -2.0213749   -1.9859538 
    1179   -2.9871562   -2.0213749    -1.799566 
Loop time of 3.68266e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.88052521029159
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.76031438464091
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.72451406041271
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.67861571663783
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1179   -2.9871562   -2.0213749    -1.799566 
    1180   -2.9871562   -2.0213749   -2.0099794 
Loop time of 3.64084e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 7.06044206896469
variable        y0 equal ${yi}
variable        y0 equal 6.51616222397318

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.11607330122635
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.50073685184946
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1180   -2.9871562   -2.0213749   -2.0099794 
    1181   -2.9871562   -2.0213749   -1.9834992 
Loop time of 3.60263e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 7.06044206896469
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.51616222397318
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.03516697286464
variable        y0 equal ${yi}
variable        y0 equal 6.55468170181741

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 7.98110986350871
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.61342200771798
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1181   -2.9871562   -2.0213749   -1.9834992 
    1182   -2.9871562   -2.0213749   -1.9680345 
Loop time of 3.69395e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.03516697286464
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.55468170181741
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.10421633163795
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.83522302291458
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1182   -2.9871562   -2.0213749   -1.9680345 
    1183   -2.9871562   -2.0213749   -2.0193154 
Loop time of 3.53858e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.93050993322669
variable        y0 equal ${yi}
variable        y0 equal 6.34705883995524

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 5.00746601461707
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.36561738983622
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1183   -2.9871562   -2.0213749   -2.0193154 
    1184   -2.9871562   -2.0213749   -1.8933824 
Loop time of 3.61861e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.93050993322669
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.34705883995524
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.01394880412914
variable        y0 equal ${yi}
variable        y0 equal 4.70269989127085

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 7.94163720010616
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.77196945303843
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1184   -2.9871562   -2.0213749   -1.8933824 
    1185   -2.9871562   -2.0213749   -1.9826666 
Loop time of 3.53519e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.01394880412914
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.70269989127085
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.07785165627651
variable        y0 equal ${yi}
variable        y0 equal 1.86409153125352

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.14450186808758
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.8815385617978
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1185   -2.9871562   -2.0213749   -1.9826666 
    1186   -2.9871562   -2.0213749   -2.0297209 
Loop time of 3.54032e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.02972094507468
variable naccept equal ${increment}
variable naccept equal 283

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.1395422999035
variable        y0 equal ${yi}
variable        y0 equal 9.26925461995929

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.21645496527063
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 9.32952886331409
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1186   -2.9871562   -2.0297209   -2.0297209 
    1187   -2.9871562   -2.0297209   -2.0296301 
Loop time of 3.57245e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.02963008454577
variable naccept equal ${increment}
variable naccept equal 284

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.39977147975828
variable        y0 equal ${yi}
variable        y0 equal 7.33912527885698

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.49273593822386
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.38600676384233
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1187   -2.9871562   -2.0296301   -2.0296301 
    1188   -2.9871562   -2.0296301   -2.0176459 
Loop time of 3.64717e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.39977147975828
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.33912527885698
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.53927736996728
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.24006181087756
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1188   -2.9871562   -2.0296301   -2.0176459 
    1189   -2.9871562   -2.0296301   -1.9271365 
Loop time of 3.52604e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47168833731729
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.2979036006
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.75350688019877
variable        y0 equal ${yi}
variable        y0 equal 6.49352085129252

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.81859772721415
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.51868253485194
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1189   -2.9871562   -2.0296301   -1.9271365 
    1190   -2.9871562   -2.0296301   -2.0319729 
Loop time of 6.083e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.03197293208134
variable naccept equal ${increment}
variable naccept equal 285

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.44468214351904
variable        y0 equal ${yi}
variable        y0 equal 1.838471952892

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.37177669842016
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.882863263107
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1190   -2.9871562   -2.0319729   -2.0319729 
    1191   -2.9871562   -2.0319729   -2.0002752 
Loop time of 3.57971e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.44468214351904
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.838471952892
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.67839514174882
variable        y0 equal ${yi}
variable        y0 equal 3.73824497027528

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.6576410786194
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.7081167058481
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1191   -2.9871562   -2.0319729   -2.0002752 
    1192   -2.9871562   -2.0319729   -2.0386109 
Loop time of 3.49525e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.03861088640886
variable naccept equal ${increment}
variable naccept equal 286

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.7578687568469
variable        y0 equal ${yi}
variable        y0 equal 8.39387903131541

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.84931912620496
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.32087517894801
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1192   -2.9871562   -2.0386109   -2.0386109 
    1193   -2.9871562   -2.0386109   -2.0277959 
Loop time of 3.58876e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.7578687568469
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.39387903131541
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.42239316224176
variable        y0 equal ${yi}
variable        y0 equal 5.58969682400423

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.36651968478281
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.64549362604814
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1193   -2.9871562   -2.0386109   -2.0277959 
    1194   -2.9871562   -2.0386109   -1.9563399 
Loop time of 3.58488e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.42239316224176
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.58969682400423
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 6.02990794141284
variable        y0 equal ${yi}
variable        y0 equal 8.29363690532741

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.09604406316272
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.22993471540508
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1194   -2.9871562   -2.0386109   -1.9563399 
    1195   -2.9871562   -2.0386109    -1.963539 
Loop time of 3.54729e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 6.02990794141284
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.29363690532741
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.18923630793306
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.57717388813693
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1195   -2.9871562   -2.0386109    -1.963539 
    1196   -2.9871562   -2.0386109   -2.0281512 
Loop time of 3.57016e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.92188998102486
variable        y0 equal ${yi}
variable        y0 equal 0.869733079183434

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 5.00585063337624
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.804548271406029
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1196   -2.9871562   -2.0386109   -2.0281512 
    1197   -2.9871562   -2.0386109   -2.0091631 
Loop time of 3.57449e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.92188998102486
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.869733079183434
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.57918032883284
variable        y0 equal ${yi}
variable        y0 equal 0.0850776791572572

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.53504850147841
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.0161377668380738
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1197   -2.9871562   -2.0386109   -2.0091631 
    1198   -2.9871562   -2.0386109   -1.9940269 
Loop time of 3.69485e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 79 x ${x0}
set atom 79 x 9.57918032883284
  1 settings made for x
set atom $i y ${y0}
set atom 79 y ${y0}
set atom 79 y 0.0850776791572572
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.42793486197206
variable        y0 equal ${yi}
variable        y0 equal 1.83933557651109

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.52691242773744
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.76785669705934
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1198   -2.9871562   -2.0386109   -1.9940269 
    1199   -2.9871562   -2.0386109   -1.9524517 
Loop time of 3.59852e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.42793486197206
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.83933557651109
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.7141129513545
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.53802260891428
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1199   -2.9871562   -2.0386109   -1.9524517 
    1200   -2.9871562   -2.0386109   -2.0278299 
Loop time of 3.5478e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.471242232719327
variable        y0 equal ${yi}
variable        y0 equal 6.49353084103098

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.467624564567472
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.53444678322306
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1200   -2.9871562   -2.0386109   -2.0278299 
    1201   -2.9871562   -2.0386109   -2.0431604 
Loop time of 3.54867e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.04316041928561
variable naccept equal ${increment}
variable naccept equal 287

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.86732061425333
variable        y0 equal ${yi}
variable        y0 equal 8.43319919027385

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.91285182753687
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.4636543742567
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1201   -2.9871562   -2.0431604   -2.0431604 
    1202   -2.9871562   -2.0431604   -2.0163515 
Loop time of 3.62626e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.86732061425333
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.43319919027385
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.71003035782453
variable        y0 equal ${yi}
variable        y0 equal 7.4907858523395

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.76638019560453
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.42700258817934
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1202   -2.9871562   -2.0431604   -2.0163515 
    1203   -2.9871562   -2.0431604   -2.0133888 
Loop time of 3.55277e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 99 x ${x0}
set atom 99 x 9.71003035782453
  1 settings made for x
set atom $i y ${y0}
set atom 99 y ${y0}
set atom 99 y 7.4907858523395
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 6.02990794141284
variable        y0 equal ${yi}
variable        y0 equal 8.29363690532741

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.0544263120412
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.348205172196
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1203   -2.9871562   -2.0431604   -2.0133888 
    1204   -2.9871562   -2.0431604   -2.0210125 
Loop time of 3.64253e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 6.02990794141284
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.29363690532741
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.42371865907575
variable        y0 equal ${yi}
variable        y0 equal 1.7675963201291

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.36212658086683
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.83420915982789
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1204   -2.9871562   -2.0431604   -2.0210125 
    1205   -2.9871562   -2.0431604   -2.0176573 
Loop time of 3.56573e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.42371865907575
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.7675963201291
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.59587104518843
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.52673739925852
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1205   -2.9871562   -2.0431604   -2.0176573 
    1206   -2.9871562   -2.0431604   -2.0246946 
Loop time of 3.64535e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.14450186808758
variable        y0 equal ${yi}
variable        y0 equal 1.8815385617978

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.09933940489941
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.87607542655534
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1206   -2.9871562   -2.0431604   -2.0246946 
    1207   -2.9871562   -2.0431604   -2.0410172 
Loop time of 3.55003e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.14450186808758
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.8815385617978
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.43551569699365
variable        y0 equal ${yi}
variable        y0 equal 1.89214071414535

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.37599049328882
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.83015450618331
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1207   -2.9871562   -2.0431604   -2.0410172 
    1208   -2.9871562   -2.0431604   -2.0313653 
Loop time of 3.6578e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.43551569699365
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.89214071414535
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2971436027547
variable        y0 equal ${yi}
variable        y0 equal 4.75506552809641

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.2367704752942
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.84632073992655
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1208   -2.9871562   -2.0431604   -2.0313653 
    1209   -2.9871562   -2.0431604   -1.9689561 
Loop time of 3.54005e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.2971436027547
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.75506552809641
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.55870154936087
variable        y0 equal ${yi}
variable        y0 equal 9.25253196466296

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.45912840206396
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.24604691970675
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1209   -2.9871562   -2.0431604   -1.9689561 
    1210   -2.9871562   -2.0431604   -2.0083585 
Loop time of 3.56602e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.55870154936087
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.25253196466296
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.10567082484418
variable        y0 equal ${yi}
variable        y0 equal 3.7027230934633

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.1096025260275
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.7893677787317
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1210   -2.9871562   -2.0431604   -2.0083585 
    1211   -2.9871562   -2.0431604   -2.0450841 
Loop time of 3.59503e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.04508408209914
variable naccept equal ${increment}
variable naccept equal 288

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.45505593855154
variable        y0 equal ${yi}
variable        y0 equal 7.39650682535434

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.48385869104635
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.38020931806827
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1211   -2.9871562   -2.0450841   -2.0450841 
    1212   -2.9871562   -2.0450841   -2.0464444 
Loop time of 3.6222e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.0464444104666
variable naccept equal ${increment}
variable naccept equal 289

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.1493705244735
variable        y0 equal ${yi}
variable        y0 equal 4.58995101803705

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.14458888489754
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.66268037909433
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1212   -2.9871562   -2.0464444   -2.0464444 
    1213   -2.9871562   -2.0464444   -2.0146936 
Loop time of 3.58551e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.1493705244735
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.58995101803705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.14450186808758
variable        y0 equal ${yi}
variable        y0 equal 1.8815385617978

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.08959751446896
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.78425991914338
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1213   -2.9871562   -2.0464444   -2.0146936 
    1214   -2.9871562   -2.0464444   -2.0372354 
Loop time of 3.4867e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.14450186808758
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.8815385617978
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.71318878133726
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.44230272308817
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1214   -2.9871562   -2.0464444   -2.0372354 
    1215   -2.9871562   -2.0464444   -2.0425969 
Loop time of 3.71437e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.02537268677399
variable        y0 equal ${yi}
variable        y0 equal 0.926061685788958

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.07822217026398
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.904532392728655
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1215   -2.9871562   -2.0464444   -2.0425969 
    1216   -2.9871562   -2.0464444   -2.0360272 
Loop time of 3.61905e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.02537268677399
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.926061685788958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.93050993322669
variable        y0 equal ${yi}
variable        y0 equal 6.34705883995524

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.85694417595206
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.25868141190043
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1216   -2.9871562   -2.0464444   -2.0360272 
    1217   -2.9871562   -2.0464444   -1.9252471 
Loop time of 3.53239e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.93050993322669
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.34705883995524
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.63480706095477
variable        y0 equal ${yi}
variable        y0 equal 2.83259171220163

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.59251241564532
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.74855053397516
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1217   -2.9871562   -2.0464444   -1.9252471 
    1218   -2.9871562   -2.0464444    -2.023126 
Loop time of 3.57796e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.63480706095477
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.83259171220163
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.79833471099025
variable        y0 equal ${yi}
variable        y0 equal 2.75330324145654

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.87144294301158
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.78142455788949
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1218   -2.9871562   -2.0464444    -2.023126 
    1219   -2.9871562   -2.0464444   -2.0542014 
Loop time of 3.59012e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.05420136728354
variable naccept equal ${increment}
variable naccept equal 290

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.05018270610667
variable        y0 equal ${yi}
variable        y0 equal 0.883626898038715

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.08605186342097
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.950601537931293
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1219   -2.9871562   -2.0542014   -2.0542014 
    1220   -2.9871562   -2.0542014   -2.0697416 
Loop time of 3.55669e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.06974156963354
variable naccept equal ${increment}
variable naccept equal 291

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.77895602463362
variable        y0 equal ${yi}
variable        y0 equal 1.81722146651811

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.85536535261748
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.78223531625337
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1220   -2.9871562   -2.0697416   -2.0697416 
    1221   -2.9871562   -2.0697416   -2.0660682 
Loop time of 3.53885e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.77895602463362
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.81722146651811
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0128975868225374
variable        y0 equal ${yi}
variable        y0 equal 3.77990783019196

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 0.00899409055712602
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.86809534592759
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1221   -2.9871562   -2.0697416   -2.0660682 
    1222   -2.9871562   -2.0697416   -2.0600354 
Loop time of 3.53708e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 0.0128975868225374
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.77990783019196
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.1260053876897
variable        y0 equal ${yi}
variable        y0 equal 8.43344125665721

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.0880036000272
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.41472051061687
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1222   -2.9871562   -2.0697416   -2.0600354 
    1223   -2.9871562   -2.0697416   -2.0801189 
Loop time of 3.56084e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.08011890451265
variable naccept equal ${increment}
variable naccept equal 292

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.40183663447114
variable        y0 equal ${yi}
variable        y0 equal 9.26865103948443

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.35622006733628
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.31842041719286
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1223   -2.9871562   -2.0801189   -2.0801189 
    1224   -2.9871562   -2.0801189   -2.0789277 
Loop time of 3.5909e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.40183663447114
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.26865103948443
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.50875395376456
variable        y0 equal ${yi}
variable        y0 equal 5.60411881153779

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.42310156662238
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.6235783452292
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1224   -2.9871562   -2.0801189   -2.0789277 
    1225   -2.9871562   -2.0801189   -2.0550598 
Loop time of 3.53419e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.50875395376456
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.60411881153779
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75591478546096
variable        y0 equal ${yi}
variable        y0 equal 4.61056455725595

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.69529688556625
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.69740037077829
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1225   -2.9871562   -2.0801189   -2.0550598 
    1226   -2.9871562   -2.0801189    -2.079782 
Loop time of 3.59896e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.75591478546096
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.61056455725595
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82797947445994
variable        y0 equal ${yi}
variable        y0 equal 0.89721691201958

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.87983915129786
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.835797878015369
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1226   -2.9871562   -2.0801189    -2.079782 
    1227   -2.9871562   -2.0801189   -2.0709652 
Loop time of 3.7588e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82797947445994
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.89721691201958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.67264876246233
variable        y0 equal ${yi}
variable        y0 equal 0.871292896974415

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.60164279818316
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.965081926095814
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1227   -2.9871562   -2.0801189   -2.0709652 
    1228   -2.9871562   -2.0801189   -2.0699508 
Loop time of 3.57721e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.67264876246233
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.871292896974415
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.67264876246233
variable        y0 equal ${yi}
variable        y0 equal 0.871292896974415

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.64305690407534
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.838249679315418
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1228   -2.9871562   -2.0801189   -2.0699508 
    1229   -2.9871562   -2.0801189   -2.0731095 
Loop time of 3.5986e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.67264876246233
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.871292896974415
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.05858910678721
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.93125933381418
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1229   -2.9871562   -2.0801189   -2.0731095 
    1230   -2.9871562   -2.0801189   -2.0614007 
Loop time of 3.53037e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.14450186808758
variable        y0 equal ${yi}
variable        y0 equal 1.8815385617978

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.11691451390438
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.88451303622788
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1230   -2.9871562   -2.0801189   -2.0614007 
    1231   -2.9871562   -2.0801189   -2.0802213 
Loop time of 3.49745e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.08022127324264
variable naccept equal ${increment}
variable naccept equal 293

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20891928433934
variable        y0 equal ${yi}
variable        y0 equal 5.56093283837038

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.18084370851079
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.56798210089403
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1231   -2.9871562   -2.0802213   -2.0802213 
    1232   -2.9871562   -2.0802213   -2.0770092 
Loop time of 3.43321e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20891928433934
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56093283837038
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.03516697286464
variable        y0 equal ${yi}
variable        y0 equal 6.55468170181741

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.06752826570369
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.5408651901864
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1232   -2.9871562   -2.0802213   -2.0770092 
    1233   -2.9871562   -2.0802213   -2.0868428 
Loop time of 3.68559e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.08684282550895
variable naccept equal ${increment}
variable naccept equal 294

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78581515748931
variable        y0 equal ${yi}
variable        y0 equal 1.04153251241478

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.84789194066955
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.04790150712761
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1233   -2.9871562   -2.0868428   -2.0868428 
    1234   -2.9871562   -2.0868428   -2.0613121 
Loop time of 3.48886e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.78581515748931
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.04153251241478
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82797947445994
variable        y0 equal ${yi}
variable        y0 equal 0.89721691201958

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.78681855717784
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.933114345777362
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1234   -2.9871562   -2.0868428   -2.0613121 
    1235   -2.9871562   -2.0868428   -2.0762743 
Loop time of 3.57141e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82797947445994
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.89721691201958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.56331699967166
variable        y0 equal ${yi}
variable        y0 equal 6.51610798374643

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.5961974489667
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.55421015755167
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1235   -2.9871562   -2.0868428   -2.0762743 
    1236   -2.9871562   -2.0868428   -2.0878587 
Loop time of 3.7507e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.08785869129181
variable naccept equal ${increment}
variable naccept equal 295

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.22191747505876
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.55020866339404
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1236   -2.9871562   -2.0878587   -2.0878587 
    1237   -2.9871562   -2.0878587   -2.0876543 
Loop time of 3.55649e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.92188998102486
variable        y0 equal ${yi}
variable        y0 equal 0.869733079183434

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.8900455796653
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.887486429918145
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1237   -2.9871562   -2.0878587   -2.0876543 
    1238   -2.9871562   -2.0878587   -2.0871636 
Loop time of 3.59422e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.08716356080169
variable naccept equal ${increment}
variable naccept equal 296

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.63480706095477
variable        y0 equal ${yi}
variable        y0 equal 2.83259171220163

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.60699390053531
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.75067588063577
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1238   -2.9871562   -2.0871636   -2.0871636 
    1239   -2.9871562   -2.0871636   -2.0690508 
Loop time of 3.52519e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.63480706095477
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.83259171220163
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.75571450511104
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.73598080033229
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1239   -2.9871562   -2.0871636   -2.0690508 
    1240   -2.9871562   -2.0871636   -2.0715053 
Loop time of 3.52104e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.7578687568469
variable        y0 equal ${yi}
variable        y0 equal 8.39387903131541

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.72197404106092
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.43824620164927
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1240   -2.9871562   -2.0871636   -2.0715053 
    1241   -2.9871562   -2.0871636    -2.079212 
Loop time of 3.49935e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.7578687568469
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.39387903131541
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0880036000272
variable        y0 equal ${yi}
variable        y0 equal 8.41472051061687

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.0499979976674
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.36318765796718
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1241   -2.9871562   -2.0871636    -2.079212 
    1242   -2.9871562   -2.0871636   -2.0681399 
Loop time of 3.5186e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.0880036000272
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.41472051061687
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.36321673154392
variable        y0 equal ${yi}
variable        y0 equal 1.8523390569455

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.30958131312885
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.78912239453858
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1242   -2.9871562   -2.0871636   -2.0681399 
    1243   -2.9871562   -2.0871636   -2.0395327 
Loop time of 3.60594e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.36321673154392
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.8523390569455
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.650485213583
variable        y0 equal ${yi}
variable        y0 equal 5.67973738854128

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.6736718733959
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.61172091906267
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1243   -2.9871562   -2.0871636   -2.0395327 
    1244   -2.9871562   -2.0871636   -2.0692173 
Loop time of 3.56253e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.650485213583
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.67973738854128
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.55870154936087
variable        y0 equal ${yi}
variable        y0 equal 9.25253196466296

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.46396787006628
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.32107061851352
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1244   -2.9871562   -2.0871636   -2.0692173 
    1245   -2.9871562   -2.0871636   -2.0507758 
Loop time of 3.53997e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.55870154936087
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.25253196466296
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.520060713687803
variable        y0 equal ${yi}
variable        y0 equal 2.88988070460657

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.456307776370909
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.91903431388239
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1245   -2.9871562   -2.0871636   -2.0507758 
    1246   -2.9871562   -2.0871636   -2.0109348 
Loop time of 3.54835e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.520060713687803
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.88988070460657
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.47115233658868
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.20769968357348
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1246   -2.9871562   -2.0871636   -2.0109348 
    1247   -2.9871562   -2.0871636   -2.0357391 
Loop time of 3.50268e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47168833731729
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.2979036006
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.73788064876024
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.75094509883058
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1247   -2.9871562   -2.0871636   -2.0357391 
    1248   -2.9871562   -2.0871636   -2.0439945 
Loop time of 3.60571e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.26462735890904
variable        y0 equal ${yi}
variable        y0 equal 3.68544435067308

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.35170801639119
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.58696794076097
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1248   -2.9871562   -2.0871636   -2.0439945 
    1249   -2.9871562   -2.0871636   -2.0407442 
Loop time of 3.60341e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.26462735890904
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.68544435067308
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.15449824968682
variable        y0 equal ${yi}
variable        y0 equal 3.83953256173264

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.05949656406747
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.8778437690271
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1249   -2.9871562   -2.0871636   -2.0407442 
    1250   -2.9871562   -2.0871636   -2.0344444 
Loop time of 3.50186e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.15449824968682
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.83953256173264
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3219509963055
variable        y0 equal ${yi}
variable        y0 equal 0.846012469041675

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.352406740572
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.932316275346607
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1250   -2.9871562   -2.0871636   -2.0344444 
    1251   -2.9871562   -2.0871636   -2.0818757 
Loop time of 3.62785e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.3219509963055
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.846012469041675
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.02537268677399
variable        y0 equal ${yi}
variable        y0 equal 0.926061685788958

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 6.96656333485291
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.95227506946358
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1251   -2.9871562   -2.0871636   -2.0818757 
    1252   -2.9871562   -2.0871636   -2.0726985 
Loop time of 3.56619e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.02537268677399
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.926061685788958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.18865935881349
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.66837321465213
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1252   -2.9871562   -2.0871636   -2.0726985 
    1253   -2.9871562   -2.0871636   -2.0379502 
Loop time of 3.55511e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.88052521029159
variable        y0 equal ${yi}
variable        y0 equal 4.76031438464091

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.88754160681411
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.83181625956462
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1253   -2.9871562   -2.0871636   -2.0379502 
    1254   -2.9871562   -2.0871636   -2.0159492 
Loop time of 3.66113e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.88052521029159
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.76031438464091
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.15449824968682
variable        y0 equal ${yi}
variable        y0 equal 3.83953256173264

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.19995692411767
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.89043402238022
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1254   -2.9871562   -2.0871636   -2.0159492 
    1255   -2.9871562   -2.0871636   -2.0378429 
Loop time of 3.48972e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.15449824968682
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.83953256173264
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.40183663447114
variable        y0 equal ${yi}
variable        y0 equal 9.26865103948443

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.38238061745378
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.36215121257632
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1255   -2.9871562   -2.0871636   -2.0378429 
    1256   -2.9871562   -2.0871636   -2.0753032 
Loop time of 3.50774e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.40183663447114
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.26865103948443
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.11234346348793
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.56240842260416
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1256   -2.9871562   -2.0871636   -2.0753032 
    1257   -2.9871562   -2.0871636   -2.0429615 
Loop time of 3.54275e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.03154995162041
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.4676475397497
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3219509963055
variable        y0 equal ${yi}
variable        y0 equal 0.846012469041675

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.3921663407345
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.792940195310443
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1257   -2.9871562   -2.0871636   -2.0429615 
    1258   -2.9871562   -2.0871636    -2.012863 
Loop time of 3.54776e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.3219509963055
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.846012469041675
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.00392820794575
variable        y0 equal ${yi}
variable        y0 equal 0.864141031015247

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 6.01885508258335
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.854142566430896
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1258   -2.9871562   -2.0871636    -2.012863 
    1259   -2.9871562   -2.0871636   -2.0824776 
Loop time of 3.6674e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 6.00392820794575
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.864141031015247
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.650485213583
variable        y0 equal ${yi}
variable        y0 equal 5.67973738854128

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.5744429190807
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.70718094055849
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1259   -2.9871562   -2.0871636   -2.0824776 
    1260   -2.9871562   -2.0871636    -2.068255 
Loop time of 3.52241e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.650485213583
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.67973738854128
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.50628010192338
variable        y0 equal ${yi}
variable        y0 equal 1.936454562164

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.41222801366273
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.96541057012146
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1260   -2.9871562   -2.0871636    -2.068255 
    1261   -2.9871562   -2.0871636   -2.0602681 
Loop time of 3.60002e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.50628010192338
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.936454562164
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.08605186342097
variable        y0 equal ${yi}
variable        y0 equal 0.950601537931293

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.08594568370677
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.872425206411212
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1261   -2.9871562   -2.0871636   -2.0602681 
    1262   -2.9871562   -2.0871636   -2.0518421 
Loop time of 3.59175e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.08605186342097
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.950601537931293
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78581515748931
variable        y0 equal ${yi}
variable        y0 equal 1.04153251241478

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.81124744613601
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.09393161128792
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1262   -2.9871562   -2.0871636   -2.0518421 
    1263   -2.9871562   -2.0871636   -2.0553179 
Loop time of 3.58957e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.78581515748931
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.04153251241478
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.63480706095477
variable        y0 equal ${yi}
variable        y0 equal 2.83259171220163

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.65521777748843
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.91274797889093
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1263   -2.9871562   -2.0871636   -2.0553179 
    1264   -2.9871562   -2.0871636   -2.0826894 
Loop time of 3.55885e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.63480706095477
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.83259171220163
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.68400031485979
variable        y0 equal ${yi}
variable        y0 equal 7.40458581772113

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.74443187871401
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.34354160156512
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1264   -2.9871562   -2.0871636   -2.0826894 
    1265   -2.9871562   -2.0871636   -2.0439401 
Loop time of 3.48152e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.68400031485979
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.40458581772113
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.00922752936536
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.38159917917513
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1265   -2.9871562   -2.0871636   -2.0439401 
    1266   -2.9871562   -2.0871636   -2.0742561 
Loop time of 3.51189e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.77895602463362
variable        y0 equal ${yi}
variable        y0 equal 1.81722146651811

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.83481663941023
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.73427629849977
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1266   -2.9871562   -2.0871636   -2.0742561 
    1267   -2.9871562   -2.0871636   -2.0644573 
Loop time of 3.46767e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.77895602463362
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.81722146651811
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.43551569699365
variable        y0 equal ${yi}
variable        y0 equal 1.89214071414535

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.49394695281106
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.9419732966191
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1267   -2.9871562   -2.0871636   -2.0644573 
    1268   -2.9871562   -2.0871636   -2.0601597 
Loop time of 3.43939e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.43551569699365
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.89214071414535
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.44468214351904
variable        y0 equal ${yi}
variable        y0 equal 1.838471952892

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.41392129499685
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.75338049314087
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1268   -2.9871562   -2.0871636   -2.0601597 
    1269   -2.9871562   -2.0871636   -2.0283403 
Loop time of 3.68027e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.44468214351904
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.838471952892
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.77895602463362
variable        y0 equal ${yi}
variable        y0 equal 1.81722146651811

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.83057032106993
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.83415137908525
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1269   -2.9871562   -2.0871636   -2.0283403 
    1270   -2.9871562   -2.0871636   -2.0953273 
Loop time of 3.56525e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.09532728144892
variable naccept equal ${increment}
variable naccept equal 297

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2971436027547
variable        y0 equal ${yi}
variable        y0 equal 4.75506552809641

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.3214380506536
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.80256086939737
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1270   -2.9871562   -2.0953273   -2.0953273 
    1271   -2.9871562   -2.0953273   -2.0620801 
Loop time of 3.45887e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.2971436027547
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.75506552809641
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.86732061425333
variable        y0 equal ${yi}
variable        y0 equal 8.43319919027385

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.95851325312738
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.50774944938716
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1271   -2.9871562   -2.0953273   -2.0620801 
    1272   -2.9871562   -2.0953273   -1.9862073 
Loop time of 3.6328e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.86732061425333
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.43319919027385
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.22285979706795
variable        y0 equal ${yi}
variable        y0 equal 2.74353152486184

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.26270291525871
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.70625076266625
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1272   -2.9871562   -2.0953273   -1.9862073 
    1273   -2.9871562   -2.0953273   -2.0905001 
Loop time of 3.5016e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.22285979706795
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.74353152486184
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.88052521029159
variable        y0 equal ${yi}
variable        y0 equal 4.76031438464091

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.83429396429702
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.79084574335978
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1273   -2.9871562   -2.0953273   -2.0905001 
    1274   -2.9871562   -2.0953273   -2.0443442 
Loop time of 3.58594e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.88052521029159
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.76031438464091
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.40183663447114
variable        y0 equal ${yi}
variable        y0 equal 9.26865103948443

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.49901454527589
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.27621036279528
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1274   -2.9871562   -2.0953273   -2.0443442 
    1275   -2.9871562   -2.0953273    -2.075165 
Loop time of 3.52195e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.40183663447114
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.26865103948443
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.42793486197206
variable        y0 equal ${yi}
variable        y0 equal 1.83933557651109

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.44524025995943
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.81169107339448
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1275   -2.9871562   -2.0953273    -2.075165 
    1276   -2.9871562   -2.0953273    -2.087053 
Loop time of 3.57906e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.42793486197206
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.83933557651109
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.14502597490654
variable        y0 equal ${yi}
variable        y0 equal 5.53364494984346

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.23940112034187
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.4447217458983
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1276   -2.9871562   -2.0953273    -2.087053 
    1277   -2.9871562   -2.0953273   -2.0592686 
Loop time of 3.53884e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.14502597490654
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.53364494984346
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.1493705244735
variable        y0 equal ${yi}
variable        y0 equal 4.58995101803705

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.14090885836632
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.66216105574533
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1277   -2.9871562   -2.0953273   -2.0592686 
    1278   -2.9871562   -2.0953273   -2.0652046 
Loop time of 3.50945e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.1493705244735
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.58995101803705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.70177712321062
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.30152096666392
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1278   -2.9871562   -2.0953273   -2.0652046 
    1279   -2.9871562   -2.0953273   -2.0930701 
Loop time of 3.60471e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0128297571202
variable        y0 equal ${yi}
variable        y0 equal 6.50182060734263

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 9.94221425094802
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.40663272873393
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1279   -2.9871562   -2.0953273   -2.0930701 
    1280   -2.9871562   -2.0953273   -2.0244612 
Loop time of 3.53617e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.0128297571202
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.50182060734263
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.52147714613992
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.35812387790942
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1280   -2.9871562   -2.0953273   -2.0244612 
    1281   -2.9871562   -2.0953273   -2.0829448 
Loop time of 3.57643e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47168833731729
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.2979036006
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2971436027547
variable        y0 equal ${yi}
variable        y0 equal 4.75506552809641

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.3523326639196
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.82883544320032
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1281   -2.9871562   -2.0953273   -2.0829448 
    1282   -2.9871562   -2.0953273   -2.0171535 
Loop time of 3.92925e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.2971436027547
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.75506552809641
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.51757102727013
variable        y0 equal ${yi}
variable        y0 equal 3.74784597916733

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.41855881928521
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.78684511942993
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1282   -2.9871562   -2.0953273   -2.0171535 
    1283   -2.9871562   -2.0953273   -2.0954493 
Loop time of 3.57393e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.09544933527417
variable naccept equal ${increment}
variable naccept equal 298

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.8674810047864
variable        y0 equal ${yi}
variable        y0 equal 6.36184206739894

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.89402630288592
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.43323876396648
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1283   -2.9871562   -2.0954493   -2.0954493 
    1284   -2.9871562   -2.0954493   -2.1518726 
Loop time of 3.48631e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.15187260287451
variable naccept equal ${increment}
variable naccept equal 299

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.8608382340192
variable        y0 equal ${yi}
variable        y0 equal 2.70200465890266

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.80282862145893
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.65782771083213
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1284   -2.9871562   -2.1518726   -2.1518726 
    1285   -2.9871562   -2.1518726   -2.0481199 
Loop time of 3.57246e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.8608382340192
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.70200465890266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.84427213628283
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.33744594589702
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1285   -2.9871562   -2.1518726   -2.0481199 
    1286   -2.9871562   -2.1518726   -2.0414109 
Loop time of 3.50237e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0128297571202
variable        y0 equal ${yi}
variable        y0 equal 6.50182060734263

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.0608747247716
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.4793810679101
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1286   -2.9871562   -2.1518726   -2.0414109 
    1287   -2.9871562   -2.1518726   -2.1600464 
Loop time of 3.48389e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.16004641349101
variable naccept equal ${increment}
variable naccept equal 300

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82797947445994
variable        y0 equal ${yi}
variable        y0 equal 0.89721691201958

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.73734676161891
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.832287677038043
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1287   -2.9871562   -2.1600464   -2.1600464 
    1288   -2.9871562   -2.1600464   -2.1017639 
Loop time of 3.52525e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82797947445994
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.89721691201958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.50628010192338
variable        y0 equal ${yi}
variable        y0 equal 1.936454562164

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.45212336936418
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.90238742015426
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1288   -2.9871562   -2.1600464   -2.1017639 
    1289   -2.9871562   -2.1600464    -2.149931 
Loop time of 3.71734e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.50628010192338
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.936454562164
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.26462735890904
variable        y0 equal ${yi}
variable        y0 equal 3.68544435067308

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.23124396562138
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.7009764389528
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1289   -2.9871562   -2.1600464    -2.149931 
    1290   -2.9871562   -2.1600464   -2.1591959 
Loop time of 3.5499e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.26462735890904
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.68544435067308
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.43551569699365
variable        y0 equal ${yi}
variable        y0 equal 1.89214071414535

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.41359194039422
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.96864056966369
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1290   -2.9871562   -2.1600464   -2.1591959 
    1291   -2.9871562   -2.1600464   -2.1102318 
Loop time of 3.56385e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.43551569699365
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.89214071414535
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.63595545449678
variable        y0 equal ${yi}
variable        y0 equal 0.131007170677185

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.65522127309267
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.0931625247001647
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1291   -2.9871562   -2.1600464   -2.1102318 
    1292   -2.9871562   -2.1600464   -2.1481019 
Loop time of 3.58216e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.63595545449678
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.131007170677185
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.15449824968682
variable        y0 equal ${yi}
variable        y0 equal 3.83953256173264

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.11698845068322
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.79524089856278
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1292   -2.9871562   -2.1600464   -2.1481019 
    1293   -2.9871562   -2.1600464   -2.1689575 
Loop time of 3.4986e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.16895754504708
variable naccept equal ${increment}
variable naccept equal 301

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.29979578892099
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 0.0633015275001558
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1293   -2.9871562   -2.1689575   -2.1689575 
    1294   -2.9871562   -2.1689575    -2.155919 
Loop time of 3.59044e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.650485213583
variable        y0 equal ${yi}
variable        y0 equal 5.67973738854128

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.6504576523953
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.66441398804384
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1294   -2.9871562   -2.1689575    -2.155919 
    1295   -2.9871562   -2.1689575   -2.1690795 
Loop time of 3.64575e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.16907949465701
variable naccept equal ${increment}
variable naccept equal 302

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.00392820794575
variable        y0 equal ${yi}
variable        y0 equal 0.864141031015247

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 5.90431323010914
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.788480599630207
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1295   -2.9871562   -2.1690795   -2.1690795 
    1296   -2.9871562   -2.1690795   -2.1309315 
Loop time of 3.48374e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 6.00392820794575
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.864141031015247
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.444242735305691
variable        y0 equal ${yi}
variable        y0 equal 8.30422124780711

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.42525350610342
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.22058670438823
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1296   -2.9871562   -2.1690795   -2.1309315 
    1297   -2.9871562   -2.1690795   -2.1144748 
Loop time of 3.57205e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.444242735305691
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.30422124780711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0880036000272
variable        y0 equal ${yi}
variable        y0 equal 8.41472051061687

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.0539224986097
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.44660737432537
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1297   -2.9871562   -2.1690795   -2.1144748 
    1298   -2.9871562   -2.1690795   -2.1639395 
Loop time of 3.53849e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.0880036000272
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.41472051061687
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6504576523953
variable        y0 equal ${yi}
variable        y0 equal 5.66441398804384

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.6635706742459
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.5794506067534
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1298   -2.9871562   -2.1690795   -2.1639395 
    1299   -2.9871562   -2.1690795   -2.1254689 
Loop time of 3.55213e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.6504576523953
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.66441398804384
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.27604624986211
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.0174713373184204
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1299   -2.9871562   -2.1690795   -2.1254689 
    1300   -2.9871562   -2.1690795   -2.1664369 
Loop time of 3.66059e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.63595545449678
variable        y0 equal ${yi}
variable        y0 equal 0.131007170677185

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.71033736625139
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.223865342140198
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1300   -2.9871562   -2.1690795   -2.1664369 
    1301   -2.9871562   -2.1690795    -2.060589 
Loop time of 3.55845e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.63595545449678
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.131007170677185
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.39977147975828
variable        y0 equal ${yi}
variable        y0 equal 7.33912527885698

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.31873767772581
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.38054533329271
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1301   -2.9871562   -2.1690795    -2.060589 
    1302   -2.9871562   -2.1690795   -2.1428713 
Loop time of 3.51607e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.39977147975828
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.33912527885698
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.83057032106993
variable        y0 equal ${yi}
variable        y0 equal 1.83415137908525

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.87712363480208
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.75677637240953
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1302   -2.9871562   -2.1690795   -2.1428713 
    1303   -2.9871562   -2.1690795    -2.145361 
Loop time of 3.52454e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.83057032106993
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.83415137908525
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.97784195223495
variable        y0 equal ${yi}
variable        y0 equal 8.32680290855464

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.9814669040744
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.31534441627559
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1303   -2.9871562   -2.1690795    -2.145361 
    1304   -2.9871562   -2.1690795   -2.1709236 
Loop time of 3.69088e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.17092361955443
variable naccept equal ${increment}
variable naccept equal 303

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 0.956568280059633
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.5056192668941
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1304   -2.9871562   -2.1709236   -2.1709236 
    1305   -2.9871562   -2.1709236   -2.1284128 
Loop time of 3.64226e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.42371865907575
variable        y0 equal ${yi}
variable        y0 equal 1.7675963201291

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.51240967908765
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.68646393201417
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1305   -2.9871562   -2.1709236   -2.1284128 
    1306   -2.9871562   -2.1709236    -2.129451 
Loop time of 3.58201e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.42371865907575
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.7675963201291
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.66485743720961
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.50440787807932
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1306   -2.9871562   -2.1709236    -2.129451 
    1307   -2.9871562   -2.1709236   -2.1686209 
Loop time of 3.6621e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3102847699186
variable        y0 equal ${yi}
variable        y0 equal 2.86695545884469

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.256485164549
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.92573828669885
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1307   -2.9871562   -2.1709236   -2.1686209 
    1308   -2.9871562   -2.1709236   -2.1558671 
Loop time of 3.55715e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3102847699186
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.86695545884469
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.50875395376456
variable        y0 equal ${yi}
variable        y0 equal 5.60411881153779

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.51490057546866
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.65973335449891
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1308   -2.9871562   -2.1709236   -2.1558671 
    1309   -2.9871562   -2.1709236   -2.1607033 
Loop time of 3.5459e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.50875395376456
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.60411881153779
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 7.06044206896469
variable        y0 equal ${yi}
variable        y0 equal 6.51616222397318

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 6.99216622391388
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.45942620769968
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1309   -2.9871562   -2.1709236   -2.1607033 
    1310   -2.9871562   -2.1709236   -2.1948066 
Loop time of 3.66343e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.19480661518917
variable naccept equal ${increment}
variable naccept equal 304

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.97122610449133
variable        y0 equal ${yi}
variable        y0 equal 2.87912948104242

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.91699399589834
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.91251749965051
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1310   -2.9871562   -2.1948066   -2.1948066 
    1311   -2.9871562   -2.1948066   -2.2303481 
Loop time of 3.80963e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.23034811239363
variable naccept equal ${increment}
variable naccept equal 305

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.02622429727413
variable        y0 equal ${yi}
variable        y0 equal 8.30461697496469

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 7.98142287134029
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.40128244079645
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1311   -2.9871562   -2.2303481   -2.2303481 
    1312   -2.9871562   -2.2303481   -2.2016324 
Loop time of 3.679e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.02622429727413
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.30461697496469
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.26462735890904
variable        y0 equal ${yi}
variable        y0 equal 3.68544435067308

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.30109411239186
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.60543022914064
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1312   -2.9871562   -2.2303481   -2.2016324 
    1313   -2.9871562   -2.2303481   -2.2138936 
Loop time of 3.72553e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.26462735890904
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.68544435067308
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82797947445994
variable        y0 equal ${yi}
variable        y0 equal 0.89721691201958

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.88464222470408
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.865290578115314
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1313   -2.9871562   -2.2303481   -2.2138936 
    1314   -2.9871562   -2.2303481   -2.2246273 
Loop time of 3.4594e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82797947445994
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.89721691201958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.85723299621878
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.56618254536554
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1314   -2.9871562   -2.2303481   -2.2246273 
    1315   -2.9871562   -2.2303481   -2.2026861 
Loop time of 3.49472e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2971436027547
variable        y0 equal ${yi}
variable        y0 equal 4.75506552809641

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.2581158045789
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.71512710207865
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1315   -2.9871562   -2.2303481   -2.2026861 
    1316   -2.9871562   -2.2303481   -2.2478419 
Loop time of 3.52966e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.24784189611618
variable naccept equal ${increment}
variable naccept equal 306

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.445388899634
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.32776836481357
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1316   -2.9871562   -2.2478419   -2.2478419 
    1317   -2.9871562   -2.2478419   -2.2215139 
Loop time of 3.52516e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.48385869104635
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.38020931806827
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.04304151255638
variable        y0 equal ${yi}
variable        y0 equal 6.44874846474161

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 8.99526753146202
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.40142399803629
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1317   -2.9871562   -2.2478419   -2.2215139 
    1318   -2.9871562   -2.2478419   -2.2127465 
Loop time of 3.53926e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.04304151255638
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.44874846474161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.86732061425333
variable        y0 equal ${yi}
variable        y0 equal 8.43319919027385

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.85250865737085
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.45175487913188
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1318   -2.9871562   -2.2478419   -2.2127465 
    1319   -2.9871562   -2.2478419   -2.2446631 
Loop time of 3.47244e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.86732061425333
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.43319919027385
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57543257355471
variable        y0 equal ${yi}
variable        y0 equal 4.67648406380578

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.47945750832339
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.73496817702218
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1319   -2.9871562   -2.2478419   -2.2446631 
    1320   -2.9871562   -2.2478419   -2.1974294 
Loop time of 3.6844e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.57543257355471
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.67648406380578
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.57222292898772
variable        y0 equal ${yi}
variable        y0 equal 5.48064044659334

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.55923593519805
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.3917986029883
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1320   -2.9871562   -2.2478419   -2.1974294 
    1321   -2.9871562   -2.2478419   -2.1697589 
Loop time of 3.51727e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.57222292898772
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.48064044659334
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.88052521029159
variable        y0 equal ${yi}
variable        y0 equal 4.76031438464091

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.87112944403335
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.73469646328852
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1321   -2.9871562   -2.2478419   -2.1697589 
    1322   -2.9871562   -2.2478419   -2.2568453 
Loop time of 3.66349e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.25684530429726
variable naccept equal ${increment}
variable naccept equal 307

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0880036000272
variable        y0 equal ${yi}
variable        y0 equal 8.41472051061687

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.1560731057187
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.39084089912471
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1322   -2.9871562   -2.2568453   -2.2568453 
    1323   -2.9871562   -2.2568453   -2.2515154 
Loop time of 3.53455e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.0880036000272
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.41472051061687
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.69108613053447
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.59948205107616
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1323   -2.9871562   -2.2568453   -2.2515154 
    1324   -2.9871562   -2.2568453   -2.2220859 
Loop time of 3.57164e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.1096025260275
variable        y0 equal ${yi}
variable        y0 equal 3.7893677787317

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.1570786984747
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.84408280415666
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1324   -2.9871562   -2.2568453   -2.2220859 
    1325   -2.9871562   -2.2568453    -2.207597 
Loop time of 6.19805e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.1096025260275
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.7893677787317
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.444242735305691
variable        y0 equal ${yi}
variable        y0 equal 8.30422124780711

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.455236812034512
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.38789409317073
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1325   -2.9871562   -2.2568453    -2.207597 
    1326   -2.9871562   -2.2568453   -2.2398339 
Loop time of 3.60066e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.444242735305691
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.30422124780711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.50875395376456
variable        y0 equal ${yi}
variable        y0 equal 5.60411881153779

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.54608468849433
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.53016226237016
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1326   -2.9871562   -2.2568453   -2.2398339 
    1327   -2.9871562   -2.2568453   -2.2381445 
Loop time of 3.5798e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.50875395376456
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.60411881153779
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.57222292898772
variable        y0 equal ${yi}
variable        y0 equal 5.48064044659334

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.58438292025206
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.46414071266847
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1327   -2.9871562   -2.2568453   -2.2381445 
    1328   -2.9871562   -2.2568453   -2.2550981 
Loop time of 3.56925e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.57222292898772
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.48064044659334
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.68400031485979
variable        y0 equal ${yi}
variable        y0 equal 7.40458581772113

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.71083032050554
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.37539278593326
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1328   -2.9871562   -2.2568453   -2.2550981 
    1329   -2.9871562   -2.2568453   -2.2431009 
Loop time of 3.67711e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.68400031485979
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.40458581772113
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.72637173095171
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.773006279899
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1329   -2.9871562   -2.2568453   -2.2431009 
    1330   -2.9871562   -2.2568453   -2.2072011 
Loop time of 3.46719e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.93805575012504
variable        y0 equal ${yi}
variable        y0 equal 8.32736837781961

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.9013831341201
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.28903211273248
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1330   -2.9871562   -2.2568453   -2.2072011 
    1331   -2.9871562   -2.2568453     -2.24189 
Loop time of 3.61931e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.93805575012504
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.32736837781961
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75591478546096
variable        y0 equal ${yi}
variable        y0 equal 4.61056455725595

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.77586567600204
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.61321362608835
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1331   -2.9871562   -2.2568453     -2.24189 
    1332   -2.9871562   -2.2568453   -2.2531878 
Loop time of 3.58031e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.75591478546096
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.61056455725595
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.58889481027555
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.4456082655572
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1332   -2.9871562   -2.2568453   -2.2531878 
    1333   -2.9871562   -2.2568453   -2.2410676 
Loop time of 3.58934e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 6.9320023683612
variable        y0 equal ${yi}
variable        y0 equal 2.82359918328622

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.97252110520049
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.85475352975228
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1333   -2.9871562   -2.2568453   -2.2410676 
    1334   -2.9871562   -2.2568453   -2.2580383 
Loop time of 3.56948e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.25803829403113
variable naccept equal ${increment}
variable naccept equal 308

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0880036000272
variable        y0 equal ${yi}
variable        y0 equal 8.41472051061687

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.0967216853162
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.32303357042369
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1334   -2.9871562   -2.2580383   -2.2580383 
    1335   -2.9871562   -2.2580383   -2.2273396 
Loop time of 3.60281e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.0880036000272
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.41472051061687
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.26323072353708
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y -0.0424773097038237
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1335   -2.9871562   -2.2580383   -2.2273396 
    1336   -2.9871562   -2.2580383   -2.2511309 
Loop time of 3.66937e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.36321673154392
variable        y0 equal ${yi}
variable        y0 equal 1.8523390569455

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.38702585458317
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.89600253484314
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1336   -2.9871562   -2.2580383   -2.2511309 
    1337   -2.9871562   -2.2580383   -2.2582179 
Loop time of 3.5332e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.25821787520345
variable naccept equal ${increment}
variable naccept equal 309

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.42371865907575
variable        y0 equal ${yi}
variable        y0 equal 1.7675963201291

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.44677014747526
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.79859002015657
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1337   -2.9871562   -2.2582179   -2.2582179 
    1338   -2.9871562   -2.2582179    -2.253994 
Loop time of 4.86747e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.42371865907575
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.7675963201291
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 6.99216622391388
variable        y0 equal ${yi}
variable        y0 equal 6.45942620769968

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.06851001063034
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.48140239254465
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1338   -2.9871562   -2.2582179    -2.253994 
    1339   -2.9871562   -2.2582179   -2.2432745 
Loop time of 3.69187e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 6.99216622391388
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.45942620769968
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.39977147975828
variable        y0 equal ${yi}
variable        y0 equal 7.33912527885698

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.36878840127851
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.26645512905382
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1339   -2.9871562   -2.2582179   -2.2432745 
    1340   -2.9871562   -2.2582179   -2.2395973 
Loop time of 3.674e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.39977147975828
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.33912527885698
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.87144294301158
variable        y0 equal ${yi}
variable        y0 equal 2.78142455788949

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.86570303956157
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.68259519311288
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1340   -2.9871562   -2.2582179   -2.2395973 
    1341   -2.9871562   -2.2582179   -2.2123148 
Loop time of 3.74168e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.87144294301158
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.78142455788949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.520060713687803
variable        y0 equal ${yi}
variable        y0 equal 2.88988070460657

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.594005592265989
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.84451084109644
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1341   -2.9871562   -2.2582179   -2.2123148 
    1342   -2.9871562   -2.2582179    -2.282248 
Loop time of 3.64502e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.2822480367634
variable naccept equal ${increment}
variable naccept equal 310

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2581158045789
variable        y0 equal ${yi}
variable        y0 equal 4.71512710207865

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.2594074849149
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.68333946818278
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1342   -2.9871562    -2.282248    -2.282248 
    1343   -2.9871562    -2.282248   -2.2853013 
Loop time of 3.55017e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.28530133627804
variable naccept equal ${increment}
variable naccept equal 311

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.7578687568469
variable        y0 equal ${yi}
variable        y0 equal 8.39387903131541

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.76264746387434
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.40153711952266
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1343   -2.9871562   -2.2853013   -2.2853013 
    1344   -2.9871562   -2.2853013   -2.2847118 
Loop time of 3.54929e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.28471182958254
variable naccept equal ${increment}
variable naccept equal 312

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.8608382340192
variable        y0 equal ${yi}
variable        y0 equal 2.70200465890266

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.86630587537281
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.78282643529274
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1344   -2.9871562   -2.2847118   -2.2847118 
    1345   -2.9871562   -2.2847118   -2.2942206 
Loop time of 3.59556e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.29422057402841
variable naccept equal ${increment}
variable naccept equal 313

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.68400031485979
variable        y0 equal ${yi}
variable        y0 equal 7.40458581772113

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.64699440160219
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.49384123411441
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1345   -2.9871562   -2.2942206   -2.2942206 
    1346   -2.9871562   -2.2942206   -2.2966924 
Loop time of 3.49227e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.2966924353143
variable naccept equal ${increment}
variable naccept equal 314

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 8.9487295838073
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.38910113491114
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1346   -2.9871562   -2.2966924   -2.2966924 
    1347   -2.9871562   -2.2966924   -2.2307235 
Loop time of 3.51339e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.03154995162041
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.4676475397497
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.76264746387434
variable        y0 equal ${yi}
variable        y0 equal 8.40153711952266

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.82419401605558
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.49790887750682
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1347   -2.9871562   -2.2966924   -2.2307235 
    1348   -2.9871562   -2.2966924   -2.2604512 
Loop time of 3.48504e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.76264746387434
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.40153711952266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.22307850757944
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 0.117599344253543
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1348   -2.9871562   -2.2966924   -2.2604512 
    1349   -2.9871562   -2.2966924   -2.2622381 
Loop time of 3.49054e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.93050993322669
variable        y0 equal ${yi}
variable        y0 equal 6.34705883995524

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.95934480070411
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.29185982481471
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1349   -2.9871562   -2.2966924   -2.2622381 
    1350   -2.9871562   -2.2966924   -2.1896056 
Loop time of 3.5664e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.93050993322669
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.34705883995524
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.01039157508708
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.63155791298379
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1350   -2.9871562   -2.2966924   -2.1896056 
    1351   -2.9871562   -2.2966924   -2.2520052 
Loop time of 3.5653e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.02537268677399
variable        y0 equal ${yi}
variable        y0 equal 0.926061685788958

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.07478685656235
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.945640977132647
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1351   -2.9871562   -2.2966924   -2.2520052 
    1352   -2.9871562   -2.2966924   -2.2841155 
Loop time of 3.61811e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.02537268677399
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.926061685788958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.75149758337614
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.72807035012376
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1352   -2.9871562   -2.2966924   -2.2841155 
    1353   -2.9871562   -2.2966924    -2.293138 
Loop time of 3.56271e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.86630587537281
variable        y0 equal ${yi}
variable        y0 equal 2.78282643529274

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.86599037606709
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.75700093480446
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1353   -2.9871562   -2.2966924    -2.293138 
    1354   -2.9871562   -2.2966924   -2.2967869 
Loop time of 3.4313e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.29678692787812
variable naccept equal ${increment}
variable naccept equal 315

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.55870154936087
variable        y0 equal ${yi}
variable        y0 equal 9.25253196466296

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.46702210743201
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.19019991863101
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1354   -2.9871562   -2.2967869   -2.2967869 
    1355   -2.9871562   -2.2967869   -2.2580851 
Loop time of 3.62023e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.55870154936087
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.25253196466296
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.25279456138173
variable        y0 equal ${yi}
variable        y0 equal 7.38214940157198

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.20211485385457
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.28344999876284
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1355   -2.9871562   -2.2967869   -2.2580851 
    1356   -2.9871562   -2.2967869   -2.2585442 
Loop time of 3.57944e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.25279456138173
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.38214940157198
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.112628924846649
variable        y0 equal ${yi}
variable        y0 equal 1.75601954839296

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.210712003707886
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.79972389123506
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1356   -2.9871562   -2.2967869   -2.2585442 
    1357   -2.9871562   -2.2967869   -2.2477122 
Loop time of 3.48774e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 6 x ${x0}
set atom 6 x 0.112628924846649
  1 settings made for x
set atom $i y ${y0}
set atom 6 y ${y0}
set atom 6 y 1.75601954839296
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.12239968497307
variable        y0 equal ${yi}
variable        y0 equal 1.09747809957299

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.10422742087395
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.06806945394311
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1357   -2.9871562   -2.2967869   -2.2477122 
    1358   -2.9871562   -2.2967869   -2.2964731 
Loop time of 3.52335e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.12239968497307
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.09747809957299
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.70135916987545
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.65350441092418
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1358   -2.9871562   -2.2967869   -2.2964731 
    1359   -2.9871562   -2.2967869   -2.2742079 
Loop time of 3.55721e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40260913768674
variable        y0 equal ${yi}
variable        y0 equal 5.5414461011191

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.46634027162458
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.45191775505739
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1359   -2.9871562   -2.2967869   -2.2742079 
    1360   -2.9871562   -2.2967869   -2.2532086 
Loop time of 3.55461e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.40260913768674
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.5414461011191
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3219509963055
variable        y0 equal ${yi}
variable        y0 equal 0.846012469041675

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.3944902781506
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.91998109411034
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1360   -2.9871562   -2.2967869   -2.2532086 
    1361   -2.9871562   -2.2967869    -2.274679 
Loop time of 3.52717e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.3219509963055
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.846012469041675
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.63595545449678
variable        y0 equal ${yi}
variable        y0 equal 0.131007170677185

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.70715711274568
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.122656655311584
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1361   -2.9871562   -2.2967869    -2.274679 
    1362   -2.9871562   -2.2967869   -2.2095473 
Loop time of 3.5664e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.63595545449678
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.131007170677185
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.40893839437734
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.46570730533863
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1362   -2.9871562   -2.2967869   -2.2095473 
    1363   -2.9871562   -2.2967869   -2.2527396 
Loop time of 3.49387e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.48385869104635
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.38020931806827
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.39977147975828
variable        y0 equal ${yi}
variable        y0 equal 7.33912527885698

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.31515962282087
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.37282084551119
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1363   -2.9871562   -2.2967869   -2.2527396 
    1364   -2.9871562   -2.2967869   -2.2694224 
Loop time of 3.61785e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.39977147975828
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.33912527885698
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.71051430900526
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.5312137676858
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1364   -2.9871562   -2.2967869   -2.2694224 
    1365   -2.9871562   -2.2967869   -2.2894692 
Loop time of 3.82619e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.26462735890904
variable        y0 equal ${yi}
variable        y0 equal 3.68544435067308

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.2568802213625
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.74628468318117
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1365   -2.9871562   -2.2967869   -2.2894692 
    1366   -2.9871562   -2.2967869   -2.2875658 
Loop time of 3.61523e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.26462735890904
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.68544435067308
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.75374778984662
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.74065848155152
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1366   -2.9871562   -2.2967869   -2.2875658 
    1367   -2.9871562   -2.2967869   -2.2925966 
Loop time of 3.68164e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.444242735305691
variable        y0 equal ${yi}
variable        y0 equal 8.30422124780711

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.407972128787899
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.24859927810725
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1367   -2.9871562   -2.2967869   -2.2925966 
    1368   -2.9871562   -2.2967869   -2.2667379 
Loop time of 3.67584e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.444242735305691
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.30422124780711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.31231993197957
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.0670478582382202
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1368   -2.9871562   -2.2967869   -2.2667379 
    1369   -2.9871562   -2.2967869   -2.2768693 
Loop time of 3.77281e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.87144294301158
variable        y0 equal ${yi}
variable        y0 equal 2.78142455788949

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.86872723618632
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.7278352019439
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1369   -2.9871562   -2.2967869   -2.2768693 
    1370   -2.9871562   -2.2967869   -2.2833772 
Loop time of 3.76825e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.87144294301158
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.78142455788949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.55870154936087
variable        y0 equal ${yi}
variable        y0 equal 9.25253196466296

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.60946123440039
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.32436089027255
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1370   -2.9871562   -2.2967869   -2.2833772 
    1371   -2.9871562   -2.2967869   -2.2938814 
Loop time of 4.76959e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.55870154936087
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.25253196466296
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.9717422036235
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.25728794254359
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1371   -2.9871562   -2.2967869   -2.2938814 
    1372   -2.9871562   -2.2967869   -2.2871802 
Loop time of 3.61582e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.467624564567472
variable        y0 equal ${yi}
variable        y0 equal 6.53444678322306

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.392557497421171
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.62843032614222
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1372   -2.9871562   -2.2967869   -2.2871802 
    1373   -2.9871562   -2.2967869   -2.2016895 
Loop time of 3.51853e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.467624564567472
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.53444678322306
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.8375572884017
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.65691000574991
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1373   -2.9871562   -2.2967869   -2.2016895 
    1374   -2.9871562   -2.2967869   -2.2919243 
Loop time of 3.5148e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.467624564567472
variable        y0 equal ${yi}
variable        y0 equal 6.53444678322306

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.506249304214384
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.52357215420237
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1374   -2.9871562   -2.2967869   -2.2919243 
    1375   -2.9871562   -2.2967869   -2.2987327 
Loop time of 3.458e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.29873265206359
variable naccept equal ${increment}
variable naccept equal 316

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82797947445994
variable        y0 equal ${yi}
variable        y0 equal 0.89721691201958

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.86748724499827
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.962843628633349
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1375   -2.9871562   -2.2987327   -2.2987327 
    1376   -2.9871562   -2.2987327   -2.2964806 
Loop time of 3.4441e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82797947445994
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.89721691201958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.1096025260275
variable        y0 equal ${yi}
variable        y0 equal 3.7893677787317

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.08257999737912
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.83302069468629
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1376   -2.9871562   -2.2987327   -2.2964806 
    1377   -2.9871562   -2.2987327   -2.2871744 
Loop time of 3.64477e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.1096025260275
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.7893677787317
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.565379925170804
variable        y0 equal ${yi}
variable        y0 equal 4.68124908560678

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.576007445255185
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.67061537856027
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1377   -2.9871562   -2.2987327   -2.2871744 
    1378   -2.9871562   -2.2987327   -2.2952204 
Loop time of 3.56852e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.565379925170804
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.68124908560678
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.46746646562482
variable        y0 equal ${yi}
variable        y0 equal 9.264607102755

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.55049354234601
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.19428467262118
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1378   -2.9871562   -2.2987327   -2.2952204 
    1379   -2.9871562   -2.2987327   -2.2785667 
Loop time of 3.54626e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.46746646562482
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.264607102755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.73273937343893
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.70559453123972
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1379   -2.9871562   -2.2987327   -2.2785667 
    1380   -2.9871562   -2.2987327   -2.2739914 
Loop time of 3.57112e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 6.99216622391388
variable        y0 equal ${yi}
variable        y0 equal 6.45942620769968

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 6.94526104012177
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.49924540058603
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1380   -2.9871562   -2.2987327   -2.2739914 
    1381   -2.9871562   -2.2987327   -2.2741591 
Loop time of 3.63921e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 6.99216622391388
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.45942620769968
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.25279456138173
variable        y0 equal ${yi}
variable        y0 equal 7.38214940157198

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.16427966117421
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.28314904299044
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1381   -2.9871562   -2.2987327   -2.2741591 
    1382   -2.9871562   -2.2987327   -2.2462928 
Loop time of 3.56215e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.25279456138173
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.38214940157198
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.81859772721415
variable        y0 equal ${yi}
variable        y0 equal 6.51868253485194

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.7493218354333
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.55292835966578
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1382   -2.9871562   -2.2987327   -2.2462928 
    1383   -2.9871562   -2.2987327   -2.2854412 
Loop time of 3.62141e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.81859772721415
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.51868253485194
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.86732061425333
variable        y0 equal ${yi}
variable        y0 equal 8.43319919027385

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.81228961268549
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.38006076730785
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1383   -2.9871562   -2.2987327   -2.2854412 
    1384   -2.9871562   -2.2987327   -2.3091246 
Loop time of 3.56706e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.30912455047066
variable naccept equal ${increment}
variable naccept equal 317

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.54942037581521
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.23195419636034
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1384   -2.9871562   -2.3091246   -2.3091246 
    1385   -2.9871562   -2.3091246   -2.2065695 
Loop time of 3.52255e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47168833731729
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.2979036006
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.39977147975828
variable        y0 equal ${yi}
variable        y0 equal 7.33912527885698

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.43833291927244
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.40899122085832
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1385   -2.9871562   -2.3091246   -2.2065695 
    1386   -2.9871562   -2.3091246   -2.3085615 
Loop time of 3.69463e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.30856154400775
variable naccept equal ${increment}
variable naccept equal 318

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3219509963055
variable        y0 equal ${yi}
variable        y0 equal 0.846012469041675

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.3095719222088
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.876188357580036
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1386   -2.9871562   -2.3085615   -2.3085615 
    1387   -2.9871562   -2.3085615   -2.3183744 
Loop time of 3.58005e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.31837443516701
variable naccept equal ${increment}
variable naccept equal 319

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 6.97252110520049
variable        y0 equal ${yi}
variable        y0 equal 2.85475352975228

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.90948485413237
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.89382953616479
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1387   -2.9871562   -2.3183744   -2.3183744 
    1388   -2.9871562   -2.3183744   -2.3097417 
Loop time of 3.55086e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 6.97252110520049
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.85475352975228
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0128975868225374
variable        y0 equal ${yi}
variable        y0 equal 3.77990783019196

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x -0.00734441280362227
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.86569726033341
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1388   -2.9871562   -2.3183744   -2.3097417 
    1389   -2.9871562   -2.3183744    -2.287784 
Loop time of 3.59095e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 0.0128975868225374
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.77990783019196
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.55870154936087
variable        y0 equal ${yi}
variable        y0 equal 9.25253196466296

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.63810863334906
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.34586569774478
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1389   -2.9871562   -2.3183744    -2.287784 
    1390   -2.9871562   -2.3183744   -2.3057573 
Loop time of 3.51272e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.55870154936087
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.25253196466296
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.00392820794575
variable        y0 equal ${yi}
variable        y0 equal 0.864141031015247

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 5.93170262534611
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.793554993379444
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1390   -2.9871562   -2.3183744   -2.3057573 
    1391   -2.9871562   -2.3183744   -2.2926986 
Loop time of 3.45323e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 6.00392820794575
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.864141031015247
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.63595545449678
variable        y0 equal ${yi}
variable        y0 equal 0.131007170677185

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.65587240615312
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.10512501001358
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1391   -2.9871562   -2.3183744   -2.2926986 
    1392   -2.9871562   -2.3183744   -2.3063602 
Loop time of 3.5489e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.63595545449678
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.131007170677185
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.68445487497922
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.65802933735978
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1392   -2.9871562   -2.3183744   -2.3063602 
    1393   -2.9871562   -2.3183744   -2.3107792 
Loop time of 3.53573e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3095719222088
variable        y0 equal ${yi}
variable        y0 equal 0.876188357580036

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.2619098190327
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.965363748777241
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1393   -2.9871562   -2.3183744   -2.3107792 
    1394   -2.9871562   -2.3183744   -2.3036499 
Loop time of 3.54399e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.3095719222088
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.876188357580036
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0880036000272
variable        y0 equal ${yi}
variable        y0 equal 8.41472051061687

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.0533270482084
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.49043468154964
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1394   -2.9871562   -2.3183744   -2.3036499 
    1395   -2.9871562   -2.3183744   -2.2946796 
Loop time of 3.54499e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.0880036000272
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.41472051061687
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.29060267845497
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.50434527721667
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1395   -2.9871562   -2.3183744   -2.2946796 
    1396   -2.9871562   -2.3183744   -2.2935703 
Loop time of 3.5478e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2594074849149
variable        y0 equal ${yi}
variable        y0 equal 4.68333946818278

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.354881716158
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.76321200484202
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1396   -2.9871562   -2.3183744   -2.2935703 
    1397   -2.9871562   -2.3183744   -2.2679989 
Loop time of 3.51295e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.2594074849149
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.68333946818278
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.42793486197206
variable        y0 equal ${yi}
variable        y0 equal 1.83933557651109

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.33556759436342
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.93658558509416
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1397   -2.9871562   -2.3183744   -2.2679989 
    1398   -2.9871562   -2.3183744   -2.2812655 
Loop time of 3.49197e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.42793486197206
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.83933557651109
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.12239968497307
variable        y0 equal ${yi}
variable        y0 equal 1.09747809957299

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.114229962416
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.01085750650201
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1398   -2.9871562   -2.3183744   -2.2812655 
    1399   -2.9871562   -2.3183744   -2.3121778 
Loop time of 3.49334e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.12239968497307
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.09747809957299
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.5961974489667
variable        y0 equal ${yi}
variable        y0 equal 6.55421015755167

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.5037566292264
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.53606520430078
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1399   -2.9871562   -2.3183744   -2.3121778 
    1400   -2.9871562   -2.3183744   -2.3018344 
Loop time of 3.63737e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.5961974489667
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.55421015755167
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.08605186342097
variable        y0 equal ${yi}
variable        y0 equal 0.950601537931293

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.16548388599253
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.915460844743579
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1400   -2.9871562   -2.3183744   -2.3018344 
    1401   -2.9871562   -2.3183744   -2.2600965 
Loop time of 3.49116e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.08605186342097
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.950601537931293
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.67264876246233
variable        y0 equal ${yi}
variable        y0 equal 0.871292896974415

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.70825549244661
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.799817045438618
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1401   -2.9871562   -2.3183744   -2.2600965 
    1402   -2.9871562   -2.3183744    -2.281831 
Loop time of 3.58963e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.67264876246233
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.871292896974415
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.91699399589834
variable        y0 equal ${yi}
variable        y0 equal 2.91251749965051

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.82280280231771
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.92665051194528
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1402   -2.9871562   -2.3183744    -2.281831 
    1403   -2.9871562   -2.3183744   -2.3094137 
Loop time of 3.50332e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.91699399589834
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.91251749965051
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78581515748931
variable        y0 equal ${yi}
variable        y0 equal 1.04153251241478

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.74684044321013
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.0974559981707
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1403   -2.9871562   -2.3183744   -2.3094137 
    1404   -2.9871562   -2.3183744   -2.3064718 
Loop time of 3.4847e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.78581515748931
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.04153251241478
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.8900455796653
variable        y0 equal ${yi}
variable        y0 equal 0.887486429918145

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.79996865629494
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.975292392480706
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1404   -2.9871562   -2.3183744   -2.3064718 
    1405   -2.9871562   -2.3183744   -2.2653731 
Loop time of 3.51168e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.8900455796653
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.887486429918145
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.22285979706795
variable        y0 equal ${yi}
variable        y0 equal 2.74353152486184

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.20629341322929
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.76325721713403
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1405   -2.9871562   -2.3183744   -2.2653731 
    1406   -2.9871562   -2.3183744   -2.3182149 
Loop time of 3.5826e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.31821489258063
variable naccept equal ${increment}
variable naccept equal 320

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7380775292569
variable        y0 equal ${yi}
variable        y0 equal 7.41298324194217

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.660105868166
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.44789954748416
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1406   -2.9871562   -2.3182149   -2.3182149 
    1407   -2.9871562   -2.3182149   -2.3037214 
Loop time of 3.53595e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7380775292569
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41298324194217
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.43551569699365
variable        y0 equal ${yi}
variable        y0 equal 1.89214071414535

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.37443038939554
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.87579856298034
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1407   -2.9871562   -2.3182149   -2.3037214 
    1408   -2.9871562   -2.3182149   -2.3017838 
Loop time of 3.58395e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.43551569699365
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.89214071414535
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75591478546096
variable        y0 equal ${yi}
variable        y0 equal 4.61056455725595

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.65845219095184
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.67336435669824
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1408   -2.9871562   -2.3182149   -2.3017838 
    1409   -2.9871562   -2.3182149   -2.3137536 
Loop time of 3.55293e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.75591478546096
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.61056455725595
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.86943823932944
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.73079638832972
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1409   -2.9871562   -2.3182149   -2.3137536 
    1410   -2.9871562   -2.3182149   -2.2860304 
Loop time of 3.60465e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 6.02990794141284
variable        y0 equal ${yi}
variable        y0 equal 8.29363690532741

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.12527561147204
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.27373706020412
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1410   -2.9871562   -2.3182149   -2.2860304 
    1411   -2.9871562   -2.3182149   -2.1800551 
Loop time of 3.51323e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 6.02990794141284
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.29363690532741
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.08300354798489
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.8529365219838
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1411   -2.9871562   -2.3182149   -2.1800551 
    1412   -2.9871562   -2.3182149   -2.3116125 
Loop time of 3.61154e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.41855881928521
variable        y0 equal ${yi}
variable        y0 equal 3.78684511942993

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.44607109545785
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.8141516403688
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1412   -2.9871562   -2.3182149   -2.3116125 
    1413   -2.9871562   -2.3182149   -2.3163411 
Loop time of 3.5069e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.41855881928521
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.78684511942993
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.14187918344841
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.92360203645295
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1413   -2.9871562   -2.3182149   -2.3163411 
    1414   -2.9871562   -2.3182149   -2.3138366 
Loop time of 3.546e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 1.04256149848156
variable        y0 equal ${yi}
variable        y0 equal 9.12870747554629

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 1.10092277844601
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.22189815748065
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1414   -2.9871562   -2.3182149   -2.3138366 
    1415   -2.9871562   -2.3182149   -2.3229325 
Loop time of 3.56052e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.32293252604824
variable naccept equal ${increment}
variable naccept equal 321

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.66643896578428
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.69896776242387
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1415   -2.9871562   -2.3229325   -2.3229325 
    1416   -2.9871562   -2.3229325   -2.3179313 
Loop time of 3.59942e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03084906657391
variable        y0 equal ${yi}
variable        y0 equal 5.64538028185563

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 1.01252993663006
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.66969828551011
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1416   -2.9871562   -2.3229325   -2.3179313 
    1417   -2.9871562   -2.3229325   -2.3163977 
Loop time of 3.56298e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03084906657391
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.64538028185563
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.00392820794575
variable        y0 equal ${yi}
variable        y0 equal 0.864141031015247

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 5.92925465066426
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.835108359563678
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1417   -2.9871562   -2.3229325   -2.3163977 
    1418   -2.9871562   -2.3229325   -2.3154593 
Loop time of 3.54631e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 6.00392820794575
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.864141031015247
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.09907968956978
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.3799534193426
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1418   -2.9871562   -2.3229325   -2.3154593 
    1419   -2.9871562   -2.3229325   -2.3120496 
Loop time of 3.52185e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.03154995162041
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.4676475397497
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03084906657391
variable        y0 equal ${yi}
variable        y0 equal 5.64538028185563

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 1.09016319831067
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.70068373625474
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1419   -2.9871562   -2.3229325   -2.3120496 
    1420   -2.9871562   -2.3229325   -2.3086136 
Loop time of 3.5753e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03084906657391
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.64538028185563
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.1096025260275
variable        y0 equal ${yi}
variable        y0 equal 3.7893677787317

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.16716537793332
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.83030838532579
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1420   -2.9871562   -2.3229325   -2.3086136 
    1421   -2.9871562   -2.3229325   -2.2758018 
Loop time of 3.58525e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.1096025260275
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.7893677787317
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.40737680593396
variable        y0 equal ${yi}
variable        y0 equal 3.73942260308396

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.32953774133588
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.73953622145783
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1421   -2.9871562   -2.3229325   -2.2758018 
    1422   -2.9871562   -2.3229325   -2.3088007 
Loop time of 3.57358e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.40737680593396
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.73942260308396
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.86599037606709
variable        y0 equal ${yi}
variable        y0 equal 2.75700093480446

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.95838304717534
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.82275391789772
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1422   -2.9871562   -2.3229325   -2.3088007 
    1423   -2.9871562   -2.3229325   -2.3359604 
Loop time of 6.21927e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.33596044179629
variable naccept equal ${increment}
variable naccept equal 322

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7380775292569
variable        y0 equal ${yi}
variable        y0 equal 7.41298324194217

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.6568497498685
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.39509505358005
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1423   -2.9871562   -2.3359604   -2.3359604 
    1424   -2.9871562   -2.3359604   -2.3257216 
Loop time of 3.61844e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7380775292569
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41298324194217
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 7.97951994537212
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.44711102978219
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1424   -2.9871562   -2.3359604   -2.3257216 
    1425   -2.9871562   -2.3359604   -2.3185218 
Loop time of 3.63488e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.25279456138173
variable        y0 equal ${yi}
variable        y0 equal 7.38214940157198

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.34796803950826
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.33313538160585
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1425   -2.9871562   -2.3359604   -2.3185218 
    1426   -2.9871562   -2.3359604    -2.301199 
Loop time of 3.53156e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.25279456138173
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.38214940157198
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.42793486197206
variable        y0 equal ${yi}
variable        y0 equal 1.83933557651109

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.48640339453432
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.89979504725999
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1426   -2.9871562   -2.3359604    -2.301199 
    1427   -2.9871562   -2.3359604   -2.3180617 
Loop time of 3.5904e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.42793486197206
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.83933557651109
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.03861522077417
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.92653944465021
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1427   -2.9871562   -2.3359604   -2.3180617 
    1428   -2.9871562   -2.3359604   -2.3178273 
Loop time of 3.6298e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.5961974489667
variable        y0 equal ${yi}
variable        y0 equal 6.55421015755167

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.53344938635607
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.50123551622858
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1428   -2.9871562   -2.3359604   -2.3178273 
    1429   -2.9871562   -2.3359604   -2.3249295 
Loop time of 3.57253e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.5961974489667
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.55421015755167
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.83057032106993
variable        y0 equal ${yi}
variable        y0 equal 1.83415137908525

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.86155322073576
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.87893718860216
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1429   -2.9871562   -2.3359604   -2.3249295 
    1430   -2.9871562   -2.3359604   -2.3360453 
Loop time of 3.51679e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.33604531312322
variable naccept equal ${increment}
variable naccept equal 323

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.95838304717534
variable        y0 equal ${yi}
variable        y0 equal 2.82275391789772

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.90394569594853
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.92176248999931
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1430   -2.9871562   -2.3360453   -2.3360453 
    1431   -2.9871562   -2.3360453   -2.3003799 
Loop time of 3.53699e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.95838304717534
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.82275391789772
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.04304151255638
variable        y0 equal ${yi}
variable        y0 equal 6.44874846474161

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.02654598671944
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.36133466497888
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1431   -2.9871562   -2.3360453   -2.3003799 
    1432   -2.9871562   -2.3360453   -2.2955827 
Loop time of 3.52527e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.04304151255638
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.44874846474161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.42239316224176
variable        y0 equal ${yi}
variable        y0 equal 5.58969682400423

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.40116958140451
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.67528531496721
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1432   -2.9871562   -2.3360453   -2.2955827 
    1433   -2.9871562   -2.3360453   -2.2907288 
Loop time of 3.64384e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.42239316224176
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.58969682400423
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.42239316224176
variable        y0 equal ${yi}
variable        y0 equal 5.58969682400423

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.46714736937601
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.60852153246599
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1433   -2.9871562   -2.3360453   -2.2907288 
    1434   -2.9871562   -2.3360453   -2.3314575 
Loop time of 3.62046e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.42239316224176
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.58969682400423
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.8900455796653
variable        y0 equal ${yi}
variable        y0 equal 0.887486429918145

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.7916107141906
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.901366039026116
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1434   -2.9871562   -2.3360453   -2.3314575 
    1435   -2.9871562   -2.3360453   -2.3070648 
Loop time of 3.5156e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.8900455796653
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.887486429918145
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2594074849149
variable        y0 equal ${yi}
variable        y0 equal 4.68333946818278

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.2641314629575
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.68107558840678
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1435   -2.9871562   -2.3360453   -2.3070648 
    1436   -2.9871562   -2.3360453   -2.3354858 
Loop time of 3.50499e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.33548581360791
variable naccept equal ${increment}
variable naccept equal 324

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.5961974489667
variable        y0 equal ${yi}
variable        y0 equal 6.55421015755167

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.68127614140292
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.62805070415964
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1436   -2.9871562   -2.3354858   -2.3354858 
    1437   -2.9871562   -2.3354858   -2.2912399 
Loop time of 3.60085e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.5961974489667
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.55421015755167
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.6302324012908
variable        y0 equal ${yi}
variable        y0 equal 0.804496832597583

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.566492326656248
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.77395977567467
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1437   -2.9871562   -2.3354858   -2.2912399 
    1438   -2.9871562   -2.3354858    -2.330864 
Loop time of 3.59205e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.6302324012908
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.804496832597583
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.20629341322929
variable        y0 equal ${yi}
variable        y0 equal 2.76325721713403

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.25120809990913
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.80950764390329
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1438   -2.9871562   -2.3354858    -2.330864 
    1439   -2.9871562   -2.3354858   -2.3247379 
Loop time of 3.56771e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.20629341322929
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.76325721713403
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.14502597490654
variable        y0 equal ${yi}
variable        y0 equal 5.53364494984346

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.16523640791283
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.5816991681357
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1439   -2.9871562   -2.3354858   -2.3247379 
    1440   -2.9871562   -2.3354858   -2.3334565 
Loop time of 3.6486e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.14502597490654
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.53364494984346
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.87144294301158
variable        y0 equal ${yi}
variable        y0 equal 2.78142455788949

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.84774541178828
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.83943608971932
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1440   -2.9871562   -2.3354858   -2.3334565 
    1441   -2.9871562   -2.3354858    -2.330142 
Loop time of 3.44566e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.87144294301158
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.78142455788949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.86155322073576
variable        y0 equal ${yi}
variable        y0 equal 1.87893718860216

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.82882172344801
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.80076647183962
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1441   -2.9871562   -2.3354858    -2.330142 
    1442   -2.9871562   -2.3354858   -2.3277123 
Loop time of 3.65333e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.86155322073576
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.87893718860216
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57543257355471
variable        y0 equal ${yi}
variable        y0 equal 4.67648406380578

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.52891533255358
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.67184528464242
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1442   -2.9871562   -2.3354858   -2.3277123 
    1443   -2.9871562   -2.3354858   -2.3172728 
Loop time of 3.53059e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.57543257355471
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.67648406380578
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.641241686331
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.71155355734956
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1443   -2.9871562   -2.3354858   -2.3172728 
    1444   -2.9871562   -2.3354858   -2.3217868 
Loop time of 3.56748e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.506249304214384
variable        y0 equal ${yi}
variable        y0 equal 6.52357215420237

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.49673288623419
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.44398190514079
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1444   -2.9871562   -2.3354858   -2.3217868 
    1445   -2.9871562   -2.3354858   -2.3088595 
Loop time of 3.54247e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.506249304214384
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.52357215420237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.14502597490654
variable        y0 equal ${yi}
variable        y0 equal 5.53364494984346

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.12036636511192
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.4709979886313
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1445   -2.9871562   -2.3354858   -2.3088595 
    1446   -2.9871562   -2.3354858   -2.3178019 
Loop time of 3.5688e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.14502597490654
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.53364494984346
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.63480706095477
variable        y0 equal ${yi}
variable        y0 equal 2.83259171220163

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.57215049147387
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.85515712472299
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1446   -2.9871562   -2.3354858   -2.3178019 
    1447   -2.9871562   -2.3354858   -2.3202426 
Loop time of 3.58039e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.63480706095477
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.83259171220163
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.20968485196285
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.86336876533097
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1447   -2.9871562   -2.3354858   -2.3202426 
    1448   -2.9871562   -2.3354858   -2.3180955 
Loop time of 3.52333e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.91351584155551
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.36171482340328
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1448   -2.9871562   -2.3354858   -2.3180955 
    1449   -2.9871562   -2.3354858   -2.2928132 
Loop time of 3.47213e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3102847699186
variable        y0 equal ${yi}
variable        y0 equal 2.86695545884469

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.2547336820623
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.88034429522851
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1449   -2.9871562   -2.3354858   -2.2928132 
    1450   -2.9871562   -2.3354858   -2.3299746 
Loop time of 3.58683e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3102847699186
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.86695545884469
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.7094180158723
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.60855645293162
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1450   -2.9871562   -2.3354858   -2.3299746 
    1451   -2.9871562   -2.3354858    -2.315233 
Loop time of 3.47236e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.76264746387434
variable        y0 equal ${yi}
variable        y0 equal 8.40153711952266

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.79408501584959
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.44038051284847
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1451   -2.9871562   -2.3354858    -2.315233 
    1452   -2.9871562   -2.3354858   -2.3252415 
Loop time of 3.51471e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.76264746387434
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.40153711952266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.2084968598669
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.91521376750535
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1452   -2.9871562   -2.3354858   -2.3252415 
    1453   -2.9871562   -2.3354858   -2.3120367 
Loop time of 3.53891e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.24271897713052
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y -0.0374420881271331
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1453   -2.9871562   -2.3354858   -2.3120367 
    1454   -2.9871562   -2.3354858   -2.3334186 
Loop time of 4.26354e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.52172473191339
variable        y0 equal ${yi}
variable        y0 equal 9.28439741838305

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.53905990838129
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.30578265893786
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1454   -2.9871562   -2.3354858   -2.3334186 
    1455   -2.9871562   -2.3354858   -2.3316224 
Loop time of 3.82992e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.52172473191339
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.28439741838305
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.42793486197206
variable        y0 equal ${yi}
variable        y0 equal 1.83933557651109

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.48488563378069
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.9082223095662
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1455   -2.9871562   -2.3354858   -2.3316224 
    1456   -2.9871562   -2.3354858   -2.3187705 
Loop time of 3.62345e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.42793486197206
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.83933557651109
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.13669994472361
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.78909854861597
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1456   -2.9871562   -2.3354858   -2.3187705 
    1457   -2.9871562   -2.3354858     -2.30833 
Loop time of 3.61814e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.40183663447114
variable        y0 equal ${yi}
variable        y0 equal 9.26865103948443

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.3840241916916
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.27708193767397
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1457   -2.9871562   -2.3354858     -2.30833 
    1458   -2.9871562   -2.3354858   -2.3359755 
Loop time of 3.51174e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.33597553455559
variable naccept equal ${increment}
variable naccept equal 325

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.52172473191339
variable        y0 equal ${yi}
variable        y0 equal 9.28439741838305

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.60568624257165
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.24815598237841
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1458   -2.9871562   -2.3359755   -2.3359755 
    1459   -2.9871562   -2.3359755   -2.3110764 
Loop time of 3.511e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.52172473191339
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.28439741838305
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.42371865907575
variable        y0 equal ${yi}
variable        y0 equal 1.7675963201291

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.3817596356001
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.80364097735948
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1459   -2.9871562   -2.3359755   -2.3110764 
    1460   -2.9871562   -2.3359755   -2.3271402 
Loop time of 3.67075e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.42371865907575
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.7675963201291
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0608747247716
variable        y0 equal ${yi}
variable        y0 equal 6.4793810679101

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.0342196110745
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.41360306278696
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1460   -2.9871562   -2.3359755   -2.3271402 
    1461   -2.9871562   -2.3359755   -2.3153043 
Loop time of 3.45475e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.0608747247716
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.4793810679101
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.5961974489667
variable        y0 equal ${yi}
variable        y0 equal 6.55421015755167

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.65478142380496
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.62443742290964
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1461   -2.9871562   -2.3359755   -2.3153043 
    1462   -2.9871562   -2.3359755   -2.3072385 
Loop time of 3.44851e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.5961974489667
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.55421015755167
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0608747247716
variable        y0 equal ${yi}
variable        y0 equal 6.4793810679101

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.0937441233655
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.38177889124384
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1462   -2.9871562   -2.3359755   -2.3072385 
    1463   -2.9871562   -2.3359755    -2.279608 
Loop time of 3.56051e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.0608747247716
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.4793810679101
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.47148673374426
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.36053728189731
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1463   -2.9871562   -2.3359755    -2.279608 
    1464   -2.9871562   -2.3359755   -2.3299212 
Loop time of 3.50043e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.48385869104635
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.38020931806827
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.91699399589834
variable        y0 equal ${yi}
variable        y0 equal 2.91251749965051

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.98461982845602
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.98740296336511
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1464   -2.9871562   -2.3359755   -2.3299212 
    1465   -2.9871562   -2.3359755   -2.1973369 
Loop time of 3.53535e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.91699399589834
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.91251749965051
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.31363192240106
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 0.0706104516983064
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1465   -2.9871562   -2.3359755   -2.1973369 
    1466   -2.9871562   -2.3359755    -2.318447 
Loop time of 4.03339e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.84376939494601
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.38102900520793
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1466   -2.9871562   -2.3359755    -2.318447 
    1467   -2.9871562   -2.3359755   -2.2729811 
Loop time of 3.55795e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.87112944403335
variable        y0 equal ${yi}
variable        y0 equal 4.73469646328852

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.84120251217529
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.71674102896616
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1467   -2.9871562   -2.3359755   -2.2729811 
    1468   -2.9871562   -2.3359755   -2.3309737 
Loop time of 3.54058e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.87112944403335
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.73469646328852
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.56218094665777
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.3721314462688
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1468   -2.9871562   -2.3359755   -2.3309737 
    1469   -2.9871562   -2.3359755   -2.3311615 
Loop time of 3.56796e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.48385869104635
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.38020931806827
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.14502597490654
variable        y0 equal ${yi}
variable        y0 equal 5.53364494984346

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.21649797598228
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.6108479136725
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1469   -2.9871562   -2.3359755   -2.3311615 
    1470   -2.9871562   -2.3359755   -2.3124649 
Loop time of 3.57159e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.14502597490654
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.53364494984346
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.50875395376456
variable        y0 equal ${yi}
variable        y0 equal 5.60411881153779

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.56075496513617
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.65053445046143
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1470   -2.9871562   -2.3359755   -2.3124649 
    1471   -2.9871562   -2.3359755   -2.3290786 
Loop time of 3.61053e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.50875395376456
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.60411881153779
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.02537268677399
variable        y0 equal ${yi}
variable        y0 equal 0.926061685788958

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 6.9623318342273
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.980351443994372
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1471   -2.9871562   -2.3359755   -2.3290786 
    1472   -2.9871562   -2.3359755    -2.313886 
Loop time of 4.06364e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.02537268677399
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.926061685788958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.81734974343768
variable        y0 equal ${yi}
variable        y0 equal 4.6230520998852

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.86954605538836
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.6797511851208
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1472   -2.9871562   -2.3359755    -2.313886 
    1473   -2.9871562   -2.3359755   -2.3418345 
Loop time of 4.07394e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.34183454989203
variable naccept equal ${increment}
variable naccept equal 326

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.565379925170804
variable        y0 equal ${yi}
variable        y0 equal 4.68124908560678

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.582093294063474
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.70527601593896
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1473   -2.9871562   -2.3418345   -2.3418345 
    1474   -2.9871562   -2.3418345   -2.3398117 
Loop time of 3.44135e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.565379925170804
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.68124908560678
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.51113512038309
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.24846828308367
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1474   -2.9871562   -2.3418345   -2.3398117 
    1475   -2.9871562   -2.3418345    -2.298883 
Loop time of 3.44779e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47168833731729
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.2979036006
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0608747247716
variable        y0 equal ${yi}
variable        y0 equal 6.4793810679101

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.0489624623319
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.45366355911722
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1475   -2.9871562   -2.3418345    -2.298883 
    1476   -2.9871562   -2.3418345   -2.3357304 
Loop time of 3.56335e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.0608747247716
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.4793810679101
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.565379925170804
variable        y0 equal ${yi}
variable        y0 equal 4.68124908560678

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.511257930198575
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.64666885489389
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1476   -2.9871562   -2.3418345   -2.3357304 
    1477   -2.9871562   -2.3418345   -2.3322255 
Loop time of 3.6276e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.565379925170804
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.68124908560678
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.444242735305691
variable        y0 equal ${yi}
variable        y0 equal 8.30422124780711

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.42982077161398
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.3828137747198
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1477   -2.9871562   -2.3418345   -2.3322255 
    1478   -2.9871562   -2.3418345   -2.3470294 
Loop time of 3.42088e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.34702943006057
variable naccept equal ${increment}
variable naccept equal 327

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82797947445994
variable        y0 equal ${yi}
variable        y0 equal 0.89721691201958

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.78489679614192
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.942320318925708
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1478   -2.9871562   -2.3470294   -2.3470294 
    1479   -2.9871562   -2.3470294   -2.3403993 
Loop time of 3.4724e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82797947445994
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.89721691201958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.8377886887311
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.43081728950969
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1479   -2.9871562   -2.3470294   -2.3403993 
    1480   -2.9871562   -2.3470294   -2.3063934 
Loop time of 3.57471e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.1493705244735
variable        y0 equal ${yi}
variable        y0 equal 4.58995101803705

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.0898608537391
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.5575342690365
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1480   -2.9871562   -2.3470294   -2.3063934 
    1481   -2.9871562   -2.3470294   -2.3372209 
Loop time of 3.51734e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.1493705244735
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.58995101803705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.40737680593396
variable        y0 equal ${yi}
variable        y0 equal 3.73942260308396

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.50689446130658
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.70838336510789
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1481   -2.9871562   -2.3470294   -2.3372209 
    1482   -2.9871562   -2.3470294   -2.2945356 
Loop time of 3.51862e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.40737680593396
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.73942260308396
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.23812293449747
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y -0.0542686343193022
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1482   -2.9871562   -2.3470294   -2.2945356 
    1483   -2.9871562   -2.3470294   -2.3426447 
Loop time of 3.47365e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.01394880412914
variable        y0 equal ${yi}
variable        y0 equal 4.70269989127085

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 7.96091677545406
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.78881372565195
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1483   -2.9871562   -2.3470294   -2.3426447 
    1484   -2.9871562   -2.3470294    -2.299097 
Loop time of 3.51853e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.01394880412914
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.70269989127085
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.02622429727413
variable        y0 equal ${yi}
variable        y0 equal 8.30461697496469

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.05344901679851
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.27774798788125
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1484   -2.9871562   -2.3470294    -2.299097 
    1485   -2.9871562   -2.3470294   -2.3363448 
Loop time of 3.45565e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.02622429727413
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.30461697496469
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2641314629575
variable        y0 equal ${yi}
variable        y0 equal 4.68107558840678

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.1733241085073
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.58913582915232
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1485   -2.9871562   -2.3470294   -2.3363448 
    1486   -2.9871562   -2.3470294   -2.3326097 
Loop time of 3.61298e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.2641314629575
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.68107558840678
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 6.97252110520049
variable        y0 equal ${yi}
variable        y0 equal 2.85475352975228

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 7.01612061539336
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.79489908191064
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1486   -2.9871562   -2.3470294   -2.3326097 
    1487   -2.9871562   -2.3470294   -2.3491821 
Loop time of 3.56082e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.3491821489585
variable naccept equal ${increment}
variable naccept equal 328

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82797947445994
variable        y0 equal ${yi}
variable        y0 equal 0.89721691201958

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.87742778578883
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.858543499219745
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1487   -2.9871562   -2.3491821   -2.3491821 
    1488   -2.9871562   -2.3491821   -2.3402033 
Loop time of 3.35991e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82797947445994
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.89721691201958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.565379925170804
variable        y0 equal ${yi}
variable        y0 equal 4.68124908560678

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.589415891567136
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.64320851916238
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1488   -2.9871562   -2.3491821   -2.3402033 
    1489   -2.9871562   -2.3491821   -2.3360632 
Loop time of 3.50475e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.565379925170804
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.68124908560678
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.43833291927244
variable        y0 equal ${yi}
variable        y0 equal 7.40899122085832

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.34070295492079
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.48544802990221
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1489   -2.9871562   -2.3491821   -2.3360632 
    1490   -2.9871562   -2.3491821   -2.2940326 
Loop time of 3.52671e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.43833291927244
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.40899122085832
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.59938967108507
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.25094348110255
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1490   -2.9871562   -2.3491821   -2.2940326 
    1491   -2.9871562   -2.3491821   -2.3251076 
Loop time of 3.45118e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.06304890512325
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.56639753118982
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1491   -2.9871562   -2.3491821   -2.3251076 
    1492   -2.9871562   -2.3491821   -2.3466041 
Loop time of 3.56519e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.1493705244735
variable        y0 equal ${yi}
variable        y0 equal 4.58995101803705

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.10710482317955
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.59937599057123
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1492   -2.9871562   -2.3491821   -2.3466041 
    1493   -2.9871562   -2.3491821   -2.3497084 
Loop time of 3.47095e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.34970835992476
variable naccept equal ${increment}
variable naccept equal 329

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 6.02990794141284
variable        y0 equal ${yi}
variable        y0 equal 8.29363690532741

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.00572709996692
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.24073799766597
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1493   -2.9871562   -2.3497084   -2.3497084 
    1494   -2.9871562   -2.3497084   -2.3517455 
Loop time of 3.47956e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.35174554876471
variable naccept equal ${increment}
variable naccept equal 330

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.81228961268549
variable        y0 equal ${yi}
variable        y0 equal 8.38006076730785

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.85623695174341
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.47520034231243
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1494   -2.9871562   -2.3517455   -2.3517455 
    1495   -2.9871562   -2.3517455     -2.32621 
Loop time of 3.56672e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.81228961268549
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.38006076730785
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.3048199836384
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y -0.0480352044105498
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1495   -2.9871562   -2.3517455     -2.32621 
    1496   -2.9871562   -2.3517455   -2.3269154 
Loop time of 3.52947e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.55870154936087
variable        y0 equal ${yi}
variable        y0 equal 9.25253196466296

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.58914505083334
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.25292026508181
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1496   -2.9871562   -2.3517455   -2.3269154 
    1497   -2.9871562   -2.3517455   -2.3521796 
Loop time of 3.45981e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.35217961398725
variable naccept equal ${increment}
variable naccept equal 331

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.71003035782453
variable        y0 equal ${yi}
variable        y0 equal 7.4907858523395

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.71789805172559
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.52806635227465
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1497   -2.9871562   -2.3521796   -2.3521796 
    1498   -2.9871562   -2.3521796   -2.3394071 
Loop time of 3.51951e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 99 x ${x0}
set atom 99 x 9.71003035782453
  1 settings made for x
set atom $i y ${y0}
set atom 99 y ${y0}
set atom 99 y 7.4907858523395
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.50628010192338
variable        y0 equal ${yi}
variable        y0 equal 1.936454562164

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.60320955672685
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 2.02137250087326
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1498   -2.9871562   -2.3521796   -2.3394071 
    1499   -2.9871562   -2.3521796   -2.3263956 
Loop time of 3.52106e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.50628010192338
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.936454562164
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.03392777163536
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.38657822526987
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1499   -2.9871562   -2.3521796   -2.3263956 
    1500   -2.9871562   -2.3521796   -2.3390436 
Loop time of 3.48508e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.03154995162041
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.4676475397497
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.08605186342097
variable        y0 equal ${yi}
variable        y0 equal 0.950601537931293

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.01268419622279
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.977742036092609
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1500   -2.9871562   -2.3521796   -2.3390436 
    1501   -2.9871562   -2.3521796   -2.3508371 
Loop time of 3.49394e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.08605186342097
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.950601537931293
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 6.00572709996692
variable        y0 equal ${yi}
variable        y0 equal 8.24073799766597

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.09214819629184
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.28739581026134
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1501   -2.9871562   -2.3521796   -2.3508371 
    1502   -2.9871562   -2.3521796   -2.2863159 
Loop time of 3.46777e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 6.00572709996692
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.24073799766597
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6291183312588
variable        y0 equal ${yi}
variable        y0 equal 9.2346125077042

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.6723551591091
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.27579969871372
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1502   -2.9871562   -2.3521796   -2.2863159 
    1503   -2.9871562   -2.3521796   -2.3609608 
Loop time of 3.60212e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.36096081852969
variable naccept equal ${increment}
variable naccept equal 332

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.565379925170804
variable        y0 equal ${yi}
variable        y0 equal 4.68124908560678

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.625119288364316
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.67244114035531
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1503   -2.9871562   -2.3609608   -2.3609608 
    1504   -2.9871562   -2.3609608   -2.3360017 
Loop time of 3.37243e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.565379925170804
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.68124908560678
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.67264876246233
variable        y0 equal ${yi}
variable        y0 equal 0.871292896974415

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.77034671187182
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.819079120862812
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1504   -2.9871562   -2.3609608   -2.3360017 
    1505   -2.9871562   -2.3609608   -2.3057656 
Loop time of 3.55972e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.67264876246233
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.871292896974415
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.60553795257036
variable        y0 equal ${yi}
variable        y0 equal 5.53007482235628

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.54147622743074
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.60716458504396
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1505   -2.9871562   -2.3609608   -2.3057656 
    1506   -2.9871562   -2.3609608   -2.3673137 
Loop time of 3.52683e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.367313738859
variable naccept equal ${increment}
variable naccept equal 333

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0128975868225374
variable        y0 equal ${yi}
variable        y0 equal 3.77990783019196

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 0.0231997132301607
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.7308114127649
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1506   -2.9871562   -2.3673137   -2.3673137 
    1507   -2.9871562   -2.3673137   -2.3611926 
Loop time of 3.53875e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 0.0128975868225374
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.77990783019196
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.3840241916916
variable        y0 equal ${yi}
variable        y0 equal 9.27708193767397

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.31305292923661
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.33197137821047
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1507   -2.9871562   -2.3673137   -2.3611926 
    1508   -2.9871562   -2.3673137   -2.3519727 
Loop time of 3.48216e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.3840241916916
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.27708193767397
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.14502597490654
variable        y0 equal ${yi}
variable        y0 equal 5.53364494984346

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.15831883589134
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.59136620705324
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1508   -2.9871562   -2.3673137   -2.3519727 
    1509   -2.9871562   -2.3673137   -2.3651713 
Loop time of 3.51809e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.14502597490654
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.53364494984346
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 1.10092277844601
variable        y0 equal ${yi}
variable        y0 equal 9.22189815748065

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 1.13485514243298
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.16339764106601
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1509   -2.9871562   -2.3673137   -2.3651713 
    1510   -2.9871562   -2.3673137   -2.3622463 
Loop time of 3.56061e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 1.10092277844601
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.22189815748065
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.93050993322669
variable        y0 equal ${yi}
variable        y0 equal 6.34705883995524

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.99692866443931
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.37873343960276
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1510   -2.9871562   -2.3673137   -2.3622463 
    1511   -2.9871562   -2.3673137   -2.3191587 
Loop time of 3.40765e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.93050993322669
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.34705883995524
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2641314629575
variable        y0 equal ${yi}
variable        y0 equal 4.68107558840678

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.2359365467092
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.64773264283107
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1511   -2.9871562   -2.3673137   -2.3191587 
    1512   -2.9871562   -2.3673137   -2.3688238 
Loop time of 3.54006e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.36882384710886
variable naccept equal ${increment}
variable naccept equal 334

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.50276778458673
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.20062113132739
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1512   -2.9871562   -2.3688238   -2.3688238 
    1513   -2.9871562   -2.3688238   -2.2758381 
Loop time of 3.44976e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47168833731729
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.2979036006
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.52172473191339
variable        y0 equal ${yi}
variable        y0 equal 9.28439741838305

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.4789235901745
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.36222570646136
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1513   -2.9871562   -2.3688238   -2.2758381 
    1514   -2.9871562   -2.3688238   -2.3282103 
Loop time of 3.6426e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.52172473191339
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.28439741838305
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 1.10092277844601
variable        y0 equal ${yi}
variable        y0 equal 9.22189815748065

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 1.09443744738751
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.17019675481647
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1514   -2.9871562   -2.3688238   -2.3282103 
    1515   -2.9871562   -2.3688238   -2.3669062 
Loop time of 3.53405e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 1.10092277844601
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.22189815748065
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.506249304214384
variable        y0 equal ${yi}
variable        y0 equal 6.52357215420237

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.435167701640989
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.53249285952082
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1515   -2.9871562   -2.3688238   -2.3669062 
    1516   -2.9871562   -2.3688238   -2.3617071 
Loop time of 3.52306e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.506249304214384
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.52357215420237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.86954605538836
variable        y0 equal ${yi}
variable        y0 equal 4.6797511851208

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.79038659293643
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.74197206849025
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1516   -2.9871562   -2.3688238   -2.3617071 
    1517   -2.9871562   -2.3688238   -2.2934037 
Loop time of 3.575e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.86954605538836
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.6797511851208
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.08605186342097
variable        y0 equal ${yi}
variable        y0 equal 0.950601537931293

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.09907574056483
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 1.0210932571772
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1517   -2.9871562   -2.3688238   -2.2934037 
    1518   -2.9871562   -2.3688238   -2.3655404 
Loop time of 3.44335e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.08605186342097
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.950601537931293
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.64699440160219
variable        y0 equal ${yi}
variable        y0 equal 7.49384123411441

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.62012494960253
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.40796141948962
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1518   -2.9871562   -2.3688238   -2.3655404 
    1519   -2.9871562   -2.3688238   -2.3707154 
Loop time of 3.72534e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.37071540031597
variable naccept equal ${increment}
variable naccept equal 335

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.04105659126139
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.91440737220148
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1519   -2.9871562   -2.3707154   -2.3707154 
    1520   -2.9871562   -2.3707154   -2.3576305 
Loop time of 3.51725e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.50875395376456
variable        y0 equal ${yi}
variable        y0 equal 5.60411881153779

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.48013179142249
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.56685413067536
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1520   -2.9871562   -2.3707154   -2.3576305 
    1521   -2.9871562   -2.3707154   -2.3697081 
Loop time of 3.61245e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.50875395376456
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.60411881153779
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.67264876246233
variable        y0 equal ${yi}
variable        y0 equal 0.871292896974415

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.65424995302935
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.940276082265705
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1521   -2.9871562   -2.3707154   -2.3697081 
    1522   -2.9871562   -2.3707154   -2.3761966 
Loop time of 3.48313e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.37619664617867
variable naccept equal ${increment}
variable naccept equal 336

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.87112944403335
variable        y0 equal ${yi}
variable        y0 equal 4.73469646328852

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.83973346033737
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.79766978377268
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1522   -2.9871562   -2.3761966   -2.3761966 
    1523   -2.9871562   -2.3761966   -2.3057216 
Loop time of 3.431e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.87112944403335
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.73469646328852
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.38702585458317
variable        y0 equal ${yi}
variable        y0 equal 1.89600253484314

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.36681755542317
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.93881245038574
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1523   -2.9871562   -2.3761966   -2.3057216 
    1524   -2.9871562   -2.3761966   -2.3684866 
Loop time of 3.43074e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.38702585458317
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.89600253484314
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.43833291927244
variable        y0 equal ${yi}
variable        y0 equal 7.40899122085832

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.34686632553007
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.49731763925813
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1524   -2.9871562   -2.3761966   -2.3684866 
    1525   -2.9871562   -2.3761966   -2.3133852 
Loop time of 3.4701e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.43833291927244
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.40899122085832
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.9194044617717
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.3104681960493
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1525   -2.9871562   -2.3761966   -2.3133852 
    1526   -2.9871562   -2.3761966    -2.338616 
Loop time of 3.49821e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.87112944403335
variable        y0 equal ${yi}
variable        y0 equal 4.73469646328852

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.87009383717224
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.74487979763911
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1526   -2.9871562   -2.3761966    -2.338616 
    1527   -2.9871562   -2.3761966   -2.3716183 
Loop time of 3.44236e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.87112944403335
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.73469646328852
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.63595545449678
variable        y0 equal ${yi}
variable        y0 equal 0.131007170677185

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.71495827594225
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.1336461186409
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1527   -2.9871562   -2.3761966   -2.3716183 
    1528   -2.9871562   -2.3761966   -2.2730698 
Loop time of 3.46285e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.63595545449678
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.131007170677185
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.8900455796653
variable        y0 equal ${yi}
variable        y0 equal 0.887486429918145

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.86354889511406
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.835030194032525
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1528   -2.9871562   -2.3761966   -2.2730698 
    1529   -2.9871562   -2.3761966   -2.3682944 
Loop time of 3.44435e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.8900455796653
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.887486429918145
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.12239968497307
variable        y0 equal ${yi}
variable        y0 equal 1.09747809957299

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.18301769215615
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.18054794858727
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1529   -2.9871562   -2.3761966   -2.3682944 
    1530   -2.9871562   -2.3761966   -2.3588238 
Loop time of 3.54513e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.12239968497307
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.09747809957299
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.38702585458317
variable        y0 equal ${yi}
variable        y0 equal 1.89600253484314

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.40706796407261
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.92051968953674
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1530   -2.9871562   -2.3761966   -2.3588238 
    1531   -2.9871562   -2.3761966   -2.3669225 
Loop time of 3.56448e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.38702585458317
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.89600253484314
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40260913768674
variable        y0 equal ${yi}
variable        y0 equal 5.5414461011191

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.38028432527448
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.5347274178763
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1531   -2.9871562   -2.3761966   -2.3669225 
    1532   -2.9871562   -2.3761966   -2.3773056 
Loop time of 3.4891e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.37730563413064
variable naccept equal ${increment}
variable naccept equal 337

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.02622429727413
variable        y0 equal ${yi}
variable        y0 equal 8.30461697496469

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.03061267732479
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.28878506340082
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1532   -2.9871562   -2.3773056   -2.3773056 
    1533   -2.9871562   -2.3773056    -2.377033 
Loop time of 3.55199e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.37703298990854
variable naccept equal ${increment}
variable naccept equal 338

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.86681641299716
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.45958036915294
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1533   -2.9871562    -2.377033    -2.377033 
    1534   -2.9871562    -2.377033   -2.3688285 
Loop time of 3.40174e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.20629341322929
variable        y0 equal ${yi}
variable        y0 equal 2.76325721713403

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.24500529486686
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.79421185227731
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1534   -2.9871562    -2.377033   -2.3688285 
    1535   -2.9871562    -2.377033   -2.3706467 
Loop time of 3.4804e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.20629341322929
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.76325721713403
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.00392820794575
variable        y0 equal ${yi}
variable        y0 equal 0.864141031015247

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 6.01172782142155
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.868171354043811
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1535   -2.9871562    -2.377033   -2.3706467 
    1536   -2.9871562    -2.377033   -2.3762185 
Loop time of 3.48034e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 6.00392820794575
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.864141031015247
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.66294191041414
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.67760833068025
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1536   -2.9871562    -2.377033   -2.3762185 
    1537   -2.9871562    -2.377033   -2.3735907 
Loop time of 3.4903e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.42239316224176
variable        y0 equal ${yi}
variable        y0 equal 5.58969682400423

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.44479728459436
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.55894197170931
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1537   -2.9871562    -2.377033   -2.3735907 
    1538   -2.9871562    -2.377033   -2.3610517 
Loop time of 3.43687e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.42239316224176
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.58969682400423
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54731318790685
variable        y0 equal ${yi}
variable        y0 equal 3.75024119181764

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.54946586925756
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.75025760693681
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1538   -2.9871562    -2.377033   -2.3610517 
    1539   -2.9871562    -2.377033   -2.3767451 
Loop time of 3.40224e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.37674513133299
variable naccept equal ${increment}
variable naccept equal 339

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.18524035850868
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.38575051155352
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1539   -2.9871562   -2.3767451   -2.3767451 
    1540   -2.9871562   -2.3767451   -2.3721045 
Loop time of 3.62899e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.2665855534813
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.74414208693635
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1540   -2.9871562   -2.3767451   -2.3721045 
    1541   -2.9871562   -2.3767451   -2.3718399 
Loop time of 3.54037e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03061267732479
variable        y0 equal ${yi}
variable        y0 equal 8.28878506340082

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.00800922511913
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.35900400795038
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1541   -2.9871562   -2.3767451   -2.3718399 
    1542   -2.9871562   -2.3767451   -2.3687947 
Loop time of 3.58697e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03061267732479
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.28878506340082
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7380775292569
variable        y0 equal ${yi}
variable        y0 equal 7.41298324194217

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.741250999754
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.3905377539661
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1542   -2.9871562   -2.3767451   -2.3687947 
    1543   -2.9871562   -2.3767451      -2.3742 
Loop time of 3.37713e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7380775292569
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41298324194217
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.38702585458317
variable        y0 equal ${yi}
variable        y0 equal 1.89600253484314

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.37659301518955
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.91308428428238
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1543   -2.9871562   -2.3767451      -2.3742 
    1544   -2.9871562   -2.3767451   -2.3753267 
Loop time of 3.45276e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.38702585458317
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.89600253484314
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.01612061539336
variable        y0 equal ${yi}
variable        y0 equal 2.79489908191064

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.95665450373336
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.85447638007501
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1544   -2.9871562   -2.3767451   -2.3753267 
    1545   -2.9871562   -2.3767451   -2.3713464 
Loop time of 3.53401e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 7.01612061539336
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.79489908191064
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.93050993322669
variable        y0 equal ${yi}
variable        y0 equal 6.34705883995524

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 5.0077486598426
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.41248542801371
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1545   -2.9871562   -2.3767451   -2.3713464 
    1546   -2.9871562   -2.3767451   -2.3309876 
Loop time of 3.51496e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.93050993322669
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.34705883995524
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47168833731729
variable        y0 equal ${yi}
variable        y0 equal 7.2979036006

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.43071805953103
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.32951377954745
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1546   -2.9871562   -2.3767451   -2.3309876 
    1547   -2.9871562   -2.3767451   -2.3774237 
Loop time of 3.44377e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.37742366594311
variable naccept equal ${increment}
variable naccept equal 340

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.20629341322929
variable        y0 equal ${yi}
variable        y0 equal 2.76325721713403

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.12962397057563
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.82432608577112
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1547   -2.9871562   -2.3774237   -2.3774237 
    1548   -2.9871562   -2.3774237   -2.3630894 
Loop time of 3.54697e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.20629341322929
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.76325721713403
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.61079005478498
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.72778749032151
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1548   -2.9871562   -2.3774237   -2.3630894 
    1549   -2.9871562   -2.3774237   -2.3501657 
Loop time of 3.53869e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.12734762747936
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.93802600286072
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1549   -2.9871562   -2.3774237   -2.3501657 
    1550   -2.9871562   -2.3774237   -2.3726131 
Loop time of 3.44076e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.3095719222088
variable        y0 equal ${yi}
variable        y0 equal 0.876188357580036

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.2537579540272
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.909067996251911
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1550   -2.9871562   -2.3774237   -2.3726131 
    1551   -2.9871562   -2.3774237    -2.389182 
Loop time of 3.41426e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.38918201398972
variable naccept equal ${increment}
variable naccept equal 341

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03061267732479
variable        y0 equal ${yi}
variable        y0 equal 8.28878506340082

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.00893616079189
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.31115449585016
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1551   -2.9871562    -2.389182    -2.389182 
    1552   -2.9871562    -2.389182   -2.3885758 
Loop time of 3.52826e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03061267732479
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.28878506340082
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.01537109334023
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.42497081674631
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1552   -2.9871562    -2.389182   -2.3885758 
    1553   -2.9871562    -2.389182   -2.3882099 
Loop time of 3.49034e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.03154995162041
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.4676475397497
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.95838304717534
variable        y0 equal ${yi}
variable        y0 equal 2.82275391789772

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.95919567306035
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.9115227815757
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1553   -2.9871562    -2.389182   -2.3882099 
    1554   -2.9871562    -2.389182   -2.3682939 
Loop time of 3.47356e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.95838304717534
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.82275391789772
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.5961974489667
variable        y0 equal ${yi}
variable        y0 equal 6.55421015755167

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.64326201557894
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.51083962456217
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1554   -2.9871562    -2.389182   -2.3682939 
    1555   -2.9871562    -2.389182   -2.3859641 
Loop time of 3.50056e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.5961974489667
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.55421015755167
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6504576523953
variable        y0 equal ${yi}
variable        y0 equal 5.66441398804384

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.655749269312
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.73148243372637
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1555   -2.9871562    -2.389182   -2.3859641 
    1556   -2.9871562    -2.389182   -2.3608339 
Loop time of 3.33729e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.6504576523953
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.66441398804384
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.2537579540272
variable        y0 equal ${yi}
variable        y0 equal 0.909067996251911

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.2695594672222
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.902667458761066
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1556   -2.9871562    -2.389182   -2.3608339 
    1557   -2.9871562    -2.389182   -2.3878496 
Loop time of 3.31186e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.2537579540272
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.909067996251911
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.81026060540667
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.48969021574489
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1557   -2.9871562    -2.389182   -2.3878496 
    1558   -2.9871562    -2.389182   -2.3206951 
Loop time of 3.40656e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.14502597490654
variable        y0 equal ${yi}
variable        y0 equal 5.53364494984346

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.11205590406761
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.54899147694307
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1558   -2.9871562    -2.389182   -2.3206951 
    1559   -2.9871562    -2.389182   -2.3896268 
Loop time of 3.5285e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.38962679129838
variable naccept equal ${increment}
variable naccept equal 342

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.43551569699365
variable        y0 equal ${yi}
variable        y0 equal 1.89214071414535

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.42690716504175
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.90854758403366
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1559   -2.9871562   -2.3896268   -2.3896268 
    1560   -2.9871562   -2.3896268   -2.3874994 
Loop time of 3.48614e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.43551569699365
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.89214071414535
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.43833291927244
variable        y0 equal ${yi}
variable        y0 equal 7.40899122085832

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.53812940517332
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.36047025051378
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1560   -2.9871562   -2.3896268   -2.3874994 
    1561   -2.9871562   -2.3896268   -2.3048149 
Loop time of 3.48174e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.43833291927244
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.40899122085832
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.11205590406761
variable        y0 equal ${yi}
variable        y0 equal 5.54899147694307

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.20577104727135
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.51198691075044
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1561   -2.9871562   -2.3896268   -2.3048149 
    1562   -2.9871562   -2.3896268   -2.3796826 
Loop time of 3.48016e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.11205590406761
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.54899147694307
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03084906657391
variable        y0 equal ${yi}
variable        y0 equal 5.64538028185563

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 1.0154843838995
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.6486886853476
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1562   -2.9871562   -2.3896268   -2.3796826 
    1563   -2.9871562   -2.3896268   -2.3882302 
Loop time of 3.4476e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03084906657391
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.64538028185563
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.41855881928521
variable        y0 equal ${yi}
variable        y0 equal 3.78684511942993

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.32633780955392
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.79338975710998
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1563   -2.9871562   -2.3896268   -2.3882302 
    1564   -2.9871562   -2.3896268   -2.3338222 
Loop time of 3.50651e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.41855881928521
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.78684511942993
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.46746646562482
variable        y0 equal ${yi}
variable        y0 equal 9.264607102755

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.42992707887555
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.27564311731189
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1564   -2.9871562   -2.3896268   -2.3338222 
    1565   -2.9871562   -2.3896268   -2.3878875 
Loop time of 3.47091e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.46746646562482
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.264607102755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.20629341322929
variable        y0 equal ${yi}
variable        y0 equal 2.76325721713403

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.19705078322441
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.81751230927804
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1565   -2.9871562   -2.3896268   -2.3878875 
    1566   -2.9871562   -2.3896268    -2.382329 
Loop time of 3.51214e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.20629341322929
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.76325721713403
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.54147622743074
variable        y0 equal ${yi}
variable        y0 equal 5.60716458504396

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.50745934405748
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.56924527828889
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1566   -2.9871562   -2.3896268    -2.382329 
    1567   -2.9871562   -2.3896268   -2.3908578 
Loop time of 3.4852e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.39085783729603
variable naccept equal ${increment}
variable naccept equal 343

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03061267732479
variable        y0 equal ${yi}
variable        y0 equal 8.28878506340082

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 7.97098349927761
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.38290502943094
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1567   -2.9871562   -2.3908578   -2.3908578 
    1568   -2.9871562   -2.3908578   -2.3625309 
Loop time of 3.39594e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03061267732479
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.28878506340082
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.65424995302935
variable        y0 equal ${yi}
variable        y0 equal 0.940276082265705

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.74623134016772
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.960273619401783
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1568   -2.9871562   -2.3908578   -2.3625309 
    1569   -2.9871562   -2.3908578   -2.3856967 
Loop time of 3.38322e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.65424995302935
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.940276082265705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.8900455796653
variable        y0 equal ${yi}
variable        y0 equal 0.887486429918145

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.86644296287834
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.924780436265801
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1569   -2.9871562   -2.3908578   -2.3856967 
    1570   -2.9871562   -2.3908578   -2.3823636 
Loop time of 3.45333e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.8900455796653
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.887486429918145
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03061267732479
variable        y0 equal ${yi}
variable        y0 equal 8.28878506340082

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 7.99167135356762
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.23094727911051
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1570   -2.9871562   -2.3908578   -2.3823636 
    1571   -2.9871562   -2.3908578   -2.3788484 
Loop time of 3.45593e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03061267732479
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.28878506340082
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.42546442587148
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.28257979479099
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1571   -2.9871562   -2.3908578   -2.3788484 
    1572   -2.9871562   -2.3908578   -2.3336592 
Loop time of 3.53365e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.48385869104635
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.38020931806827
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.02537268677399
variable        y0 equal ${yi}
variable        y0 equal 0.926061685788958

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.03727689066574
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.91603718589577
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1572   -2.9871562   -2.3908578   -2.3336592 
    1573   -2.9871562   -2.3908578   -2.3921592 
Loop time of 3.49812e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.39215916890571
variable naccept equal ${increment}
variable naccept equal 344

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 6.00392820794575
variable        y0 equal ${yi}
variable        y0 equal 0.864141031015247

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 5.97854424674504
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.914465494859546
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1573   -2.9871562   -2.3921592   -2.3921592 
    1574   -2.9871562   -2.3921592    -2.394011 
Loop time of 3.48019e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.39401101494812
variable naccept equal ${increment}
variable naccept equal 345

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.2537579540272
variable        y0 equal ${yi}
variable        y0 equal 0.909067996251911

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.2643844489117
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.8478167731646
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1574   -2.9871562    -2.394011    -2.394011 
    1575   -2.9871562    -2.394011   -2.3799565 
Loop time of 3.53518e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.2537579540272
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.909067996251911
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.38028432527448
variable        y0 equal ${yi}
variable        y0 equal 5.5347274178763

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.33703600564863
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.47514280026155
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1575   -2.9871562    -2.394011   -2.3799565 
    1576   -2.9871562    -2.394011    -2.394262 
Loop time of 3.52093e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.39426203637691
variable naccept equal ${increment}
variable naccept equal 346

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.93050993322669
variable        y0 equal ${yi}
variable        y0 equal 6.34705883995524

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.84836245416938
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.26088276640406
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1576   -2.9871562    -2.394262    -2.394262 
    1577   -2.9871562    -2.394262    -2.258698 
Loop time of 3.45599e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.93050993322669
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.34705883995524
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.95838304717534
variable        y0 equal ${yi}
variable        y0 equal 2.82275391789772

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.91528079469197
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.77867687913277
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1577   -2.9871562    -2.394262    -2.258698 
    1578   -2.9871562    -2.394262   -2.3909952 
Loop time of 3.36588e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.95838304717534
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.82275391789772
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.0893364131341
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.90921703549723
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1578   -2.9871562    -2.394262   -2.3909952 
    1579   -2.9871562    -2.394262   -2.3861833 
Loop time of 3.48321e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.62699805338155
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.75734753174913
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1579   -2.9871562    -2.394262   -2.3861833 
    1580   -2.9871562    -2.394262   -2.3761296 
Loop time of 3.43991e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6723551591091
variable        y0 equal ${yi}
variable        y0 equal 9.27579969871372

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.7559182484798
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.28018943775028
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1580   -2.9871562    -2.394262   -2.3761296 
    1581   -2.9871562    -2.394262   -2.3894484 
Loop time of 3.35192e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6723551591091
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.27579969871372
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.44468214351904
variable        y0 equal ${yi}
variable        y0 equal 1.838471952892

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.52162269193899
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.84969287297791
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1581   -2.9871562    -2.394262   -2.3894484 
    1582   -2.9871562    -2.394262   -2.3967567 
Loop time of 3.5967e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.39675665720689
variable naccept equal ${increment}
variable naccept equal 347

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.43071805953103
variable        y0 equal ${yi}
variable        y0 equal 7.32951377954745

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.37371773242074
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.24087052669787
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1582   -2.9871562   -2.3967567   -2.3967567 
    1583   -2.9871562   -2.3967567   -2.3460236 
Loop time of 3.48592e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.43071805953103
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.32951377954745
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.6302324012908
variable        y0 equal ${yi}
variable        y0 equal 0.804496832597583

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.636937864223387
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.794898768174976
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1583   -2.9871562   -2.3967567   -2.3460236 
    1584   -2.9871562   -2.3967567   -2.3933692 
Loop time of 3.60931e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.6302324012908
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.804496832597583
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.23380876858445
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.69530561728608
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1584   -2.9871562   -2.3967567   -2.3933692 
    1585   -2.9871562   -2.3967567   -2.3728138 
Loop time of 3.6017e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.33703600564863
variable        y0 equal ${yi}
variable        y0 equal 5.47514280026155

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.40210565725233
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.41143176500993
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1585   -2.9871562   -2.3967567   -2.3728138 
    1586   -2.9871562   -2.3967567   -2.3014081 
Loop time of 3.48109e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.33703600564863
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.47514280026155
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0608747247716
variable        y0 equal ${yi}
variable        y0 equal 6.4793810679101

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.1511675480863
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.43177567259302
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1586   -2.9871562   -2.3967567   -2.3014081 
    1587   -2.9871562   -2.3967567   -2.3559358 
Loop time of 3.4918e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.0608747247716
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.4793810679101
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.93805575012504
variable        y0 equal ${yi}
variable        y0 equal 8.32736837781961

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.97838403820335
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.27705650247629
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1587   -2.9871562   -2.3967567   -2.3559358 
    1588   -2.9871562   -2.3967567   -2.3776653 
Loop time of 3.42244e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.93805575012504
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.32736837781961
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.52162269193899
variable        y0 equal ${yi}
variable        y0 equal 1.84969287297791

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.43480664331686
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.77541529319352
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1588   -2.9871562   -2.3967567   -2.3776653 
    1589   -2.9871562   -2.3967567   -2.3698955 
Loop time of 3.52272e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.52162269193899
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.84969287297791
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.93050993322669
variable        y0 equal ${yi}
variable        y0 equal 6.34705883995524

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.86739642261802
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.2995079709672
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1589   -2.9871562   -2.3967567   -2.3698955 
    1590   -2.9871562   -2.3967567    -2.351696 
Loop time of 3.50301e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.93050993322669
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.34705883995524
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.34726541995564
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.0826954364776612
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1590   -2.9871562   -2.3967567    -2.351696 
    1591   -2.9871562   -2.3967567    -2.369528 
Loop time of 3.40439e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03061267732479
variable        y0 equal ${yi}
variable        y0 equal 8.28878506340082

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 7.97396156190731
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.26578401245172
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1591   -2.9871562   -2.3967567    -2.369528 
    1592   -2.9871562   -2.3967567   -2.3875192 
Loop time of 3.50323e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03061267732479
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.28878506340082
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.50628010192338
variable        y0 equal ${yi}
variable        y0 equal 1.936454562164

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.59718036809388
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 2.01303313157623
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1592   -2.9871562   -2.3967567   -2.3875192 
    1593   -2.9871562   -2.3967567   -2.3884138 
Loop time of 3.5034e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.50628010192338
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.936454562164
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0128975868225374
variable        y0 equal ${yi}
variable        y0 equal 3.77990783019196

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 0.0289654493332186
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.83693432374131
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1593   -2.9871562   -2.3967567   -2.3884138 
    1594   -2.9871562   -2.3967567   -2.3841827 
Loop time of 3.47445e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 0.0128975868225374
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.77990783019196
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.64135602593203
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.40701757587489
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1594   -2.9871562   -2.3967567   -2.3841827 
    1595   -2.9871562   -2.3967567   -2.3860846 
Loop time of 3.54665e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.43551569699365
variable        y0 equal ${yi}
variable        y0 equal 1.89214071414535

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.3980341625126
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.97295897386138
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1595   -2.9871562   -2.3967567   -2.3860846 
    1596   -2.9871562   -2.3967567   -2.3645114 
Loop time of 3.4186e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.43551569699365
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.89214071414535
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.10710482317955
variable        y0 equal ${yi}
variable        y0 equal 4.59937599057123

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.17118136603386
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.55287211293146
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1596   -2.9871562   -2.3967567   -2.3645114 
    1597   -2.9871562   -2.3967567   -2.3863824 
Loop time of 3.40363e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.10710482317955
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.59937599057123
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.42793486197206
variable        y0 equal ${yi}
variable        y0 equal 1.83933557651109

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.44382004816743
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.8044141688115
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1597   -2.9871562   -2.3967567   -2.3863824 
    1598   -2.9871562   -2.3967567   -2.3883279 
Loop time of 3.6199e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.42793486197206
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.83933557651109
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57543257355471
variable        y0 equal ${yi}
variable        y0 equal 4.67648406380578

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.56137241005679
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.72013165110513
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1598   -2.9871562   -2.3967567   -2.3883279 
    1599   -2.9871562   -2.3967567    -2.395142 
Loop time of 3.5152e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.57543257355471
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.67648406380578
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.42982077161398
variable        y0 equal ${yi}
variable        y0 equal 8.3828137747198

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.406736107269192
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.40122474350032
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1599   -2.9871562   -2.3967567    -2.395142 
    1600   -2.9871562   -2.3967567   -2.3906146 
Loop time of 3.432e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.42982077161398
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.3828137747198
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.25279456138173
variable        y0 equal ${yi}
variable        y0 equal 7.38214940157198

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.22330659389058
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.46451312628054
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1600   -2.9871562   -2.3967567   -2.3906146 
    1601   -2.9871562   -2.3967567   -2.3954025 
Loop time of 3.44575e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.25279456138173
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.38214940157198
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 5.97854424674504
variable        y0 equal ${yi}
variable        y0 equal 0.914465494859546

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 5.92014288861745
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.862345774877399
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1601   -2.9871562   -2.3967567   -2.3954025 
    1602   -2.9871562   -2.3967567   -2.3894755 
Loop time of 3.39928e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 5.97854424674504
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.914465494859546
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.46167096057359
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.57022019570069
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1602   -2.9871562   -2.3967567   -2.3894755 
    1603   -2.9871562   -2.3967567   -2.3749092 
Loop time of 3.41014e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.21353167930946
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.3602361592319
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1603   -2.9871562   -2.3967567   -2.3749092 
    1604   -2.9871562   -2.3967567   -2.3823936 
Loop time of 3.42129e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.60411336261999
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.83266422314775
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1604   -2.9871562   -2.3967567   -2.3823936 
    1605   -2.9871562   -2.3967567   -2.3782454 
Loop time of 3.46135e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.50875395376456
variable        y0 equal ${yi}
variable        y0 equal 5.60411881153779

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.55266139347327
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.61738377754884
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1605   -2.9871562   -2.3967567   -2.3782454 
    1606   -2.9871562   -2.3967567   -2.3819348 
Loop time of 3.62737e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.50875395376456
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.60411881153779
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.81859772721415
variable        y0 equal ${yi}
variable        y0 equal 6.51868253485194

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.81946296015864
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.45068209902278
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1606   -2.9871562   -2.3967567   -2.3819348 
    1607   -2.9871562   -2.3967567   -2.3832763 
Loop time of 3.52895e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.81859772721415
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.51868253485194
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03061267732479
variable        y0 equal ${yi}
variable        y0 equal 8.28878506340082

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.04029147027828
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.25850142158563
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1607   -2.9871562   -2.3967567   -2.3832763 
    1608   -2.9871562   -2.3967567   -2.3931312 
Loop time of 3.61044e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03061267732479
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.28878506340082
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.11205590406761
variable        y0 equal ${yi}
variable        y0 equal 5.54899147694307

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.1064336244236
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.61231265013414
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1608   -2.9871562   -2.3967567   -2.3931312 
    1609   -2.9871562   -2.3967567   -2.3948602 
Loop time of 3.50425e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.11205590406761
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.54899147694307
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2359365467092
variable        y0 equal ${yi}
variable        y0 equal 4.64773264283107

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.242561090376
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.64110292548106
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1609   -2.9871562   -2.3967567   -2.3948602 
    1610   -2.9871562   -2.3967567   -2.3950462 
Loop time of 3.532e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.2359365467092
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.64773264283107
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.12239968497307
variable        y0 equal ${yi}
variable        y0 equal 1.09747809957299

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.07095741946251
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.06844511817727
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1610   -2.9871562   -2.3967567   -2.3950462 
    1611   -2.9871562   -2.3967567   -2.3832581 
Loop time of 3.41036e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.12239968497307
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.09747809957299
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7380775292569
variable        y0 equal ${yi}
variable        y0 equal 7.41298324194217

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.6960725267583
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.43435540523792
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1611   -2.9871562   -2.3967567   -2.3832581 
    1612   -2.9871562   -2.3967567   -2.3943511 
Loop time of 3.62564e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7380775292569
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41298324194217
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.63595545449678
variable        y0 equal ${yi}
variable        y0 equal 0.131007170677185

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.70272027411882
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.154402554035187
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1612   -2.9871562   -2.3967567   -2.3943511 
    1613   -2.9871562   -2.3967567   -2.3209696 
Loop time of 3.53698e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.63595545449678
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.131007170677185
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.46746646562482
variable        y0 equal ${yi}
variable        y0 equal 9.264607102755

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.45701496997739
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.28743154514163
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1613   -2.9871562   -2.3967567   -2.3209696 
    1614   -2.9871562   -2.3967567   -2.3955806 
Loop time of 3.67838e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.46746646562482
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.264607102755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.95269584932968
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.2710354081541
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1614   -2.9871562   -2.3967567   -2.3955806 
    1615   -2.9871562   -2.3967567   -2.3812612 
Loop time of 3.57972e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.45199407179128
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.37369788017536
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1615   -2.9871562   -2.3967567   -2.3812612 
    1616   -2.9871562   -2.3967567   -2.3925994 
Loop time of 3.49179e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.48385869104635
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.38020931806827
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.03727689066574
variable        y0 equal ${yi}
variable        y0 equal 0.91603718589577

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.09564354696915
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.837364741075366
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1616   -2.9871562   -2.3967567   -2.3925994 
    1617   -2.9871562   -2.3967567   -2.3811318 
Loop time of 3.44984e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.03727689066574
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.91603718589577
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.46746646562482
variable        y0 equal ${yi}
variable        y0 equal 9.264607102755

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.40658594766523
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.26384200561374
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1617   -2.9871562   -2.3967567   -2.3811318 
    1618   -2.9871562   -2.3967567    -2.390751 
Loop time of 3.5395e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.46746646562482
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.264607102755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.86954605538836
variable        y0 equal ${yi}
variable        y0 equal 4.6797511851208

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.82465205152026
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.66146899813578
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1618   -2.9871562   -2.3967567    -2.390751 
    1619   -2.9871562   -2.3967567   -2.3919641 
Loop time of 3.70194e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.86954605538836
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.6797511851208
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.33703600564863
variable        y0 equal ${yi}
variable        y0 equal 5.47514280026155

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.24110746780302
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.3994308585425
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1619   -2.9871562   -2.3967567   -2.3919641 
    1620   -2.9871562   -2.3967567   -2.2517506 
Loop time of 6.27685e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.33703600564863
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.47514280026155
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.50087765295278
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.46227217045093
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1620   -2.9871562   -2.3967567   -2.2517506 
    1621   -2.9871562   -2.3967567   -2.3838523 
Loop time of 3.6127e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.48385869104635
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.38020931806827
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.74466399152708
variable        y0 equal ${yi}
variable        y0 equal 2.74569092961648

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.66883688171339
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.8217652794967
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1621   -2.9871562   -2.3967567   -2.3838523 
    1622   -2.9871562   -2.3967567    -2.395597 
Loop time of 3.55954e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.74466399152708
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.74569092961648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03061267732479
variable        y0 equal ${yi}
variable        y0 equal 8.28878506340082

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.03638686536648
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.31822016157205
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1622   -2.9871562   -2.3967567    -2.395597 
    1623   -2.9871562   -2.3967567   -2.3959434 
Loop time of 3.55628e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03061267732479
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.28878506340082
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.42239316224176
variable        y0 equal ${yi}
variable        y0 equal 5.58969682400423

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.40398987053949
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.57818756048876
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1623   -2.9871562   -2.3967567   -2.3959434 
    1624   -2.9871562   -2.3967567   -2.3961382 
Loop time of 3.66424e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.42239316224176
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.58969682400423
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.91699399589834
variable        y0 equal ${yi}
variable        y0 equal 2.91251749965051

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.95663658022222
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.96936016055444
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1624   -2.9871562   -2.3967567   -2.3961382 
    1625   -2.9871562   -2.3967567   -2.3238046 
Loop time of 3.59458e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.91699399589834
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.91251749965051
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.13668940385036
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.7966759838826
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1625   -2.9871562   -2.3967567   -2.3238046 
    1626   -2.9871562   -2.3967567   -2.3888636 
Loop time of 3.42809e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0608747247716
variable        y0 equal ${yi}
variable        y0 equal 6.4793810679101

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.0998515967389
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.55315701500406
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1626   -2.9871562   -2.3967567   -2.3888636 
    1627   -2.9871562   -2.3967567   -2.4004429 
Loop time of 3.57105e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.400442933398
variable naccept equal ${increment}
variable naccept equal 348

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.81859772721415
variable        y0 equal ${yi}
variable        y0 equal 6.51868253485194

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.85056946793681
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.58491022125712
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1627   -2.9871562   -2.4004429   -2.4004429 
    1628   -2.9871562   -2.4004429   -2.3918205 
Loop time of 4.05517e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.81859772721415
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.51868253485194
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78581515748931
variable        y0 equal ${yi}
variable        y0 equal 1.04153251241478

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.70544864137603
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.13196807693275
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1628   -2.9871562   -2.4004429   -2.3918205 
    1629   -2.9871562   -2.4004429   -2.3636143 
Loop time of 3.49505e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.78581515748931
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.04153251241478
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.71003035782453
variable        y0 equal ${yi}
variable        y0 equal 7.4907858523395

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.6573487090933
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.44725758161806
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1629   -2.9871562   -2.4004429   -2.3636143 
    1630   -2.9871562   -2.4004429   -2.4069494 
Loop time of 3.52209e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.40694942149642
variable naccept equal ${increment}
variable naccept equal 349

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0998515967389
variable        y0 equal ${yi}
variable        y0 equal 6.55315701500406

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.0979187730809
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.63510351912012
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1630   -2.9871562   -2.4069494   -2.4069494 
    1631   -2.9871562   -2.4069494    -2.363002 
Loop time of 6.14929e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.0998515967389
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.55315701500406
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57543257355471
variable        y0 equal ${yi}
variable        y0 equal 4.67648406380578

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.50386013865252
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.73356182927056
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1631   -2.9871562   -2.4069494    -2.363002 
    1632   -2.9871562   -2.4069494   -2.3790823 
Loop time of 3.60324e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.57543257355471
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.67648406380578
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.565379925170804
variable        y0 equal ${yi}
variable        y0 equal 4.68124908560678

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.53745518485632
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.67062938565179
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1632   -2.9871562   -2.4069494   -2.3790823 
    1633   -2.9871562   -2.4069494   -2.4085297 
Loop time of 3.6456e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.4085296710323
variable naccept equal ${increment}
variable naccept equal 350

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.42982077161398
variable        y0 equal ${yi}
variable        y0 equal 8.3828137747198

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.449145431915189
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.34512849964198
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1633   -2.9871562   -2.4085297   -2.4085297 
    1634   -2.9871562   -2.4085297   -2.4100201 
Loop time of 3.53527e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.41002012024877
variable naccept equal ${increment}
variable naccept equal 351

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03084906657391
variable        y0 equal ${yi}
variable        y0 equal 5.64538028185563

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 0.933642402488522
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.66180599873261
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1634   -2.9871562   -2.4100201   -2.4100201 
    1635   -2.9871562   -2.4100201   -2.3871551 
Loop time of 3.49027e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03084906657391
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.64538028185563
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.95838304717534
variable        y0 equal ${yi}
variable        y0 equal 2.82275391789772

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 6.02872692306035
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.726897382463
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1635   -2.9871562   -2.4100201   -2.3871551 
    1636   -2.9871562   -2.4100201   -2.3622287 
Loop time of 3.58402e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.95838304717534
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.82275391789772
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3102847699186
variable        y0 equal ${yi}
variable        y0 equal 2.86695545884469

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.2870564106962
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.91827194663384
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1636   -2.9871562   -2.4100201   -2.3622287 
    1637   -2.9871562   -2.4100201   -2.3906711 
Loop time of 3.54396e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3102847699186
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.86695545884469
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0998515967389
variable        y0 equal ${yi}
variable        y0 equal 6.55315701500406

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.0664774183293
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.45402191416254
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1637   -2.9871562   -2.4100201   -2.3906711 
    1638   -2.9871562   -2.4100201   -2.4041982 
Loop time of 6.09722e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.0998515967389
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.55315701500406
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.112628924846649
variable        y0 equal ${yi}
variable        y0 equal 1.75601954839296

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.165302717685699
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.6786185064084
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1638   -2.9871562   -2.4100201   -2.4041982 
    1639   -2.9871562   -2.4100201   -2.3880255 
Loop time of 3.51533e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 6 x ${x0}
set atom 6 x 0.112628924846649
  1 settings made for x
set atom $i y ${y0}
set atom 6 y ${y0}
set atom 6 y 1.75601954839296
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.42239316224176
variable        y0 equal ${yi}
variable        y0 equal 5.58969682400423

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.34992105483133
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.67801991646486
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1639   -2.9871562   -2.4100201   -2.3880255 
    1640   -2.9871562   -2.4100201   -2.3309467 
Loop time of 3.50365e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.42239316224176
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.58969682400423
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.52162269193899
variable        y0 equal ${yi}
variable        y0 equal 1.84969287297791

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.44202568371069
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.77204065702027
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1640   -2.9871562   -2.4100201   -2.3309467 
    1641   -2.9871562   -2.4100201   -2.3838581 
Loop time of 3.46709e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.52162269193899
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.84969287297791
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.93050993322669
variable        y0 equal ${yi}
variable        y0 equal 6.34705883995524

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.84048221945106
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.44614082113734
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1641   -2.9871562   -2.4100201   -2.3838581 
    1642   -2.9871562   -2.4100201   -2.4546801 
Loop time of 3.5619e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.45468014565983
variable naccept equal ${increment}
variable naccept equal 352

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.71964113036281
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.56571184748576
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1642   -2.9871562   -2.4546801   -2.4546801 
    1643   -2.9871562   -2.4546801   -2.4292189 
Loop time of 3.47879e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.41855881928521
variable        y0 equal ${yi}
variable        y0 equal 3.78684511942993

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.49318475245553
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.8258053378595
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1643   -2.9871562   -2.4546801   -2.4292189 
    1644   -2.9871562   -2.4546801   -2.4498977 
Loop time of 3.4821e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.41855881928521
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.78684511942993
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.57767070689622
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.5189726943274
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1644   -2.9871562   -2.4546801   -2.4498977 
    1645   -2.9871562   -2.4546801   -2.4532078 
Loop time of 3.58992e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 6.00572709996692
variable        y0 equal ${yi}
variable        y0 equal 8.24073799766597

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.02036504704944
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.15331437505779
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1645   -2.9871562   -2.4546801   -2.4532078 
    1646   -2.9871562   -2.4546801   -2.3831545 
Loop time of 3.51671e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 6.00572709996692
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.24073799766597
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.63480706095477
variable        y0 equal ${yi}
variable        y0 equal 2.83259171220163

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.57092106222888
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.80133521529535
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1646   -2.9871562   -2.4546801   -2.3831545 
    1647   -2.9871562   -2.4546801    -2.437121 
Loop time of 3.58557e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.63480706095477
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.83259171220163
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.12239968497307
variable        y0 equal ${yi}
variable        y0 equal 1.09747809957299

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.08331709820778
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.03719662021432
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1647   -2.9871562   -2.4546801    -2.437121 
    1648   -2.9871562   -2.4546801   -2.4418515 
Loop time of 3.48561e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.12239968497307
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.09747809957299
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.03727689066574
variable        y0 equal ${yi}
variable        y0 equal 0.91603718589577

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.01635973730728
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.97898919175896
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1648   -2.9871562   -2.4546801   -2.4418515 
    1649   -2.9871562   -2.4546801   -2.4482802 
Loop time of 3.58689e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.03727689066574
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.91603718589577
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.6573487090933
variable        y0 equal ${yi}
variable        y0 equal 7.44725758161806

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.69856387852308
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.44056930866503
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1649   -2.9871562   -2.4546801   -2.4482802 
    1650   -2.9871562   -2.4546801   -2.4457014 
Loop time of 3.44642e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 99 x ${x0}
set atom 99 x 9.6573487090933
  1 settings made for x
set atom $i y ${y0}
set atom 99 y ${y0}
set atom 99 y 7.44725758161806
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.19165719508687
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.0144035696983337
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1650   -2.9871562   -2.4546801   -2.4457014 
    1651   -2.9871562   -2.4546801   -2.4312399 
Loop time of 3.61086e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.57222292898772
variable        y0 equal ${yi}
variable        y0 equal 5.48064044659334

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.55012845276473
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.43772259895998
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1651   -2.9871562   -2.4546801   -2.4312399 
    1652   -2.9871562   -2.4546801   -2.4318207 
Loop time of 3.42801e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.57222292898772
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.48064044659334
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.46746646562482
variable        y0 equal ${yi}
variable        y0 equal 9.264607102755

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.38620512882138
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.33445448386996
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1652   -2.9871562   -2.4546801   -2.4318207 
    1653   -2.9871562   -2.4546801    -2.434256 
Loop time of 3.89258e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.46746646562482
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.264607102755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.50875395376456
variable        y0 equal ${yi}
variable        y0 equal 5.60411881153779

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.59699330169928
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.58218789046006
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1653   -2.9871562   -2.4546801    -2.434256 
    1654   -2.9871562   -2.4546801   -2.3965401 
Loop time of 3.51353e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.50875395376456
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.60411881153779
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 5.97854424674504
variable        y0 equal ${yi}
variable        y0 equal 0.914465494859546

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 5.90471900660985
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.963729925859302
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1654   -2.9871562   -2.4546801   -2.3965401 
    1655   -2.9871562   -2.4546801   -2.4187071 
Loop time of 3.52261e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 5.97854424674504
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.914465494859546
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.87112944403335
variable        y0 equal ${yi}
variable        y0 equal 4.73469646328852

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.92686012068435
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.65877217406199
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1655   -2.9871562   -2.4546801   -2.4187071 
    1656   -2.9871562   -2.4546801   -2.4771683 
Loop time of 3.41981e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.47716830550977
variable naccept equal ${increment}
variable naccept equal 353

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03061267732479
variable        y0 equal ${yi}
variable        y0 equal 8.28878506340082

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.0932127654443
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.28723951496179
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1656   -2.9871562   -2.4771683   -2.4771683 
    1657   -2.9871562   -2.4771683   -2.4593754 
Loop time of 3.54543e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03061267732479
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.28878506340082
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.16092934011316
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.80374376746515
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1657   -2.9871562   -2.4771683   -2.4593754 
    1658   -2.9871562   -2.4771683   -2.4502813 
Loop time of 3.57636e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75591478546096
variable        y0 equal ${yi}
variable        y0 equal 4.61056455725595

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.65670803983642
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.62625749463006
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1658   -2.9871562   -2.4771683   -2.4502813 
    1659   -2.9871562   -2.4771683   -2.4758949 
Loop time of 3.44301e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.75591478546096
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.61056455725595
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.506249304214384
variable        y0 equal ${yi}
variable        y0 equal 6.52357215420237

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.437867458263304
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.6103725983285
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1659   -2.9871562   -2.4771683   -2.4758949 
    1660   -2.9871562   -2.4771683   -2.4327166 
Loop time of 3.62976e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.506249304214384
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.52357215420237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.86155322073576
variable        y0 equal ${yi}
variable        y0 equal 1.87893718860216

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.77681892393705
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.79851738593645
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1660   -2.9871562   -2.4771683   -2.4327166 
    1661   -2.9871562   -2.4771683   -2.4579178 
Loop time of 3.64867e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.86155322073576
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.87893718860216
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.86954605538836
variable        y0 equal ${yi}
variable        y0 equal 4.6797511851208

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.81550116498461
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.66097144240306
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1661   -2.9871562   -2.4771683   -2.4579178 
    1662   -2.9871562   -2.4771683   -2.4628814 
Loop time of 3.70546e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.86954605538836
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.6797511851208
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.63523735283491
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.76121059222352
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1662   -2.9871562   -2.4771683   -2.4628814 
    1663   -2.9871562   -2.4771683     -2.45898 
Loop time of 3.69515e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.63595545449678
variable        y0 equal ${yi}
variable        y0 equal 0.131007170677185

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.58196511426393
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.0479238748550414
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1663   -2.9871562   -2.4771683     -2.45898 
    1664   -2.9871562   -2.4771683   -2.4929299 
Loop time of 3.5995e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.49292987654532
variable naccept equal ${increment}
variable naccept equal 354

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6723551591091
variable        y0 equal ${yi}
variable        y0 equal 9.27579969871372

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.6899928529911
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.17756562936634
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1664   -2.9871562   -2.4929299   -2.4929299 
    1665   -2.9871562   -2.4929299   -2.4657483 
Loop time of 3.45497e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6723551591091
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.27579969871372
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.27000193039285
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y -0.0453639030456511
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1665   -2.9871562   -2.4929299   -2.4657483 
    1666   -2.9871562   -2.4929299   -2.4754582 
Loop time of 3.60858e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.11698845068322
variable        y0 equal ${yi}
variable        y0 equal 3.79524089856278

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.08993453422891
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.75500698847901
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1666   -2.9871562   -2.4929299   -2.4754582 
    1667   -2.9871562   -2.4929299   -2.4872291 
Loop time of 3.58765e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.11698845068322
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.79524089856278
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.5961974489667
variable        y0 equal ${yi}
variable        y0 equal 6.55421015755167

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.50188500761767
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.60791731611719
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1667   -2.9871562   -2.4929299   -2.4872291 
    1668   -2.9871562   -2.4929299   -2.4680639 
Loop time of 3.48982e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.5961974489667
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.55421015755167
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.26462735890904
variable        y0 equal ${yi}
variable        y0 equal 3.68544435067308

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.28058383225957
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.78253848118913
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1668   -2.9871562   -2.4929299   -2.4680639 
    1669   -2.9871562   -2.4929299   -2.4673965 
Loop time of 3.61568e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.26462735890904
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.68544435067308
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0880036000272
variable        y0 equal ${yi}
variable        y0 equal 8.41472051061687

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.0981746677419
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.3256763450056
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1669   -2.9871562   -2.4929299   -2.4673965 
    1670   -2.9871562   -2.4929299   -2.4843053 
Loop time of 3.49829e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.0880036000272
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.41472051061687
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.58849234461565
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.24321492828425
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1670   -2.9871562   -2.4929299   -2.4843053 
    1671   -2.9871562   -2.4929299   -2.4617056 
Loop time of 3.52162e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.28138184308568
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.114672362804413
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1671   -2.9871562   -2.4929299   -2.4617056 
    1672   -2.9871562   -2.4929299   -2.4700945 
Loop time of 3.60199e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.57222292898772
variable        y0 equal ${yi}
variable        y0 equal 5.48064044659334

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.5445865321028
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.54097448532778
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1672   -2.9871562   -2.4929299   -2.4700945 
    1673   -2.9871562   -2.4929299   -2.4965542 
Loop time of 3.46736e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.49655424872074
variable naccept equal ${increment}
variable naccept equal 355

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.40737680593396
variable        y0 equal ${yi}
variable        y0 equal 3.73942260308396

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.48845975795651
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.79264831109177
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1673   -2.9871562   -2.4965542   -2.4965542 
    1674   -2.9871562   -2.4965542   -2.4624825 
Loop time of 3.56109e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.40737680593396
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.73942260308396
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.93490587750122
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.24860521472987
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1674   -2.9871562   -2.4965542   -2.4624825 
    1675   -2.9871562   -2.4965542   -2.4649953 
Loop time of 3.47456e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.43833291927244
variable        y0 equal ${yi}
variable        y0 equal 7.40899122085832

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.4786498228636
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.4614208015468
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1675   -2.9871562   -2.4965542   -2.4649953 
    1676   -2.9871562   -2.4965542   -2.4549697 
Loop time of 3.51914e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.43833291927244
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.40899122085832
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.43071805953103
variable        y0 equal ${yi}
variable        y0 equal 7.32951377954745

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.52785648821908
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.30990929928088
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1676   -2.9871562   -2.4965542   -2.4549697 
    1677   -2.9871562   -2.4965542    -2.478262 
Loop time of 3.48606e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.43071805953103
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.32951377954745
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2359365467092
variable        y0 equal ${yi}
variable        y0 equal 4.64773264283107

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.1978039626142
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.57808778637813
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1677   -2.9871562   -2.4965542    -2.478262 
    1678   -2.9871562   -2.4965542   -2.4799561 
Loop time of 3.49678e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.2359365467092
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.64773264283107
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3102847699186
variable        y0 equal ${yi}
variable        y0 equal 2.86695545884469

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.3119584802648
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.82274574014047
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1678   -2.9871562   -2.4965542   -2.4799561 
    1679   -2.9871562   -2.4965542   -2.5025094 
Loop time of 3.54763e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.50250938716008
variable naccept equal ${increment}
variable naccept equal 356

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.42239316224176
variable        y0 equal ${yi}
variable        y0 equal 5.58969682400423

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.41449785946924
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.54428255503374
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1679   -2.9871562   -2.5025094   -2.5025094 
    1680   -2.9871562   -2.5025094   -2.5036933 
Loop time of 3.54046e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.50369325315213
variable naccept equal ${increment}
variable naccept equal 357

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.81859772721415
variable        y0 equal ${yi}
variable        y0 equal 6.51868253485194

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.72002211133128
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.53052052990428
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1680   -2.9871562   -2.5036933   -2.5036933 
    1681   -2.9871562   -2.5036933    -2.497061 
Loop time of 3.4861e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.81859772721415
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.51868253485194
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03061267732479
variable        y0 equal ${yi}
variable        y0 equal 8.28878506340082

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.09545504449703
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.32751440919931
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1681   -2.9871562   -2.5036933    -2.497061 
    1682   -2.9871562   -2.5036933   -2.4831311 
Loop time of 3.59911e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03061267732479
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.28878506340082
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20891928433934
variable        y0 equal ${yi}
variable        y0 equal 5.56093283837038

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.1275073862032
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.50266772453981
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1682   -2.9871562   -2.5036933   -2.4831311 
    1683   -2.9871562   -2.5036933    -2.477832 
Loop time of 3.57439e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20891928433934
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56093283837038
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.112628924846649
variable        y0 equal ${yi}
variable        y0 equal 1.75601954839296

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.0292789459228514
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.80685344121523
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1683   -2.9871562   -2.5036933    -2.477832 
    1684   -2.9871562   -2.5036933   -2.4639682 
Loop time of 3.50746e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 6 x ${x0}
set atom 6 x 0.112628924846649
  1 settings made for x
set atom $i y ${y0}
set atom 6 y ${y0}
set atom 6 y 1.75601954839296
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.41449785946924
variable        y0 equal ${yi}
variable        y0 equal 5.54428255503374

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.33472361086923
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.62742012684542
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1684   -2.9871562   -2.5036933   -2.4639682 
    1685   -2.9871562   -2.5036933    -2.454718 
Loop time of 3.49449e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.41449785946924
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.54428255503374
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.594005592265989
variable        y0 equal ${yi}
variable        y0 equal 2.84451084109644

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.686274023452665
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.7525081393371
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1685   -2.9871562   -2.5036933    -2.454718 
    1686   -2.9871562   -2.5036933   -2.4635605 
Loop time of 3.5267e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.594005592265989
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.84451084109644
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.09749433714897
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.51907868303354
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1686   -2.9871562   -2.5036933   -2.4635605 
    1687   -2.9871562   -2.5036933   -2.4854279 
Loop time of 3.50353e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.03154995162041
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.4676475397497
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 6.99216622391388
variable        y0 equal ${yi}
variable        y0 equal 6.45942620769968

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.04428096094772
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.3851640297555
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1687   -2.9871562   -2.5036933   -2.4854279 
    1688   -2.9871562   -2.5036933   -2.4505498 
Loop time of 3.52878e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 6.99216622391388
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.45942620769968
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.37309358198854
variable        y0 equal ${yi}
variable        y0 equal 7.47418843832278

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.34094121535036
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.51014274683261
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1688   -2.9871562   -2.5036933   -2.4505498 
    1689   -2.9871562   -2.5036933   -2.4972196 
Loop time of 3.58208e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.37309358198854
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.47418843832278
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.63480706095477
variable        y0 equal ${yi}
variable        y0 equal 2.83259171220163

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.62633978009005
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.82587088319162
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1689   -2.9871562   -2.5036933   -2.4972196 
    1690   -2.9871562   -2.5036933   -2.5026406 
Loop time of 3.49916e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.50264063042503
variable naccept equal ${increment}
variable naccept equal 358

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.449145431915189
variable        y0 equal ${yi}
variable        y0 equal 8.34512849964198

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.548886127868558
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.27903829731044
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1690   -2.9871562   -2.5026406   -2.5026406 
    1691   -2.9871562   -2.5026406   -2.4727447 
Loop time of 3.67465e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.449145431915189
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.34512849964198
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.20629341322929
variable        y0 equal ${yi}
variable        y0 equal 2.76325721713403

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.26263253409416
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.69270189973214
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1691   -2.9871562   -2.5026406   -2.4727447 
    1692   -2.9871562   -2.5026406   -2.4931963 
Loop time of 3.52868e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.20629341322929
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.76325721713403
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.26462735890904
variable        y0 equal ${yi}
variable        y0 equal 3.68544435067308

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.29448477983037
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.67024091048372
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1692   -2.9871562   -2.5026406   -2.4931963 
    1693   -2.9871562   -2.5026406   -2.4981758 
Loop time of 3.44255e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.26462735890904
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.68544435067308
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.11205590406761
variable        y0 equal ${yi}
variable        y0 equal 5.54899147694307

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.13915432134971
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.57011886780458
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1693   -2.9871562   -2.5026406   -2.4981758 
    1694   -2.9871562   -2.5026406   -2.5035466 
Loop time of 3.53035e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.50354662175157
variable naccept equal ${increment}
variable naccept equal 359

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.61910304863225
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.75476046366822
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1694   -2.9871562   -2.5035466   -2.5035466 
    1695   -2.9871562   -2.5035466   -2.4887741 
Loop time of 3.4285e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7380775292569
variable        y0 equal ${yi}
variable        y0 equal 7.41298324194217

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.7830727418118
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.35438224401737
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1695   -2.9871562   -2.5035466   -2.4887741 
    1696   -2.9871562   -2.5035466   -2.4763093 
Loop time of 3.55863e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7380775292569
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41298324194217
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.163542932261
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.5604364587449
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1696   -2.9871562   -2.5035466   -2.4763093 
    1697   -2.9871562   -2.5035466   -2.4076434 
Loop time of 3.44532e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.86954605538836
variable        y0 equal ${yi}
variable        y0 equal 4.6797511851208

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.86243808228961
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.72056377285884
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1697   -2.9871562   -2.5035466   -2.4076434 
    1698   -2.9871562   -2.5035466   -2.4738189 
Loop time of 3.66616e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.86954605538836
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.6797511851208
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.81228961268549
variable        y0 equal ${yi}
variable        y0 equal 8.38006076730785

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.83742323437815
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.44023446954784
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1698   -2.9871562   -2.5035466   -2.4738189 
    1699   -2.9871562   -2.5035466   -2.4944781 
Loop time of 3.58599e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.81228961268549
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.38006076730785
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.43071805953103
variable        y0 equal ${yi}
variable        y0 equal 7.32951377954745

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.47645036696511
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.31240052309298
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1699   -2.9871562   -2.5035466   -2.4944781 
    1700   -2.9871562   -2.5035466   -2.5052032 
Loop time of 3.3973e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.50520318840328
variable naccept equal ${increment}
variable naccept equal 360

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.42793486197206
variable        y0 equal ${yi}
variable        y0 equal 1.83933557651109

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.43611706574174
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.93803538463182
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1700   -2.9871562   -2.5052032   -2.5052032 
    1701   -2.9871562   -2.5052032   -2.5010222 
Loop time of 3.59136e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.42793486197206
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.83933557651109
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0128975868225374
variable        y0 equal ${yi}
variable        y0 equal 3.77990783019196

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x -0.0646457195281706
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.78777840895783
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1701   -2.9871562   -2.5052032   -2.5010222 
    1702   -2.9871562   -2.5052032   -2.4796599 
Loop time of 3.61656e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 0.0128975868225374
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.77990783019196
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.95838304717534
variable        y0 equal ${yi}
variable        y0 equal 2.82275391789772

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 6.04427204091542
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.87912248345711
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1702   -2.9871562   -2.5052032   -2.4796599 
    1703   -2.9871562   -2.5052032   -2.4778222 
Loop time of 3.43785e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.95838304717534
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.82275391789772
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.58196511426393
variable        y0 equal ${yi}
variable        y0 equal 0.0479238748550414

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.61689335265581
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y -0.00714834928512584
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1703   -2.9871562   -2.5052032   -2.4778222 
    1704   -2.9871562   -2.5052032   -2.4716481 
Loop time of 3.56033e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.58196511426393
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.0479238748550414
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.8900455796653
variable        y0 equal ${yi}
variable        y0 equal 0.887486429918145

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.82800073265373
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.809622975099419
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1704   -2.9871562   -2.5052032   -2.4716481 
    1705   -2.9871562   -2.5052032   -2.4757157 
Loop time of 3.4599e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.8900455796653
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.887486429918145
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.594005592265989
variable        y0 equal ${yi}
variable        y0 equal 2.84451084109644

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.496187026897337
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.79063544246058
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1705   -2.9871562   -2.5052032   -2.4757157 
    1706   -2.9871562   -2.5052032   -2.4722889 
Loop time of 3.48765e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.594005592265989
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.84451084109644
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.40737680593396
variable        y0 equal ${yi}
variable        y0 equal 3.73942260308396

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.38844372430707
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.82687561078202
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1706   -2.9871562   -2.5052032   -2.4722889 
    1707   -2.9871562   -2.5052032   -2.5091008 
Loop time of 3.5123e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.50910079429771
variable naccept equal ${increment}
variable naccept equal 361

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.92686012068435
variable        y0 equal ${yi}
variable        y0 equal 4.65877217406199

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.94640118160888
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.57404141777918
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1707   -2.9871562   -2.5091008   -2.5091008 
    1708   -2.9871562   -2.5091008   -2.4861597 
Loop time of 6.09763e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.92686012068435
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.65877217406199
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6723551591091
variable        y0 equal ${yi}
variable        y0 equal 9.27579969871372

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.7322315653019
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.17771583307117
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1708   -2.9871562   -2.5091008   -2.4861597 
    1709   -2.9871562   -2.5091008   -2.4803825 
Loop time of 3.58632e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6723551591091
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.27579969871372
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.5961974489667
variable        y0 equal ${yi}
variable        y0 equal 6.55421015755167

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.64691278815051
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.49844058290949
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1709   -2.9871562   -2.5091008   -2.4803825 
    1710   -2.9871562   -2.5091008   -2.5025212 
Loop time of 3.63535e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.5961974489667
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.55421015755167
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.72050107875292
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.75067352814806
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1710   -2.9871562   -2.5091008   -2.5025212 
    1711   -2.9871562   -2.5091008   -2.4741442 
Loop time of 3.58658e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.91699399589834
variable        y0 equal ${yi}
variable        y0 equal 2.91251749965051

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.93335930942831
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.82367047044137
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1711   -2.9871562   -2.5091008   -2.4741442 
    1712   -2.9871562   -2.5091008    -2.520648 
Loop time of 3.48111e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.52064802942036
variable naccept equal ${increment}
variable naccept equal 362

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.88017401654711
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.38569732443325
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1712   -2.9871562    -2.520648    -2.520648 
    1713   -2.9871562    -2.520648   -2.5146796 
Loop time of 3.47468e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.01612061539336
variable        y0 equal ${yi}
variable        y0 equal 2.79489908191064

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.95006734409972
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.88501722785333
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1713   -2.9871562    -2.520648   -2.5146796 
    1714   -2.9871562    -2.520648   -2.5087249 
Loop time of 3.47967e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 7.01612061539336
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.79489908191064
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.52162269193899
variable        y0 equal ${yi}
variable        y0 equal 1.84969287297791

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.51683604557287
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.75404261729783
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1714   -2.9871562    -2.520648   -2.5087249 
    1715   -2.9871562    -2.520648   -2.4922866 
Loop time of 3.4757e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.52162269193899
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.84969287297791
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.9393853183507
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.38535024658672
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1715   -2.9871562    -2.520648   -2.4922866 
    1716   -2.9871562    -2.520648   -2.5056025 
Loop time of 3.92768e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.2359365467092
variable        y0 equal ${yi}
variable        y0 equal 4.64773264283107

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.1955849651357
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.64925400370525
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1716   -2.9871562    -2.520648   -2.5056025 
    1717   -2.9871562    -2.520648   -2.5252357 
Loop time of 3.48029e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.5252357273383
variable naccept equal ${increment}
variable naccept equal 363

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.03727689066574
variable        y0 equal ${yi}
variable        y0 equal 0.91603718589577

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.09419071951553
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.87392201017174
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1717   -2.9871562   -2.5252357   -2.5252357 
    1718   -2.9871562   -2.5252357   -2.5152684 
Loop time of 3.50005e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.03727689066574
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.91603718589577
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 6.99216622391388
variable        y0 equal ${yi}
variable        y0 equal 6.45942620769968

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.08438959398911
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.46819922462931
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1718   -2.9871562   -2.5252357   -2.5152684 
    1719   -2.9871562   -2.5252357   -2.4988393 
Loop time of 3.45413e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 6.99216622391388
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.45942620769968
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.48956688482534
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.68926217122209
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1719   -2.9871562   -2.5252357   -2.4988393 
    1720   -2.9871562   -2.5252357   -2.5150608 
Loop time of 3.51631e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 6.00572709996692
variable        y0 equal ${yi}
variable        y0 equal 8.24073799766597

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 5.95845205743305
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.26673827089366
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1720   -2.9871562   -2.5252357   -2.5150608 
    1721   -2.9871562   -2.5252357   -2.5336625 
Loop time of 3.54235e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.53366251624764
variable naccept equal ${increment}
variable naccept equal 364

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.13960191606379
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.81274038525919
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1721   -2.9871562   -2.5336625   -2.5336625 
    1722   -2.9871562   -2.5336625   -2.5199283 
Loop time of 3.51627e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.3840241916916
variable        y0 equal ${yi}
variable        y0 equal 9.27708193767397

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.28814752180787
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.1915381621155
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1722   -2.9871562   -2.5336625   -2.5199283 
    1723   -2.9871562   -2.5336625    -2.494914 
Loop time of 3.4469e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.3840241916916
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.27708193767397
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.0353988706956
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.57467481628885
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1723   -2.9871562   -2.5336625    -2.494914 
    1724   -2.9871562   -2.5336625    -2.529532 
Loop time of 3.50194e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.43551569699365
variable        y0 equal ${yi}
variable        y0 equal 1.89214071414535

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.45440085648614
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.83466087958877
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1724   -2.9871562   -2.5336625    -2.529532 
    1725   -2.9871562   -2.5336625   -2.5350055 
Loop time of 3.5939e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.53500553959531
variable naccept equal ${increment}
variable naccept equal 365

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.43833291927244
variable        y0 equal ${yi}
variable        y0 equal 7.40899122085832

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.42746895948316
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.4308916958835
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1725   -2.9871562   -2.5350055   -2.5350055 
    1726   -2.9871562   -2.5350055   -2.5296084 
Loop time of 3.54201e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.43833291927244
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.40899122085832
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.00113770364619
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.58045211569299
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1726   -2.9871562   -2.5350055   -2.5296084 
    1727   -2.9871562   -2.5350055   -2.5221895 
Loop time of 3.60222e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0128975868225374
variable        y0 equal ${yi}
variable        y0 equal 3.77990783019196

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x -0.0145100712775908
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.84760378165375
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1727   -2.9871562   -2.5350055   -2.5221895 
    1728   -2.9871562   -2.5350055   -2.5085489 
Loop time of 3.55249e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 0.0128975868225374
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.77990783019196
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.04304151255638
variable        y0 equal ${yi}
variable        y0 equal 6.44874846474161

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.03554602582008
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.4771493865632
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1728   -2.9871562   -2.5350055   -2.5085489 
    1729   -2.9871562   -2.5350055   -2.5328326 
Loop time of 3.58016e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.04304151255638
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.44874846474161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.53745518485632
variable        y0 equal ${yi}
variable        y0 equal 4.67062938565179

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.623014207282925
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.68607427233621
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1729   -2.9871562   -2.5350055   -2.5328326 
    1730   -2.9871562   -2.5350055   -2.5070966 
Loop time of 3.46212e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.53745518485632
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.67062938565179
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 8.99216509778054
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.50616855539377
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1730   -2.9871562   -2.5350055   -2.5070966 
    1731   -2.9871562   -2.5350055   -2.5043093 
Loop time of 3.5047e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.03154995162041
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.4676475397497
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.6573487090933
variable        y0 equal ${yi}
variable        y0 equal 7.44725758161806

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.69786289213773
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.43296710577272
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1731   -2.9871562   -2.5350055   -2.5043093 
    1732   -2.9871562   -2.5350055   -2.5238844 
Loop time of 3.48985e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 99 x ${x0}
set atom 99 x 9.6573487090933
  1 settings made for x
set atom $i y ${y0}
set atom 99 y ${y0}
set atom 99 y 7.44725758161806
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.55426178136293
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.58511054461198
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1732   -2.9871562   -2.5350055   -2.5238844 
    1733   -2.9871562   -2.5350055   -2.5333953 
Loop time of 3.55951e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.594005592265989
variable        y0 equal ${yi}
variable        y0 equal 2.84451084109644

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.539912517467405
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.89228781434397
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1733   -2.9871562   -2.5350055   -2.5333953 
    1734   -2.9871562   -2.5350055   -2.5212536 
Loop time of 3.54764e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.594005592265989
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.84451084109644
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.449145431915189
variable        y0 equal ${yi}
variable        y0 equal 8.34512849964198

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.355550296703244
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.40425751127299
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1734   -2.9871562   -2.5350055   -2.5212536 
    1735   -2.9871562   -2.5350055   -2.5116742 
Loop time of 3.66902e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.449145431915189
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.34512849964198
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7380775292569
variable        y0 equal ${yi}
variable        y0 equal 7.41298324194217

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.7044513543301
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.41026051368976
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1735   -2.9871562   -2.5350055   -2.5116742 
    1736   -2.9871562   -2.5350055   -2.5371967 
Loop time of 3.56539e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.53719665786099
variable naccept equal ${increment}
variable naccept equal 366

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.23598166783067
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.78784682316911
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1736   -2.9871562   -2.5371967   -2.5371967 
    1737   -2.9871562   -2.5371967   -2.5046071 
Loop time of 3.51277e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47645036696511
variable        y0 equal ${yi}
variable        y0 equal 7.31240052309298

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.52850690602379
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.31748434629702
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1737   -2.9871562   -2.5371967   -2.5046071 
    1738   -2.9871562   -2.5371967   -2.5176151 
Loop time of 3.4242e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.47645036696511
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.31240052309298
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.3840241916916
variable        y0 equal ${yi}
variable        y0 equal 9.27708193767397

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.33022639830323
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.22609883058397
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1738   -2.9871562   -2.5371967   -2.5176151 
    1739   -2.9871562   -2.5371967   -2.5277397 
Loop time of 3.54996e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.3840241916916
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.27708193767397
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.52162269193899
variable        y0 equal ${yi}
variable        y0 equal 1.84969287297791

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.55375546056997
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.82437674186295
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1739   -2.9871562   -2.5371967   -2.5277397 
    1740   -2.9871562   -2.5371967   -2.5230402 
Loop time of 3.51034e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.52162269193899
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.84969287297791
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.58196511426393
variable        y0 equal ${yi}
variable        y0 equal 0.0479238748550414

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.61205681720201
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.0507784008979796
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1740   -2.9871562   -2.5371967   -2.5230402 
    1741   -2.9871562   -2.5371967   -2.5309982 
Loop time of 3.41687e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.58196511426393
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.0479238748550414
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.62012494960253
variable        y0 equal ${yi}
variable        y0 equal 7.40796141948962

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.61455693402712
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.4608101996448
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1741   -2.9871562   -2.5371967   -2.5309982 
    1742   -2.9871562   -2.5371967   -2.5379295 
Loop time of 3.40876e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.53792950773144
variable naccept equal ${increment}
variable naccept equal 367

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.2327599501566
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.0140663385391236
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1742   -2.9871562   -2.5379295   -2.5379295 
    1743   -2.9871562   -2.5379295   -2.5333729 
Loop time of 3.6185e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.28554112672368
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0260292768478394
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.2537579540272
variable        y0 equal ${yi}
variable        y0 equal 0.909067996251911

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.1841107610722
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.907786758649677
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1743   -2.9871562   -2.5379295   -2.5333729 
    1744   -2.9871562   -2.5379295   -2.5348727 
Loop time of 3.45466e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.2537579540272
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.909067996251911
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.25279456138173
variable        y0 equal ${yi}
variable        y0 equal 7.38214940157198

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.19915828465978
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.35852843847536
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1744   -2.9871562   -2.5379295   -2.5348727 
    1745   -2.9871562   -2.5379295   -2.5274589 
Loop time of 3.43264e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.25279456138173
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.38214940157198
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 1.10092277844601
variable        y0 equal ${yi}
variable        y0 equal 9.22189815748065

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 1.13034690936261
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.30300995815127
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1745   -2.9871562   -2.5379295   -2.5274589 
    1746   -2.9871562   -2.5379295   -2.5169299 
Loop time of 3.52815e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 1.10092277844601
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.22189815748065
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.95838304717534
variable        y0 equal ${yi}
variable        y0 equal 2.82275391789772

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.95892525870793
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.73191907378532
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1746   -2.9871562   -2.5379295   -2.5169299 
    1747   -2.9871562   -2.5379295   -2.5335481 
Loop time of 3.50536e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.95838304717534
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.82275391789772
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57543257355471
variable        y0 equal ${yi}
variable        y0 equal 4.67648406380578

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.56119179606219
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.67536011094018
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1747   -2.9871562   -2.5379295   -2.5335481 
    1748   -2.9871562   -2.5379295   -2.5351623 
Loop time of 3.36459e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.57543257355471
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.67648406380578
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.25279456138173
variable        y0 equal ${yi}
variable        y0 equal 7.38214940157198

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.16796849727193
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.4324191602733
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1748   -2.9871562   -2.5379295   -2.5351623 
    1749   -2.9871562   -2.5379295   -2.5222158 
Loop time of 3.47848e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.25279456138173
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.38214940157198
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.20629341322929
variable        y0 equal ${yi}
variable        y0 equal 2.76325721713403

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.13100845534355
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.84614725085595
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1749   -2.9871562   -2.5379295   -2.5222158 
    1750   -2.9871562   -2.5379295   -2.5163872 
Loop time of 3.59987e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.20629341322929
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.76325721713403
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.28554112672368
variable        y0 equal ${yi}
variable        y0 equal 0.0260292768478394

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.26296605824986
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.0278776645660401
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1750   -2.9871562   -2.5379295   -2.5163872 
    1751   -2.9871562   -2.5379295   -2.5375918 
Loop time of 3.45884e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.53759181911076
variable naccept equal ${increment}
variable naccept equal 368

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6504576523953
variable        y0 equal ${yi}
variable        y0 equal 5.66441398804384

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.7037909229451
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.69787647669512
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1751   -2.9871562   -2.5375918   -2.5375918 
    1752   -2.9871562   -2.5375918    -2.526228 
Loop time of 3.42853e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.6504576523953
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.66441398804384
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.02992838938885
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.80619720599717
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1752   -2.9871562   -2.5375918    -2.526228 
    1753   -2.9871562   -2.5375918   -2.4933298 
Loop time of 3.42205e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.81228961268549
variable        y0 equal ${yi}
variable        y0 equal 8.38006076730785

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.73956752339487
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.28104330219326
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1753   -2.9871562   -2.5375918   -2.4933298 
    1754   -2.9871562   -2.5375918   -2.5159986 
Loop time of 3.9836e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.81228961268549
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.38006076730785
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.1096025260275
variable        y0 equal ${yi}
variable        y0 equal 3.7893677787317

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.0800673158949
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.73807540698182
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1754   -2.9871562   -2.5375918   -2.5159986 
    1755   -2.9871562   -2.5375918   -2.5441869 
Loop time of 3.52437e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.54418690610811
variable naccept equal ${increment}
variable naccept equal 369

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.5961974489667
variable        y0 equal ${yi}
variable        y0 equal 6.55421015755167

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.65516315579196
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.59632435575953
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1755   -2.9871562   -2.5441869   -2.5441869 
    1756   -2.9871562   -2.5441869   -2.5268803 
Loop time of 3.5863e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.5961974489667
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.55421015755167
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.95838304717534
variable        y0 equal ${yi}
variable        y0 equal 2.82275391789772

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.92365086038106
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.91276236745216
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1756   -2.9871562   -2.5441869   -2.5268803 
    1757   -2.9871562   -2.5441869   -2.5279753 
Loop time of 3.50484e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.95838304717534
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.82275391789772
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.594005592265989
variable        y0 equal ${yi}
variable        y0 equal 2.84451084109644

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.579389603534605
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.85864369841913
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1757   -2.9871562   -2.5441869   -2.5279753 
    1758   -2.9871562   -2.5441869   -2.5422301 
Loop time of 3.50381e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.594005592265989
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.84451084109644
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.01394880412914
variable        y0 equal ${yi}
variable        y0 equal 4.70269989127085

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 7.92472044824459
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.6253284966366
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1758   -2.9871562   -2.5441869   -2.5422301 
    1759   -2.9871562   -2.5441869   -2.5207086 
Loop time of 3.59365e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.01394880412914
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.70269989127085
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.26296605824986
variable        y0 equal ${yi}
variable        y0 equal 0.0278776645660401

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.28712333201924
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.0503280758857726
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1759   -2.9871562   -2.5441869   -2.5207086 
    1760   -2.9871562   -2.5441869   -2.5346709 
Loop time of 3.4091e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.26296605824986
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.0278776645660401
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.5634195105118
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.6086884016295
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1760   -2.9871562   -2.5441869   -2.5346709 
    1761   -2.9871562   -2.5441869   -2.5333411 
Loop time of 3.59124e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.16038156191215
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.43982385721469
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1761   -2.9871562   -2.5441869   -2.5333411 
    1762   -2.9871562   -2.5441869   -2.5431973 
Loop time of 3.46163e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.57918032883284
variable        y0 equal ${yi}
variable        y0 equal 0.0850776791572572

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.5497148442137
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.15411182641983
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1762   -2.9871562   -2.5441869   -2.5431973 
    1763   -2.9871562   -2.5441869   -2.5307365 
Loop time of 3.60049e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 79 x ${x0}
set atom 79 x 9.57918032883284
  1 settings made for x
set atom $i y ${y0}
set atom 79 y ${y0}
set atom 79 y 0.0850776791572572
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.86155322073576
variable        y0 equal ${yi}
variable        y0 equal 1.87893718860216

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.8352217841017
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.80433634898729
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1763   -2.9871562   -2.5441869   -2.5307365 
    1764   -2.9871562   -2.5441869   -2.5324266 
Loop time of 3.54846e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.86155322073576
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.87893718860216
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.57918032883284
variable        y0 equal ${yi}
variable        y0 equal 0.0850776791572572

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.66764053581831
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.168480408191681
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1764   -2.9871562   -2.5441869   -2.5324266 
    1765   -2.9871562   -2.5441869   -2.5170873 
Loop time of 3.56249e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 79 x ${x0}
set atom 79 x 9.57918032883284
  1 settings made for x
set atom $i y ${y0}
set atom 79 y ${y0}
set atom 79 y 0.0850776791572572
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.52172473191339
variable        y0 equal ${yi}
variable        y0 equal 9.28439741838305

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.50278776406366
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.31913047540514
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1765   -2.9871562   -2.5441869   -2.5170873 
    1766   -2.9871562   -2.5441869    -2.540056 
Loop time of 3.55405e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.52172473191339
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.28439741838305
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6504576523953
variable        y0 equal ${yi}
variable        y0 equal 5.66441398804384

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.6848535259419
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.65403784458834
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1766   -2.9871562   -2.5441869    -2.540056 
    1767   -2.9871562   -2.5441869   -2.5449499 
Loop time of 3.50301e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.54494993248879
variable naccept equal ${increment}
variable naccept equal 370

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.50628010192338
variable        y0 equal ${yi}
variable        y0 equal 1.936454562164

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.53458213963929
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.99115990779465
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1767   -2.9871562   -2.5449499   -2.5449499 
    1768   -2.9871562   -2.5449499   -2.5452285 
Loop time of 3.5068e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.54522850877388
variable naccept equal ${increment}
variable naccept equal 371

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.67850255846758
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.25108941711482
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1768   -2.9871562   -2.5452285   -2.5452285 
    1769   -2.9871562   -2.5452285   -2.5262895 
Loop time of 3.47031e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.45440085648614
variable        y0 equal ${yi}
variable        y0 equal 1.83466087958877

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.53039344071466
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.76207554719512
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1769   -2.9871562   -2.5452285   -2.5262895 
    1770   -2.9871562   -2.5452285   -2.5213012 
Loop time of 6.21234e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.45440085648614
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.83466087958877
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.60326097209883
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.44940249458781
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1770   -2.9871562   -2.5452285   -2.5213012 
    1771   -2.9871562   -2.5452285   -2.5302479 
Loop time of 3.54964e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.08605186342097
variable        y0 equal ${yi}
variable        y0 equal 0.950601537931293

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.11660491823054
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.885099514234394
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1771   -2.9871562   -2.5452285   -2.5302479 
    1772   -2.9871562   -2.5452285   -2.5244681 
Loop time of 3.68545e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.08605186342097
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.950601537931293
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57543257355471
variable        y0 equal ${yi}
variable        y0 equal 4.67648406380578

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.49982416510363
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.70867832058831
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1772   -2.9871562   -2.5452285   -2.5244681 
    1773   -2.9871562   -2.5452285   -2.5265271 
Loop time of 3.52399e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.57543257355471
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.67648406380578
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.95845205743305
variable        y0 equal ${yi}
variable        y0 equal 8.26673827089366

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.01924133260242
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.3652742258459
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1773   -2.9871562   -2.5452285   -2.5265271 
    1774   -2.9871562   -2.5452285   -2.5384721 
Loop time of 3.53661e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 5.95845205743305
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.26673827089366
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.36751908142778
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.61824872439105
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1774   -2.9871562   -2.5452285   -2.5384721 
    1775   -2.9871562   -2.5452285   -2.5139247 
Loop time of 3.6412e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.23032474596711
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.59244195168216
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1775   -2.9871562   -2.5452285   -2.5139247 
    1776   -2.9871562   -2.5452285   -2.5440386 
Loop time of 3.50174e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.24577650467264
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 0.0595231056213411
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1776   -2.9871562   -2.5452285   -2.5440386 
    1777   -2.9871562   -2.5452285   -2.5408327 
Loop time of 3.61204e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.03727689066574
variable        y0 equal ${yi}
variable        y0 equal 0.91603718589577

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.02466696777984
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.941939647901385
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1777   -2.9871562   -2.5452285   -2.5408327 
    1778   -2.9871562   -2.5452285   -2.5427415 
Loop time of 3.605e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.03727689066574
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.91603718589577
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.48380352098715
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.28595095005298
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1778   -2.9871562   -2.5452285   -2.5427415 
    1779   -2.9871562   -2.5452285   -2.5016143 
Loop time of 3.56835e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.48385869104635
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.38020931806827
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78581515748931
variable        y0 equal ${yi}
variable        y0 equal 1.04153251241478

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.72495936353637
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.06987096856865
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1779   -2.9871562   -2.5452285   -2.5016143 
    1780   -2.9871562   -2.5452285   -2.5401832 
Loop time of 3.70232e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.78581515748931
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.04153251241478
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.81228961268549
variable        y0 equal ${yi}
variable        y0 equal 8.38006076730785

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.90980408707743
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.34070913709697
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1780   -2.9871562   -2.5452285   -2.5401832 
    1781   -2.9871562   -2.5452285    -2.527435 
Loop time of 3.53538e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.81228961268549
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.38006076730785
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.26296605824986
variable        y0 equal ${yi}
variable        y0 equal 0.0278776645660401

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.25888566731968
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.0328114271163941
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1781   -2.9871562   -2.5452285    -2.527435 
    1782   -2.9871562   -2.5452285   -2.5448454 
Loop time of 3.7902e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.54484537024388
variable naccept equal ${increment}
variable naccept equal 372

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.93335930942831
variable        y0 equal ${yi}
variable        y0 equal 2.82367047044137

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.87498824238119
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.77401319714883
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1782   -2.9871562   -2.5448454   -2.5448454 
    1783   -2.9871562   -2.5448454   -2.5382075 
Loop time of 3.56494e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.93335930942831
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.82367047044137
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.08258329032756
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.45428351894845
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1783   -2.9871562   -2.5448454   -2.5382075 
    1784   -2.9871562   -2.5448454   -2.5249859 
Loop time of 3.58887e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.1955849651357
variable        y0 equal ${yi}
variable        y0 equal 4.64925400370525

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.252942192938
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.72382209652828
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1784   -2.9871562   -2.5448454   -2.5249859 
    1785   -2.9871562   -2.5448454   -2.5390075 
Loop time of 3.63874e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.1955849651357
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.64925400370525
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.45440085648614
variable        y0 equal ${yi}
variable        y0 equal 1.83466087958877

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.49662729024011
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.85665681741302
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1785   -2.9871562   -2.5448454   -2.5390075 
    1786   -2.9871562   -2.5448454   -2.5460889 
Loop time of 3.5647e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.5460889289725
variable naccept equal ${increment}
variable naccept equal 373

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.09111318906002
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.83324671170777
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1786   -2.9871562   -2.5460889   -2.5460889 
    1787   -2.9871562   -2.5460889   -2.5404359 
Loop time of 3.66132e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.65424995302935
variable        y0 equal ${yi}
variable        y0 equal 0.940276082265705

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.57824828505297
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.997331877458424
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1787   -2.9871562   -2.5460889   -2.5404359 
    1788   -2.9871562   -2.5460889   -2.5189482 
Loop time of 3.57538e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.65424995302935
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.940276082265705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.74466399152708
variable        y0 equal ${yi}
variable        y0 equal 2.74569092961648

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.72697503765058
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.78031077357629
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1788   -2.9871562   -2.5460889   -2.5189482 
    1789   -2.9871562   -2.5460889   -2.5491282 
Loop time of 3.5363e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.54912818017732
variable naccept equal ${increment}
variable naccept equal 374

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.52162269193899
variable        y0 equal ${yi}
variable        y0 equal 1.84969287297791

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.50493277151357
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.76863004348343
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1789   -2.9871562   -2.5491282   -2.5491282 
    1790   -2.9871562   -2.5491282   -2.5258004 
Loop time of 3.58483e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.52162269193899
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.84969287297791
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 6.99216622391388
variable        y0 equal ${yi}
variable        y0 equal 6.45942620769968

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.04342638531372
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.43675356642237
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1790   -2.9871562   -2.5491282   -2.5258004 
    1791   -2.9871562   -2.5491282   -2.5359483 
Loop time of 3.60597e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 6.99216622391388
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.45942620769968
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.5961974489667
variable        y0 equal ${yi}
variable        y0 equal 6.55421015755167

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.59274229883929
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.53889024988642
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1791   -2.9871562   -2.5491282   -2.5359483 
    1792   -2.9871562   -2.5491282   -2.5496823 
Loop time of 3.54418e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.5496823214291
variable naccept equal ${increment}
variable naccept equal 375

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.65424995302935
variable        y0 equal ${yi}
variable        y0 equal 0.940276082265705

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.59290629505892
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 1.03642875741753
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1792   -2.9871562   -2.5496823   -2.5496823 
    1793   -2.9871562   -2.5496823   -2.5184743 
Loop time of 3.57803e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.65424995302935
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.940276082265705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.90432184894076
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.43020383850566
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1793   -2.9871562   -2.5496823   -2.5184743 
    1794   -2.9871562   -2.5496823   -2.5490825 
Loop time of 3.85769e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57543257355471
variable        y0 equal ${yi}
variable        y0 equal 4.67648406380578

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.62919407963534
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.69314476603433
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1794   -2.9871562   -2.5496823   -2.5490825 
    1795   -2.9871562   -2.5496823   -2.5483718 
Loop time of 3.59974e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.57543257355471
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.67648406380578
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6723551591091
variable        y0 equal ${yi}
variable        y0 equal 9.27579969871372

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.6490416963749
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.32753394353718
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1795   -2.9871562   -2.5496823   -2.5483718 
    1796   -2.9871562   -2.5496823   -2.5368862 
Loop time of 3.55536e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6723551591091
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.27579969871372
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.81859772721415
variable        y0 equal ${yi}
variable        y0 equal 6.51868253485194

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.74206342021113
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.43850475088588
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1796   -2.9871562   -2.5496823   -2.5368862 
    1797   -2.9871562   -2.5496823    -2.544819 
Loop time of 3.64852e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.81859772721415
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.51868253485194
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.93335930942831
variable        y0 equal ${yi}
variable        y0 equal 2.82367047044137

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.93808599352178
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.84255808564523
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1797   -2.9871562   -2.5496823    -2.544819 
    1798   -2.9871562   -2.5496823   -2.5483924 
Loop time of 3.57942e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.93335930942831
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.82367047044137
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.594005592265989
variable        y0 equal ${yi}
variable        y0 equal 2.84451084109644

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.534600217739011
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.87810680838923
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1798   -2.9871562   -2.5496823   -2.5483924 
    1799   -2.9871562   -2.5496823   -2.5360113 
Loop time of 3.64679e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.594005592265989
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.84451084109644
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.38702585458317
variable        y0 equal ${yi}
variable        y0 equal 1.89600253484314

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.41569397210636
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.90903677127426
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1799   -2.9871562   -2.5496823   -2.5360113 
    1800   -2.9871562   -2.5496823   -2.5408473 
Loop time of 3.73009e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.38702585458317
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.89600253484314
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0128975868225374
variable        y0 equal ${yi}
variable        y0 equal 3.77990783019196

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 0.0618719935417452
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.73080971999299
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1800   -2.9871562   -2.5496823   -2.5408473 
    1801   -2.9871562   -2.5496823   -2.5458545 
Loop time of 3.55535e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 0.0128975868225374
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.77990783019196
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0998515967389
variable        y0 equal ${yi}
variable        y0 equal 6.55315701500406

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.0719734314938
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.64505201117029
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1801   -2.9871562   -2.5496823   -2.5458545 
    1802   -2.9871562   -2.5496823   -2.4765567 
Loop time of 3.61599e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.0998515967389
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.55315701500406
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20891928433934
variable        y0 equal ${yi}
variable        y0 equal 5.56093283837038

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.20813699721852
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.56420804207521
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1802   -2.9871562   -2.5496823   -2.4765567 
    1803   -2.9871562   -2.5496823   -2.5497843 
Loop time of 3.55435e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.54978426026955
variable naccept equal ${increment}
variable naccept equal 376

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.86258747219382
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.66741485947535
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1803   -2.9871562   -2.5497843   -2.5497843 
    1804   -2.9871562   -2.5497843   -2.5239171 
Loop time of 3.56534e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57543257355471
variable        y0 equal ${yi}
variable        y0 equal 4.67648406380578

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.54482389569064
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.70050764435693
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1804   -2.9871562   -2.5497843   -2.5239171 
    1805   -2.9871562   -2.5497843   -2.5467991 
Loop time of 3.61932e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.57543257355471
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.67648406380578
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.60230735420962
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.50133109823695
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1805   -2.9871562   -2.5497843   -2.5467991 
    1806   -2.9871562   -2.5497843   -2.5474986 
Loop time of 3.56461e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.11492097695523
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.55218602743411
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1806   -2.9871562   -2.5497843   -2.5474986 
    1807   -2.9871562   -2.5497843   -2.5200669 
Loop time of 3.54984e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.03154995162041
variable        y0 equal ${yi}
variable        y0 equal 8.4676475397497

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.02246614415199
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.41134195245798
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1807   -2.9871562   -2.5497843   -2.5200669 
    1808   -2.9871562   -2.5497843   -2.5529262 
Loop time of 3.47524e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.55292622958613
variable naccept equal ${increment}
variable naccept equal 377

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.87719584027416
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.71249293440745
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1808   -2.9871562   -2.5529262   -2.5529262 
    1809   -2.9871562   -2.5529262   -2.4999851 
Loop time of 3.43835e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.04304151255638
variable        y0 equal ${yi}
variable        y0 equal 6.44874846474161

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.02944190222771
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.53856098190775
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1809   -2.9871562   -2.5529262   -2.4999851 
    1810   -2.9871562   -2.5529262   -2.5471813 
Loop time of 3.64756e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.04304151255638
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.44874846474161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0998515967389
variable        y0 equal ${yi}
variable        y0 equal 6.55315701500406

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.1583498839398
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.61824439302911
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1810   -2.9871562   -2.5529262   -2.5471813 
    1811   -2.9871562   -2.5529262   -2.5232989 
Loop time of 3.59715e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.0998515967389
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.55315701500406
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.2591690309784
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.65173040194642
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1811   -2.9871562   -2.5529262   -2.5232989 
    1812   -2.9871562   -2.5529262   -2.5233019 
Loop time of 3.60055e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.112628924846649
variable        y0 equal ${yi}
variable        y0 equal 1.75601954839296

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.101794230937958
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.84877194545335
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1812   -2.9871562   -2.5529262   -2.5233019 
    1813   -2.9871562   -2.5529262   -2.5538717 
Loop time of 3.59065e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.5538716574854
variable naccept equal ${increment}
variable naccept equal 378

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.10710482317955
variable        y0 equal ${yi}
variable        y0 equal 4.59937599057123

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.01997161824257
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.66652038449213
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1813   -2.9871562   -2.5538717   -2.5538717 
    1814   -2.9871562   -2.5538717   -2.5447943 
Loop time of 3.50816e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.10710482317955
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.59937599057123
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.70134830116568
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.70194355601236
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1814   -2.9871562   -2.5538717   -2.5447943 
    1815   -2.9871562   -2.5538717   -2.5094795 
Loop time of 3.65765e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.47645036696511
variable        y0 equal ${yi}
variable        y0 equal 7.31240052309298

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.44055470942574
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.31046043958926
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1815   -2.9871562   -2.5538717   -2.5094795 
    1816   -2.9871562   -2.5538717   -2.5546778 
Loop time of 3.63876e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.55467775795898
variable naccept equal ${increment}
variable naccept equal 379

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.01394880412914
variable        y0 equal ${yi}
variable        y0 equal 4.70269989127085

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.00799162982799
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.67230892533228
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1816   -2.9871562   -2.5546778   -2.5546778 
    1817   -2.9871562   -2.5546778   -2.5599244 
Loop time of 3.64298e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.55992442649894
variable naccept equal ${increment}
variable naccept equal 380

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.5445865321028
variable        y0 equal ${yi}
variable        y0 equal 5.54097448532778

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.59619499920485
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.62779643480974
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1817   -2.9871562   -2.5599244   -2.5599244 
    1818   -2.9871562   -2.5599244    -2.555432 
Loop time of 3.60386e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.5445865321028
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.54097448532778
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.95845205743305
variable        y0 equal ${yi}
variable        y0 equal 8.26673827089366

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 5.99770929772846
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.22371219314631
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1818   -2.9871562   -2.5599244    -2.555432 
    1819   -2.9871562   -2.5599244   -2.5460609 
Loop time of 3.51665e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 5.95845205743305
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.26673827089366
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 1.10092277844601
variable        y0 equal ${yi}
variable        y0 equal 9.22189815748065

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 1.00265704711132
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.2645429562363
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1819   -2.9871562   -2.5599244   -2.5460609 
    1820   -2.9871562   -2.5599244   -2.5190345 
Loop time of 3.59071e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 1.10092277844601
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.22189815748065
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.52172473191339
variable        y0 equal ${yi}
variable        y0 equal 9.28439741838305

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.61834455250818
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.20195424068301
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1820   -2.9871562   -2.5599244   -2.5190345 
    1821   -2.9871562   -2.5599244   -2.5210694 
Loop time of 3.57358e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.52172473191339
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.28439741838305
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3119584802648
variable        y0 equal ${yi}
variable        y0 equal 2.82274574014047

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.3012223724386
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.8246198293815
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1821   -2.9871562   -2.5599244   -2.5210694 
    1822   -2.9871562   -2.5599244   -2.5605963 
Loop time of 3.51772e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.56059630889649
variable naccept equal ${increment}
variable naccept equal 381

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 7.0805607823436
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.3602160684019
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1822   -2.9871562   -2.5605963   -2.5605963 
    1823   -2.9871562   -2.5605963   -2.5340718 
Loop time of 3.57444e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.76264746387434
variable        y0 equal ${yi}
variable        y0 equal 8.40153711952266

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.7356065889163
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.49638192571697
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1823   -2.9871562   -2.5605963   -2.5340718 
    1824   -2.9871562   -2.5605963   -2.5343535 
Loop time of 3.58212e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.76264746387434
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.40153711952266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.86954605538836
variable        y0 equal ${yi}
variable        y0 equal 4.6797511851208

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.96114921529284
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.64598255509303
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1824   -2.9871562   -2.5605963   -2.5343535 
    1825   -2.9871562   -2.5605963   -2.5510302 
Loop time of 3.82478e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.86954605538836
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.6797511851208
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6848535259419
variable        y0 equal ${yi}
variable        y0 equal 5.65403784458834

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.7153768380337
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.69499117081362
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1825   -2.9871562   -2.5605963   -2.5510302 
    1826   -2.9871562   -2.5605963   -2.5473259 
Loop time of 3.71676e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.6848535259419
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.65403784458834
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.41855881928521
variable        y0 equal ${yi}
variable        y0 equal 3.78684511942993

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.46636033772546
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.78071368498932
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1826   -2.9871562   -2.5605963   -2.5473259 
    1827   -2.9871562   -2.5605963   -2.5622978 
Loop time of 3.59657e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.56229781340085
variable naccept equal ${increment}
variable naccept equal 382

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.81859772721415
variable        y0 equal ${yi}
variable        y0 equal 6.51868253485194

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.85957013884669
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.47382871643534
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1827   -2.9871562   -2.5622978   -2.5622978 
    1828   -2.9871562   -2.5622978    -2.540156 
Loop time of 3.6235e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.81859772721415
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.51868253485194
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.61020664174986
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.55562060610285
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1828   -2.9871562   -2.5622978    -2.540156 
    1829   -2.9871562   -2.5622978   -2.5337669 
Loop time of 3.5773e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.93626568276873
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.50207442776195
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1829   -2.9871562   -2.5622978   -2.5337669 
    1830   -2.9871562   -2.5622978   -2.5381344 
Loop time of 3.61082e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.58914505083334
variable        y0 equal ${yi}
variable        y0 equal 9.25292026508181

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.53207862217199
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.2839910458359
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1830   -2.9871562   -2.5622978   -2.5381344 
    1831   -2.9871562   -2.5622978   -2.5638586 
Loop time of 3.5847e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.56385858485901
variable naccept equal ${increment}
variable naccept equal 383

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7044513543301
variable        y0 equal ${yi}
variable        y0 equal 7.41026051368976

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.6636687596493
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.32326462593341
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1831   -2.9871562   -2.5638586   -2.5638586 
    1832   -2.9871562   -2.5638586   -2.5276119 
Loop time of 3.60049e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7044513543301
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41026051368976
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.43833291927244
variable        y0 equal ${yi}
variable        y0 equal 7.40899122085832

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.37865453163053
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.39225429621004
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1832   -2.9871562   -2.5638586   -2.5276119 
    1833   -2.9871562   -2.5638586   -2.5695907 
Loop time of 3.66991e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.56959072853682
variable naccept equal ${increment}
variable naccept equal 384

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.69429761329118
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.65729857249391
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1833   -2.9871562   -2.5695907   -2.5695907 
    1834   -2.9871562   -2.5695907   -2.5593871 
Loop time of 3.5428e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82797947445994
variable        y0 equal ${yi}
variable        y0 equal 0.89721691201958

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.88721724072581
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.816356690633624
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1834   -2.9871562   -2.5695907   -2.5593871 
    1835   -2.9871562   -2.5695907   -2.5440445 
Loop time of 3.62038e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82797947445994
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.89721691201958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03084906657391
variable        y0 equal ${yi}
variable        y0 equal 5.64538028185563

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 0.932671478587918
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.59579435532288
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1835   -2.9871562   -2.5695907   -2.5440445 
    1836   -2.9871562   -2.5695907   -2.5508968 
Loop time of 3.62423e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03084906657391
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.64538028185563
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.04304151255638
variable        y0 equal ${yi}
variable        y0 equal 6.44874846474161

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.07460362631828
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.51190980211725
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1836   -2.9871562   -2.5695907   -2.5508968 
    1837   -2.9871562   -2.5695907   -2.5793752 
Loop time of 3.61246e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.57937521666617
variable naccept equal ${increment}
variable naccept equal 385

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.51222945291769
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.34793477382923
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1837   -2.9871562   -2.5793752   -2.5793752 
    1838   -2.9871562   -2.5793752   -2.5715053 
Loop time of 3.55227e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.48385869104635
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.38020931806827
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.25888566731968
variable        y0 equal ${yi}
variable        y0 equal 0.0328114271163941

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.29362520932713
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.011324155330658
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1838   -2.9871562   -2.5793752   -2.5715053 
    1839   -2.9871562   -2.5793752   -2.5800747 
Loop time of 3.52883e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.58007470931308
variable naccept equal ${increment}
variable naccept equal 386

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.95845205743305
variable        y0 equal ${yi}
variable        y0 equal 8.26673827089366

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 5.86688097674839
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.16859446682033
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1839   -2.9871562   -2.5800747   -2.5800747 
    1840   -2.9871562   -2.5800747   -2.4974262 
Loop time of 3.59176e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 5.95845205743305
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.26673827089366
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.53369914451067
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.65620416348176
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1840   -2.9871562   -2.5800747   -2.4974262 
    1841   -2.9871562   -2.5800747   -2.5705149 
Loop time of 4.04207e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.37865453163053
variable        y0 equal ${yi}
variable        y0 equal 7.39225429621004

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.45318866172697
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.43499161329531
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1841   -2.9871562   -2.5800747   -2.5705149 
    1842   -2.9871562   -2.5800747   -2.5616191 
Loop time of 3.59607e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.37865453163053
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.39225429621004
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.48795623937074
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.49787443821626
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1842   -2.9871562   -2.5800747   -2.5616191 
    1843   -2.9871562   -2.5800747   -2.5568561 
Loop time of 3.7033e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.46746646562482
variable        y0 equal ${yi}
variable        y0 equal 9.264607102755

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.53577111163999
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.34494162309497
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1843   -2.9871562   -2.5800747   -2.5568561 
    1844   -2.9871562   -2.5800747   -2.5534948 
Loop time of 3.68676e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.46746646562482
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.264607102755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.101794230937958
variable        y0 equal ${yi}
variable        y0 equal 1.84877194545335

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.17396309375763
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.83638629100389
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1844   -2.9871562   -2.5800747   -2.5534948 
    1845   -2.9871562   -2.5800747   -2.5655117 
Loop time of 3.49168e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 6 x ${x0}
set atom 6 x 0.101794230937958
  1 settings made for x
set atom $i y ${y0}
set atom 6 y ${y0}
set atom 6 y 1.84877194545335
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.53207862217199
variable        y0 equal ${yi}
variable        y0 equal 9.2839910458359

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.54215763647329
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.36234892118304
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1845   -2.9871562   -2.5800747   -2.5655117 
    1846   -2.9871562   -2.5800747   -2.5680141 
Loop time of 3.6488e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.53207862217199
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.2839910458359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.84287891347399
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.47077840105525
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1846   -2.9871562   -2.5800747   -2.5680141 
    1847   -2.9871562   -2.5800747   -2.5728141 
Loop time of 3.62628e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 7.98698818086482
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.53119159475793
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1847   -2.9871562   -2.5800747   -2.5728141 
    1848   -2.9871562   -2.5800747   -2.5695792 
Loop time of 3.61771e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.52162269193899
variable        y0 equal ${yi}
variable        y0 equal 1.84969287297791

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.49926587183248
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.83106564662522
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1848   -2.9871562   -2.5800747   -2.5695792 
    1849   -2.9871562   -2.5800747   -2.5755145 
Loop time of 3.57865e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.52162269193899
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.84969287297791
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03084906657391
variable        y0 equal ${yi}
variable        y0 equal 5.64538028185563

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 1.03143052180462
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.57988774721818
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1849   -2.9871562   -2.5800747   -2.5755145 
    1850   -2.9871562   -2.5800747   -2.5812663 
Loop time of 3.54352e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.58126625708575
variable naccept equal ${increment}
variable naccept equal 387

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0128975868225374
variable        y0 equal ${yi}
variable        y0 equal 3.77990783019196

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 0.0623780131340303
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.84349489970337
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1850   -2.9871562   -2.5812663   -2.5812663 
    1851   -2.9871562   -2.5812663   -2.5537034 
Loop time of 3.57706e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 0.0128975868225374
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.77990783019196
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.13915432134971
variable        y0 equal ${yi}
variable        y0 equal 5.57011886780458

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.05949252287254
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.62731474583345
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1851   -2.9871562   -2.5812663   -2.5537034 
    1852   -2.9871562   -2.5812663   -2.5708129 
Loop time of 3.59476e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.13915432134971
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.57011886780458
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.26462735890904
variable        y0 equal ${yi}
variable        y0 equal 3.68544435067308

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.36127097367802
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.74421174092424
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1852   -2.9871562   -2.5812663   -2.5708129 
    1853   -2.9871562   -2.5812663   -2.5400927 
Loop time of 3.53655e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.26462735890904
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.68544435067308
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03143052180462
variable        y0 equal ${yi}
variable        y0 equal 5.57988774721818

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 1.04277170022183
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.50159170572953
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1853   -2.9871562   -2.5812663   -2.5400927 
    1854   -2.9871562   -2.5812663   -2.5538229 
Loop time of 3.62737e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03143052180462
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.57988774721818
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03143052180462
variable        y0 equal ${yi}
variable        y0 equal 5.57988774721818

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 1.01399797518902
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.49435603563981
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1854   -2.9871562   -2.5812663   -2.5538229 
    1855   -2.9871562   -2.5812663   -2.5462702 
Loop time of 6.62299e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03143052180462
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.57988774721818
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57543257355471
variable        y0 equal ${yi}
variable        y0 equal 4.67648406380578

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.55166655659457
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.68653668517037
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1855   -2.9871562   -2.5812663   -2.5462702 
    1856   -2.9871562   -2.5812663   -2.5775561 
Loop time of 3.51018e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.57543257355471
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.67648406380578
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.6302324012908
variable        y0 equal ${yi}
variable        y0 equal 0.804496832597583

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.584775789180662
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.789224715936511
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1856   -2.9871562   -2.5812663   -2.5775561 
    1857   -2.9871562   -2.5812663     -2.58335 
Loop time of 3.61178e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.58334998869571
variable naccept equal ${increment}
variable naccept equal 388

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.61588268755552
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.66659215254914
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1857   -2.9871562     -2.58335     -2.58335 
    1858   -2.9871562     -2.58335   -2.5543628 
Loop time of 3.62765e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.07460362631828
variable        y0 equal ${yi}
variable        y0 equal 6.51190980211725

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.00319345910103
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.51083938614359
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1858   -2.9871562     -2.58335   -2.5543628 
    1859   -2.9871562     -2.58335   -2.5543726 
Loop time of 3.5653e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.07460362631828
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.51190980211725
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.67305530467455
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.67659921212328
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1859   -2.9871562     -2.58335   -2.5543726 
    1860   -2.9871562     -2.58335    -2.579457 
Loop time of 3.54636e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7044513543301
variable        y0 equal ${yi}
variable        y0 equal 7.41026051368976

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.6953882773571
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.35575481977725
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1860   -2.9871562     -2.58335    -2.579457 
    1861   -2.9871562     -2.58335   -2.5701517 
Loop time of 3.66945e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7044513543301
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41026051368976
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.72697503765058
variable        y0 equal ${yi}
variable        y0 equal 2.78031077357629

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.65378763874006
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.85547994347909
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1861   -2.9871562     -2.58335   -2.5701517 
    1862   -2.9871562     -2.58335   -2.5763068 
Loop time of 3.51734e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.72697503765058
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.78031077357629
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0998515967389
variable        y0 equal ${yi}
variable        y0 equal 6.55315701500406

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.0020563129445
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.53062744871607
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1862   -2.9871562     -2.58335   -2.5763068 
    1863   -2.9871562     -2.58335   -2.5389363 
Loop time of 3.50079e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.0998515967389
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.55315701500406
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.87144294301158
variable        y0 equal ${yi}
variable        y0 equal 2.78142455788949

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.82393460789805
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.73978015157083
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1863   -2.9871562     -2.58335   -2.5389363 
    1864   -2.9871562     -2.58335   -2.5665702 
Loop time of 3.56894e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.87144294301158
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.78142455788949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.84048221945106
variable        y0 equal ${yi}
variable        y0 equal 6.44614082113734

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.93000365137397
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.47577857510081
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1864   -2.9871562     -2.58335   -2.5665702 
    1865   -2.9871562     -2.58335   -2.5706232 
Loop time of 3.47546e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.84048221945106
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.44614082113734
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0880036000272
variable        y0 equal ${yi}
variable        y0 equal 8.41472051061687

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.0507404808065
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.49747159399089
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1865   -2.9871562     -2.58335   -2.5706232 
    1866   -2.9871562     -2.58335   -2.5649354 
Loop time of 3.49616e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.0880036000272
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.41472051061687
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.13872285484172
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.49737404123773
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1866   -2.9871562     -2.58335   -2.5649354 
    1867   -2.9871562     -2.58335   -2.5501113 
Loop time of 3.59877e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03061267732479
variable        y0 equal ${yi}
variable        y0 equal 8.28878506340082

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 7.9661053359399
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.29230674423273
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1867   -2.9871562     -2.58335   -2.5501113 
    1868   -2.9871562     -2.58335   -2.5816332 
Loop time of 3.58339e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03061267732479
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.28878506340082
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.04947792886592
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.47544700638284
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1868   -2.9871562     -2.58335   -2.5816332 
    1869   -2.9871562     -2.58335   -2.5804362 
Loop time of 3.62422e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.92686012068435
variable        y0 equal ${yi}
variable        y0 equal 4.65877217406199

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.96131946125671
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.70026796215937
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1869   -2.9871562     -2.58335   -2.5804362 
    1870   -2.9871562     -2.58335   -2.5872214 
Loop time of 3.52074e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.58722142500987
variable naccept equal ${increment}
variable naccept equal 389

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.11698845068322
variable        y0 equal ${yi}
variable        y0 equal 3.79524089856278

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.08638619819985
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.75737629695069
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1870   -2.9871562   -2.5872214   -2.5872214 
    1871   -2.9871562   -2.5872214   -2.5841006 
Loop time of 3.49102e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.11698845068322
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.79524089856278
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.42371865907575
variable        y0 equal ${yi}
variable        y0 equal 1.7675963201291

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.40199131170179
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.77806965491838
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1871   -2.9871562   -2.5872214   -2.5841006 
    1872   -2.9871562   -2.5872214   -2.5837687 
Loop time of 3.61244e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.42371865907575
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.7675963201291
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.37865453163053
variable        y0 equal ${yi}
variable        y0 equal 7.39225429621004

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.44250448146726
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.2953432950046
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1872   -2.9871562   -2.5872214   -2.5837687 
    1873   -2.9871562   -2.5872214   -2.5712947 
Loop time of 3.61786e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.37865453163053
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.39225429621004
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.00799162982799
variable        y0 equal ${yi}
variable        y0 equal 4.67230892533228

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.0681977808366
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.6233086740391
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1873   -2.9871562   -2.5872214   -2.5712947 
    1874   -2.9871562   -2.5872214   -2.5881336 
Loop time of 3.50499e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.58813361995263
variable naccept equal ${increment}
variable naccept equal 390

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.76264746387434
variable        y0 equal ${yi}
variable        y0 equal 8.40153711952266

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.66579325397444
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.33878207124767
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1874   -2.9871562   -2.5881336   -2.5881336 
    1875   -2.9871562   -2.5881336   -2.5786387 
Loop time of 3.52086e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.76264746387434
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.40153711952266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75591478546096
variable        y0 equal ${yi}
variable        y0 equal 4.61056455725595

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.66409136255218
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.6007033144848
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1875   -2.9871562   -2.5881336   -2.5786387 
    1876   -2.9871562   -2.5881336   -2.5822386 
Loop time of 3.60288e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.75591478546096
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.61056455725595
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.61455693402712
variable        y0 equal ${yi}
variable        y0 equal 7.4608101996448

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.71156503119891
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.49588091697955
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1876   -2.9871562   -2.5881336   -2.5822386 
    1877   -2.9871562   -2.5881336   -2.5462494 
Loop time of 3.635e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.61455693402712
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.4608101996448
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.95845205743305
variable        y0 equal ${yi}
variable        y0 equal 8.26673827089366

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 5.86569193561069
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.17034159816798
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1877   -2.9871562   -2.5881336   -2.5462494 
    1878   -2.9871562   -2.5881336   -2.5056641 
Loop time of 3.64126e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 5.95845205743305
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.26673827089366
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.24611243645057
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.90366143367356
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1878   -2.9871562   -2.5881336   -2.5056641 
    1879   -2.9871562   -2.5881336   -2.5819896 
Loop time of 3.68264e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.3840241916916
variable        y0 equal ${yi}
variable        y0 equal 9.27708193767397

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.29019582350465
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.34692974794237
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1879   -2.9871562   -2.5881336   -2.5819896 
    1880   -2.9871562   -2.5881336   -2.5587229 
Loop time of 3.62329e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.3840241916916
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.27708193767397
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.86155322073576
variable        y0 equal ${yi}
variable        y0 equal 1.87893718860216

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.78923815964338
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.97841115377016
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1880   -2.9871562   -2.5881336   -2.5587229 
    1881   -2.9871562   -2.5881336   -2.5790492 
Loop time of 3.55327e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.86155322073576
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.87893718860216
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.03181864340954
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.89008063457078
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1881   -2.9871562   -2.5881336   -2.5790492 
    1882   -2.9871562   -2.5881336   -2.5545784 
Loop time of 3.59594e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.95845205743305
variable        y0 equal ${yi}
variable        y0 equal 8.26673827089366

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 5.9042545076131
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.24002698577937
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1882   -2.9871562   -2.5881336   -2.5545784 
    1883   -2.9871562   -2.5881336   -2.5700222 
Loop time of 3.52536e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 5.95845205743305
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.26673827089366
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.5445865321028
variable        y0 equal ${yi}
variable        y0 equal 5.54097448532778

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.5039488124716
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.53426376526552
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1883   -2.9871562   -2.5881336   -2.5700222 
    1884   -2.9871562   -2.5881336   -2.5765579 
Loop time of 3.52374e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.5445865321028
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.54097448532778
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.38844372430707
variable        y0 equal ${yi}
variable        y0 equal 3.82687561078202

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.36364214816953
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.86040654940736
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1884   -2.9871562   -2.5881336   -2.5765579 
    1885   -2.9871562   -2.5881336   -2.5712529 
Loop time of 3.71109e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.38844372430707
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.82687561078202
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.01612061539336
variable        y0 equal ${yi}
variable        y0 equal 2.79489908191064

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.98422845879241
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.80314019891122
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1885   -2.9871562   -2.5881336   -2.5712529 
    1886   -2.9871562   -2.5881336    -2.586116 
Loop time of 3.5234e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 7.01612061539336
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.79489908191064
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 0.0128975868225374
variable        y0 equal ${yi}
variable        y0 equal 3.77990783019196

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x -0.00186144113537886
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.74340155882966
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1886   -2.9871562   -2.5881336    -2.586116 
    1887   -2.9871562   -2.5881336   -2.5876734 
Loop time of 3.49348e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.58767340192887
variable naccept equal ${increment}
variable naccept equal 391

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.584775789180662
variable        y0 equal ${yi}
variable        y0 equal 0.789224715936511

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.601145465770628
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.786428554761737
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1887   -2.9871562   -2.5876734   -2.5876734 
    1888   -2.9871562   -2.5876734   -2.5857354 
Loop time of 3.4683e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.584775789180662
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.789224715936511
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.37865453163053
variable        y0 equal ${yi}
variable        y0 equal 7.39225429621004

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.42935876050855
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.38294791307711
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1888   -2.9871562   -2.5876734   -2.5857354 
    1889   -2.9871562   -2.5876734   -2.5878371 
Loop time of 3.53793e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.58783705289961
variable naccept equal ${increment}
variable naccept equal 392

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.86335536200991
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.47340589300624
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1889   -2.9871562   -2.5878371   -2.5878371 
    1890   -2.9871562   -2.5878371    -2.579713 
Loop time of 3.57412e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.46746646562482
variable        y0 equal ${yi}
variable        y0 equal 9.264607102755

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.42949339548017
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.19470688808291
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1890   -2.9871562   -2.5878371    -2.579713 
    1891   -2.9871562   -2.5878371   -2.5770209 
Loop time of 3.55054e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.46746646562482
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.264607102755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.59803893764448
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.40111606852045
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1891   -2.9871562   -2.5878371   -2.5770209 
    1892   -2.9871562   -2.5878371    -2.553184 
Loop time of 3.62977e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.6585701096036
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.54065520302286
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1892   -2.9871562   -2.5878371    -2.553184 
    1893   -2.9871562   -2.5878371   -2.5769736 
Loop time of 3.59276e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.57084057171117
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.28348309126163
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1893   -2.9871562   -2.5878371   -2.5769736 
    1894   -2.9871562   -2.5878371    -2.505794 
Loop time of 3.56134e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.48385869104635
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.38020931806827
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.84048221945106
variable        y0 equal ${yi}
variable        y0 equal 6.44614082113734

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.82874970077812
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.51564840809336
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1894   -2.9871562   -2.5878371    -2.505794 
    1895   -2.9871562   -2.5878371   -2.5891772 
Loop time of 3.49726e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.58917717248504
variable naccept equal ${increment}
variable naccept equal 393

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.60116907556486
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.55864587561121
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1895   -2.9871562   -2.5891772   -2.5891772 
    1896   -2.9871562   -2.5891772    -2.555182 
Loop time of 3.58216e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.46746646562482
variable        y0 equal ${yi}
variable        y0 equal 9.264607102755

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.54596418538953
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.19124872196048
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1896   -2.9871562   -2.5891772    -2.555182 
    1897   -2.9871562   -2.5891772   -2.5672851 
Loop time of 3.5275e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.46746646562482
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.264607102755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.38702585458317
variable        y0 equal ${yi}
variable        y0 equal 1.89600253484314

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.32259763240376
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.91972836635178
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1897   -2.9871562   -2.5891772   -2.5672851 
    1898   -2.9871562   -2.5891772   -2.5914905 
Loop time of 3.69171e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.59149050996939
variable naccept equal ${increment}
variable naccept equal 394

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal -0.00186144113537886
variable        y0 equal ${yi}
variable        y0 equal 3.74340155882966

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x -0.0303421378135405
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.83573509020936
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1898   -2.9871562   -2.5914905   -2.5914905 
    1899   -2.9871562   -2.5914905   -2.5688877 
Loop time of 3.4881e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x -0.00186144113537886
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.74340155882966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.50875395376456
variable        y0 equal ${yi}
variable        y0 equal 5.60411881153779

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.58294182855857
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.69350345080094
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1899   -2.9871562   -2.5914905   -2.5688877 
    1900   -2.9871562   -2.5914905   -2.5336588 
Loop time of 3.68492e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.50875395376456
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.60411881153779
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.49662729024011
variable        y0 equal ${yi}
variable        y0 equal 1.85665681741302

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.54568498848993
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.83739685199325
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1900   -2.9871562   -2.5914905   -2.5336588 
    1901   -2.9871562   -2.5914905    -2.577899 
Loop time of 3.69316e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.49662729024011
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.85665681741302
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.42793486197206
variable        y0 equal ${yi}
variable        y0 equal 1.83933557651109

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.35429295380327
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.7671802916295
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1901   -2.9871562   -2.5914905    -2.577899 
    1902   -2.9871562   -2.5914905   -2.5877647 
Loop time of 3.5768e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.42793486197206
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.83933557651109
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.08336665033197
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.97793387147288
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1902   -2.9871562   -2.5914905   -2.5877647 
    1903   -2.9871562   -2.5914905   -2.5342068 
Loop time of 3.57085e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.46746646562482
variable        y0 equal ${yi}
variable        y0 equal 9.264607102755

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.43905691305066
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.33485363233416
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1903   -2.9871562   -2.5914905   -2.5342068 
    1904   -2.9871562   -2.5914905    -2.582762 
Loop time of 3.45655e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.46746646562482
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.264607102755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.28592051903116
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 0.1098183631897
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1904   -2.9871562   -2.5914905    -2.582762 
    1905   -2.9871562   -2.5914905   -2.5791339 
Loop time of 3.58784e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7044513543301
variable        y0 equal ${yi}
variable        y0 equal 7.41026051368976

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.7963839371853
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.3296146663692
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1905   -2.9871562   -2.5914905   -2.5791339 
    1906   -2.9871562   -2.5914905   -2.5389128 
Loop time of 3.68946e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7044513543301
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41026051368976
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.12239968497307
variable        y0 equal ${yi}
variable        y0 equal 1.09747809957299

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.17300830800087
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.0788206536654
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1906   -2.9871562   -2.5914905   -2.5389128 
    1907   -2.9871562   -2.5914905   -2.5926119 
Loop time of 3.4809e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.59261187276412
variable naccept equal ${increment}
variable naccept equal 395

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 0.942098882991609
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.3978742035892
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1907   -2.9871562   -2.5926119   -2.5926119 
    1908   -2.9871562   -2.5926119   -2.5617945 
Loop time of 3.50889e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.95838304717534
variable        y0 equal ${yi}
variable        y0 equal 2.82275391789772

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.94982099492543
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.75380679341652
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1908   -2.9871562   -2.5926119   -2.5617945 
    1909   -2.9871562   -2.5926119   -2.5899742 
Loop time of 3.53895e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.95838304717534
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.82275391789772
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.25001341183397
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.56284218971927
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1909   -2.9871562   -2.5926119   -2.5899742 
    1910   -2.9871562   -2.5926119   -2.5906551 
Loop time of 3.4819e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.81228961268549
variable        y0 equal ${yi}
variable        y0 equal 8.38006076730785

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.74078957358484
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.40383260168132
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1910   -2.9871562   -2.5926119   -2.5906551 
    1911   -2.9871562   -2.5926119    -2.574504 
Loop time of 3.65237e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.81228961268549
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.38006076730785
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.594005592265989
variable        y0 equal ${yi}
variable        y0 equal 2.84451084109644

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.572148425975706
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.90917313071589
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1911   -2.9871562   -2.5926119    -2.574504 
    1912   -2.9871562   -2.5926119   -2.5735554 
Loop time of 3.5173e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.594005592265989
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.84451084109644
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.6573487090933
variable        y0 equal ${yi}
variable        y0 equal 7.44725758161806

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.6082365083563
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.40139909115099
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1912   -2.9871562   -2.5926119   -2.5735554 
    1913   -2.9871562   -2.5926119   -2.5799156 
Loop time of 3.58903e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 99 x ${x0}
set atom 99 x 9.6573487090933
  1 settings made for x
set atom $i y ${y0}
set atom 99 y ${y0}
set atom 99 y 7.44725758161806
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.49662729024011
variable        y0 equal ${yi}
variable        y0 equal 1.85665681741302

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.44857986687738
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.77746022126739
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1913   -2.9871562   -2.5926119   -2.5799156 
    1914   -2.9871562   -2.5926119   -2.5766085 
Loop time of 3.46425e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.49662729024011
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.85665681741302
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.65424995302935
variable        y0 equal ${yi}
variable        y0 equal 0.940276082265705

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.61632748722811
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.900820871103138
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1914   -2.9871562   -2.5926119   -2.5766085 
    1915   -2.9871562   -2.5926119   -2.5893289 
Loop time of 3.57982e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.65424995302935
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.940276082265705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.85170476952678
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.61007587069438
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1915   -2.9871562   -2.5926119   -2.5893289 
    1916   -2.9871562   -2.5926119   -2.5649745 
Loop time of 3.44109e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.61455693402712
variable        y0 equal ${yi}
variable        y0 equal 7.4608101996448

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.55057543673937
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.50053246345782
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1916   -2.9871562   -2.5926119   -2.5649745 
    1917   -2.9871562   -2.5926119    -2.569845 
Loop time of 3.63654e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.61455693402712
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.4608101996448
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 5.97854424674504
variable        y0 equal ${yi}
variable        y0 equal 0.914465494859546

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 6.0378567333936
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.820648987996906
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1917   -2.9871562   -2.5926119    -2.569845 
    1918   -2.9871562   -2.5926119   -2.5709295 
Loop time of 3.58147e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 5.97854424674504
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.914465494859546
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.29362520932713
variable        y0 equal ${yi}
variable        y0 equal 0.011324155330658

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.33090700864354
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.0219839692115784
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1918   -2.9871562   -2.5926119   -2.5709295 
    1919   -2.9871562   -2.5926119   -2.5879434 
Loop time of 3.49804e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.29362520932713
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.011324155330658
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.76264746387434
variable        y0 equal ${yi}
variable        y0 equal 8.40153711952266

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.7484208007617
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.4937744132429
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1919   -2.9871562   -2.5926119   -2.5879434 
    1920   -2.9871562   -2.5926119   -2.5680111 
Loop time of 3.56262e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.76264746387434
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.40153711952266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.3840241916916
variable        y0 equal ${yi}
variable        y0 equal 9.27708193767397

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.4451393850586
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.25483386028139
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1920   -2.9871562   -2.5926119   -2.5680111 
    1921   -2.9871562   -2.5926119   -2.5861487 
Loop time of 3.64539e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.3840241916916
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.27708193767397
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.72697503765058
variable        y0 equal ${yi}
variable        y0 equal 2.78031077357629

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.67858633001279
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.6860172030578
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1921   -2.9871562   -2.5926119   -2.5861487 
    1922   -2.9871562   -2.5926119   -2.5470698 
Loop time of 3.50515e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.72697503765058
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.78031077357629
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.90266047993347
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.36944211639461
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1922   -2.9871562   -2.5926119   -2.5470698 
    1923   -2.9871562   -2.5926119   -2.5608436 
Loop time of 3.548e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.8900455796653
variable        y0 equal ${yi}
variable        y0 equal 0.887486429918145

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.95209471821129
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.920424016225671
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1923   -2.9871562   -2.5926119   -2.5608436 
    1924   -2.9871562   -2.5926119   -2.5769435 
Loop time of 3.5967e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.8900455796653
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.887486429918145
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.82874970077812
variable        y0 equal ${yi}
variable        y0 equal 6.51564840809336

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.8606200063163
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.41976522938242
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1924   -2.9871562   -2.5926119   -2.5769435 
    1925   -2.9871562   -2.5926119   -2.5879859 
Loop time of 3.52584e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.82874970077812
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.51564840809336
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.3840241916916
variable        y0 equal ${yi}
variable        y0 equal 9.27708193767397

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.39554654438706
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.37596957195131
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1925   -2.9871562   -2.5926119   -2.5879859 
    1926   -2.9871562   -2.5926119   -2.5610809 
Loop time of 3.54021e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.3840241916916
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.27708193767397
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3012223724386
variable        y0 equal ${yi}
variable        y0 equal 2.8246198293815

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.3247253898641
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.80344607802728
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1926   -2.9871562   -2.5926119   -2.5610809 
    1927   -2.9871562   -2.5926119   -2.5908908 
Loop time of 3.97744e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3012223724386
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.8246198293815
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.86954605538836
variable        y0 equal ${yi}
variable        y0 equal 4.6797511851208

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.84087495763293
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.61630157584117
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1927   -2.9871562   -2.5926119   -2.5908908 
    1928   -2.9871562   -2.5926119    -2.560999 
Loop time of 3.52429e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.86954605538836
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.6797511851208
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.87144294301158
variable        y0 equal ${yi}
variable        y0 equal 2.78142455788949

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.81590004483348
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.71425565453866
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1928   -2.9871562   -2.5926119    -2.560999 
    1929   -2.9871562   -2.5926119   -2.5632405 
Loop time of 3.61012e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.87144294301158
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.78142455788949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.08605186342097
variable        y0 equal ${yi}
variable        y0 equal 0.950601537931293

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.09319434760905
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.990582271325916
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1929   -2.9871562   -2.5926119   -2.5632405 
    1930   -2.9871562   -2.5926119   -2.5927176 
Loop time of 3.47039e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.59271764191045
variable naccept equal ${increment}
variable naccept equal 396

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57543257355471
variable        y0 equal ${yi}
variable        y0 equal 4.67648406380578

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.66430145382662
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.64495692604943
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1930   -2.9871562   -2.5927176   -2.5927176 
    1931   -2.9871562   -2.5927176   -2.5794071 
Loop time of 3.67112e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.57543257355471
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.67648406380578
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.584775789180662
variable        y0 equal ${yi}
variable        y0 equal 0.789224715936511

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.566282685199644
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.865556212175219
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1931   -2.9871562   -2.5927176   -2.5794071 
    1932   -2.9871562   -2.5927176    -2.601688 
Loop time of 3.53896e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.60168798660648
variable naccept equal ${increment}
variable naccept equal 397

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.38844372430707
variable        y0 equal ${yi}
variable        y0 equal 3.82687561078202

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.35614831844235
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.74340068860184
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1932   -2.9871562    -2.601688    -2.601688 
    1933   -2.9871562    -2.601688   -2.6124519 
Loop time of 3.54766e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.61245189298714
variable naccept equal ${increment}
variable naccept equal 398

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.1955849651357
variable        y0 equal ${yi}
variable        y0 equal 4.64925400370525

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.1008500818273
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.71313414925502
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1933   -2.9871562   -2.6124519   -2.6124519 
    1934   -2.9871562   -2.6124519   -2.5941786 
Loop time of 3.58346e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.1955849651357
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.64925400370525
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.54950123865377
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.4420496138599
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1934   -2.9871562   -2.6124519   -2.5941786 
    1935   -2.9871562   -2.6124519   -2.6010892 
Loop time of 3.54746e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.48385869104635
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.38020931806827
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.101794230937958
variable        y0 equal ${yi}
variable        y0 equal 1.84877194545335

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.0824616909027102
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.86063473603791
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1935   -2.9871562   -2.6124519   -2.6010892 
    1936   -2.9871562   -2.6124519   -2.6080876 
Loop time of 3.56747e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 6 x ${x0}
set atom 6 x 0.101794230937958
  1 settings made for x
set atom $i y ${y0}
set atom 6 y ${y0}
set atom 6 y 1.84877194545335
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.41449785946924
variable        y0 equal ${yi}
variable        y0 equal 5.54428255503374

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.46196884631235
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.60429812615114
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1936   -2.9871562   -2.6124519   -2.6080876 
    1937   -2.9871562   -2.6124519   -2.6083998 
Loop time of 3.46854e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.41449785946924
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.54428255503374
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.44055470942574
variable        y0 equal ${yi}
variable        y0 equal 7.31046043958926

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.45262900113183
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.22866106357837
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1937   -2.9871562   -2.6124519   -2.6083998 
    1938   -2.9871562   -2.6124519   -2.5712589 
Loop time of 3.53451e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.44055470942574
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.31046043958926
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.95845205743305
variable        y0 equal ${yi}
variable        y0 equal 8.26673827089366

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 5.87389231879703
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.20943769134578
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1938   -2.9871562   -2.6124519   -2.5712589 
    1939   -2.9871562   -2.6124519   -2.5549129 
Loop time of 3.55389e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 5.95845205743305
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.26673827089366
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.53458213963929
variable        y0 equal ${yi}
variable        y0 equal 1.99115990779465

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.46380344787064
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 2.0284749068982
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1939   -2.9871562   -2.6124519   -2.5549129 
    1940   -2.9871562   -2.6124519   -2.5669344 
Loop time of 3.58831e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.53458213963929
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.99115990779465
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.52172473191339
variable        y0 equal ${yi}
variable        y0 equal 9.28439741838305

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.61202945231515
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.22294412362902
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1940   -2.9871562   -2.6124519   -2.5669344 
    1941   -2.9871562   -2.6124519   -2.5572817 
Loop time of 3.57453e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.52172473191339
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.28439741838305
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78581515748931
variable        y0 equal ${yi}
variable        y0 equal 1.04153251241478

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.70806782443954
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.13282606195244
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1941   -2.9871562   -2.6124519   -2.5572817 
    1942   -2.9871562   -2.6124519   -2.5727555 
Loop time of 3.7125e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.78581515748931
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.04153251241478
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.20654361883506
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.8675343193776
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1942   -2.9871562   -2.6124519   -2.5727555 
    1943   -2.9871562   -2.6124519   -2.6101587 
Loop time of 3.58118e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.62633978009005
variable        y0 equal ${yi}
variable        y0 equal 2.82587088319162

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.54861431002398
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.74267264577249
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1943   -2.9871562   -2.6124519   -2.6101587 
    1944   -2.9871562   -2.6124519   -2.5682219 
Loop time of 3.61919e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.62633978009005
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.82587088319162
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.46636033772546
variable        y0 equal ${yi}
variable        y0 equal 3.78071368498932

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.37763447283822
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.87727593941818
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1944   -2.9871562   -2.6124519   -2.5682219 
    1945   -2.9871562   -2.6124519   -2.5723988 
Loop time of 3.47168e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.46636033772546
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.78071368498932
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.02246614415199
variable        y0 equal ${yi}
variable        y0 equal 8.41134195245798

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 8.96391457039863
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.39380206979807
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1945   -2.9871562   -2.6124519   -2.5723988 
    1946   -2.9871562   -2.6124519   -2.5789777 
Loop time of 3.56391e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.02246614415199
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.41134195245798
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.78458021203167
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.61391864174769
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1946   -2.9871562   -2.6124519   -2.5789777 
    1947   -2.9871562   -2.6124519   -2.6101109 
Loop time of 3.47406e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.19761607725831
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.67567684595782
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1947   -2.9871562   -2.6124519   -2.6101109 
    1948   -2.9871562   -2.6124519   -2.5601997 
Loop time of 3.50833e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.16086302398539
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.94104750129084
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1948   -2.9871562   -2.6124519   -2.5601997 
    1949   -2.9871562   -2.6124519   -2.5635562 
Loop time of 3.53658e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.61672473985921
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.80885036749971
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1949   -2.9871562   -2.6124519   -2.5635562 
    1950   -2.9871562   -2.6124519   -2.5766855 
Loop time of 3.5308e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.93805575012504
variable        y0 equal ${yi}
variable        y0 equal 8.32736837781961

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.98098420738517
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.22753000177438
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1950   -2.9871562   -2.6124519   -2.5766855 
    1951   -2.9871562   -2.6124519   -2.5613829 
Loop time of 3.5017e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.93805575012504
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.32736837781961
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.2379414264332
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 0.0867336750030549
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1951   -2.9871562   -2.6124519   -2.5613829 
    1952   -2.9871562   -2.6124519   -2.6080986 
Loop time of 3.5422e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 7.00936227121994
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.31230893053111
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1952   -2.9871562   -2.6124519   -2.6080986 
    1953   -2.9871562   -2.6124519   -2.6113578 
Loop time of 3.64418e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.96131946125671
variable        y0 equal ${yi}
variable        y0 equal 4.70026796215937

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 7.05524943152114
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.62832535857127
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1953   -2.9871562   -2.6124519   -2.6113578 
    1954   -2.9871562   -2.6124519   -2.6048994 
Loop time of 3.74824e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.96131946125671
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.70026796215937
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.10710482317955
variable        y0 equal ${yi}
variable        y0 equal 4.59937599057123

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.14786480385811
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.54210950488016
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1954   -2.9871562   -2.6124519   -2.6048994 
    1955   -2.9871562   -2.6124519   -2.5971966 
Loop time of 3.68087e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.10710482317955
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.59937599057123
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.75583070158301
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.56607356423304
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1955   -2.9871562   -2.6124519   -2.5971966 
    1956   -2.9871562   -2.6124519   -2.5903408 
Loop time of 3.50726e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.33703600564863
variable        y0 equal ${yi}
variable        y0 equal 5.47514280026155

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.29218043485548
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.45070875828462
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1956   -2.9871562   -2.6124519   -2.5903408 
    1957   -2.9871562   -2.6124519   -2.5853773 
Loop time of 3.63205e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.33703600564863
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.47514280026155
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.53207862217199
variable        y0 equal ${yi}
variable        y0 equal 9.2839910458359

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.49274283487569
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.3186181734833
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1957   -2.9871562   -2.6124519   -2.5853773 
    1958   -2.9871562   -2.6124519   -2.5971188 
Loop time of 3.60405e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.53207862217199
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.2839910458359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.93805575012504
variable        y0 equal ${yi}
variable        y0 equal 8.32736837781961

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.85956760286628
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.31168992437417
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1958   -2.9871562   -2.6124519   -2.5971188 
    1959   -2.9871562   -2.6124519   -2.6019163 
Loop time of 3.53196e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.93805575012504
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.32736837781961
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.42371865907575
variable        y0 equal ${yi}
variable        y0 equal 1.7675963201291

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.46139991680051
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.85337124250001
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1959   -2.9871562   -2.6124519   -2.6019163 
    1960   -2.9871562   -2.6124519   -2.6262396 
Loop time of 3.69632e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.6262396324932
variable naccept equal ${increment}
variable naccept equal 399

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.42793486197206
variable        y0 equal ${yi}
variable        y0 equal 1.83933557651109

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.35658786375734
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.8282853164441
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1960   -2.9871562   -2.6262396   -2.6262396 
    1961   -2.9871562   -2.6262396   -2.6258852 
Loop time of 3.52345e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.62588519237748
variable naccept equal ${increment}
variable naccept equal 400

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.44055470942574
variable        y0 equal ${yi}
variable        y0 equal 7.31046043958926

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.35280724286156
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.29239620294833
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1961   -2.9871562   -2.6258852   -2.6258852 
    1962   -2.9871562   -2.6258852   -2.5788763 
Loop time of 3.54465e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.44055470942574
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.31046043958926
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.5020066368558
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.63609029785624
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1962   -2.9871562   -2.6258852   -2.5788763 
    1963   -2.9871562   -2.6258852   -2.5866389 
Loop time of 3.54494e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.594005592265989
variable        y0 equal ${yi}
variable        y0 equal 2.84451084109644

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.67484281817999
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.82343237372736
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1963   -2.9871562   -2.6258852   -2.5866389 
    1964   -2.9871562   -2.6258852   -2.5989166 
Loop time of 3.96226e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.594005592265989
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.84451084109644
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.95838304717534
variable        y0 equal ${yi}
variable        y0 equal 2.82275391789772

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.9641524072408
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.85610704394676
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1964   -2.9871562   -2.6258852   -2.5989166 
    1965   -2.9871562   -2.6258852   -2.6245178 
Loop time of 3.54738e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.95838304717534
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.82275391789772
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.52172473191339
variable        y0 equal ${yi}
variable        y0 equal 9.28439741838305

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.47866305827219
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.25160747278063
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1965   -2.9871562   -2.6258852   -2.6245178 
    1966   -2.9871562   -2.6258852   -2.6272019 
Loop time of 3.56769e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.62720186299398
variable naccept equal ${increment}
variable naccept equal 401

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.1955849651357
variable        y0 equal ${yi}
variable        y0 equal 4.64925400370525

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.2600111607572
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.67218886965679
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1966   -2.9871562   -2.6272019   -2.6272019 
    1967   -2.9871562   -2.6272019    -2.621516 
Loop time of 3.60154e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.1955849651357
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.64925400370525
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.46746646562482
variable        y0 equal ${yi}
variable        y0 equal 9.264607102755

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.41825508275891
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.29823296773761
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1967   -2.9871562   -2.6272019    -2.621516 
    1968   -2.9871562   -2.6272019   -2.6262989 
Loop time of 3.58376e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.46746646562482
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.264607102755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6848535259419
variable        y0 equal ${yi}
variable        y0 equal 5.65403784458834

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.6536131818944
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.68581156676012
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1968   -2.9871562   -2.6272019   -2.6262989 
    1969   -2.9871562   -2.6272019   -2.6221721 
Loop time of 3.54117e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.6848535259419
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.65403784458834
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.506249304214384
variable        y0 equal ${yi}
variable        y0 equal 6.52357215420237

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.594374831119444
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.5627228929185
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1969   -2.9871562   -2.6272019   -2.6221721 
    1970   -2.9871562   -2.6272019   -2.6131694 
Loop time of 3.51016e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.506249304214384
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.52357215420237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03143052180462
variable        y0 equal ${yi}
variable        y0 equal 5.57988774721818

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 1.10688520987682
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.49450701420503
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1970   -2.9871562   -2.6272019   -2.6131694 
    1971   -2.9871562   -2.6272019   -2.5850058 
Loop time of 3.54361e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03143052180462
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.57988774721818
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.95845205743305
variable        y0 equal ${yi}
variable        y0 equal 8.26673827089366

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 5.86694589812748
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.2719438783079
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1971   -2.9871562   -2.6272019   -2.5850058 
    1972   -2.9871562   -2.6272019   -2.5870278 
Loop time of 3.52534e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 5.95845205743305
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.26673827089366
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.42935876050855
variable        y0 equal ${yi}
variable        y0 equal 7.38294791307711

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.34044415155317
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.45816960659289
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1972   -2.9871562   -2.6272019   -2.5870278 
    1973   -2.9871562   -2.6272019   -2.5920889 
Loop time of 3.39908e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.42935876050855
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.38294791307711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.04726804812603
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.85517396113938
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1973   -2.9871562   -2.6272019   -2.5920889 
    1974   -2.9871562   -2.6272019   -2.6054977 
Loop time of 3.55526e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.50088549732943
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.4964317156457
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1974   -2.9871562   -2.6272019   -2.6054977 
    1975   -2.9871562   -2.6272019   -2.6136933 
Loop time of 3.4998e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03143052180462
variable        y0 equal ${yi}
variable        y0 equal 5.57988774721818

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 1.02380173524075
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.48579527085023
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1975   -2.9871562   -2.6272019   -2.6136933 
    1976   -2.9871562   -2.6272019   -2.5868822 
Loop time of 3.52014e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03143052180462
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.57988774721818
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.53745518485632
variable        y0 equal ${yi}
variable        y0 equal 4.67062938565179

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.527254207530881
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.66832068318292
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1976   -2.9871562   -2.6272019   -2.5868822 
    1977   -2.9871562   -2.6272019   -2.6284162 
Loop time of 3.49179e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.62841622796503
variable naccept equal ${increment}
variable naccept equal 402

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.17300830800087
variable        y0 equal ${yi}
variable        y0 equal 1.0788206536654

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.11682046372444
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.16459966491494
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1977   -2.9871562   -2.6284162   -2.6284162 
    1978   -2.9871562   -2.6284162   -2.6151779 
Loop time of 3.54679e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.17300830800087
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.0788206536654
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.81228961268549
variable        y0 equal ${yi}
variable        y0 equal 8.38006076730785

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.73365576783304
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.35974439300594
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1978   -2.9871562   -2.6284162   -2.6151779 
    1979   -2.9871562   -2.6284162   -2.6120499 
Loop time of 3.54838e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.81228961268549
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.38006076730785
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6848535259419
variable        y0 equal ${yi}
variable        y0 equal 5.65403784458834

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.6692195852452
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.70620185082156
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1979   -2.9871562   -2.6284162   -2.6120499 
    1980   -2.9871562   -2.6284162   -2.6172212 
Loop time of 3.59625e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.6848535259419
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.65403784458834
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.27962877193796
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 0.00211440324783643
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1980   -2.9871562   -2.6284162   -2.6172212 
    1981   -2.9871562   -2.6284162   -2.6183008 
Loop time of 3.54865e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.57918032883284
variable        y0 equal ${yi}
variable        y0 equal 0.0850776791572572

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.48965818165419
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.0275716900825502
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1981   -2.9871562   -2.6284162   -2.6183008 
    1982   -2.9871562   -2.6284162   -2.5700802 
Loop time of 4.67059e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 79 x ${x0}
set atom 79 x 9.57918032883284
  1 settings made for x
set atom $i y ${y0}
set atom 79 y ${y0}
set atom 79 y 0.0850776791572572
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.566282685199644
variable        y0 equal ${yi}
variable        y0 equal 0.865556212175219

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.470958586135771
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.811273415792315
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1982   -2.9871562   -2.6284162   -2.5700802 
    1983   -2.9871562   -2.6284162   -2.5984832 
Loop time of 6.70273e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.566282685199644
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.865556212175219
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.61493019023363
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.77061665816438
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1983   -2.9871562   -2.6284162   -2.5984832 
    1984   -2.9871562   -2.6284162   -2.6159324 
Loop time of 3.77221e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6723551591091
variable        y0 equal ${yi}
variable        y0 equal 9.27579969871372

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.6465650637798
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.21225748765796
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1984   -2.9871562   -2.6284162   -2.6159324 
    1985   -2.9871562   -2.6284162    -2.612607 
Loop time of 3.7257e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6723551591091
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.27579969871372
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03061267732479
variable        y0 equal ${yi}
variable        y0 equal 8.28878506340082

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.01604235767223
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.19863289512689
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1985   -2.9871562   -2.6284162    -2.612607 
    1986   -2.9871562   -2.6284162   -2.5927676 
Loop time of 3.69529e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03061267732479
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.28878506340082
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.29362520932713
variable        y0 equal ${yi}
variable        y0 equal 0.011324155330658

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.297263345714
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.0278402686119079
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1986   -2.9871562   -2.6284162   -2.5927676 
    1987   -2.9871562   -2.6284162   -2.6244939 
Loop time of 3.92464e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.29362520932713
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.011324155330658
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.01415445207454
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.52520989910593
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1987   -2.9871562   -2.6284162   -2.6244939 
    1988   -2.9871562   -2.6284162   -2.6269267 
Loop time of 4.21045e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.09319434760905
variable        y0 equal ${yi}
variable        y0 equal 0.990582271325916

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.10946962236262
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.923097487199634
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1988   -2.9871562   -2.6284162   -2.6269267 
    1989   -2.9871562   -2.6284162    -2.623586 
Loop time of 3.6822e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.09319434760905
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.990582271325916
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.13915432134971
variable        y0 equal ${yi}
variable        y0 equal 5.57011886780458

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.22696057001457
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.54877798502641
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1989   -2.9871562   -2.6284162    -2.623586 
    1990   -2.9871562   -2.6284162   -2.6110568 
Loop time of 3.67404e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.13915432134971
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.57011886780458
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.53458213963929
variable        y0 equal ${yi}
variable        y0 equal 1.99115990779465

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.475442101149
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.93202218196457
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1990   -2.9871562   -2.6284162   -2.6110568 
    1991   -2.9871562   -2.6284162   -2.6115047 
Loop time of 3.77227e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.53458213963929
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.99115990779465
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.56315948803198
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.35577223625446
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1991   -2.9871562   -2.6284162   -2.6115047 
    1992   -2.9871562   -2.6284162   -2.6117925 
Loop time of 3.81154e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.48385869104635
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.38020931806827
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.46636033772546
variable        y0 equal ${yi}
variable        y0 equal 3.78071368498932

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.43275641917306
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.83499285740982
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1992   -2.9871562   -2.6284162   -2.6117925 
    1993   -2.9871562   -2.6284162   -2.6179129 
Loop time of 3.7028e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.46636033772546
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.78071368498932
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.86155322073576
variable        y0 equal ${yi}
variable        y0 equal 1.87893718860216

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.95717859743711
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.88970078609056
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1993   -2.9871562   -2.6284162   -2.6179129 
    1994   -2.9871562   -2.6284162   -2.5430906 
Loop time of 3.62535e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.86155322073576
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.87893718860216
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03061267732479
variable        y0 equal ${yi}
variable        y0 equal 8.28878506340082

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.08188425897457
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.24850158609445
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1994   -2.9871562   -2.6284162   -2.5430906 
    1995   -2.9871562   -2.6284162   -2.5909826 
Loop time of 3.68192e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03061267732479
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.28878506340082
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.35658786375734
variable        y0 equal ${yi}
variable        y0 equal 1.8282853164441

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.29375739176485
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.91718260428971
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1995   -2.9871562   -2.6284162   -2.5909826 
    1996   -2.9871562   -2.6284162   -2.5915116 
Loop time of 3.73009e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.35658786375734
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.8282853164441
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82797947445994
variable        y0 equal ${yi}
variable        y0 equal 0.89721691201958

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.76338865080958
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.879891808736652
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1996   -2.9871562   -2.6284162   -2.5915116 
    1997   -2.9871562   -2.6284162   -2.6121732 
Loop time of 3.638e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82797947445994
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.89721691201958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.58196511426393
variable        y0 equal ${yi}
variable        y0 equal 0.0479238748550414

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.510789300589
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y -0.00191041231155407
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1997   -2.9871562   -2.6284162   -2.6121732 
    1998   -2.9871562   -2.6284162   -2.6227246 
Loop time of 3.81885e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.58196511426393
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.0479238748550414
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.11225053707466
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.98809355876511
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1998   -2.9871562   -2.6284162   -2.6227246 
    1999   -2.9871562   -2.6284162   -2.5966724 
Loop time of 3.722e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.48137225944769
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.2875762852695
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    1999   -2.9871562   -2.6284162   -2.5966724 
    2000   -2.9871562   -2.6284162   -2.5865315 
Loop time of 4.22861e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.48385869104635
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.38020931806827
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.96131946125671
variable        y0 equal ${yi}
variable        y0 equal 4.70026796215937

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 7.01451349535629
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.67800829762385
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2000   -2.9871562   -2.6284162   -2.5865315 
    2001   -2.9871562   -2.6284162   -2.6322392 
Loop time of 3.71937e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.63223919960847
variable naccept equal ${increment}
variable naccept equal 403

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.44055470942574
variable        y0 equal ${yi}
variable        y0 equal 7.31046043958926

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.41708299635964
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.39001784649157
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2001   -2.9871562   -2.6322392   -2.6322392 
    2002   -2.9871562   -2.6322392   -2.6258199 
Loop time of 3.66234e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.44055470942574
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.31046043958926
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.11103429237709
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.37715884771609
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2002   -2.9871562   -2.6322392   -2.6258199 
    2003   -2.9871562   -2.6322392   -2.6196286 
Loop time of 3.6795e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.2537579540272
variable        y0 equal ${yi}
variable        y0 equal 0.909067996251911

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.2678407315274
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.894402166116566
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2003   -2.9871562   -2.6322392   -2.6196286 
    2004   -2.9871562   -2.6322392   -2.6294321 
Loop time of 3.79307e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.2537579540272
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.909067996251911
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.35658786375734
variable        y0 equal ${yi}
variable        y0 equal 1.8282853164441

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.32799846012804
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.76740742108888
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2004   -2.9871562   -2.6322392   -2.6294321 
    2005   -2.9871562   -2.6322392   -2.6188911 
Loop time of 3.69936e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.35658786375734
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.8282853164441
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.87144294301158
variable        y0 equal ${yi}
variable        y0 equal 2.78142455788949

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.79148860493785
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.73661241504052
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2005   -2.9871562   -2.6322392   -2.6188911 
    2006   -2.9871562   -2.6322392   -2.6068673 
Loop time of 3.59803e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.87144294301158
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.78142455788949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.11698845068322
variable        y0 equal ${yi}
variable        y0 equal 3.79524089856278

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.05609445015298
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.89521548314225
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2006   -2.9871562   -2.6322392   -2.6068673 
    2007   -2.9871562   -2.6322392   -2.5618491 
Loop time of 3.73294e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.11698845068322
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.79524089856278
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.72697503765058
variable        y0 equal ${yi}
variable        y0 equal 2.78031077357629

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.6946355958743
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.68314399691919
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2007   -2.9871562   -2.6322392   -2.5618491 
    2008   -2.9871562   -2.6322392    -2.589185 
Loop time of 3.74446e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.72697503765058
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.78031077357629
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.52162269193899
variable        y0 equal ${yi}
variable        y0 equal 1.84969287297791

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.44189226467382
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.76767996928757
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2008   -2.9871562   -2.6322392    -2.589185 
    2009   -2.9871562   -2.6322392   -2.5774066 
Loop time of 3.68101e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.52162269193899
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.84969287297791
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.20456645567628
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.52942302172382
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2009   -2.9871562   -2.6322392   -2.5774066 
    2010   -2.9871562   -2.6322392   -2.6125366 
Loop time of 3.67554e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.63106594561216
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.71398614211213
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2010   -2.9871562   -2.6322392   -2.6125366 
    2011   -2.9871562   -2.6322392   -2.6169739 
Loop time of 3.81921e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6723551591091
variable        y0 equal ${yi}
variable        y0 equal 9.27579969871372

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.6205372651272
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.28430906045765
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2011   -2.9871562   -2.6322392   -2.6169739 
    2012   -2.9871562   -2.6322392   -2.6220843 
Loop time of 3.54036e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6723551591091
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.27579969871372
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.26690107027397
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.4026491912868
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2012   -2.9871562   -2.6322392   -2.6220843 
    2013   -2.9871562   -2.6322392   -2.6163083 
Loop time of 3.60066e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.49662729024011
variable        y0 equal ${yi}
variable        y0 equal 1.85665681741302

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.47432732104379
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.94574048898284
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2013   -2.9871562   -2.6322392   -2.6163083 
    2014   -2.9871562   -2.6322392   -2.6196981 
Loop time of 3.56069e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.49662729024011
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.85665681741302
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.53207862217199
variable        y0 equal ${yi}
variable        y0 equal 9.2839910458359

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.50784586508047
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.24297188032
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2014   -2.9871562   -2.6322392   -2.6196981 
    2015   -2.9871562   -2.6322392   -2.6298891 
Loop time of 3.65149e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.53207862217199
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.2839910458359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.25279456138173
variable        y0 equal ${yi}
variable        y0 equal 7.38214940157198

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.17853147744695
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.46440419283175
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2015   -2.9871562   -2.6322392   -2.6298891 
    2016   -2.9871562   -2.6322392   -2.6185873 
Loop time of 3.70397e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.25279456138173
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.38214940157198
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.86954605538836
variable        y0 equal ${yi}
variable        y0 equal 4.6797511851208

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.83751034696093
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.74792468899653
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2016   -2.9871562   -2.6322392   -2.6185873 
    2017   -2.9871562   -2.6322392   -2.5442142 
Loop time of 3.7082e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.86954605538836
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.6797511851208
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.11264473517591
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.54524356451296
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2017   -2.9871562   -2.6322392   -2.5442142 
    2018   -2.9871562   -2.6322392   -2.6071001 
Loop time of 3.61994e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.62633978009005
variable        y0 equal ${yi}
variable        y0 equal 2.82587088319162

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.69002660393496
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.8819009420524
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2018   -2.9871562   -2.6322392   -2.6071001 
    2019   -2.9871562   -2.6322392   -2.6264458 
Loop time of 3.64499e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.62633978009005
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.82587088319162
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.527254207530881
variable        y0 equal ${yi}
variable        y0 equal 4.66832068318292

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.428175468841458
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.74842284077569
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2019   -2.9871562   -2.6322392   -2.6264458 
    2020   -2.9871562   -2.6322392    -2.615024 
Loop time of 3.78865e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.527254207530881
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.66832068318292
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.13915432134971
variable        y0 equal ${yi}
variable        y0 equal 5.57011886780458

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.13317146936759
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.47944934313493
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2020   -2.9871562   -2.6322392    -2.615024 
    2021   -2.9871562   -2.6322392   -2.6190385 
Loop time of 3.74786e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.13915432134971
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.57011886780458
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.62633978009005
variable        y0 equal ${yi}
variable        y0 equal 2.82587088319162

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.5371486413457
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.89149364205698
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2021   -2.9871562   -2.6322392   -2.6190385 
    2022   -2.9871562   -2.6322392   -2.5821879 
Loop time of 3.77134e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.62633978009005
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.82587088319162
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 7.01451349535629
variable        y0 equal ${yi}
variable        y0 equal 4.67800829762385

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 7.03616481104538
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.77653991335795
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2022   -2.9871562   -2.6322392   -2.5821879 
    2023   -2.9871562   -2.6322392   -2.5978199 
Loop time of 3.86066e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 7.01451349535629
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.67800829762385
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.58196511426393
variable        y0 equal ${yi}
variable        y0 equal 0.0479238748550414

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.56384705462877
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.0929038047790526
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2023   -2.9871562   -2.6322392   -2.5978199 
    2024   -2.9871562   -2.6322392   -2.6317787 
Loop time of 3.64365e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.63177865315337
variable naccept equal ${increment}
variable naccept equal 404

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.449145431915189
variable        y0 equal ${yi}
variable        y0 equal 8.34512849964198

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.377074857154752
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.29165397800502
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2024   -2.9871562   -2.6317787   -2.6317787 
    2025   -2.9871562   -2.6317787   -2.6122211 
Loop time of 3.66455e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.449145431915189
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.34512849964198
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7044513543301
variable        y0 equal ${yi}
variable        y0 equal 7.41026051368976

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.763589449709
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.36412775841022
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2025   -2.9871562   -2.6317787   -2.6122211 
    2026   -2.9871562   -2.6317787   -2.6138256 
Loop time of 3.70201e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7044513543301
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41026051368976
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.61461975732271
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.77646606726778
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2026   -2.9871562   -2.6317787   -2.6138256 
    2027   -2.9871562   -2.6317787   -2.6164888 
Loop time of 3.73827e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.76264746387434
variable        y0 equal ${yi}
variable        y0 equal 8.40153711952266

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.78298455675077
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.49539030708369
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2027   -2.9871562   -2.6317787   -2.6164888 
    2028   -2.9871562   -2.6317787   -2.6015956 
Loop time of 3.71651e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.76264746387434
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.40153711952266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.42935876050855
variable        y0 equal ${yi}
variable        y0 equal 7.38294791307711

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.51182095209028
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.30601953592562
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2028   -2.9871562   -2.6317787   -2.6015956 
    2029   -2.9871562   -2.6317787   -2.5726356 
Loop time of 3.64621e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.42935876050855
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.38294791307711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.86155322073576
variable        y0 equal ${yi}
variable        y0 equal 1.87893718860216

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.92876458643553
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.79883866689272
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2029   -2.9871562   -2.6317787   -2.5726356 
    2030   -2.9871562   -2.6317787   -2.5640602 
Loop time of 3.69812e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.86155322073576
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.87893718860216
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.81228961268549
variable        y0 equal ${yi}
variable        y0 equal 8.38006076730785

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.89381748953943
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.37316666759548
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2030   -2.9871562   -2.6317787   -2.5640602 
    2031   -2.9871562   -2.6317787   -2.6237387 
Loop time of 3.76265e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.81228961268549
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.38006076730785
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.82874970077812
variable        y0 equal ${yi}
variable        y0 equal 6.51564840809336

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.88622611402809
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.54206478134623
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2031   -2.9871562   -2.6317787   -2.6237387 
    2032   -2.9871562   -2.6317787   -2.6265259 
Loop time of 3.77656e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.82874970077812
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.51564840809336
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.86954605538836
variable        y0 equal ${yi}
variable        y0 equal 4.6797511851208

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.86047263104907
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.67771562689708
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2032   -2.9871562   -2.6317787   -2.6265259 
    2033   -2.9871562   -2.6317787   -2.6301278 
Loop time of 3.5668e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.86954605538836
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.6797511851208
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.07460362631828
variable        y0 equal ${yi}
variable        y0 equal 6.51190980211725

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.00065579134971
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.54441654221048
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2033   -2.9871562   -2.6317787   -2.6301278 
    2034   -2.9871562   -2.6317787   -2.5953389 
Loop time of 3.7141e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.07460362631828
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.51190980211725
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.49662729024011
variable        y0 equal ${yi}
variable        y0 equal 1.85665681741302

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.54241103648263
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.76524867198532
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2034   -2.9871562   -2.6317787   -2.5953389 
    2035   -2.9871562   -2.6317787   -2.6061763 
Loop time of 3.70254e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.49662729024011
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.85665681741302
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.01612061539336
variable        y0 equal ${yi}
variable        y0 equal 2.79489908191064

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.93673168697997
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.82332797023156
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2035   -2.9871562   -2.6317787   -2.6061763 
    2036   -2.9871562   -2.6317787    -2.617423 
Loop time of 3.80041e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 7.01612061539336
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.79489908191064
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0880036000272
variable        y0 equal ${yi}
variable        y0 equal 8.41472051061687

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.1686777833959
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.47002659954128
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2036   -2.9871562   -2.6317787    -2.617423 
    2037   -2.9871562   -2.6317787   -2.6040586 
Loop time of 3.82123e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.0880036000272
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.41472051061687
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.17300830800087
variable        y0 equal ${yi}
variable        y0 equal 1.0788206536654

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.26159610468895
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.01986627172265
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2037   -2.9871562   -2.6317787   -2.6040586 
    2038   -2.9871562   -2.6317787   -2.6072478 
Loop time of 3.62374e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.17300830800087
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.0788206536654
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.01612061539336
variable        y0 equal ${yi}
variable        y0 equal 2.79489908191064

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.93327521362944
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.88468193980554
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2038   -2.9871562   -2.6317787   -2.6072478 
    2039   -2.9871562   -2.6317787   -2.6096444 
Loop time of 3.66495e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 7.01612061539336
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.79489908191064
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.85870788613445
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.67067398184703
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2039   -2.9871562   -2.6317787   -2.6096444 
    2040   -2.9871562   -2.6317787   -2.6027096 
Loop time of 3.82636e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.35614831844235
variable        y0 equal ${yi}
variable        y0 equal 3.74340068860184

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.3894811908331
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.64595493836533
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2040   -2.9871562   -2.6317787   -2.6027096 
    2041   -2.9871562   -2.6317787   -2.5963496 
Loop time of 3.72029e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.35614831844235
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.74340068860184
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.09859546740705
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.50702008333468
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2041   -2.9871562   -2.6317787   -2.5963496 
    2042   -2.9871562   -2.6317787   -2.6238399 
Loop time of 3.75848e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.33703600564863
variable        y0 equal ${yi}
variable        y0 equal 5.47514280026155

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.40162080922987
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.54853548948961
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2042   -2.9871562   -2.6317787   -2.6238399 
    2043   -2.9871562   -2.6317787   -2.6485748 
Loop time of 3.70061e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.64857475149618
variable naccept equal ${increment}
variable naccept equal 405

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.02246614415199
variable        y0 equal ${yi}
variable        y0 equal 8.41134195245798

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.11354686934501
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.4509523145109
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2043   -2.9871562   -2.6485748   -2.6485748 
    2044   -2.9871562   -2.6485748   -2.6439371 
Loop time of 3.62525e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.02246614415199
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.41134195245798
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.32259763240376
variable        y0 equal ${yi}
variable        y0 equal 1.91972836635178

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.29978656529942
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.85333593270844
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2044   -2.9871562   -2.6485748   -2.6439371 
    2045   -2.9871562   -2.6485748   -2.6388254 
Loop time of 3.82013e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.32259763240376
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.91972836635178
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6848535259419
variable        y0 equal ${yi}
variable        y0 equal 5.65403784458834

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.6997664650136
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.5742603296538
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2045   -2.9871562   -2.6485748   -2.6388254 
    2046   -2.9871562   -2.6485748   -2.6490563 
Loop time of 3.75901e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.64905632053271
variable naccept equal ${increment}
variable naccept equal 406

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.27116128285142
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.68752443356645
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2046   -2.9871562   -2.6490563   -2.6490563 
    2047   -2.9871562   -2.6490563   -2.6391356 
Loop time of 3.7213e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.52162269193899
variable        y0 equal ${yi}
variable        y0 equal 1.84969287297791

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.53705383379232
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.92912966392106
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2047   -2.9871562   -2.6490563   -2.6391356 
    2048   -2.9871562   -2.6490563   -2.6467113 
Loop time of 3.63187e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.52162269193899
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.84969287297791
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.82874970077812
variable        y0 equal ${yi}
variable        y0 equal 6.51564840809336

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.81660802006065
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.59819979206553
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2048   -2.9871562   -2.6490563   -2.6467113 
    2049   -2.9871562   -2.6490563   -2.6259083 
Loop time of 3.79368e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.82874970077812
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.51564840809336
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7044513543301
variable        y0 equal ${yi}
variable        y0 equal 7.41026051368976

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.685078008955
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.31318958130145
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2049   -2.9871562   -2.6490563   -2.6259083 
    2050   -2.9871562   -2.6490563   -2.6111682 
Loop time of 3.81884e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7044513543301
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41026051368976
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.46139991680051
variable        y0 equal ${yi}
variable        y0 equal 1.85337124250001

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.4790786186781
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.76643147847718
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2050   -2.9871562   -2.6490563   -2.6111682 
    2051   -2.9871562   -2.6490563   -2.6325507 
Loop time of 3.82629e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.46139991680051
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.85337124250001
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.86155322073576
variable        y0 equal ${yi}
variable        y0 equal 1.87893718860216

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.92313839672682
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.95393885753221
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2051   -2.9871562   -2.6490563   -2.6325507 
    2052   -2.9871562   -2.6490563   -2.5954764 
Loop time of 3.80495e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.86155322073576
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.87893718860216
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 10.7438378771
variable        y0 equal ${yi}
variable        y0 equal 3.74340155882966

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 10.6685197671109
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.68003744645249
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2052   -2.9871562   -2.6490563   -2.5954764 
    2053   -2.9871562   -2.6490563   -2.5968168 
Loop time of 3.73655e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 10.7438378771
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.74340155882966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.17300830800087
variable        y0 equal ${yi}
variable        y0 equal 1.0788206536654

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.19387582261116
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.1026515800837
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2053   -2.9871562   -2.6490563   -2.5968168 
    2054   -2.9871562   -2.6490563   -2.6456349 
Loop time of 3.72245e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.17300830800087
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.0788206536654
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.01612061539336
variable        y0 equal ${yi}
variable        y0 equal 2.79489908191064

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.92493995705291
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.77293726178506
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2054   -2.9871562   -2.6490563   -2.6456349 
    2055   -2.9871562   -2.6490563   -2.6252475 
Loop time of 3.75587e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 7.01612061539336
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.79489908191064
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.16727634071208
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.51159619823923
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2055   -2.9871562   -2.6490563   -2.6252475 
    2056   -2.9871562   -2.6490563   -2.5872335 
Loop time of 3.68149e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.25279456138173
variable        y0 equal ${yi}
variable        y0 equal 7.38214940157198

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.1815040445284
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.36683659878038
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2056   -2.9871562   -2.6490563   -2.5872335 
    2057   -2.9871562   -2.6490563   -2.6347171 
Loop time of 3.61162e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.25279456138173
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.38214940157198
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 7.98203504680492
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.5763654185914
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2057   -2.9871562   -2.6490563   -2.6347171 
    2058   -2.9871562   -2.6490563   -2.6222374 
Loop time of 3.63461e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7044513543301
variable        y0 equal ${yi}
variable        y0 equal 7.41026051368976

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.7482892234974
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.33873100605274
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2058   -2.9871562   -2.6490563   -2.6222374 
    2059   -2.9871562   -2.6490563   -2.6236291 
Loop time of 3.65081e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7044513543301
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41026051368976
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.01612061539336
variable        y0 equal ${yi}
variable        y0 equal 2.79489908191064

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 7.04345748701735
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.78294523927072
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2059   -2.9871562   -2.6490563   -2.6236291 
    2060   -2.9871562   -2.6490563   -2.6469978 
Loop time of 3.69449e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 7.01612061539336
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.79489908191064
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.95286738831988
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.45779751078121
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2060   -2.9871562   -2.6490563   -2.6469978 
    2061   -2.9871562   -2.6490563   -2.6413846 
Loop time of 3.69327e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.86954605538836
variable        y0 equal ${yi}
variable        y0 equal 4.6797511851208

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.78713641126147
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.68623925799296
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2061   -2.9871562   -2.6490563   -2.6413846 
    2062   -2.9871562   -2.6490563   -2.6188379 
Loop time of 3.6086e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.86954605538836
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.6797511851208
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.48905432064306
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.33510278787876
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2062   -2.9871562   -2.6490563   -2.6188379 
    2063   -2.9871562   -2.6490563   -2.6375743 
Loop time of 3.8501e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.48385869104635
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.38020931806827
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.6573487090933
variable        y0 equal ${yi}
variable        y0 equal 7.44725758161806

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.71329887388822
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.53788806524538
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2063   -2.9871562   -2.6490563   -2.6375743 
    2064   -2.9871562   -2.6490563    -2.626705 
Loop time of 3.80712e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 99 x ${x0}
set atom 99 x 9.6573487090933
  1 settings made for x
set atom $i y ${y0}
set atom 99 y ${y0}
set atom 99 y 7.44725758161806
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.35199898560258
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.80541380210054
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2064   -2.9871562   -2.6490563    -2.626705 
    2065   -2.9871562   -2.6490563   -2.6246798 
Loop time of 3.75079e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0880036000272
variable        y0 equal ${yi}
variable        y0 equal 8.41472051061687

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.0851176146527
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.45487257160244
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2065   -2.9871562   -2.6490563   -2.6246798 
    2066   -2.9871562   -2.6490563   -2.6438198 
Loop time of 3.62241e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.0880036000272
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.41472051061687
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.0998515967389
variable        y0 equal ${yi}
variable        y0 equal 6.55315701500406

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.1372151497861
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.56728928820123
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2066   -2.9871562   -2.6490563   -2.6438198 
    2067   -2.9871562   -2.6490563   -2.6493682 
Loop time of 3.71599e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.64936821847401
variable naccept equal ${increment}
variable naccept equal 407

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.86954605538836
variable        y0 equal ${yi}
variable        y0 equal 4.6797511851208

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.84264154393664
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.64205295199321
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2067   -2.9871562   -2.6493682   -2.6493682 
    2068   -2.9871562   -2.6493682   -2.6517641 
Loop time of 3.72384e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.65176406607028
variable naccept equal ${increment}
variable naccept equal 408

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.20629341322929
variable        y0 equal ${yi}
variable        y0 equal 2.76325721713403

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.19823426920921
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.67179243537286
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2068   -2.9871562   -2.6517641   -2.6517641 
    2069   -2.9871562   -2.6517641   -2.6260618 
Loop time of 3.69486e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.20629341322929
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.76325721713403
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.86155322073576
variable        y0 equal ${yi}
variable        y0 equal 1.87893718860216

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.86807623385069
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.86096693656511
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2069   -2.9871562   -2.6517641   -2.6260618 
    2070   -2.9871562   -2.6517641   -2.6477162 
Loop time of 3.82116e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.86155322073576
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.87893718860216
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7044513543301
variable        y0 equal ${yi}
variable        y0 equal 7.41026051368976

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.7317555864506
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.50981210794711
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2070   -2.9871562   -2.6517641   -2.6477162 
    2071   -2.9871562   -2.6517641   -2.6377743 
Loop time of 3.73523e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7044513543301
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41026051368976
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.56384705462877
variable        y0 equal ${yi}
variable        y0 equal 0.0929038047790526

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.55653579392854
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.102318131923675
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2071   -2.9871562   -2.6517641   -2.6377743 
    2072   -2.9871562   -2.6517641   -2.6500223 
Loop time of 3.68109e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.56384705462877
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.0929038047790526
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.01612061539336
variable        y0 equal ${yi}
variable        y0 equal 2.79489908191064

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.95377936640426
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.86373200389245
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2072   -2.9871562   -2.6517641   -2.6500223 
    2073   -2.9871562   -2.6517641    -2.640733 
Loop time of 4.14366e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 7.01612061539336
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.79489908191064
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.32259763240376
variable        y0 equal ${yi}
variable        y0 equal 1.91972836635178

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.23738232612172
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.96804883859223
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2073   -2.9871562   -2.6517641    -2.640733 
    2074   -2.9871562   -2.6517641   -2.6330306 
Loop time of 3.66355e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.32259763240376
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.91972836635178
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.26462735890904
variable        y0 equal ${yi}
variable        y0 equal 3.68544435067308

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.2062298512415
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.7013570980562
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2074   -2.9871562   -2.6517641   -2.6330306 
    2075   -2.9871562   -2.6517641   -2.6490727 
Loop time of 3.67243e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.26462735890904
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.68544435067308
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.506249304214384
variable        y0 equal ${yi}
variable        y0 equal 6.52357215420237

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.448989291587736
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.55478728548518
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2075   -2.9871562   -2.6517641   -2.6490727 
    2076   -2.9871562   -2.6517641   -2.6403841 
Loop time of 3.60854e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.506249304214384
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.52357215420237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.01612061539336
variable        y0 equal ${yi}
variable        y0 equal 2.79489908191064

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 7.03542357960387
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.85165057154992
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2076   -2.9871562   -2.6517641   -2.6403841 
    2077   -2.9871562   -2.6517641    -2.649243 
Loop time of 3.71499e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 7.01612061539336
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.79489908191064
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.35658786375734
variable        y0 equal ${yi}
variable        y0 equal 1.8282853164441

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.39980769236299
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.76565012118882
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2077   -2.9871562   -2.6517641    -2.649243 
    2078   -2.9871562   -2.6517641    -2.643803 
Loop time of 3.69679e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.35658786375734
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.8282853164441
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.72697503765058
variable        y0 equal ${yi}
variable        y0 equal 2.78031077357629

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.74880151946973
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.8138187286506
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2078   -2.9871562   -2.6517641    -2.643803 
    2079   -2.9871562   -2.6517641   -2.6511852 
Loop time of 3.60207e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.72697503765058
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.78031077357629
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.81228961268549
variable        y0 equal ${yi}
variable        y0 equal 8.38006076730785

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.84038932839518
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.35802853025493
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2079   -2.9871562   -2.6517641   -2.6511852 
    2080   -2.9871562   -2.6517641   -2.6515534 
Loop time of 3.73686e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.65155340829806
variable naccept equal ${increment}
variable naccept equal 409

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.30592141230317
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.64572917168338
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2080   -2.9871562   -2.6515534   -2.6515534 
    2081   -2.9871562   -2.6515534    -2.643178 
Loop time of 3.68116e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.11698845068322
variable        y0 equal ${yi}
variable        y0 equal 3.79524089856278

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.17206690946923
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.82480040354859
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2081   -2.9871562   -2.6515534    -2.643178 
    2082   -2.9871562   -2.6515534   -2.6436129 
Loop time of 3.81057e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.11698845068322
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.79524089856278
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.07460362631828
variable        y0 equal ${yi}
variable        y0 equal 6.51190980211725

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.13773007113487
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.4807119442605
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2082   -2.9871562   -2.6515534   -2.6436129 
    2083   -2.9871562   -2.6515534   -2.6483974 
Loop time of 3.7527e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.07460362631828
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.51190980211725
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.506249304214384
variable        y0 equal ${yi}
variable        y0 equal 6.52357215420237

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.465543539920713
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.54243880049219
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2083   -2.9871562   -2.6515534   -2.6483974 
    2084   -2.9871562   -2.6515534   -2.6461765 
Loop time of 3.73669e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.506249304214384
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.52357215420237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.449145431915189
variable        y0 equal ${yi}
variable        y0 equal 8.34512849964198

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.549047072330381
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.25699111141261
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2084   -2.9871562   -2.6515534   -2.6461765 
    2085   -2.9871562   -2.6515534   -2.6064042 
Loop time of 3.67437e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.449145431915189
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.34512849964198
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.57918032883284
variable        y0 equal ${yi}
variable        y0 equal 0.0850776791572572

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.53015740393278
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.123499178886414
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2085   -2.9871562   -2.6515534   -2.6064042 
    2086   -2.9871562   -2.6515534   -2.6324424 
Loop time of 3.76725e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 79 x ${x0}
set atom 79 x 9.57918032883284
  1 settings made for x
set atom $i y ${y0}
set atom 79 y ${y0}
set atom 79 y 0.0850776791572572
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.57918032883284
variable        y0 equal ${yi}
variable        y0 equal 0.0850776791572572

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.48406627653715
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.143958604335785
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2086   -2.9871562   -2.6515534   -2.6324424 
    2087   -2.9871562   -2.6515534   -2.5935187 
Loop time of 3.75154e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 79 x ${x0}
set atom 79 x 9.57918032883284
  1 settings made for x
set atom $i y ${y0}
set atom 79 y ${y0}
set atom 79 y 0.0850776791572572
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0880036000272
variable        y0 equal ${yi}
variable        y0 equal 8.41472051061687

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.0712319020292
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.4037723175436
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2087   -2.9871562   -2.6515534   -2.5935187 
    2088   -2.9871562   -2.6515534   -2.6506902 
Loop time of 3.84632e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.6506902071389
variable naccept equal ${increment}
variable naccept equal 410

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.37309358198854
variable        y0 equal ${yi}
variable        y0 equal 7.47418843832278

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.46468333084795
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.56760686960482
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2088   -2.9871562   -2.6506902   -2.6506902 
    2089   -2.9871562   -2.6506902   -2.5542379 
Loop time of 3.76939e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.37309358198854
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.47418843832278
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.506249304214384
variable        y0 equal ${yi}
variable        y0 equal 6.52357215420237

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.417006833949949
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.54447638527384
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2089   -2.9871562   -2.6506902   -2.5542379 
    2090   -2.9871562   -2.6506902   -2.6331212 
Loop time of 3.75845e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.506249304214384
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.52357215420237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75591478546096
variable        y0 equal ${yi}
variable        y0 equal 4.61056455725595

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.82987669904662
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.62590047472879
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2090   -2.9871562   -2.6506902   -2.6331212 
    2091   -2.9871562   -2.6506902   -2.6233949 
Loop time of 4.27705e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.75591478546096
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.61056455725595
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.0800673158949
variable        y0 equal ${yi}
variable        y0 equal 3.73807540698182

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.04395253976041
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.78102184100282
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2091   -2.9871562   -2.6506902   -2.6233949 
    2092   -2.9871562   -2.6506902   -2.6496857 
Loop time of 4.1406e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.0800673158949
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.73807540698182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.2528173812172
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.63591383640964
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2092   -2.9871562   -2.6506902   -2.6496857 
    2093   -2.9871562   -2.6506902   -2.6398035 
Loop time of 3.82141e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.0681977808366
variable        y0 equal ${yi}
variable        y0 equal 4.6233086740391

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.09154855607845
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.58367084616587
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2093   -2.9871562   -2.6506902   -2.6398035 
    2094   -2.9871562   -2.6506902   -2.6429001 
Loop time of 3.75489e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.0681977808366
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.6233086740391
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 7.01451349535629
variable        y0 equal ${yi}
variable        y0 equal 4.67800829762385

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 7.07729629555389
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.67022935503886
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2094   -2.9871562   -2.6506902   -2.6429001 
    2095   -2.9871562   -2.6506902   -2.6376487 
Loop time of 3.75318e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 7.01451349535629
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.67800829762385
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.0800673158949
variable        y0 equal ${yi}
variable        y0 equal 3.73807540698182

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.1787508519476
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.78232515616547
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2095   -2.9871562   -2.6506902   -2.6376487 
    2096   -2.9871562   -2.6506902   -2.6084161 
Loop time of 3.75803e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.0800673158949
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.73807540698182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.5922348638339
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.52171363369456
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2096   -2.9871562   -2.6506902   -2.6084161 
    2097   -2.9871562   -2.6506902   -2.6288082 
Loop time of 3.81236e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.45237238247167
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.71904719634187
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2097   -2.9871562   -2.6506902   -2.6288082 
    2098   -2.9871562   -2.6506902   -2.6408594 
Loop time of 3.64179e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.1955849651357
variable        y0 equal ${yi}
variable        y0 equal 4.64925400370525

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.2304856542608
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.64664347523616
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2098   -2.9871562   -2.6506902   -2.6408594 
    2099   -2.9871562   -2.6506902    -2.646464 
Loop time of 3.67934e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.1955849651357
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.64925400370525
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.71494046925184
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.77420702738893
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2099   -2.9871562   -2.6506902    -2.646464 
    2100   -2.9871562   -2.6506902   -2.6398608 
Loop time of 3.72549e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.7838305524934
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.55162345522807
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2100   -2.9871562   -2.6506902   -2.6398608 
    2101   -2.9871562   -2.6506902   -2.6304359 
Loop time of 3.77312e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78567172804958
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.64188341254161
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.52162269193899
variable        y0 equal ${yi}
variable        y0 equal 1.84969287297791

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.54671642620336
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.8942704357869
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2101   -2.9871562   -2.6506902   -2.6304359 
    2102   -2.9871562   -2.6506902   -2.6505522 
Loop time of 3.69016e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.52162269193899
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.84969287297791
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.02246614415199
variable        y0 equal ${yi}
variable        y0 equal 8.41134195245798

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.05161564070732
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.36008071817453
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2102   -2.9871562   -2.6506902   -2.6505522 
    2103   -2.9871562   -2.6506902   -2.6458519 
Loop time of 3.63181e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.02246614415199
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.41134195245798
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.53207862217199
variable        y0 equal ${yi}
variable        y0 equal 9.2839910458359

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.46819466192495
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.36808884847491
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2103   -2.9871562   -2.6506902   -2.6458519 
    2104   -2.9871562   -2.6506902   -2.6196209 
Loop time of 3.65302e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.53207862217199
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.2839910458359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.70000591158648
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.33845655836161
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2104   -2.9871562   -2.6506902   -2.6196209 
    2105   -2.9871562   -2.6506902     -2.65007 
Loop time of 3.76003e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.46139991680051
variable        y0 equal ${yi}
variable        y0 equal 1.85337124250001

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.55362522998716
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.89019781730241
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2105   -2.9871562   -2.6506902     -2.65007 
    2106   -2.9871562   -2.6506902   -2.6126515 
Loop time of 3.6771e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.46139991680051
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.85337124250001
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.85850470025531
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.51110568777553
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2106   -2.9871562   -2.6506902   -2.6126515 
    2107   -2.9871562   -2.6506902   -2.6321346 
Loop time of 3.73555e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.62633978009005
variable        y0 equal ${yi}
variable        y0 equal 2.82587088319162

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.61024140000124
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.78594510527948
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2107   -2.9871562   -2.6506902   -2.6321346 
    2108   -2.9871562   -2.6506902   -2.6445226 
Loop time of 3.67764e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.62633978009005
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.82587088319162
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82797947445994
variable        y0 equal ${yi}
variable        y0 equal 0.89721691201958

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.88224686900263
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.978574009645312
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2108   -2.9871562   -2.6506902   -2.6445226 
    2109   -2.9871562   -2.6506902   -2.6340777 
Loop time of 3.69124e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82797947445994
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.89721691201958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.79354886292096
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.77110095782411
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2109   -2.9871562   -2.6506902   -2.6340777 
    2110   -2.9871562   -2.6506902   -2.6091813 
Loop time of 3.70524e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.46746646562482
variable        y0 equal ${yi}
variable        y0 equal 9.264607102755

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.44636772075559
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.24993084180682
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2110   -2.9871562   -2.6506902   -2.6091813 
    2111   -2.9871562   -2.6506902   -2.6521718 
Loop time of 3.64161e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.65217182196102
variable naccept equal ${increment}
variable naccept equal 411

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.101794230937958
variable        y0 equal ${yi}
variable        y0 equal 1.84877194545335

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.127323067188263
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.92114310643739
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2111   -2.9871562   -2.6521718   -2.6521718 
    2112   -2.9871562   -2.6521718   -2.6473447 
Loop time of 3.74744e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 6 x ${x0}
set atom 6 x 0.101794230937958
  1 settings made for x
set atom $i y ${y0}
set atom 6 y ${y0}
set atom 6 y 1.84877194545335
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.65996109404985
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.70472119612825
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2112   -2.9871562   -2.6521718   -2.6473447 
    2113   -2.9871562   -2.6521718   -2.6521116 
Loop time of 3.73043e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.46139991680051
variable        y0 equal ${yi}
variable        y0 equal 1.85337124250001

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.38003664413358
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.88935792825288
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2113   -2.9871562   -2.6521718   -2.6521116 
    2114   -2.9871562   -2.6521718   -2.6483648 
Loop time of 3.71786e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.46139991680051
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.85337124250001
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.1955849651357
variable        y0 equal ${yi}
variable        y0 equal 4.64925400370525

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.1516710046789
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.66872700804638
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2114   -2.9871562   -2.6521718   -2.6483648 
    2115   -2.9871562   -2.6521718   -2.6510491 
Loop time of 3.65168e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.1955849651357
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.64925400370525
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.93805575012504
variable        y0 equal ${yi}
variable        y0 equal 8.32736837781961

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.99915307401954
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.37540954269464
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2115   -2.9871562   -2.6521718   -2.6510491 
    2116   -2.9871562   -2.6521718   -2.6293619 
Loop time of 3.72325e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.93805575012504
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.32736837781961
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.3026360575329
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 0.0635354876518281
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2116   -2.9871562   -2.6521718   -2.6293619 
    2117   -2.9871562   -2.6521718    -2.638798 
Loop time of 3.66138e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7044513543301
variable        y0 equal ${yi}
variable        y0 equal 7.41026051368976

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.7412166317158
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.38622058954502
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2117   -2.9871562   -2.6521718    -2.638798 
    2118   -2.9871562   -2.6521718   -2.6457666 
Loop time of 3.86416e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7044513543301
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.41026051368976
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.44055470942574
variable        y0 equal ${yi}
variable        y0 equal 7.31046043958926

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.39752079962807
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.27825090017581
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2118   -2.9871562   -2.6521718   -2.6457666 
    2119   -2.9871562   -2.6521718   -2.6325729 
Loop time of 3.69056e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.44055470942574
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.31046043958926
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.527254207530881
variable        y0 equal ${yi}
variable        y0 equal 4.66832068318292

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.429971070686246
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.66864577883645
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2119   -2.9871562   -2.6521718   -2.6325729 
    2120   -2.9871562   -2.6521718    -2.634122 
Loop time of 3.83823e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.527254207530881
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.66832068318292
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.53207862217199
variable        y0 equal ${yi}
variable        y0 equal 9.2839910458359

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.58466195900213
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.33182891118853
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2120   -2.9871562   -2.6521718    -2.634122 
    2121   -2.9871562   -2.6521718   -2.6405684 
Loop time of 3.7708e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.53207862217199
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.2839910458359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.93805575012504
variable        y0 equal ${yi}
variable        y0 equal 8.32736837781961

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.93485804437934
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.26757851757104
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2121   -2.9871562   -2.6521718   -2.6405684 
    2122   -2.9871562   -2.6521718     -2.63557 
Loop time of 3.675e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.93805575012504
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.32736837781961
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.72697503765058
variable        y0 equal ${yi}
variable        y0 equal 2.78031077357629

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.63746152122449
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.70112013789514
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2122   -2.9871562   -2.6521718     -2.63557 
    2123   -2.9871562   -2.6521718   -2.6004851 
Loop time of 3.64625e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.72697503765058
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.78031077357629
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0712319020292
variable        y0 equal ${yi}
variable        y0 equal 8.4037723175436

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.1664741758367
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.37916365779934
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2123   -2.9871562   -2.6521718   -2.6004851 
    2124   -2.9871562   -2.6521718   -2.6486366 
Loop time of 3.82425e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.0712319020292
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.4037723175436
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 1.10092277844601
variable        y0 equal ${yi}
variable        y0 equal 9.22189815748065

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 1.00344027598553
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.24176482665866
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2124   -2.9871562   -2.6521718   -2.6486366 
    2125   -2.9871562   -2.6521718   -2.6454046 
Loop time of 3.75977e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 1.10092277844601
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.22189815748065
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.47866305827219
variable        y0 equal ${yi}
variable        y0 equal 9.25160747278063

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.51514130353052
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.32629889953463
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2125   -2.9871562   -2.6521718   -2.6454046 
    2126   -2.9871562   -2.6521718   -2.6452103 
Loop time of 3.73449e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.47866305827219
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.25160747278063
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.11698845068322
variable        y0 equal ${yi}
variable        y0 equal 3.79524089856278

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.13120705524789
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.79238885207306
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2126   -2.9871562   -2.6521718   -2.6452103 
    2127   -2.9871562   -2.6521718   -2.6541657 
Loop time of 3.74406e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.65416565705693
variable naccept equal ${increment}
variable naccept equal 412

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.46139991680051
variable        y0 equal ${yi}
variable        y0 equal 1.85337124250001

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.537396029624
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.77984137914247
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2127   -2.9871562   -2.6541657   -2.6541657 
    2128   -2.9871562   -2.6541657   -2.6157086 
Loop time of 3.63023e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.46139991680051
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.85337124250001
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.09319434760905
variable        y0 equal ${yi}
variable        y0 equal 0.990582271325916

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.16211866735316
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 1.05880372117791
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2128   -2.9871562   -2.6541657   -2.6157086 
    2129   -2.9871562   -2.6541657   -2.6405272 
Loop time of 3.68934e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.09319434760905
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.990582271325916
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.20629341322929
variable        y0 equal ${yi}
variable        y0 equal 2.76325721713403

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.29726946074516
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.83230823251107
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2129   -2.9871562   -2.6541657   -2.6405272 
    2130   -2.9871562   -2.6541657   -2.6257017 
Loop time of 3.72538e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.20629341322929
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.76325721713403
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.37309358198854
variable        y0 equal ${yi}
variable        y0 equal 7.47418843832278

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.35413922150346
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.3762880953815
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2130   -2.9871562   -2.6541657   -2.6257017 
    2131   -2.9871562   -2.6541657   -2.6437488 
Loop time of 3.69976e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.37309358198854
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.47418843832278
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.56384705462877
variable        y0 equal ${yi}
variable        y0 equal 0.0929038047790526

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.63742518582765
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.097970676422119
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2131   -2.9871562   -2.6541657   -2.6437488 
    2132   -2.9871562   -2.6541657    -2.632478 
Loop time of 3.61682e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.56384705462877
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.0929038047790526
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20813699721852
variable        y0 equal ${yi}
variable        y0 equal 5.56420804207521

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.21354355573216
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.46741110031801
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2132   -2.9871562   -2.6541657    -2.632478 
    2133   -2.9871562   -2.6541657   -2.6292763 
Loop time of 3.70384e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20813699721852
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56420804207521
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.23928067763063
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.71271442933213
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2133   -2.9871562   -2.6541657   -2.6292763 
    2134   -2.9871562   -2.6541657   -2.6358693 
Loop time of 3.67504e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.0800673158949
variable        y0 equal ${yi}
variable        y0 equal 3.73807540698182

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.11255663951093
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.72971576018464
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2134   -2.9871562   -2.6541657   -2.6358693 
    2135   -2.9871562   -2.6541657   -2.6504695 
Loop time of 3.69427e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.0800673158949
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.73807540698182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.09319434760905
variable        y0 equal ${yi}
variable        y0 equal 0.990582271325916

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.02829797862864
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 1.07731960605416
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2135   -2.9871562   -2.6541657   -2.6504695 
    2136   -2.9871562   -2.6541657   -2.6061644 
Loop time of 3.87496e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.09319434760905
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.990582271325916
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78567172804958
variable        y0 equal ${yi}
variable        y0 equal 4.64188341254161

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.78270576516277
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.66047749871181
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2136   -2.9871562   -2.6541657   -2.6061644 
    2137   -2.9871562   -2.6541657   -2.6544228 
Loop time of 3.72663e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.65442281501059
variable naccept equal ${increment}
variable naccept equal 413

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.95845205743305
variable        y0 equal ${yi}
variable        y0 equal 8.26673827089366

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 5.87086569030277
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.18857052244243
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2137   -2.9871562   -2.6544228   -2.6544228 
    2138   -2.9871562   -2.6544228   -2.5790672 
Loop time of 3.73954e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 5.95845205743305
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.26673827089366
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.0800673158949
variable        y0 equal ${yi}
variable        y0 equal 3.73807540698182

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.11273243745023
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.8202782468332
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2138   -2.9871562   -2.6544228   -2.5790672 
    2139   -2.9871562   -2.6544228   -2.6383434 
Loop time of 3.59173e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.0800673158949
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.73807540698182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03061267732479
variable        y0 equal ${yi}
variable        y0 equal 8.28878506340082

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 7.9382041394601
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.33527191795404
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2139   -2.9871562   -2.6544228   -2.6383434 
    2140   -2.9871562   -2.6544228   -2.6435102 
Loop time of 3.63504e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.03061267732479
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.28878506340082
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.2537579540272
variable        y0 equal ${yi}
variable        y0 equal 0.909067996251911

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.2904264334698
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.826200159299702
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2140   -2.9871562   -2.6544228   -2.6435102 
    2141   -2.9871562   -2.6544228   -2.6168254 
Loop time of 3.63209e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.2537579540272
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.909067996251911
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78581515748931
variable        y0 equal ${yi}
variable        y0 equal 1.04153251241478

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.78417022426559
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.03279469798836
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2141   -2.9871562   -2.6544228   -2.6168254 
    2142   -2.9871562   -2.6544228   -2.6560049 
Loop time of 3.74941e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.65600486061613
variable naccept equal ${increment}
variable naccept equal 414

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.46464086611044
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.33087302770877
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2142   -2.9871562   -2.6560049   -2.6560049 
    2143   -2.9871562   -2.6560049   -2.6411201 
Loop time of 3.67929e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.48385869104635
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.38020931806827
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.52162269193899
variable        y0 equal ${yi}
variable        y0 equal 1.84969287297791

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.58485812980902
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.84283347508973
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2143   -2.9871562   -2.6560049   -2.6411201 
    2144   -2.9871562   -2.6560049   -2.6380111 
Loop time of 3.72918e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.52162269193899
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.84969287297791
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.87144294301158
variable        y0 equal ${yi}
variable        y0 equal 2.78142455788949

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.95031871119624
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.69382988187173
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2144   -2.9871562   -2.6560049   -2.6380111 
    2145   -2.9871562   -2.6560049   -2.6165023 
Loop time of 3.73347e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.87144294301158
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.78142455788949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.72773063063402
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.25068991102275
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2145   -2.9871562   -2.6560049   -2.6165023 
    2146   -2.9871562   -2.6560049   -2.6273866 
Loop time of 3.80834e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.88563143848715
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.56517958992884
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2146   -2.9871562   -2.6560049   -2.6273866 
    2147   -2.9871562   -2.6560049   -2.6079102 
Loop time of 3.61509e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.06206500847989
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.54715144958758
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2147   -2.9871562   -2.6560049   -2.6079102 
    2148   -2.9871562   -2.6560049   -2.6384727 
Loop time of 3.63934e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.07460362631828
variable        y0 equal ${yi}
variable        y0 equal 6.51190980211725

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.05631386954338
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.44240958229532
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2148   -2.9871562   -2.6560049   -2.6384727 
    2149   -2.9871562   -2.6560049   -2.6467524 
Loop time of 3.73232e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.07460362631828
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.51190980211725
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.81859772721415
variable        y0 equal ${yi}
variable        y0 equal 6.51868253485194

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.82902186432963
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.56671006218425
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2149   -2.9871562   -2.6560049   -2.6467524 
    2150   -2.9871562   -2.6560049   -2.6491618 
Loop time of 3.72521e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.81859772721415
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.51868253485194
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78270576516277
variable        y0 equal ${yi}
variable        y0 equal 4.66047749871181

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.8234502963174
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.69844884032177
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2150   -2.9871562   -2.6560049   -2.6491618 
    2151   -2.9871562   -2.6560049   -2.6435607 
Loop time of 3.67366e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78270576516277
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.66047749871181
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.53458213963929
variable        y0 equal ${yi}
variable        y0 equal 1.99115990779465

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.546811200766
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 2.03412101647919
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2151   -2.9871562   -2.6560049   -2.6435607 
    2152   -2.9871562   -2.6560049   -2.6394728 
Loop time of 3.64867e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.53458213963929
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.99115990779465
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.49455503065359
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.67532368464601
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2152   -2.9871562   -2.6560049   -2.6394728 
    2153   -2.9871562   -2.6560049   -2.6431006 
Loop time of 3.58227e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.41449785946924
variable        y0 equal ${yi}
variable        y0 equal 5.54428255503374

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.48261589526254
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.6048602098723
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2153   -2.9871562   -2.6560049   -2.6431006 
    2154   -2.9871562   -2.6560049   -2.6470254 
Loop time of 3.68192e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.41449785946924
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.54428255503374
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.0800673158949
variable        y0 equal ${yi}
variable        y0 equal 3.73807540698182

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.08254816849881
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.82229228778016
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2154   -2.9871562   -2.6560049   -2.6470254 
    2155   -2.9871562   -2.6560049     -2.64458 
Loop time of 3.70776e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.0800673158949
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.73807540698182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.92807142693988
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.42052541510097
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2155   -2.9871562   -2.6560049     -2.64458 
    2156   -2.9871562   -2.6560049   -2.6524967 
Loop time of 3.65758e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.5445865321028
variable        y0 equal ${yi}
variable        y0 equal 5.54097448532778

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.50823430298445
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.59881491606432
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2156   -2.9871562   -2.6560049   -2.6524967 
    2157   -2.9871562   -2.6560049   -2.6453813 
Loop time of 3.71325e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.5445865321028
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.54097448532778
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.82075489718905
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.42266584173671
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2157   -2.9871562   -2.6560049   -2.6453813 
    2158   -2.9871562   -2.6560049    -2.638128 
Loop time of 3.63849e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.35658786375734
variable        y0 equal ${yi}
variable        y0 equal 1.8282853164441

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.34203376848909
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.90096129558152
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2158   -2.9871562   -2.6560049    -2.638128 
    2159   -2.9871562   -2.6560049   -2.6457959 
Loop time of 3.69325e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.35658786375734
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.8282853164441
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.72697503765058
variable        y0 equal ${yi}
variable        y0 equal 2.78031077357629

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.79369437892866
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.76082882853845
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2159   -2.9871562   -2.6560049   -2.6457959 
    2160   -2.9871562   -2.6560049   -2.6455052 
Loop time of 3.86346e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.72697503765058
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.78031077357629
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57543257355471
variable        y0 equal ${yi}
variable        y0 equal 4.67648406380578

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.54005938648959
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.76738500946923
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2160   -2.9871562   -2.6560049   -2.6455052 
    2161   -2.9871562   -2.6560049    -2.625353 
Loop time of 3.62068e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.57543257355471
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.67648406380578
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.70790265956346
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.64100172085893
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2161   -2.9871562   -2.6560049    -2.625353 
    2162   -2.9871562   -2.6560049    -2.640234 
Loop time of 3.77575e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.25279456138173
variable        y0 equal ${yi}
variable        y0 equal 7.38214940157198

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.26551517009297
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.42613175239824
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2162   -2.9871562   -2.6560049    -2.640234 
    2163   -2.9871562   -2.6560049   -2.6595856 
Loop time of 3.60546e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.65958562572399
variable naccept equal ${increment}
variable naccept equal 415

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.32259763240376
variable        y0 equal ${yi}
variable        y0 equal 1.91972836635178

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.32135609149495
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.92942055842942
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2163   -2.9871562   -2.6595856   -2.6595856 
    2164   -2.9871562   -2.6595856   -2.6584002 
Loop time of 3.89276e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.32259763240376
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.91972836635178
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6723551591091
variable        y0 equal ${yi}
variable        y0 equal 9.27579969871372

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.7549557884388
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.18734588134617
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2164   -2.9871562   -2.6595856   -2.6584002 
    2165   -2.9871562   -2.6595856    -2.634065 
Loop time of 3.75995e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6723551591091
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.27579969871372
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.0800673158949
variable        y0 equal ${yi}
variable        y0 equal 3.73807540698182

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.15602333863431
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.81261592669618
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2165   -2.9871562   -2.6595856    -2.634065 
    2166   -2.9871562   -2.6595856    -2.628935 
Loop time of 3.73078e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.0800673158949
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.73807540698182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.24283930698738
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.87993563792771
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2166   -2.9871562   -2.6595856    -2.628935 
    2167   -2.9871562   -2.6595856   -2.6533032 
Loop time of 3.79002e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.29362520932713
variable        y0 equal ${yi}
variable        y0 equal 0.011324155330658

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.20945510625401
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.0720707654953003
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2167   -2.9871562   -2.6595856   -2.6533032 
    2168   -2.9871562   -2.6595856   -2.6211621 
Loop time of 3.63111e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.29362520932713
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.011324155330658
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.56384705462877
variable        y0 equal ${yi}
variable        y0 equal 0.0929038047790526

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.50967637458269
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.150994110107422
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2168   -2.9871562   -2.6595856   -2.6211621 
    2169   -2.9871562   -2.6595856   -2.6258734 
Loop time of 3.57281e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.56384705462877
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.0929038047790526
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.84264154393664
variable        y0 equal ${yi}
variable        y0 equal 4.64205295199321

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.89158437211505
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.70706205719875
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2169   -2.9871562   -2.6595856   -2.6258734 
    2170   -2.9871562   -2.6595856   -2.6472328 
Loop time of 3.76221e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.84264154393664
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.64205295199321
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.32259763240376
variable        y0 equal ${yi}
variable        y0 equal 1.91972836635178

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.2721233224825
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.85941118381089
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2170   -2.9871562   -2.6595856   -2.6472328 
    2171   -2.9871562   -2.6595856   -2.6494351 
Loop time of 3.7292e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.32259763240376
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.91972836635178
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.26551517009297
variable        y0 equal ${yi}
variable        y0 equal 7.42613175239824

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.26226229428807
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.49070853319429
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2171   -2.9871562   -2.6595856   -2.6494351 
    2172   -2.9871562   -2.6595856   -2.6542988 
Loop time of 3.7284e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.26551517009297
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.42613175239824
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40162080922987
variable        y0 equal ${yi}
variable        y0 equal 5.54853548948961

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.43006588617231
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.63260774557787
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2172   -2.9871562   -2.6595856   -2.6542988 
    2173   -2.9871562   -2.6595856   -2.6201573 
Loop time of 6.59303e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.40162080922987
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.54853548948961
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.90266371050522
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.27108971990642
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2173   -2.9871562   -2.6595856   -2.6201573 
    2174   -2.9871562   -2.6595856   -2.6328228 
Loop time of 3.68735e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.41449785946924
variable        y0 equal ${yi}
variable        y0 equal 5.54428255503374

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.46617823361475
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.45620604698854
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2174   -2.9871562   -2.6595856   -2.6328228 
    2175   -2.9871562   -2.6595856   -2.6386873 
Loop time of 3.81696e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.41449785946924
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.54428255503374
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.56384705462877
variable        y0 equal ${yi}
variable        y0 equal 0.0929038047790526

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.61516220727388
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.0171679377555846
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2175   -2.9871562   -2.6595856   -2.6386873 
    2176   -2.9871562   -2.6595856   -2.6456315 
Loop time of 3.79605e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.56384705462877
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.0929038047790526
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.57918032883284
variable        y0 equal ${yi}
variable        y0 equal 0.0850776791572572

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.59558219193098
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.106504940986633
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2176   -2.9871562   -2.6595856   -2.6456315 
    2177   -2.9871562   -2.6595856   -2.6587135 
Loop time of 3.79694e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.65871347043457
variable naccept equal ${increment}
variable naccept equal 416

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.35614831844235
variable        y0 equal ${yi}
variable        y0 equal 3.74340068860184

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.44880861440564
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.83790946765076
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2177   -2.9871562   -2.6587135   -2.6587135 
    2178   -2.9871562   -2.6587135    -2.583633 
Loop time of 3.69465e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.35614831844235
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.74340068860184
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.17348919509745
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.93185343715052
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2178   -2.9871562   -2.6587135    -2.583633 
    2179   -2.9871562   -2.6587135   -2.6096004 
Loop time of 3.81219e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.35614831844235
variable        y0 equal ${yi}
variable        y0 equal 3.74340068860184

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.29934437671567
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.81756913228165
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2179   -2.9871562   -2.6587135   -2.6096004 
    2180   -2.9871562   -2.6587135   -2.6339206 
Loop time of 3.69595e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.35614831844235
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.74340068860184
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.81859772721415
variable        y0 equal ${yi}
variable        y0 equal 6.51868253485194

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.73383305588847
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.58010403648844
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2180   -2.9871562   -2.6587135   -2.6339206 
    2181   -2.9871562   -2.6587135   -2.6513472 
Loop time of 3.75926e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.81859772721415
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.51868253485194
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.93805575012504
variable        y0 equal ${yi}
variable        y0 equal 8.32736837781961

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.84544412731468
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.40656472362573
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2181   -2.9871562   -2.6587135   -2.6513472 
    2182   -2.9871562   -2.6587135   -2.6438134 
Loop time of 3.7955e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.93805575012504
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.32736837781961
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.20629341322929
variable        y0 equal ${yi}
variable        y0 equal 2.76325721713403

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.12832965571434
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.81034527989724
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2182   -2.9871562   -2.6587135   -2.6438134 
    2183   -2.9871562   -2.6587135   -2.6462595 
Loop time of 4.87071e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.20629341322929
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.76325721713403
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.01612061539336
variable        y0 equal ${yi}
variable        y0 equal 2.79489908191064

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 7.00774297991439
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.80172786685327
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2183   -2.9871562   -2.6587135   -2.6462595 
    2184   -2.9871562   -2.6587135    -2.658829 
Loop time of 3.7786e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.65882898160671
variable naccept equal ${increment}
variable naccept equal 417

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6997664650136
variable        y0 equal ${yi}
variable        y0 equal 5.5742603296538

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.7957994301969
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.61603110974032
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2184   -2.9871562    -2.658829    -2.658829 
    2185   -2.9871562    -2.658829   -2.6372904 
Loop time of 3.79358e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.6997664650136
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.5742603296538
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.6573487090933
variable        y0 equal ${yi}
variable        y0 equal 7.44725758161806

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.67238969086286
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.49822200861238
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2185   -2.9871562    -2.658829   -2.6372904 
    2186   -2.9871562    -2.658829   -2.6556051 
Loop time of 3.83487e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 99 x ${x0}
set atom 99 x 9.6573487090933
  1 settings made for x
set atom $i y ${y0}
set atom 99 y ${y0}
set atom 99 y 7.44725758161806
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.0681977808366
variable        y0 equal ${yi}
variable        y0 equal 4.6233086740391

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.00911275743343
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.56628308648035
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2186   -2.9871562    -2.658829   -2.6556051 
    2187   -2.9871562    -2.658829   -2.6251603 
Loop time of 3.69436e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.0681977808366
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.6233086740391
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.09319434760905
variable        y0 equal ${yi}
variable        y0 equal 0.990582271325916

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.08551755546427
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.999508364904255
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2187   -2.9871562    -2.658829   -2.6251603 
    2188   -2.9871562    -2.658829   -2.6585371 
Loop time of 3.75713e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.09319434760905
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.990582271325916
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.81859772721415
variable        y0 equal ${yi}
variable        y0 equal 6.51868253485194

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.80706013957148
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.46486020819178
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2188   -2.9871562    -2.658829   -2.6585371 
    2189   -2.9871562    -2.658829   -2.6524322 
Loop time of 3.69263e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.81859772721415
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.51868253485194
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.53458213963929
variable        y0 equal ${yi}
variable        y0 equal 1.99115990779465

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.61535184541169
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.91233646056717
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2189   -2.9871562    -2.658829   -2.6524322 
    2190   -2.9871562    -2.658829   -2.6659724 
Loop time of 3.73416e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.66597241387253
variable naccept equal ${increment}
variable naccept equal 418

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.17300830800087
variable        y0 equal ${yi}
variable        y0 equal 1.0788206536654

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.14688937384636
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.16202245544229
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2190   -2.9871562   -2.6659724   -2.6659724 
    2191   -2.9871562   -2.6659724   -2.6170051 
Loop time of 3.74244e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.17300830800087
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.0788206536654
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.03727689066574
variable        y0 equal ${yi}
variable        y0 equal 0.91603718589577

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.10847735682175
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.83283657621178
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2191   -2.9871562   -2.6659724   -2.6170051 
    2192   -2.9871562   -2.6659724   -2.6347685 
Loop time of 3.76488e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.03727689066574
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.91603718589577
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7044513543301
variable        y0 equal ${yi}
variable        y0 equal 7.41026051368976

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.7227375467472
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.42429340210224
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2192   -2.9871562   -2.6659724   -2.6347685 
    2193   -2.9871562   -2.6659724   -2.6677719 
Loop time of 3.68684e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.66777191352139
variable naccept equal ${increment}
variable naccept equal 419

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 7.06777529993698
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.27232322610912
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2193   -2.9871562   -2.6677719   -2.6677719 
    2194   -2.9871562   -2.6677719     -2.64149 
Loop time of 3.80986e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.86155322073576
variable        y0 equal ${yi}
variable        y0 equal 1.87893718860216

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.80676798103926
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.97731651446886
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2194   -2.9871562   -2.6677719     -2.64149 
    2195   -2.9871562   -2.6677719   -2.6592931 
Loop time of 3.7015e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.86155322073576
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.87893718860216
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.95845205743305
variable        y0 equal ${yi}
variable        y0 equal 8.26673827089366

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 5.87722619731418
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.31555507101115
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2195   -2.9871562   -2.6677719   -2.6592931 
    2196   -2.9871562   -2.6677719    -2.638941 
Loop time of 3.81049e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 5.95845205743305
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.26673827089366
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.34856292088243
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.62419816200931
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2196   -2.9871562   -2.6677719    -2.638941 
    2197   -2.9871562   -2.6677719   -2.6631414 
Loop time of 3.69282e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.26551517009297
variable        y0 equal ${yi}
variable        y0 equal 7.42613175239824

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.18997851371327
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.3539776000049
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2197   -2.9871562   -2.6677719   -2.6631414 
    2198   -2.9871562   -2.6677719   -2.6503034 
Loop time of 3.56529e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.26551517009297
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.42613175239824
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.07473099826671
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.53918174044122
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2198   -2.9871562   -2.6677719   -2.6503034 
    2199   -2.9871562   -2.6677719    -2.666883 
Loop time of 3.62824e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.90249328572741
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.40160054699413
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2199   -2.9871562   -2.6677719    -2.666883 
    2200   -2.9871562   -2.6677719   -2.6604692 
Loop time of 3.64906e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.89402630288592
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.43323876396648
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20813699721852
variable        y0 equal ${yi}
variable        y0 equal 5.56420804207521

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.13534556388417
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.57540353481966
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2200   -2.9871562   -2.6677719   -2.6604692 
    2201   -2.9871562   -2.6677719   -2.6526908 
Loop time of 3.63609e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20813699721852
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56420804207521
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.17300830800087
variable        y0 equal ${yi}
variable        y0 equal 1.0788206536654

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.24387972075493
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.00732823203836
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2201   -2.9871562   -2.6677719   -2.6526908 
    2202   -2.9871562   -2.6677719   -2.6524157 
Loop time of 3.57803e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.17300830800087
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.0788206536654
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6723551591091
variable        y0 equal ${yi}
variable        y0 equal 9.27579969871372

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.7646246512585
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.18346900451511
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2202   -2.9871562   -2.6677719   -2.6524157 
    2203   -2.9871562   -2.6677719    -2.637675 
Loop time of 3.71696e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6723551591091
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.27579969871372
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.17300830800087
variable        y0 equal ${yi}
variable        y0 equal 1.0788206536654

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.25320626217873
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.12858913730416
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2203   -2.9871562   -2.6677719    -2.637675 
    2204   -2.9871562   -2.6677719    -2.644568 
Loop time of 3.65164e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.17300830800087
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.0788206536654
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.87144294301158
variable        y0 equal ${yi}
variable        y0 equal 2.78142455788949

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.82528075495845
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.87891086312631
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2204   -2.9871562   -2.6677719    -2.644568 
    2205   -2.9871562   -2.6677719   -2.6450446 
Loop time of 3.76e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.87144294301158
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.78142455788949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.8900455796653
variable        y0 equal ${yi}
variable        y0 equal 0.887486429918145

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.97368628620445
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.877779420125817
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2205   -2.9871562   -2.6677719   -2.6450446 
    2206   -2.9871562   -2.6677719   -2.6607924 
Loop time of 3.62423e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.8900455796653
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.887486429918145
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 7.01451349535629
variable        y0 equal ${yi}
variable        y0 equal 4.67800829762385

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.96750459948227
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.76832328194544
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2206   -2.9871562   -2.6677719   -2.6607924 
    2207   -2.9871562   -2.6677719   -2.6389242 
Loop time of 3.63686e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 7.01451349535629
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.67800829762385
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.75591478546096
variable        y0 equal ${yi}
variable        y0 equal 4.61056455725595

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.73731143672897
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.63249358290597
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2207   -2.9871562   -2.6677719   -2.6389242 
    2208   -2.9871562   -2.6677719   -2.6714092 
Loop time of 3.73941e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.67140919494654
variable naccept equal ${increment}
variable naccept equal 420

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 5.97854424674504
variable        y0 equal ${yi}
variable        y0 equal 0.914465494859546

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 5.90900083739751
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.980252214181751
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2208   -2.9871562   -2.6714092   -2.6714092 
    2209   -2.9871562   -2.6714092   -2.6522959 
Loop time of 3.6899e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 5.97854424674504
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.914465494859546
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.8900455796653
variable        y0 equal ${yi}
variable        y0 equal 0.887486429918145

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.8511542642051
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.896845050561761
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2209   -2.9871562   -2.6714092   -2.6522959 
    2210   -2.9871562   -2.6714092   -2.6656372 
Loop time of 3.71499e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.8900455796653
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.887486429918145
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.36733620245668
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.65996341271531
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2210   -2.9871562   -2.6714092   -2.6656372 
    2211   -2.9871562   -2.6714092   -2.6548912 
Loop time of 3.60297e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.64136810183306
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.57870021597376
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2211   -2.9871562   -2.6714092   -2.6548912 
    2212   -2.9871562   -2.6714092   -2.6595818 
Loop time of 3.78716e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03143052180462
variable        y0 equal ${yi}
variable        y0 equal 5.57988774721818

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 1.05722635110073
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.54122086708741
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2212   -2.9871562   -2.6714092   -2.6595818 
    2213   -2.9871562   -2.6714092   -2.6635266 
Loop time of 3.6898e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03143052180462
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.57988774721818
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.20514718373033
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.67354568188388
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2213   -2.9871562   -2.6714092   -2.6635266 
    2214   -2.9871562   -2.6714092    -2.623171 
Loop time of 3.58719e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.63926322340747
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.47733454243174
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2214   -2.9871562   -2.6714092    -2.623171 
    2215   -2.9871562   -2.6714092   -2.6644503 
Loop time of 3.63254e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.594005592265989
variable        y0 equal ${yi}
variable        y0 equal 2.84451084109644

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.657034964958097
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.89678043099741
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2215   -2.9871562   -2.6714092   -2.6644503 
    2216   -2.9871562   -2.6714092    -2.631227 
Loop time of 3.68701e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.594005592265989
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.84451084109644
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.95845205743305
variable        y0 equal ${yi}
variable        y0 equal 8.26673827089366

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 5.95759859044544
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.17448389448222
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2216   -2.9871562   -2.6714092    -2.631227 
    2217   -2.9871562   -2.6714092    -2.636746 
Loop time of 3.56798e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 5.95845205743305
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.26673827089366
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.0999975744854
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.44526999321246
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2217   -2.9871562   -2.6714092    -2.636746 
    2218   -2.9871562   -2.6714092   -2.6577398 
Loop time of 3.66412e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.20629341322929
variable        y0 equal ${yi}
variable        y0 equal 2.76325721713403

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.14514404255897
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.67524182769159
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2218   -2.9871562   -2.6714092   -2.6577398 
    2219   -2.9871562   -2.6714092   -2.6307112 
Loop time of 3.75901e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.20629341322929
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.76325721713403
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.37309358198854
variable        y0 equal ${yi}
variable        y0 equal 7.47418843832278

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.3633610018036
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.53956960764193
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2219   -2.9871562   -2.6714092   -2.6307112 
    2220   -2.9871562   -2.6714092    -2.646965 
Loop time of 3.73408e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.37309358198854
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.47418843832278
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.44055470942574
variable        y0 equal ${yi}
variable        y0 equal 7.31046043958926

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.4123530340107
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.30801072445178
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2220   -2.9871562   -2.6714092    -2.646965 
    2221   -2.9871562   -2.6714092   -2.6655065 
Loop time of 3.7264e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.44055470942574
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.31046043958926
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.3269280560753
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.79774907393586
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2221   -2.9871562   -2.6714092   -2.6655065 
    2222   -2.9871562   -2.6714092   -2.6578135 
Loop time of 3.67791e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.506249304214384
variable        y0 equal ${yi}
variable        y0 equal 6.52357215420237

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.448950298229124
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.52538252607813
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2222   -2.9871562   -2.6714092   -2.6578135 
    2223   -2.9871562   -2.6714092    -2.666387 
Loop time of 3.63797e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.506249304214384
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.52357215420237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.65424995302935
variable        y0 equal ${yi}
variable        y0 equal 0.940276082265705

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.67225340485354
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.841793330419392
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2223   -2.9871562   -2.6714092    -2.666387 
    2224   -2.9871562   -2.6714092   -2.6572305 
Loop time of 3.62958e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.65424995302935
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.940276082265705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.29362520932713
variable        y0 equal ${yi}
variable        y0 equal 0.011324155330658

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.30867275952855
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.0918933749198914
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2224   -2.9871562   -2.6714092   -2.6572305 
    2225   -2.9871562   -2.6714092   -2.6514103 
Loop time of 3.78615e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.29362520932713
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.011324155330658
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.75233793139239
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.33678269304332
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2225   -2.9871562   -2.6714092   -2.6514103 
    2226   -2.9871562   -2.6714092   -2.6618109 
Loop time of 3.65453e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.61535184541169
variable        y0 equal ${yi}
variable        y0 equal 1.91233646056717

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.53489669719163
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.9021213092572
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2226   -2.9871562   -2.6714092   -2.6618109 
    2227   -2.9871562   -2.6714092   -2.6666484 
Loop time of 3.6453e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.61535184541169
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.91233646056717
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.27337521950113
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 0.0801766753196748
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2227   -2.9871562   -2.6714092   -2.6666484 
    2228   -2.9871562   -2.6714092    -2.664013 
Loop time of 3.7238e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.67481106718016
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.42543584839335
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2228   -2.9871562   -2.6714092    -2.664013 
    2229   -2.9871562   -2.6714092   -2.6631668 
Loop time of 3.73705e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.47866305827219
variable        y0 equal ${yi}
variable        y0 equal 9.25160747278063

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.39451258896906
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.30999001968233
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2229   -2.9871562   -2.6714092   -2.6631668 
    2230   -2.9871562   -2.6714092   -2.6402453 
Loop time of 3.76761e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.47866305827219
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.25160747278063
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.7183762061574
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.29956148780879
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2230   -2.9871562   -2.6714092   -2.6402453 
    2231   -2.9871562   -2.6714092   -2.6633198 
Loop time of 3.80841e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.89402630288592
variable        y0 equal ${yi}
variable        y0 equal 6.43323876396648

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.88880834538928
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.44203974739543
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2231   -2.9871562   -2.6714092   -2.6633198 
    2232   -2.9871562   -2.6714092   -2.6718751 
Loop time of 3.74002e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.67187506884729
variable naccept equal ${increment}
variable naccept equal 421

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.46636033772546
variable        y0 equal ${yi}
variable        y0 equal 3.78071368498932

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.54323086260873
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.75561791224609
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2232   -2.9871562   -2.6718751   -2.6718751 
    2233   -2.9871562   -2.6718751   -2.6618421 
Loop time of 3.67275e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.46636033772546
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.78071368498932
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.61455693402712
variable        y0 equal ${yi}
variable        y0 equal 7.4608101996448

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.63414751449053
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.36404285755419
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2233   -2.9871562   -2.6718751   -2.6618421 
    2234   -2.9871562   -2.6718751   -2.6495171 
Loop time of 3.7844e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.61455693402712
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.4608101996448
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.64341646590654
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.67369483275545
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2234   -2.9871562   -2.6718751   -2.6495171 
    2235   -2.9871562   -2.6718751   -2.6671412 
Loop time of 3.71216e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.81859772721415
variable        y0 equal ${yi}
variable        y0 equal 6.51868253485194

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.84056249180918
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.56555977598658
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2235   -2.9871562   -2.6718751   -2.6671412 
    2236   -2.9871562   -2.6718751   -2.6646529 
Loop time of 3.79929e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.81859772721415
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.51868253485194
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.33724620421144
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.54337495510776
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2236   -2.9871562   -2.6718751   -2.6646529 
    2237   -2.9871562   -2.6718751   -2.6650051 
Loop time of 3.73116e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.72042853473959
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.59498741978571
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2237   -2.9871562   -2.6718751   -2.6650051 
    2238   -2.9871562   -2.6718751   -2.6263355 
Loop time of 3.59467e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.01995963175946
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.37597310867571
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2238   -2.9871562   -2.6718751   -2.6263355 
    2239   -2.9871562   -2.6718751   -2.6564094 
Loop time of 3.70977e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.61535184541169
variable        y0 equal ${yi}
variable        y0 equal 1.91233646056717

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.51639036097947
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.87305103919571
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2239   -2.9871562   -2.6718751   -2.6564094 
    2240   -2.9871562   -2.6718751   -2.6529745 
Loop time of 3.62761e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.61535184541169
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.91233646056717
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.65424995302935
variable        y0 equal ${yi}
variable        y0 equal 0.940276082265705

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.71429031967898
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.95249400924477
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2240   -2.9871562   -2.6718751   -2.6529745 
    2241   -2.9871562   -2.6718751   -2.6678814 
Loop time of 3.61874e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.65424995302935
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.940276082265705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 5.97854424674504
variable        y0 equal ${yi}
variable        y0 equal 0.914465494859546

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 5.94833642203801
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.855036564576953
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2241   -2.9871562   -2.6718751   -2.6678814 
    2242   -2.9871562   -2.6718751   -2.6685922 
Loop time of 3.80923e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 5.97854424674504
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.914465494859546
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.87144294301158
variable        y0 equal ${yi}
variable        y0 equal 2.78142455788949

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.79431719103938
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.83537367555001
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2242   -2.9871562   -2.6718751   -2.6685922 
    2243   -2.9871562   -2.6718751   -2.6634707 
Loop time of 3.71533e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.87144294301158
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.78142455788949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.73481046159697
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.39090879694453
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2243   -2.9871562   -2.6718751   -2.6634707 
    2244   -2.9871562   -2.6718751   -2.6437903 
Loop time of 3.64079e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.07460362631828
variable        y0 equal ${yi}
variable        y0 equal 6.51190980211725

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.14473947007209
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.60933053032388
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2244   -2.9871562   -2.6718751   -2.6437903 
    2245   -2.9871562   -2.6718751   -2.6465099 
Loop time of 3.88941e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.07460362631828
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.51190980211725
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.84038932839518
variable        y0 equal ${yi}
variable        y0 equal 8.35802853025493

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.87159228840952
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.27844805635509
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2245   -2.9871562   -2.6718751   -2.6465099 
    2246   -2.9871562   -2.6718751   -2.6430607 
Loop time of 3.66539e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.84038932839518
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.35802853025493
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.1955849651357
variable        y0 equal ${yi}
variable        y0 equal 4.64925400370525

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.1436875466367
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.63680539482998
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2246   -2.9871562   -2.6718751   -2.6430607 
    2247   -2.9871562   -2.6718751   -2.6689449 
Loop time of 3.60716e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.1955849651357
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.64925400370525
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.52162269193899
variable        y0 equal ${yi}
variable        y0 equal 1.84969287297791

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.49493138630163
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.85551903626984
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2247   -2.9871562   -2.6718751   -2.6689449 
    2248   -2.9871562   -2.6718751   -2.6674619 
Loop time of 3.65307e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.52162269193899
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.84969287297791
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.44055470942574
variable        y0 equal ${yi}
variable        y0 equal 7.31046043958926

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.38751481293755
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.36960257616305
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2248   -2.9871562   -2.6718751   -2.6674619 
    2249   -2.9871562   -2.6718751   -2.6554945 
Loop time of 3.64975e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.44055470942574
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.31046043958926
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.86155322073576
variable        y0 equal ${yi}
variable        y0 equal 1.87893718860216

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.90462205885527
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.7860442914731
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2249   -2.9871562   -2.6718751   -2.6554945 
    2250   -2.9871562   -2.6718751   -2.6191725 
Loop time of 3.72565e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.86155322073576
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.87893718860216
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.35614831844235
variable        y0 equal ${yi}
variable        y0 equal 3.74340068860184

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.39058380523587
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.77845866246353
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2250   -2.9871562   -2.6718751   -2.6191725 
    2251   -2.9871562   -2.6718751   -2.6661188 
Loop time of 3.72956e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.35614831844235
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.74340068860184
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.84264154393664
variable        y0 equal ${yi}
variable        y0 equal 4.64205295199321

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.92973343093386
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.74003593081401
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2251   -2.9871562   -2.6718751   -2.6661188 
    2252   -2.9871562   -2.6718751   -2.6329387 
Loop time of 3.68985e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.84264154393664
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.64205295199321
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.13120705524789
variable        y0 equal ${yi}
variable        y0 equal 3.79238885207306

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.07820982376443
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.72940481467377
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2252   -2.9871562   -2.6718751   -2.6329387 
    2253   -2.9871562   -2.6718751   -2.6617457 
Loop time of 3.67529e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.13120705524789
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.79238885207306
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57543257355471
variable        y0 equal ${yi}
variable        y0 equal 4.67648406380578

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.48381194948931
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.64040416830941
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2253   -2.9871562   -2.6718751   -2.6617457 
    2254   -2.9871562   -2.6718751    -2.638075 
Loop time of 4.04071e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.57543257355471
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.67648406380578
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.80562662720022
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.61696473711893
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2254   -2.9871562   -2.6718751    -2.638075 
    2255   -2.9871562   -2.6718751   -2.6672458 
Loop time of 3.82104e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.13385775724754
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.39633448448443
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2255   -2.9871562   -2.6718751   -2.6672458 
    2256   -2.9871562   -2.6718751   -2.6663605 
Loop time of 3.74376e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.32259763240376
variable        y0 equal ${yi}
variable        y0 equal 1.91972836635178

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.29496103286305
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.93479351184433
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2256   -2.9871562   -2.6718751   -2.6663605 
    2257   -2.9871562   -2.6718751   -2.6708822 
Loop time of 3.69389e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.32259763240376
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.91972836635178
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7227375467472
variable        y0 equal ${yi}
variable        y0 equal 7.42429340210224

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.7073550899677
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.45095640745426
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2257   -2.9871562   -2.6718751   -2.6708822 
    2258   -2.9871562   -2.6718751   -2.6729846 
Loop time of 3.71316e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.67298455748229
variable naccept equal ${increment}
variable naccept equal 422

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.51431344628115
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.5140686346673
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2258   -2.9871562   -2.6729846   -2.6729846 
    2259   -2.9871562   -2.6729846   -2.6646495 
Loop time of 3.68324e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 6.99216622391388
variable        y0 equal ${yi}
variable        y0 equal 6.45942620769968

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.02731006422684
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.50495733753672
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2259   -2.9871562   -2.6729846   -2.6646495 
    2260   -2.9871562   -2.6729846   -2.6610821 
Loop time of 3.78171e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 6.99216622391388
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.45942620769968
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.35614831844235
variable        y0 equal ${yi}
variable        y0 equal 3.74340068860184

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.32879668870831
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.65885418219696
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2260   -2.9871562   -2.6729846   -2.6610821 
    2261   -2.9871562   -2.6729846   -2.6325939 
Loop time of 3.75201e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.35614831844235
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.74340068860184
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.50875395376456
variable        y0 equal ${yi}
variable        y0 equal 5.60411881153779

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.49580335457099
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.67440532391267
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2261   -2.9871562   -2.6729846   -2.6325939 
    2262   -2.9871562   -2.6729846   -2.6435328 
Loop time of 3.64336e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.50875395376456
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.60411881153779
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.93335930942831
variable        y0 equal ${yi}
variable        y0 equal 2.82367047044137

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.99649060606298
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.77246708842614
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2262   -2.9871562   -2.6729846   -2.6435328 
    2263   -2.9871562   -2.6729846    -2.655961 
Loop time of 3.61978e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.93335930942831
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.82367047044137
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.11292224565849
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.96759807250565
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2263   -2.9871562   -2.6729846    -2.655961 
    2264   -2.9871562   -2.6729846   -2.6505507 
Loop time of 3.77459e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.594005592265989
variable        y0 equal ${yi}
variable        y0 equal 2.84451084109644

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.656066294113065
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.90200573178629
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2264   -2.9871562   -2.6729846   -2.6505507 
    2265   -2.9871562   -2.6729846   -2.6300637 
Loop time of 3.76375e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.594005592265989
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.84451084109644
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.61455693402712
variable        y0 equal ${yi}
variable        y0 equal 7.4608101996448

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.67079286733095
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.40262966480517
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2265   -2.9871562   -2.6729846   -2.6300637 
    2266   -2.9871562   -2.6729846   -2.6562604 
Loop time of 3.6084e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.61455693402712
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.4608101996448
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.73731143672897
variable        y0 equal ${yi}
variable        y0 equal 4.63249358290597

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.65598988731338
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.71969579810067
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2266   -2.9871562   -2.6729846   -2.6562604 
    2267   -2.9871562   -2.6729846   -2.6612626 
Loop time of 3.64302e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.73731143672897
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.63249358290597
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.594005592265989
variable        y0 equal ${yi}
variable        y0 equal 2.84451084109644

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.514486737647917
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.79834744902948
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2267   -2.9871562   -2.6729846   -2.6612626 
    2268   -2.9871562   -2.6729846   -2.6587338 
Loop time of 3.716e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.594005592265989
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.84451084109644
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.76264746387434
variable        y0 equal ${yi}
variable        y0 equal 8.40153711952266

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.79985871513319
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.48744980014857
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2268   -2.9871562   -2.6729846   -2.6587338 
    2269   -2.9871562   -2.6729846    -2.645366 
Loop time of 3.79683e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.76264746387434
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.40153711952266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.44636772075559
variable        y0 equal ${yi}
variable        y0 equal 9.24993084180682

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.48422375121976
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.19649617183535
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2269   -2.9871562   -2.6729846    -2.645366 
    2270   -2.9871562   -2.6729846   -2.6619173 
Loop time of 3.72065e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.44636772075559
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.24993084180682
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.62633978009005
variable        y0 equal ${yi}
variable        y0 equal 2.82587088319162

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.72184579252978
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.74577376815179
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2270   -2.9871562   -2.6729846   -2.6619173 
    2271   -2.9871562   -2.6729846   -2.6408618 
Loop time of 3.66909e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.62633978009005
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.82587088319162
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.5698231800295
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.69108985228669
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2271   -2.9871562   -2.6729846   -2.6408618 
    2272   -2.9871562   -2.6729846   -2.6567978 
Loop time of 3.68819e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.17300830800087
variable        y0 equal ${yi}
variable        y0 equal 1.0788206536654

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.15179902035744
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.09486138414178
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2272   -2.9871562   -2.6729846   -2.6567978 
    2273   -2.9871562   -2.6729846   -2.6663677 
Loop time of 3.6978e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.17300830800087
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.0788206536654
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20813699721852
variable        y0 equal ${yi}
variable        y0 equal 5.56420804207521

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.28146183251897
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.57411711161333
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2273   -2.9871562   -2.6729846   -2.6663677 
    2274   -2.9871562   -2.6729846   -2.6668257 
Loop time of 3.64871e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20813699721852
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56420804207521
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.506249304214384
variable        y0 equal ${yi}
variable        y0 equal 6.52357215420237

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.570884032646086
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.58860759273997
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2274   -2.9871562   -2.6729846   -2.6668257 
    2275   -2.9871562   -2.6729846   -2.6561807 
Loop time of 3.63424e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.506249304214384
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.52357215420237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0712319020292
variable        y0 equal ${yi}
variable        y0 equal 8.4037723175436

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.0469673279783
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.43959461368618
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2275   -2.9871562   -2.6729846   -2.6561807 
    2276   -2.9871562   -2.6729846   -2.6690725 
Loop time of 3.70317e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.0712319020292
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.4037723175436
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.41189446607057
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.55011788552003
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2276   -2.9871562   -2.6729846   -2.6690725 
    2277   -2.9871562   -2.6729846   -2.6052429 
Loop time of 3.6633e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.26551517009297
variable        y0 equal ${yi}
variable        y0 equal 7.42613175239824

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.26206803082982
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.3751387032535
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2277   -2.9871562   -2.6729846   -2.6052429 
    2278   -2.9871562   -2.6729846   -2.6683291 
Loop time of 3.68239e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.26551517009297
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.42613175239824
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.49662729024011
variable        y0 equal ${yi}
variable        y0 equal 1.85665681741302

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.58806014775354
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.76381545445983
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2278   -2.9871562   -2.6729846   -2.6683291 
    2279   -2.9871562   -2.6729846   -2.6178597 
Loop time of 3.69067e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.49662729024011
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.85665681741302
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.87144294301158
variable        y0 equal ${yi}
variable        y0 equal 2.78142455788949

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.8548615626443
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.69863684150079
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2279   -2.9871562   -2.6729846   -2.6178597 
    2280   -2.9871562   -2.6729846   -2.6422597 
Loop time of 3.87292e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.87144294301158
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.78142455788949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.1955849651357
variable        y0 equal ${yi}
variable        y0 equal 4.64925400370525

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.203212833788
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.5866992270367
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2280   -2.9871562   -2.6729846   -2.6422597 
    2281   -2.9871562   -2.6729846   -2.6619591 
Loop time of 3.6321e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.1955849651357
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.64925400370525
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.52962652325412
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.52457971111765
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2281   -2.9871562   -2.6729846   -2.6619591 
    2282   -2.9871562   -2.6729846   -2.6683885 
Loop time of 3.67482e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.58949572920581
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.479384608426
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2282   -2.9871562   -2.6729846   -2.6683885 
    2283   -2.9871562   -2.6729846   -2.6717151 
Loop time of 3.61924e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40162080922987
variable        y0 equal ${yi}
variable        y0 equal 5.54853548948961

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.49731223979856
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.45648838226991
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2283   -2.9871562   -2.6729846   -2.6717151 
    2284   -2.9871562   -2.6729846   -2.5367537 
Loop time of 6.60617e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.40162080922987
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.54853548948961
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.26551517009297
variable        y0 equal ${yi}
variable        y0 equal 7.42613175239824

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.32538952588597
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.50787601795458
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2284   -2.9871562   -2.6729846   -2.5367537 
    2285   -2.9871562   -2.6729846   -2.6583349 
Loop time of 3.68953e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.26551517009297
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.42613175239824
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.44636772075559
variable        y0 equal ${yi}
variable        y0 equal 9.24993084180682

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.37882771888639
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.21894497382968
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2285   -2.9871562   -2.6729846   -2.6583349 
    2286   -2.9871562   -2.6729846   -2.6581941 
Loop time of 3.85581e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.44636772075559
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.24993084180682
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.31198827107164
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.63901069922578
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2286   -2.9871562   -2.6729846   -2.6581941 
    2287   -2.9871562   -2.6729846   -2.6523725 
Loop time of 3.76636e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.27630655844423
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.79569992585313
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2287   -2.9871562   -2.6729846   -2.6523725 
    2288   -2.9871562   -2.6729846   -2.6589065 
Loop time of 3.74641e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.49662729024011
variable        y0 equal ${yi}
variable        y0 equal 1.85665681741302

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.51151188134271
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.78456678769653
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2288   -2.9871562   -2.6729846   -2.6589065 
    2289   -2.9871562   -2.6729846    -2.661577 
Loop time of 3.76363e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.49662729024011
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.85665681741302
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.56978323340197
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.28362710393962
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2289   -2.9871562   -2.6729846    -2.661577 
    2290   -2.9871562   -2.6729846   -2.6551788 
Loop time of 3.67506e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.76264746387434
variable        y0 equal ${yi}
variable        y0 equal 8.40153711952266

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.71348672111464
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.32691235460338
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2290   -2.9871562   -2.6729846   -2.6551788 
    2291   -2.9871562   -2.6729846   -2.6693948 
Loop time of 3.65987e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.76264746387434
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.40153711952266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20813699721852
variable        y0 equal ${yi}
variable        y0 equal 5.56420804207521

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.16870188474217
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.55743454640108
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2291   -2.9871562   -2.6729846   -2.6693948 
    2292   -2.9871562   -2.6729846   -2.6667241 
Loop time of 3.60671e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20813699721852
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56420804207521
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.527254207530881
variable        y0 equal ${yi}
variable        y0 equal 4.66832068318292

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.567865975299741
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.57908083552285
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2292   -2.9871562   -2.6729846   -2.6667241 
    2293   -2.9871562   -2.6729846   -2.6530679 
Loop time of 3.63522e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.527254207530881
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.66832068318292
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.6573487090933
variable        y0 equal ${yi}
variable        y0 equal 7.44725758161806

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.66450000284788
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.45106340971254
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2293   -2.9871562   -2.6729846   -2.6530679 
    2294   -2.9871562   -2.6729846   -2.6723594 
Loop time of 3.72651e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 99 x ${x0}
set atom 99 x 9.6573487090933
  1 settings made for x
set atom $i y ${y0}
set atom 99 y ${y0}
set atom 99 y 7.44725758161806
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 7.98431548475124
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.49266756311883
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2294   -2.9871562   -2.6729846   -2.6723594 
    2295   -2.9871562   -2.6729846   -2.6618697 
Loop time of 3.69669e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.32259763240376
variable        y0 equal ${yi}
variable        y0 equal 1.91972836635178

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.31291488170186
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.99705028913086
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2295   -2.9871562   -2.6729846   -2.6618697 
    2296   -2.9871562   -2.6729846   -2.6464213 
Loop time of 3.77098e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.32259763240376
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.91972836635178
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.53518514513751
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.49616578356257
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2296   -2.9871562   -2.6729846   -2.6464213 
    2297   -2.9871562   -2.6729846   -2.6686821 
Loop time of 3.63815e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 1.10092277844601
variable        y0 equal ${yi}
variable        y0 equal 9.22189815748065

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 1.00309595187359
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.14965434778064
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2297   -2.9871562   -2.6729846   -2.6686821 
    2298   -2.9871562   -2.6729846   -2.6528142 
Loop time of 3.78637e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 1.10092277844601
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.22189815748065
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.95499547997162
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.35248234190044
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2298   -2.9871562   -2.6729846   -2.6528142 
    2299   -2.9871562   -2.6729846   -2.6662426 
Loop time of 3.76865e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.86155322073576
variable        y0 equal ${yi}
variable        y0 equal 1.87893718860216

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.77342478512403
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.78243672034807
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2299   -2.9871562   -2.6729846   -2.6662426 
    2300   -2.9871562   -2.6729846   -2.6362578 
Loop time of 3.68754e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.86155322073576
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.87893718860216
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.08294332662925
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.8223093905217
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2300   -2.9871562   -2.6729846   -2.6362578 
    2301   -2.9871562   -2.6729846   -2.6416462 
Loop time of 3.73441e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.56384705462877
variable        y0 equal ${yi}
variable        y0 equal 0.0929038047790526

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.58814150252763
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.100607442855835
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2301   -2.9871562   -2.6729846   -2.6416462 
    2302   -2.9871562   -2.6729846   -2.6716334 
Loop time of 3.76646e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.56384705462877
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.0929038047790526
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.06469420512372
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.42712385978961
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2302   -2.9871562   -2.6729846   -2.6716334 
    2303   -2.9871562   -2.6729846   -2.6720852 
Loop time of 3.63514e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.53207862217199
variable        y0 equal ${yi}
variable        y0 equal 9.2839910458359

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.5907154424883
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.22536756503909
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2303   -2.9871562   -2.6729846   -2.6720852 
    2304   -2.9871562   -2.6729846    -2.662729 
Loop time of 3.72292e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.53207862217199
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.2839910458359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.35614831844235
variable        y0 equal ${yi}
variable        y0 equal 3.74340068860184

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.32121854225064
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.72184736294876
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2304   -2.9871562   -2.6729846    -2.662729 
    2305   -2.9871562   -2.6729846   -2.6635695 
Loop time of 3.65971e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.35614831844235
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.74340068860184
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.13120705524789
variable        y0 equal ${yi}
variable        y0 equal 3.79238885207306

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.14945381323205
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.70534809394013
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2305   -2.9871562   -2.6729846   -2.6635695 
    2306   -2.9871562   -2.6729846   -2.6756863 
Loop time of 3.72974e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.67568632080883
variable naccept equal ${increment}
variable naccept equal 423

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.84264154393664
variable        y0 equal ${yi}
variable        y0 equal 4.64205295199321

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.78621327836505
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.68440955037044
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2306   -2.9871562   -2.6756863   -2.6756863 
    2307   -2.9871562   -2.6756863   -2.6434755 
Loop time of 3.67776e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.84264154393664
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.64205295199321
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 6.99216622391388
variable        y0 equal ${yi}
variable        y0 equal 6.45942620769968

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 6.94859248676941
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.54019752279749
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2307   -2.9871562   -2.6756863   -2.6434755 
    2308   -2.9871562   -2.6756863   -2.6344528 
Loop time of 3.67105e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 6.99216622391388
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.45942620769968
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.566282685199644
variable        y0 equal ${yi}
variable        y0 equal 0.865556212175219

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.484325714507963
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.82197892259392
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2308   -2.9871562   -2.6756863   -2.6344528 
    2309   -2.9871562   -2.6756863   -2.6542766 
Loop time of 3.6771e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.566282685199644
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.865556212175219
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 7.01451349535629
variable        y0 equal ${yi}
variable        y0 equal 4.67800829762385

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.99489848890945
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.67387059086726
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2309   -2.9871562   -2.6756863   -2.6542766 
    2310   -2.9871562   -2.6756863   -2.6763688 
Loop time of 3.5725e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.6763687909158
variable naccept equal ${increment}
variable naccept equal 424

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.97221836128876
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.37232592023906
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2310   -2.9871562   -2.6763688   -2.6763688 
    2311   -2.9871562   -2.6763688   -2.6696161 
Loop time of 3.75871e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.07460362631828
variable        y0 equal ${yi}
variable        y0 equal 6.51190980211725

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.02629937846214
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.44408112303247
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2311   -2.9871562   -2.6763688   -2.6696161 
    2312   -2.9871562   -2.6763688   -2.6562379 
Loop time of 3.60191e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.07460362631828
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.51190980211725
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.75275200803709
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.39206984774104
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2312   -2.9871562   -2.6763688   -2.6562379 
    2313   -2.9871562   -2.6763688   -2.6446471 
Loop time of 3.77234e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.58132318416063
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.48498797362046
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2313   -2.9871562   -2.6763688   -2.6446471 
    2314   -2.9871562   -2.6763688   -2.6576741 
Loop time of 3.77318e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.44170257010881
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.60829119627671
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2314   -2.9871562   -2.6763688   -2.6576741 
    2315   -2.9871562   -2.6763688   -2.6412605 
Loop time of 3.75914e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.57093035140459
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.65730388922823
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2315   -2.9871562   -2.6763688   -2.6412605 
    2316   -2.9871562   -2.6763688    -2.632432 
Loop time of 3.6781e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.03727689066574
variable        y0 equal ${yi}
variable        y0 equal 0.91603718589577

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.05782242098495
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.828289802778094
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2316   -2.9871562   -2.6763688    -2.632432 
    2317   -2.9871562   -2.6763688   -2.6607201 
Loop time of 3.78677e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.03727689066574
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.91603718589577
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78270576516277
variable        y0 equal ${yi}
variable        y0 equal 4.66047749871181

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.76157131711132
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.73584933632778
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2317   -2.9871562   -2.6763688   -2.6607201 
    2318   -2.9871562   -2.6763688   -2.6626113 
Loop time of 3.66693e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78270576516277
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.66047749871181
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3012223724386
variable        y0 equal ${yi}
variable        y0 equal 2.8246198293815

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.2080015782377
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.84165590974191
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2318   -2.9871562   -2.6763688   -2.6626113 
    2319   -2.9871562   -2.6763688   -2.6625446 
Loop time of 3.65126e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3012223724386
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.8246198293815
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6723551591091
variable        y0 equal ${yi}
variable        y0 equal 9.27579969871372

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.6536255200558
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.28901371467441
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2319   -2.9871562   -2.6763688   -2.6625446 
    2320   -2.9871562   -2.6763688   -2.6727203 
Loop time of 3.66016e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6723551591091
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.27579969871372
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.50875395376456
variable        y0 equal ${yi}
variable        y0 equal 5.60411881153779

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.48443332750571
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.67331243698792
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2320   -2.9871562   -2.6763688   -2.6727203 
    2321   -2.9871562   -2.6763688   -2.6437173 
Loop time of 3.64854e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.50875395376456
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.60411881153779
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.8900455796653
variable        y0 equal ${yi}
variable        y0 equal 0.887486429918145

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.8086456382209
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.921908815610741
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2321   -2.9871562   -2.6763688   -2.6437173 
    2322   -2.9871562   -2.6763688   -2.6550776 
Loop time of 3.57717e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.8900455796653
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.887486429918145
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.1372151497861
variable        y0 equal ${yi}
variable        y0 equal 6.56728928820123

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.1904323581716
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.63526829020013
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2322   -2.9871562   -2.6763688   -2.6550776 
    2323   -2.9871562   -2.6763688   -2.6454446 
Loop time of 3.72371e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.1372151497861
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.56728928820123
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.53253645777484
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.44536280170908
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2323   -2.9871562   -2.6763688   -2.6454446 
    2324   -2.9871562   -2.6763688   -2.6633895 
Loop time of 3.66569e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.02246614415199
variable        y0 equal ${yi}
variable        y0 equal 8.41134195245798

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.05731099564582
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.44346694864328
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2324   -2.9871562   -2.6763688   -2.6633895 
    2325   -2.9871562   -2.6763688   -2.6813429 
Loop time of 3.65845e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.6813429083581
variable naccept equal ${increment}
variable naccept equal 425

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.527254207530881
variable        y0 equal ${yi}
variable        y0 equal 4.66832068318292

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.445383675495053
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.71240940445825
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2325   -2.9871562   -2.6813429   -2.6813429 
    2326   -2.9871562   -2.6813429   -2.6638945 
Loop time of 3.66566e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.527254207530881
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.66832068318292
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.20629341322929
variable        y0 equal ${yi}
variable        y0 equal 2.76325721713403

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.1258782716468
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.77081074687341
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2326   -2.9871562   -2.6813429   -2.6638945 
    2327   -2.9871562   -2.6813429   -2.6709728 
Loop time of 3.65385e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.20629341322929
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.76325721713403
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.81108888029394
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.7555294310467
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2327   -2.9871562   -2.6813429   -2.6709728 
    2328   -2.9871562   -2.6813429   -2.6643017 
Loop time of 3.57819e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.95838304717534
variable        y0 equal ${yi}
variable        y0 equal 2.82275391789772

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.99655700881474
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.72529351683952
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2328   -2.9871562   -2.6813429   -2.6643017 
    2329   -2.9871562   -2.6813429   -2.6656725 
Loop time of 3.71138e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.95838304717534
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.82275391789772
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.506249304214384
variable        y0 equal ${yi}
variable        y0 equal 6.52357215420237

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.461901982227232
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.50701750055781
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2329   -2.9871562   -2.6813429   -2.6656725 
    2330   -2.9871562   -2.6813429   -2.6798705 
Loop time of 3.74991e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.506249304214384
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.52357215420237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 6.99216622391388
variable        y0 equal ${yi}
variable        y0 equal 6.45942620769968

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.03180089274094
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.41162285343637
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2330   -2.9871562   -2.6813429   -2.6798705 
    2331   -2.9871562   -2.6813429   -2.6590403 
Loop time of 3.65774e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 6.99216622391388
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.45942620769968
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.32988982279512
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.62806203310687
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2331   -2.9871562   -2.6813429   -2.6590403 
    2332   -2.9871562   -2.6813429   -2.6778797 
Loop time of 3.62785e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.527254207530881
variable        y0 equal ${yi}
variable        y0 equal 4.66832068318292

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.501774974265958
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.62378162497445
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2332   -2.9871562   -2.6813429   -2.6778797 
    2333   -2.9871562   -2.6813429    -2.678465 
Loop time of 3.70755e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.527254207530881
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.66832068318292
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.527254207530881
variable        y0 equal ${yi}
variable        y0 equal 4.66832068318292

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.488659115234281
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.69056376570627
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2333   -2.9871562   -2.6813429    -2.678465 
    2334   -2.9871562   -2.6813429   -2.6783053 
Loop time of 3.59985e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.67830531682138
variable naccept equal ${increment}
variable naccept equal 426

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82797947445994
variable        y0 equal ${yi}
variable        y0 equal 0.89721691201958

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.85740650216227
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.813109703767627
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2334   -2.9871562   -2.6783053   -2.6783053 
    2335   -2.9871562   -2.6783053   -2.6546761 
Loop time of 3.68926e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82797947445994
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.89721691201958
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 10.7438378771
variable        y0 equal ${yi}
variable        y0 equal 3.74340155882966

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 10.6665664156132
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.76956357522141
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2335   -2.9871562   -2.6783053   -2.6546761 
    2336   -2.9871562   -2.6783053   -2.6526232 
Loop time of 3.691e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 10.7438378771
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.74340155882966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.05731099564582
variable        y0 equal ${yi}
variable        y0 equal 8.44346694864328

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.01327947098762
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.50533261217172
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2336   -2.9871562   -2.6783053   -2.6526232 
    2337   -2.9871562   -2.6783053   -2.6682894 
Loop time of 3.64529e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.05731099564582
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.44346694864328
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.46636033772546
variable        y0 equal ${yi}
variable        y0 equal 3.78071368498932

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.46262975453454
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.79210663600098
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2337   -2.9871562   -2.6783053   -2.6682894 
    2338   -2.9871562   -2.6783053   -2.6768892 
Loop time of 3.69656e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.46636033772546
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.78071368498932
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.13496974109507
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.97992011281351
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2338   -2.9871562   -2.6783053   -2.6768892 
    2339   -2.9871562   -2.6783053   -2.5903997 
Loop time of 4.1946e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.0832990586648
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.88667256804804
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.0681977808366
variable        y0 equal ${yi}
variable        y0 equal 4.6233086740391

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.12369118331768
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.66261145228312
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2339   -2.9871562   -2.6783053   -2.5903997 
    2340   -2.9871562   -2.6783053   -2.6636646 
Loop time of 3.65972e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.0681977808366
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.6233086740391
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.61535184541169
variable        y0 equal ${yi}
variable        y0 equal 1.91233646056717

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.64068950572434
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.92475976131027
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2340   -2.9871562   -2.6783053   -2.6636646 
    2341   -2.9871562   -2.6783053   -2.6757727 
Loop time of 3.69157e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.61535184541169
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.91233646056717
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.17300830800087
variable        y0 equal ${yi}
variable        y0 equal 1.0788206536654

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.10993288476021
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.03872834037576
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2341   -2.9871562   -2.6783053   -2.6757727 
    2342   -2.9871562   -2.6783053   -2.6739978 
Loop time of 3.62956e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.17300830800087
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.0788206536654
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6723551591091
variable        y0 equal ${yi}
variable        y0 equal 9.27579969871372

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.6170922239475
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.22475825059742
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2342   -2.9871562   -2.6783053   -2.6739978 
    2343   -2.9871562   -2.6783053   -2.6635648 
Loop time of 3.77527e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6723551591091
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.27579969871372
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.44055470942574
variable        y0 equal ${yi}
variable        y0 equal 7.31046043958926

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.4587552738102
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.36176157322192
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2343   -2.9871562   -2.6783053   -2.6635648 
    2344   -2.9871562   -2.6783053   -2.6835077 
Loop time of 3.66961e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.68350771342836
variable naccept equal ${increment}
variable naccept equal 427

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 10.7438378771
variable        y0 equal ${yi}
variable        y0 equal 3.74340155882966

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 10.7086081941776
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.72486369176042
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2344   -2.9871562   -2.6835077   -2.6835077 
    2345   -2.9871562   -2.6835077   -2.6729179 
Loop time of 3.76798e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 10.7438378771
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.74340155882966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.4587552738102
variable        y0 equal ${yi}
variable        y0 equal 7.36176157322192

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.55169807194787
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.33323331203723
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2345   -2.9871562   -2.6835077   -2.6729179 
    2346   -2.9871562   -2.6835077   -2.6427231 
Loop time of 3.67348e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.4587552738102
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.36176157322192
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 5.97854424674504
variable        y0 equal ${yi}
variable        y0 equal 0.914465494859546

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 5.93368703086369
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.947908409345477
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2346   -2.9871562   -2.6835077   -2.6427231 
    2347   -2.9871562   -2.6835077   -2.6779891 
Loop time of 3.82818e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 5.97854424674504
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.914465494859546
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.35614831844235
variable        y0 equal ${yi}
variable        y0 equal 3.74340068860184

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.45321966806317
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.70903363986145
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2347   -2.9871562   -2.6835077   -2.6779891 
    2348   -2.9871562   -2.6835077   -2.6741208 
Loop time of 3.65717e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.35614831844235
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.74340068860184
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.14945381323205
variable        y0 equal ${yi}
variable        y0 equal 3.70534809394013

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.1777931276928
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.72489689154755
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2348   -2.9871562   -2.6835077   -2.6741208 
    2349   -2.9871562   -2.6835077   -2.6863582 
Loop time of 3.71226e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.68635820576152
variable naccept equal ${increment}
variable naccept equal 428

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.93335930942831
variable        y0 equal ${yi}
variable        y0 equal 2.82367047044137

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.94595673918066
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.80184977027276
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2349   -2.9871562   -2.6863582   -2.6863582 
    2350   -2.9871562   -2.6863582   -2.6870603 
Loop time of 3.65897e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.68706025707265
variable naccept equal ${increment}
variable naccept equal 429

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 7.02658752480194
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.3546878687292
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2350   -2.9871562   -2.6870603   -2.6870603 
    2351   -2.9871562   -2.6870603   -2.6837026 
Loop time of 3.698e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6723551591091
variable        y0 equal ${yi}
variable        y0 equal 9.27579969871372

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.6761052210979
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.25454356181949
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2351   -2.9871562   -2.6870603   -2.6837026 
    2352   -2.9871562   -2.6870603   -2.6870825 
Loop time of 3.65583e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.68708253263477
variable naccept equal ${increment}
variable naccept equal 430

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.57543257355471
variable        y0 equal ${yi}
variable        y0 equal 4.67648406380578

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.61305398821612
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.66496637219354
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2352   -2.9871562   -2.6870825   -2.6870825 
    2353   -2.9871562   -2.6870825   -2.6888614 
Loop time of 3.7856e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.68886137906013
variable naccept equal ${increment}
variable naccept equal 431

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.1777931276928
variable        y0 equal ${yi}
variable        y0 equal 3.72489689154755

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.20790343920098
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.63997244401108
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2353   -2.9871562   -2.6888614   -2.6888614 
    2354   -2.9871562   -2.6888614   -2.6720314 
Loop time of 6.35489e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.1777931276928
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.72489689154755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40162080922987
variable        y0 equal ${yi}
variable        y0 equal 5.54853548948961

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.49312395254042
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.62107185070711
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2354   -2.9871562   -2.6888614   -2.6720314 
    2355   -2.9871562   -2.6888614   -2.5961271 
Loop time of 3.68138e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.40162080922987
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.54853548948961
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40162080922987
variable        y0 equal ${yi}
variable        y0 equal 5.54853548948961

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.42706224122908
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.62741277163225
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2355   -2.9871562   -2.6888614   -2.5961271 
    2356   -2.9871562   -2.6888614   -2.6583506 
Loop time of 3.60401e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.40162080922987
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.54853548948961
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.1777931276928
variable        y0 equal ${yi}
variable        y0 equal 3.72489689154755

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.22359154859887
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.77767148776184
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2356   -2.9871562   -2.6888614   -2.6583506 
    2357   -2.9871562   -2.6888614   -2.6790105 
Loop time of 3.70613e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.1777931276928
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.72489689154755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82797947445994
variable        y0 equal ${yi}
variable        y0 equal 0.89721691201958

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.82207543173915
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.923057528245776
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2357   -2.9871562   -2.6888614   -2.6790105 
    2358   -2.9871562   -2.6888614   -2.6896861 
Loop time of 3.64001e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.68968612231599
variable naccept equal ${increment}
variable naccept equal 432

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.40110092241975
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.73199319405687
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2358   -2.9871562   -2.6896861   -2.6896861 
    2359   -2.9871562   -2.6896861   -2.6664011 
Loop time of 3.68317e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0712319020292
variable        y0 equal ${yi}
variable        y0 equal 8.4037723175436

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.1234089855215
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.43107908882198
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2359   -2.9871562   -2.6896861   -2.6664011 
    2360   -2.9871562   -2.6896861   -2.6879119 
Loop time of 3.63874e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.0712319020292
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.4037723175436
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.10710482317955
variable        y0 equal ${yi}
variable        y0 equal 4.59937599057123

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.05928871352226
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.61548220271036
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2360   -2.9871562   -2.6896861   -2.6879119 
    2361   -2.9871562   -2.6896861   -2.6810686 
Loop time of 3.57027e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.10710482317955
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.59937599057123
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.93805575012504
variable        y0 equal ${yi}
variable        y0 equal 8.32736837781961

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.98076315759956
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.40262874282892
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2361   -2.9871562   -2.6896861   -2.6810686 
    2362   -2.9871562   -2.6896861   -2.6685259 
Loop time of 3.73574e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.93805575012504
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.32736837781961
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.18239519039497
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.93254703662461
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2362   -2.9871562   -2.6896861   -2.6685259 
    2363   -2.9871562   -2.6896861   -2.6861191 
Loop time of 3.606e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.35658786375734
variable        y0 equal ${yi}
variable        y0 equal 1.8282853164441

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.39493876774522
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.88860803029603
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2363   -2.9871562   -2.6896861   -2.6861191 
    2364   -2.9871562   -2.6896861    -2.690031 
Loop time of 3.67513e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.69003100439402
variable naccept equal ${increment}
variable naccept equal 433

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.29362520932713
variable        y0 equal ${yi}
variable        y0 equal 0.011324155330658

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.2751592731432
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.109518837928772
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2364   -2.9871562    -2.690031    -2.690031 
    2365   -2.9871562    -2.690031    -2.674201 
Loop time of 3.57572e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.29362520932713
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.011324155330658
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.594005592265989
variable        y0 equal ${yi}
variable        y0 equal 2.84451084109644

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.570451636711027
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.81422812911371
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2365   -2.9871562    -2.690031    -2.674201 
    2366   -2.9871562    -2.690031   -2.6924668 
Loop time of 3.8472e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.69246678455914
variable naccept equal ${increment}
variable naccept equal 434

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.37309358198854
variable        y0 equal ${yi}
variable        y0 equal 7.47418843832278

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.28874713261339
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.41239918794894
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2366   -2.9871562   -2.6924668   -2.6924668 
    2367   -2.9871562   -2.6924668   -2.6867062 
Loop time of 3.71058e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.37309358198854
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.47418843832278
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.72697503765058
variable        y0 equal ${yi}
variable        y0 equal 2.78031077357629

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.78555878599119
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.7789975640426
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2367   -2.9871562   -2.6924668   -2.6867062 
    2368   -2.9871562   -2.6924668   -2.6871974 
Loop time of 3.70772e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.72697503765058
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.78031077357629
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.60113894779455
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.83622986836564
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2368   -2.9871562   -2.6924668   -2.6871974 
    2369   -2.9871562   -2.6924668    -2.642562 
Loop time of 3.58462e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.03061267732479
variable        y0 equal ${yi}
variable        y0 equal 8.28878506340082

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.00191021560528
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.32666997827585
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2369   -2.9871562   -2.6924668    -2.642562 
    2370   -2.9871562   -2.6924668   -2.6966477 
Loop time of 3.67461e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.69664765902779
variable naccept equal ${increment}
variable naccept equal 435

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78270576516277
variable        y0 equal ${yi}
variable        y0 equal 4.66047749871181

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.87651651421673
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.65740065926479
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2370   -2.9871562   -2.6966477   -2.6966477 
    2371   -2.9871562   -2.6966477   -2.6491083 
Loop time of 3.62169e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78270576516277
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.66047749871181
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.00191021560528
variable        y0 equal ${yi}
variable        y0 equal 8.32666997827585

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.01081405280926
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.26463599123056
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2371   -2.9871562   -2.6966477   -2.6491083 
    2372   -2.9871562   -2.6966477   -2.6873109 
Loop time of 3.61288e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.00191021560528
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.32666997827585
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.17300830800087
variable        y0 equal ${yi}
variable        y0 equal 1.0788206536654

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.08322040755302
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.01102701019082
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2372   -2.9871562   -2.6966477   -2.6873109 
    2373   -2.9871562   -2.6966477   -2.6848662 
Loop time of 3.67007e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.17300830800087
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.0788206536654
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.4587552738102
variable        y0 equal ${yi}
variable        y0 equal 7.36176157322192

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.49185919283944
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.27268673506045
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2373   -2.9871562   -2.6966477   -2.6848662 
    2374   -2.9871562   -2.6966477    -2.670515 
Loop time of 3.65318e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.4587552738102
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.36176157322192
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.46636033772546
variable        y0 equal ${yi}
variable        y0 equal 3.78071368498932

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.49843644618112
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.77967162890564
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2374   -2.9871562   -2.6966477    -2.670515 
    2375   -2.9871562   -2.6966477   -2.6940074 
Loop time of 3.66769e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.46636033772546
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.78071368498932
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.6479291458888
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.4260314418458
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2375   -2.9871562   -2.6966477   -2.6940074 
    2376   -2.9871562   -2.6966477   -2.6856556 
Loop time of 3.6537e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.72697503765058
variable        y0 equal ${yi}
variable        y0 equal 2.78031077357629

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.71650628049802
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.73754527541497
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2376   -2.9871562   -2.6966477   -2.6856556 
    2377   -2.9871562   -2.6966477   -2.6879911 
Loop time of 3.62844e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.72697503765058
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.78031077357629
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.37309358198854
variable        y0 equal ${yi}
variable        y0 equal 7.47418843832278

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.29181702215883
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.37506341066622
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2377   -2.9871562   -2.6966477   -2.6879911 
    2378   -2.9871562   -2.6966477   -2.6804965 
Loop time of 3.6671e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.37309358198854
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.47418843832278
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.84038932839518
variable        y0 equal ${yi}
variable        y0 equal 8.35802853025493

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.92506270924693
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.32163357652721
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2378   -2.9871562   -2.6966477   -2.6804965 
    2379   -2.9871562   -2.6966477   -2.6688377 
Loop time of 3.67324e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.84038932839518
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.35802853025493
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.6573487090933
variable        y0 equal ${yi}
variable        y0 equal 7.44725758161806

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.69870952843305
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.52214891042971
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2379   -2.9871562   -2.6966477   -2.6688377 
    2380   -2.9871562   -2.6966477   -2.6784978 
Loop time of 3.58375e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 99 x ${x0}
set atom 99 x 9.6573487090933
  1 settings made for x
set atom $i y ${y0}
set atom 99 y ${y0}
set atom 99 y 7.44725758161806
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.88880834538928
variable        y0 equal ${yi}
variable        y0 equal 6.44203974739543

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.93221496303073
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.51454767719737
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2380   -2.9871562   -2.6966477   -2.6784978 
    2381   -2.9871562   -2.6966477   -2.6892008 
Loop time of 3.70182e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.88880834538928
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.44203974739543
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.45999115545522
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.68521717352998
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2381   -2.9871562   -2.6966477   -2.6892008 
    2382   -2.9871562   -2.6966477   -2.6810974 
Loop time of 3.76139e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.61455693402712
variable        y0 equal ${yi}
variable        y0 equal 7.4608101996448

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.54114090362017
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.51008165207171
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2382   -2.9871562   -2.6966477   -2.6810974 
    2383   -2.9871562   -2.6966477   -2.6855688 
Loop time of 3.61282e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.61455693402712
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.4608101996448
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.1437741696725
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.61618190542688
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2383   -2.9871562   -2.6966477   -2.6855688 
    2384   -2.9871562   -2.6966477   -2.6457864 
Loop time of 3.7367e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.0800673158949
variable        y0 equal ${yi}
variable        y0 equal 3.73807540698182

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.09694946129972
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.79307561679017
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2384   -2.9871562   -2.6966477   -2.6457864 
    2385   -2.9871562   -2.6966477   -2.6934668 
Loop time of 3.64766e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.0800673158949
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.73807540698182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.42935876050855
variable        y0 equal ${yi}
variable        y0 equal 7.38294791307711

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.47490374246503
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.46254194107317
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2385   -2.9871562   -2.6966477   -2.6934668 
    2386   -2.9871562   -2.6966477   -2.6567961 
Loop time of 3.66078e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.42935876050855
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.38294791307711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.449145431915189
variable        y0 equal ${yi}
variable        y0 equal 8.34512849964198

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.352394338050748
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.282913242951
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2386   -2.9871562   -2.6966477   -2.6567961 
    2387   -2.9871562   -2.6966477   -2.6442257 
Loop time of 3.81736e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.449145431915189
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.34512849964198
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.95838304717534
variable        y0 equal ${yi}
variable        y0 equal 2.82275391789772

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.898249673438
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.92095389338829
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2387   -2.9871562   -2.6966477   -2.6442257 
    2388   -2.9871562   -2.6966477   -2.6631276 
Loop time of 3.77024e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.95838304717534
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.82275391789772
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.4587552738102
variable        y0 equal ${yi}
variable        y0 equal 7.36176157322192

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.45070884942132
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.45584847059512
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2388   -2.9871562   -2.6966477   -2.6631276 
    2389   -2.9871562   -2.6966477    -2.666451 
Loop time of 3.737e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.4587552738102
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.36176157322192
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 7.00497995892212
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.23549548305568
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2389   -2.9871562   -2.6966477    -2.666451 
    2390   -2.9871562   -2.6966477   -2.6783326 
Loop time of 3.59279e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.4587552738102
variable        y0 equal ${yi}
variable        y0 equal 7.36176157322192

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.45164854048806
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.43906225290561
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2390   -2.9871562   -2.6966477   -2.6783326 
    2391   -2.9871562   -2.6966477   -2.6766808 
Loop time of 3.6936e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.4587552738102
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.36176157322192
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.0800673158949
variable        y0 equal ${yi}
variable        y0 equal 3.73807540698182

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.14850422461682
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.79432246251237
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2391   -2.9871562   -2.6966477   -2.6766808 
    2392   -2.9871562   -2.6966477    -2.683219 
Loop time of 3.66296e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.0800673158949
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.73807540698182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.14544790426597
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.8513142862088
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2392   -2.9871562   -2.6966477    -2.683219 
    2393   -2.9871562   -2.6966477   -2.6923725 
Loop time of 3.63336e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.488659115234281
variable        y0 equal ${yi}
variable        y0 equal 4.69056376570627

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.49041990796652
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.63726146572992
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2393   -2.9871562   -2.6966477   -2.6923725 
    2394   -2.9871562   -2.6966477   -2.6975135 
Loop time of 3.56728e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.6975134742436
variable naccept equal ${increment}
variable naccept equal 436

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.07460362631828
variable        y0 equal ${yi}
variable        y0 equal 6.51190980211725

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.01051343400032
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.52138293520441
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2394   -2.9871562   -2.6975135   -2.6975135 
    2395   -2.9871562   -2.6975135   -2.6697349 
Loop time of 3.65917e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.07460362631828
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.51190980211725
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.00774297991439
variable        y0 equal ${yi}
variable        y0 equal 2.80172786685327

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 7.05840935984298
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.82120681973794
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2395   -2.9871562   -2.6975135   -2.6697349 
    2396   -2.9871562   -2.6975135   -2.6942228 
Loop time of 3.60395e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 7.00774297991439
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.80172786685327
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.32259763240376
variable        y0 equal ${yi}
variable        y0 equal 1.91972836635178

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.37452281474629
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.83578155419892
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2396   -2.9871562   -2.6975135   -2.6942228 
    2397   -2.9871562   -2.6975135   -2.6851219 
Loop time of 3.65784e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.32259763240376
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.91972836635178
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.49041990796652
variable        y0 equal ${yi}
variable        y0 equal 4.63726146572992

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.430430086055662
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.70762758606836
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2397   -2.9871562   -2.6975135   -2.6851219 
    2398   -2.9871562   -2.6975135   -2.6760292 
Loop time of 3.55746e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.49041990796652
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.63726146572992
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.4587552738102
variable        y0 equal ${yi}
variable        y0 equal 7.36176157322192

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.43879416703301
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.37528548565173
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2398   -2.9871562   -2.6975135   -2.6760292 
    2399   -2.9871562   -2.6975135   -2.6947438 
Loop time of 3.7384e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.4587552738102
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.36176157322192
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.13915432134971
variable        y0 equal ${yi}
variable        y0 equal 5.57011886780458

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.04641234318122
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.62938622181612
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2399   -2.9871562   -2.6975135   -2.6947438 
    2400   -2.9871562   -2.6975135   -2.6848328 
Loop time of 3.51282e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.13915432134971
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.57011886780458
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.10710482317955
variable        y0 equal ${yi}
variable        y0 equal 4.59937599057123

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.14624181706459
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.60836122387811
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2400   -2.9871562   -2.6975135   -2.6848328 
    2401   -2.9871562   -2.6975135   -2.6989783 
Loop time of 3.71118e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.69897831761754
variable naccept equal ${increment}
variable naccept equal 437

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.86155322073576
variable        y0 equal ${yi}
variable        y0 equal 1.87893718860216

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.8208997893202
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.93073156259127
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2401   -2.9871562   -2.6989783   -2.6989783 
    2402   -2.9871562   -2.6989783    -2.704934 
Loop time of 3.77846e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.70493402590992
variable naccept equal ${increment}
variable naccept equal 438

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.44636772075559
variable        y0 equal ${yi}
variable        y0 equal 9.24993084180682

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.3853261033621
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.31735046613543
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2402   -2.9871562    -2.704934    -2.704934 
    2403   -2.9871562    -2.704934   -2.6928097 
Loop time of 3.73606e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.44636772075559
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.24993084180682
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82207543173915
variable        y0 equal ${yi}
variable        y0 equal 0.923057528245776

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.88425798932201
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.907239623773425
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2403   -2.9871562    -2.704934   -2.6928097 
    2404   -2.9871562    -2.704934   -2.6997456 
Loop time of 3.62237e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82207543173915
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.923057528245776
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.65424995302935
variable        y0 equal ${yi}
variable        y0 equal 0.940276082265705

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.62810066818972
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.957269092309803
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2404   -2.9871562    -2.704934   -2.6997456 
    2405   -2.9871562    -2.704934   -2.7030948 
Loop time of 3.79179e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.65424995302935
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.940276082265705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.03727689066574
variable        y0 equal ${yi}
variable        y0 equal 0.91603718589577

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.08158563652679
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.881425483930438
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2405   -2.9871562    -2.704934   -2.7030948 
    2406   -2.9871562    -2.704934   -2.6970513 
Loop time of 3.71432e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.03727689066574
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.91603718589577
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.14624181706459
variable        y0 equal ${yi}
variable        y0 equal 4.60836122387811

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.06834283787758
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.54486881846353
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2406   -2.9871562    -2.704934   -2.6970513 
    2407   -2.9871562    -2.704934   -2.6685483 
Loop time of 3.74404e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.14624181706459
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.60836122387811
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3012223724386
variable        y0 equal ${yi}
variable        y0 equal 2.8246198293815

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.2612108234426
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.84584733220438
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2407   -2.9871562    -2.704934   -2.6685483 
    2408   -2.9871562    -2.704934   -2.7038406 
Loop time of 3.67089e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3012223724386
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.8246198293815
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.05731099564582
variable        y0 equal ${yi}
variable        y0 equal 8.44346694864328

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.08620447833091
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.41325300849969
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2408   -2.9871562    -2.704934   -2.7038406 
    2409   -2.9871562    -2.704934   -2.6993601 
Loop time of 3.68716e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.05731099564582
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.44346694864328
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.94595673918066
variable        y0 equal ${yi}
variable        y0 equal 2.80184977027276

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.93075515865621
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.857803070272
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2409   -2.9871562    -2.704934   -2.6993601 
    2410   -2.9871562    -2.704934   -2.6975204 
Loop time of 3.68494e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.94595673918066
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.80184977027276
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.50875395376456
variable        y0 equal ${yi}
variable        y0 equal 5.60411881153779

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.49472845632804
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.57788908426957
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2410   -2.9871562    -2.704934   -2.6975204 
    2411   -2.9871562    -2.704934   -2.7083086 
Loop time of 3.60908e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.70830855683508
variable naccept equal ${increment}
variable naccept equal 439

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.95845205743305
variable        y0 equal ${yi}
variable        y0 equal 8.26673827089366

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 5.97845824916355
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.32162626899776
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2411   -2.9871562   -2.7083086   -2.7083086 
    2412   -2.9871562   -2.7083086   -2.7108658 
Loop time of 3.78854e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.71086578648394
variable naccept equal ${increment}
variable naccept equal 440

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.73321754215833
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.70517334504258
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2412   -2.9871562   -2.7108658   -2.7108658 
    2413   -2.9871562   -2.7108658   -2.7078899 
Loop time of 3.70403e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.5445865321028
variable        y0 equal ${yi}
variable        y0 equal 5.54097448532778

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.59509903668044
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.54114934151369
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2413   -2.9871562   -2.7108658   -2.7078899 
    2414   -2.9871562   -2.7108658   -2.7174951 
Loop time of 3.6955e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.71749513140551
variable naccept equal ${increment}
variable naccept equal 441

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.46636033772546
variable        y0 equal ${yi}
variable        y0 equal 3.78071368498932

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.44423269747811
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.6834320382608
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2414   -2.9871562   -2.7174951   -2.7174951 
    2415   -2.9871562   -2.7174951   -2.7073275 
Loop time of 3.68999e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.46636033772546
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.78071368498932
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.28583399692879
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.37569978561663
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2415   -2.9871562   -2.7174951   -2.7073275 
    2416   -2.9871562   -2.7174951   -2.6895407 
Loop time of 3.58523e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.00191021560528
variable        y0 equal ${yi}
variable        y0 equal 8.32666997827585

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 7.97728973029949
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.41952900804575
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2416   -2.9871562   -2.7174951   -2.6895407 
    2417   -2.9871562   -2.7174951   -2.7004831 
Loop time of 3.80256e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.00191021560528
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.32666997827585
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 1.10092277844601
variable        y0 equal ${yi}
variable        y0 equal 9.22189815748065

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 1.15133017619305
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.21305660713046
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2417   -2.9871562   -2.7174951   -2.7004831 
    2418   -2.9871562   -2.7174951    -2.712887 
Loop time of 3.70474e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 1.10092277844601
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.22189815748065
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.65424995302935
variable        y0 equal ${yi}
variable        y0 equal 0.940276082265705

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.60363571524401
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.988646205175251
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2418   -2.9871562   -2.7174951    -2.712887 
    2419   -2.9871562   -2.7174951   -2.7086596 
Loop time of 3.83837e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.65424995302935
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.940276082265705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.46321600515615
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.70581447644365
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2419   -2.9871562   -2.7174951   -2.7086596 
    2420   -2.9871562   -2.7174951   -2.7085391 
Loop time of 3.63059e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.00774297991439
variable        y0 equal ${yi}
variable        y0 equal 2.80172786685327

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.92852022925063
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.75473967763284
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2420   -2.9871562   -2.7174951   -2.7085391 
    2421   -2.9871562   -2.7174951   -2.6917588 
Loop time of 3.63529e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 7.00774297991439
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.80172786685327
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.03727689066574
variable        y0 equal ${yi}
variable        y0 equal 0.91603718589577

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.11708243170425
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.965916009652942
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2421   -2.9871562   -2.7174951   -2.6917588 
    2422   -2.9871562   -2.7174951   -2.6869927 
Loop time of 3.71935e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.03727689066574
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.91603718589577
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.6417047309744
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.78840672536027
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2422   -2.9871562   -2.7174951   -2.6869927 
    2423   -2.9871562   -2.7174951   -2.6847805 
Loop time of 3.6368e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 5.97854424674504
variable        y0 equal ${yi}
variable        y0 equal 0.914465494859546

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 6.01408804614537
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.971624668348163
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2423   -2.9871562   -2.7174951   -2.6847805 
    2424   -2.9871562   -2.7174951   -2.7047222 
Loop time of 3.60954e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 5.97854424674504
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.914465494859546
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82207543173915
variable        y0 equal ${yi}
variable        y0 equal 0.923057528245776

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.87490418473369
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.956824227083056
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2424   -2.9871562   -2.7174951   -2.7047222 
    2425   -2.9871562   -2.7174951   -2.7158101 
Loop time of 3.72431e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82207543173915
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.923057528245776
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.97845824916355
variable        y0 equal ${yi}
variable        y0 equal 8.32162626899776

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.02429981191151
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.38259653963146
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2425   -2.9871562   -2.7174951   -2.7158101 
    2426   -2.9871562   -2.7174951   -2.6906529 
Loop time of 3.75899e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 5.97845824916355
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.32162626899776
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.17300830800087
variable        y0 equal ${yi}
variable        y0 equal 1.0788206536654

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.24093744475395
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.08796071599755
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2426   -2.9871562   -2.7174951   -2.6906529 
    2427   -2.9871562   -2.7174951   -2.7122539 
Loop time of 3.78152e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.17300830800087
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.0788206536654
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.87144294301158
variable        y0 equal ${yi}
variable        y0 equal 2.78142455788949

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.85881524602061
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.6992598769317
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2427   -2.9871562   -2.7174951   -2.7122539 
    2428   -2.9871562   -2.7174951   -2.6809633 
Loop time of 3.77783e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.87144294301158
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.78142455788949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.78494725702878
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.69317397637498
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2428   -2.9871562   -2.7174951   -2.6809633 
    2429   -2.9871562   -2.7174951   -2.6941047 
Loop time of 3.85645e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6761052210979
variable        y0 equal ${yi}
variable        y0 equal 9.25454356181949

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.64617238838
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.28586986768573
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2429   -2.9871562   -2.7174951   -2.6941047 
    2430   -2.9871562   -2.7174951   -2.7128648 
Loop time of 3.88663e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6761052210979
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.25454356181949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.49662729024011
variable        y0 equal ${yi}
variable        y0 equal 1.85665681741302

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.43619659661371
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.94055850884979
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2430   -2.9871562   -2.7174951   -2.7128648 
    2431   -2.9871562   -2.7174951   -2.6983746 
Loop time of 4.68763e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.49662729024011
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.85665681741302
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.09319434760905
variable        y0 equal ${yi}
variable        y0 equal 0.990582271325916

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.14444211124278
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.91565798114571
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2431   -2.9871562   -2.7174951   -2.6983746 
    2432   -2.9871562   -2.7174951   -2.6805939 
Loop time of 3.91491e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.09319434760905
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.990582271325916
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.2537579540272
variable        y0 equal ${yi}
variable        y0 equal 0.909067996251911

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.1569449547787
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.866565235364765
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2432   -2.9871562   -2.7174951   -2.6805939 
    2433   -2.9871562   -2.7174951   -2.6812371 
Loop time of 3.84324e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.2537579540272
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.909067996251911
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.00191021560528
variable        y0 equal ${yi}
variable        y0 equal 8.32666997827585

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.05084016918041
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.40469950355585
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2433   -2.9871562   -2.7174951   -2.6812371 
    2434   -2.9871562   -2.7174951   -2.7139518 
Loop time of 3.9399e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.00191021560528
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.32666997827585
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.506249304214384
variable        y0 equal ${yi}
variable        y0 equal 6.52357215420237

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.464315410056974
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.43066781298151
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2434   -2.9871562   -2.7174951   -2.7139518 
    2435   -2.9871562   -2.7174951    -2.702384 
Loop time of 3.81951e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.506249304214384
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.52357215420237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.99581291952774
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.38580042041835
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2435   -2.9871562   -2.7174951    -2.702384 
    2436   -2.9871562   -2.7174951   -2.7107486 
Loop time of 3.75689e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.92015489617035
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.35425783313808
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2436   -2.9871562   -2.7174951   -2.7107486 
    2437   -2.9871562   -2.7174951   -2.6910552 
Loop time of 4.75803e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.58989846904707
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.40728972689143
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2437   -2.9871562   -2.7174951   -2.6910552 
    2438   -2.9871562   -2.7174951   -2.6810464 
Loop time of 4.13056e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.75227689900819
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.72543744607103
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2438   -2.9871562   -2.7174951   -2.6810464 
    2439   -2.9871562   -2.7174951   -2.6817377 
Loop time of 4.38989e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.1178052250515
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.889057723499
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2439   -2.9871562   -2.7174951   -2.6817377 
    2440   -2.9871562   -2.7174951     -2.71048 
Loop time of 4.129e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.49472845632804
variable        y0 equal ${yi}
variable        y0 equal 5.57788908426957

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.54543794233573
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.55907229130463
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2440   -2.9871562   -2.7174951     -2.71048 
    2441   -2.9871562   -2.7174951   -2.7072854 
Loop time of 3.91156e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.49472845632804
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.57788908426957
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.52162269193899
variable        y0 equal ${yi}
variable        y0 equal 1.84969287297791

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.51896284658682
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.92514754912919
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2441   -2.9871562   -2.7174951   -2.7072854 
    2442   -2.9871562   -2.7174951   -2.7181589 
Loop time of 3.80438e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.7181588626659
variable naccept equal ${increment}
variable naccept equal 442

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.1955849651357
variable        y0 equal ${yi}
variable        y0 equal 4.64925400370525

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.2863247398397
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.57206858748363
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2442   -2.9871562   -2.7181589   -2.7181589 
    2443   -2.9871562   -2.7181589   -2.6660735 
Loop time of 3.91893e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.1955849651357
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.64925400370525
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.61787458815996
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.79857512278688
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2443   -2.9871562   -2.7181589   -2.6660735 
    2444   -2.9871562   -2.7181589   -2.6992471 
Loop time of 3.80468e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.57615993221235
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.52241564527979
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2444   -2.9871562   -2.7181589   -2.6992471 
    2445   -2.9871562   -2.7181589   -2.6879823 
Loop time of 3.80495e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.73731143672897
variable        y0 equal ${yi}
variable        y0 equal 4.63249358290597

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.82793097694351
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.70184383744165
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2445   -2.9871562   -2.7181589   -2.6879823 
    2446   -2.9871562   -2.7181589   -2.6632981 
Loop time of 4.00616e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.73731143672897
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.63249358290597
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.449145431915189
variable        y0 equal ${yi}
variable        y0 equal 8.34512849964198

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.508004017272855
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.35369931377467
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2446   -2.9871562   -2.7181589   -2.6632981 
    2447   -2.9871562   -2.7181589   -2.7199572 
Loop time of 4.16683e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.71995717045128
variable naccept equal ${increment}
variable naccept equal 443

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.09989086707288
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.52928338375353
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2447   -2.9871562   -2.7199572   -2.7199572 
    2448   -2.9871562   -2.7199572   -2.7036379 
Loop time of 4.00509e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.69427367329378
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.31969104923304
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2448   -2.9871562   -2.7199572   -2.7036379 
    2449   -2.9871562   -2.7199572   -2.7184383 
Loop time of 3.7936e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.40162080922987
variable        y0 equal ${yi}
variable        y0 equal 5.54853548948961

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.3743338862982
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.59916444962221
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2449   -2.9871562   -2.7199572   -2.7184383 
    2450   -2.9871562   -2.7199572   -2.7231287 
Loop time of 3.92314e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.72312865616063
variable naccept equal ${increment}
variable naccept equal 444

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.49041990796652
variable        y0 equal ${yi}
variable        y0 equal 4.63726146572992

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.532790823379423
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.70789318436548
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2450   -2.9871562   -2.7231287   -2.7231287 
    2451   -2.9871562   -2.7231287   -2.7208646 
Loop time of 3.70398e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.49041990796652
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.63726146572992
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.3743338862982
variable        y0 equal ${yi}
variable        y0 equal 5.59916444962221

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.27830452123549
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.62812374775606
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2451   -2.9871562   -2.7231287   -2.7208646 
    2452   -2.9871562   -2.7231287   -2.7132373 
Loop time of 3.87714e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.3743338862982
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.59916444962221
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 6.99216622391388
variable        y0 equal ${yi}
variable        y0 equal 6.45942620769968

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.01292265930817
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.4889962984704
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2452   -2.9871562   -2.7231287   -2.7132373 
    2453   -2.9871562   -2.7231287   -2.7183216 
Loop time of 3.80935e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 6.99216622391388
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.45942620769968
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.8900455796653
variable        y0 equal ${yi}
variable        y0 equal 0.887486429918145

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.81618231176674
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.909093209016656
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2453   -2.9871562   -2.7231287   -2.7183216 
    2454   -2.9871562   -2.7231287   -2.7101312 
Loop time of 3.823e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.8900455796653
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.887486429918145
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.26462735890904
variable        y0 equal ${yi}
variable        y0 equal 3.68544435067308

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.21915989875355
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.77517982287538
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2454   -2.9871562   -2.7231287   -2.7101312 
    2455   -2.9871562   -2.7231287   -2.7085353 
Loop time of 3.89864e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.26462735890904
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.68544435067308
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.07460362631828
variable        y0 equal ${yi}
variable        y0 equal 6.51190980211725

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.02440428454429
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.560974223771
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2455   -2.9871562   -2.7231287   -2.7085353 
    2456   -2.9871562   -2.7231287   -2.6960009 
Loop time of 3.77479e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.07460362631828
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.51190980211725
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.48521473565523
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.62161884253221
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2456   -2.9871562   -2.7231287   -2.6960009 
    2457   -2.9871562   -2.7231287    -2.712438 
Loop time of 3.92921e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.0800673158949
variable        y0 equal ${yi}
variable        y0 equal 3.73807540698182

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.07789568026715
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.70459227128159
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2457   -2.9871562   -2.7231287    -2.712438 
    2458   -2.9871562   -2.7231287   -2.7192503 
Loop time of 3.87524e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.0800673158949
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.73807540698182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.61535184541169
variable        y0 equal ${yi}
variable        y0 equal 1.91233646056717

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.65082675376359
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.95300346992081
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2458   -2.9871562   -2.7231287   -2.7192503 
    2459   -2.9871562   -2.7231287   -2.7173415 
Loop time of 3.71304e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.61535184541169
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.91233646056717
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.48924627144109
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.35332931604648
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2459   -2.9871562   -2.7231287   -2.7173415 
    2460   -2.9871562   -2.7231287   -2.7179938 
Loop time of 3.7846e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.48385869104635
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.38020931806827
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.41449785946924
variable        y0 equal ${yi}
variable        y0 equal 5.54428255503374

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.43577637194711
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.52896356528002
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2460   -2.9871562   -2.7231287   -2.7179938 
    2461   -2.9871562   -2.7231287   -2.7227978 
Loop time of 3.79286e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.41449785946924
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.54428255503374
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.93805575012504
variable        y0 equal ${yi}
variable        y0 equal 8.32736837781961

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.92722187876045
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.34011304296548
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2461   -2.9871562   -2.7231287   -2.7227978 
    2462   -2.9871562   -2.7231287   -2.7244204 
Loop time of 3.75502e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.72442041221019
variable naccept equal ${increment}
variable naccept equal 445

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.10403409639702
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.34559693660998
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2462   -2.9871562   -2.7244204   -2.7244204 
    2463   -2.9871562   -2.7244204   -2.6967919 
Loop time of 3.85055e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.76264746387434
variable        y0 equal ${yi}
variable        y0 equal 8.40153711952266

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.66413638790083
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.35033913768825
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2463   -2.9871562   -2.7244204   -2.6967919 
    2464   -2.9871562   -2.7244204   -2.7132493 
Loop time of 3.70806e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.76264746387434
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.40153711952266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.72697503765058
variable        y0 equal ${yi}
variable        y0 equal 2.78031077357629

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.68702924449872
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.75312172147134
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2464   -2.9871562   -2.7244204   -2.7132493 
    2465   -2.9871562   -2.7244204   -2.7169381 
Loop time of 3.71792e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.72697503765058
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.78031077357629
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.566282685199644
variable        y0 equal ${yi}
variable        y0 equal 0.865556212175219

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.610067029395964
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.862899525869219
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2465   -2.9871562   -2.7244204   -2.7169381 
    2466   -2.9871562   -2.7244204   -2.7233427 
Loop time of 3.74313e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.566282685199644
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.865556212175219
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.35614831844235
variable        y0 equal ${yi}
variable        y0 equal 3.74340068860184

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.41676729122067
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.7113214568628
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2466   -2.9871562   -2.7244204   -2.7233427 
    2467   -2.9871562   -2.7244204   -2.7219078 
Loop time of 3.89628e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.35614831844235
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.74340068860184
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.56384705462877
variable        y0 equal ${yi}
variable        y0 equal 0.0929038047790526

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.59951268592302
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.166184055805206
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2467   -2.9871562   -2.7244204   -2.7219078 
    2468   -2.9871562   -2.7244204   -2.7063408 
Loop time of 3.73792e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.56384705462877
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.0929038047790526
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.1955849651357
variable        y0 equal ${yi}
variable        y0 equal 4.64925400370525

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.1160019878408
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.66781543845104
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2468   -2.9871562   -2.7244204   -2.7063408 
    2469   -2.9871562   -2.7244204   -2.7076015 
Loop time of 3.8038e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.1955849651357
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.64925400370525
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7073550899677
variable        y0 equal ${yi}
variable        y0 equal 7.45095640745426

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.7603984554462
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.42648356285358
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2469   -2.9871562   -2.7244204   -2.7076015 
    2470   -2.9871562   -2.7244204   -2.7178398 
Loop time of 3.71854e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7073550899677
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.45095640745426
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.64459908484098
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.75423633618485
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2470   -2.9871562   -2.7244204   -2.7178398 
    2471   -2.9871562   -2.7244204    -2.706967 
Loop time of 3.98909e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78270576516277
variable        y0 equal ${yi}
variable        y0 equal 4.66047749871181

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.81797478715069
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.62614606970714
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2471   -2.9871562   -2.7244204    -2.706967 
    2472   -2.9871562   -2.7244204   -2.7151942 
Loop time of 3.73416e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78270576516277
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.66047749871181
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.47866305827219
variable        y0 equal ${yi}
variable        y0 equal 9.25160747278063

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.50987925051767
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.17240759837954
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2472   -2.9871562   -2.7244204   -2.7151942 
    2473   -2.9871562   -2.7244204   -2.7019049 
Loop time of 3.80004e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.47866305827219
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.25160747278063
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.88880834538928
variable        y0 equal ${yi}
variable        y0 equal 6.44203974739543

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.87710480649463
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.44094907776347
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2473   -2.9871562   -2.7244204   -2.7019049 
    2474   -2.9871562   -2.7244204   -2.7217733 
Loop time of 3.84743e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.88880834538928
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.44203974739543
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.44636772075559
variable        y0 equal ${yi}
variable        y0 equal 9.24993084180682

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.53905330100919
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.27007499444812
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2474   -2.9871562   -2.7244204   -2.7217733 
    2475   -2.9871562   -2.7244204   -2.6924613 
Loop time of 3.73056e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.44636772075559
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.24993084180682
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.42935876050855
variable        y0 equal ${yi}
variable        y0 equal 7.38294791307711

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.47423966327573
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.29724189367556
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2475   -2.9871562   -2.7244204   -2.6924613 
    2476   -2.9871562   -2.7244204   -2.6859605 
Loop time of 3.7604e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.42935876050855
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.38294791307711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.49662729024011
variable        y0 equal ${yi}
variable        y0 equal 1.85665681741302

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.57311588048059
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.85656146190231
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2476   -2.9871562   -2.7244204   -2.6859605 
    2477   -2.9871562   -2.7244204   -2.6994378 
Loop time of 3.83907e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.49662729024011
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.85665681741302
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.8900455796653
variable        y0 equal ${yi}
variable        y0 equal 0.887486429918145

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.87078618645012
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.841192169893121
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2477   -2.9871562   -2.7244204   -2.6994378 
    2478   -2.9871562   -2.7244204   -2.7139887 
Loop time of 3.75562e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.8900455796653
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.887486429918145
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.66037538209383
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.75006912512911
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2478   -2.9871562   -2.7244204   -2.7139887 
    2479   -2.9871562   -2.7244204   -2.7205083 
Loop time of 3.81026e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.508004017272855
variable        y0 equal ${yi}
variable        y0 equal 8.35369931377467

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.435027511516477
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.38143749155101
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2479   -2.9871562   -2.7244204   -2.7205083 
    2480   -2.9871562   -2.7244204   -2.7210928 
Loop time of 4.13486e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.508004017272855
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.35369931377467
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.20629341322929
variable        y0 equal ${yi}
variable        y0 equal 2.76325721713403

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.22573508936912
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.75807927819589
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2480   -2.9871562   -2.7244204   -2.7210928 
    2481   -2.9871562   -2.7244204    -2.722227 
Loop time of 3.77744e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 83 x ${x0}
set atom 83 x 9.20629341322929
  1 settings made for x
set atom $i y ${y0}
set atom 83 y ${y0}
set atom 83 y 2.76325721713403
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.1372151497861
variable        y0 equal ${yi}
variable        y0 equal 6.56728928820123

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.092790639784
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.60947848097314
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2481   -2.9871562   -2.7244204    -2.722227 
    2482   -2.9871562   -2.7244204   -2.6942075 
Loop time of 3.67286e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.1372151497861
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.56728928820123
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.508004017272855
variable        y0 equal ${yi}
variable        y0 equal 8.35369931377467

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.589695210853483
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.39752567924556
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2482   -2.9871562   -2.7244204   -2.6942075 
    2483   -2.9871562   -2.7244204   -2.7072383 
Loop time of 3.69236e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.508004017272855
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.35369931377467
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78270576516277
variable        y0 equal ${yi}
variable        y0 equal 4.66047749871181

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.8505614332307
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.70219656580852
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2483   -2.9871562   -2.7244204   -2.7072383 
    2484   -2.9871562   -2.7244204   -2.6949953 
Loop time of 3.78646e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78270576516277
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.66047749871181
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.29362520932713
variable        y0 equal ${yi}
variable        y0 equal 0.011324155330658

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.30278476237812
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.0262287020683288
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2484   -2.9871562   -2.7244204   -2.6949953 
    2485   -2.9871562   -2.7244204   -2.7216631 
Loop time of 3.92456e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.29362520932713
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.011324155330658
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.26551517009297
variable        y0 equal ${yi}
variable        y0 equal 7.42613175239824

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.28169446944752
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.41342264738344
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2485   -2.9871562   -2.7244204   -2.7216631 
    2486   -2.9871562   -2.7244204   -2.7235623 
Loop time of 3.78581e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.26551517009297
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.42613175239824
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.62181185959455
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.74059807820451
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2486   -2.9871562   -2.7244204   -2.7235623 
    2487   -2.9871562   -2.7244204   -2.6990937 
Loop time of 3.83429e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.29362520932713
variable        y0 equal ${yi}
variable        y0 equal 0.011324155330658

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.34864085673848
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.0841607809066773
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2487   -2.9871562   -2.7244204   -2.6990937 
    2488   -2.9871562   -2.7244204   -2.7035859 
Loop time of 3.70198e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.29362520932713
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.011324155330658
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.1777931276928
variable        y0 equal ${yi}
variable        y0 equal 3.72489689154755

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.24698914924965
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.72886715693604
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2488   -2.9871562   -2.7244204   -2.7035859 
    2489   -2.9871562   -2.7244204   -2.7157761 
Loop time of 3.70583e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.1777931276928
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.72489689154755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82207543173915
variable        y0 equal ${yi}
variable        y0 equal 0.923057528245776

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.77348309079295
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.839610656011432
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2489   -2.9871562   -2.7244204   -2.7157761 
    2490   -2.9871562   -2.7244204   -2.6936335 
Loop time of 3.88491e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82207543173915
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.923057528245776
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82207543173915
variable        y0 equal ${yi}
variable        y0 equal 0.923057528245776

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.80040578166133
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.895316119897693
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2490   -2.9871562   -2.7244204   -2.6936335 
    2491   -2.9871562   -2.7244204    -2.718514 
Loop time of 3.82106e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82207543173915
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.923057528245776
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.72697503765058
variable        y0 equal ${yi}
variable        y0 equal 2.78031077357629

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.67052310903501
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.70643812390664
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2491   -2.9871562   -2.7244204    -2.718514 
    2492   -2.9871562   -2.7244204   -2.6926937 
Loop time of 3.8948e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.72697503765058
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.78031077357629
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.41449785946924
variable        y0 equal ${yi}
variable        y0 equal 5.54428255503374

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.37248531102258
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.57884387915331
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2492   -2.9871562   -2.7244204   -2.6926937 
    2493   -2.9871562   -2.7244204   -2.7112208 
Loop time of 3.84332e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.41449785946924
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.54428255503374
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.49041990796652
variable        y0 equal ${yi}
variable        y0 equal 4.63726146572992

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.435575933853056
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.56241592520639
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2493   -2.9871562   -2.7244204   -2.7112208 
    2494   -2.9871562   -2.7244204   -2.6742139 
Loop time of 3.78896e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.49041990796652
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.63726146572992
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.3840241916916
variable        y0 equal ${yi}
variable        y0 equal 9.27708193767397

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.34542459328385
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.35314609515993
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2494   -2.9871562   -2.7244204   -2.6742139 
    2495   -2.9871562   -2.7244204    -2.712433 
Loop time of 3.84566e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.3840241916916
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.27708193767397
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.8208997893202
variable        y0 equal ${yi}
variable        y0 equal 1.93073156259127

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.77372619389173
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.9292484082944
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2495   -2.9871562   -2.7244204    -2.712433 
    2496   -2.9871562   -2.7244204   -2.7262205 
Loop time of 3.76666e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.72622048928309
variable naccept equal ${increment}
variable naccept equal 446

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 5.97854424674504
variable        y0 equal ${yi}
variable        y0 equal 0.914465494859546

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 6.01453663070195
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.886245449292987
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2496   -2.9871562   -2.7262205   -2.7262205 
    2497   -2.9871562   -2.7262205   -2.7219928 
Loop time of 3.72215e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 5.97854424674504
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.914465494859546
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.76264746387434
variable        y0 equal ${yi}
variable        y0 equal 8.40153711952266

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.68554382522535
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.33670610107478
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2497   -2.9871562   -2.7262205   -2.7219928 
    2498   -2.9871562   -2.7262205   -2.7194778 
Loop time of 3.77939e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.76264746387434
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.40153711952266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 10.7438378771
variable        y0 equal ${yi}
variable        y0 equal 3.74340155882966

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 10.7132879455738
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.81038624806535
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2498   -2.9871562   -2.7262205   -2.7194778 
    2499   -2.9871562   -2.7262205    -2.705835 
Loop time of 3.71356e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 10.7438378771
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.74340155882966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.56384705462877
variable        y0 equal ${yi}
variable        y0 equal 0.0929038047790526

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.57013460555498
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.160969114303589
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2499   -2.9871562   -2.7262205    -2.705835 
    2500   -2.9871562   -2.7262205   -2.7080353 
Loop time of 3.81141e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.56384705462877
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.0929038047790526
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.3840241916916
variable        y0 equal ${yi}
variable        y0 equal 9.27708193767397

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.40407173712464
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.20940547693102
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2500   -2.9871562   -2.7262205   -2.7080353 
    2501   -2.9871562   -2.7262205   -2.7162258 
Loop time of 3.89249e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.3840241916916
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.27708193767397
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0712319020292
variable        y0 equal ${yi}
variable        y0 equal 8.4037723175436

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.0032175306341
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.35262674011287
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2501   -2.9871562   -2.7262205   -2.7162258 
    2502   -2.9871562   -2.7262205   -2.6887034 
Loop time of 3.79699e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.0712319020292
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.4037723175436
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.49041990796652
variable        y0 equal ${yi}
variable        y0 equal 4.63726146572992

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.40368461171713
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.63267090672418
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2502   -2.9871562   -2.7262205   -2.6887034 
    2503   -2.9871562   -2.7262205   -2.6892857 
Loop time of 3.74522e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.49041990796652
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.63726146572992
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.3743338862982
variable        y0 equal ${yi}
variable        y0 equal 5.59916444962221

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.37748662629988
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.52215564196306
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2503   -2.9871562   -2.7262205   -2.6892857 
    2504   -2.9871562   -2.7262205   -2.7248522 
Loop time of 3.8055e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.72485216754949
variable naccept equal ${increment}
variable naccept equal 447

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.2537579540272
variable        y0 equal ${yi}
variable        y0 equal 0.909067996251911

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.2259225610752
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.949090560186237
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2504   -2.9871562   -2.7248522   -2.7248522 
    2505   -2.9871562   -2.7248522   -2.7275389 
Loop time of 3.80589e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.72753887057255
variable naccept equal ${increment}
variable naccept equal 448

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78417022426559
variable        y0 equal ${yi}
variable        y0 equal 1.03279469798836

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.8281109710498
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.01877110790047
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2505   -2.9871562   -2.7275389   -2.7275389 
    2506   -2.9871562   -2.7275389   -2.7193845 
Loop time of 3.823e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.78417022426559
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.03279469798836
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.1372151497861
variable        y0 equal ${yi}
variable        y0 equal 6.56728928820123

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.153654468443
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.49468966261377
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2506   -2.9871562   -2.7275389   -2.7193845 
    2507   -2.9871562   -2.7275389   -2.7379765 
Loop time of 3.737e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.73797653017896
variable naccept equal ${increment}
variable naccept equal 449

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.62633978009005
variable        y0 equal ${yi}
variable        y0 equal 2.82587088319162

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.67416161179324
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.76648091050485
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2507   -2.9871562   -2.7379765   -2.7379765 
    2508   -2.9871562   -2.7379765   -2.7278793 
Loop time of 3.90689e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.62633978009005
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.82587088319162
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.14624181706459
variable        y0 equal ${yi}
variable        y0 equal 4.60836122387811

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.14413404185326
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.55988635176584
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2508   -2.9871562   -2.7379765   -2.7278793 
    2509   -2.9871562   -2.7379765   -2.7268855 
Loop time of 3.88184e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.14624181706459
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.60836122387811
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.47866305827219
variable        y0 equal ${yi}
variable        y0 equal 9.25160747278063

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.51858751296122
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.30669236886828
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2509   -2.9871562   -2.7379765   -2.7268855 
    2510   -2.9871562   -2.7379765   -2.7360073 
Loop time of 3.70944e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.47866305827219
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.25160747278063
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0712319020292
variable        y0 equal ${yi}
variable        y0 equal 8.4037723175436

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.066631687071
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.36661752380428
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2510   -2.9871562   -2.7379765   -2.7360073 
    2511   -2.9871562   -2.7379765    -2.734252 
Loop time of 3.73768e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.0712319020292
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.4037723175436
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.72697503765058
variable        y0 equal ${yi}
variable        y0 equal 2.78031077357629

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.7453461547656
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.79009700986245
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2511   -2.9871562   -2.7379765    -2.734252 
    2512   -2.9871562   -2.7379765    -2.737909 
Loop time of 3.76799e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.73790895472286
variable naccept equal ${increment}
variable naccept equal 450

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.10698695500545
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.79429150006836
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2512   -2.9871562    -2.737909    -2.737909 
    2513   -2.9871562    -2.737909   -2.7314421 
Loop time of 3.77802e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.07460362631828
variable        y0 equal ${yi}
variable        y0 equal 6.51190980211725

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.12681160885841
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.47935723797312
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2513   -2.9871562    -2.737909   -2.7314421 
    2514   -2.9871562    -2.737909   -2.7399766 
Loop time of 3.77039e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.73997662143941
variable naccept equal ${increment}
variable naccept equal 451

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.05731099564582
variable        y0 equal ${yi}
variable        y0 equal 8.44346694864328

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.12335204798728
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.4403239241987
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2514   -2.9871562   -2.7399766   -2.7399766 
    2515   -2.9871562   -2.7399766   -2.7192332 
Loop time of 3.74405e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.05731099564582
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.44346694864328
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.99489848890945
variable        y0 equal ${yi}
variable        y0 equal 4.67387059086726

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 7.08474793711349
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.68879310244487
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2515   -2.9871562   -2.7399766   -2.7192332 
    2516   -2.9871562   -2.7399766   -2.7171522 
Loop time of 3.83662e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.99489848890945
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.67387059086726
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 5.97854424674504
variable        y0 equal ${yi}
variable        y0 equal 0.914465494859546

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 6.02271096665852
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.898084254968494
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2516   -2.9871562   -2.7399766   -2.7171522 
    2517   -2.9871562   -2.7399766   -2.7344004 
Loop time of 3.74321e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 5.97854424674504
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.914465494859546
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.37748662629988
variable        y0 equal ${yi}
variable        y0 equal 5.52215564196306

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.36031145254042
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.55776102488237
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2517   -2.9871562   -2.7399766   -2.7344004 
    2518   -2.9871562   -2.7399766   -2.7475769 
Loop time of 3.85105e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.74757689933787
variable naccept equal ${increment}
variable naccept equal 452

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.94595673918066
variable        y0 equal ${yi}
variable        y0 equal 2.80184977027276

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 5.02701055645285
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.72345732423165
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2518   -2.9871562   -2.7475769   -2.7475769 
    2519   -2.9871562   -2.7475769    -2.700057 
Loop time of 3.78406e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.94595673918066
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.80184977027276
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3012223724386
variable        y0 equal ${yi}
variable        y0 equal 2.8246198293815

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.3366109613439
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.82603290053705
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2519   -2.9871562   -2.7475769    -2.700057 
    2520   -2.9871562   -2.7475769    -2.738187 
Loop time of 3.76189e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3012223724386
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.8246198293815
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.7453461547656
variable        y0 equal ${yi}
variable        y0 equal 2.79009700986245

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.68916875322294
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.78700021478036
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2520   -2.9871562   -2.7475769    -2.738187 
    2521   -2.9871562   -2.7475769   -2.7458118 
Loop time of 3.8724e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.7453461547656
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.79009700986245
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.14624181706459
variable        y0 equal ${yi}
variable        y0 equal 4.60836122387811

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.19923895318062
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.60343447083398
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2521   -2.9871562   -2.7475769   -2.7458118 
    2522   -2.9871562   -2.7475769    -2.736988 
Loop time of 3.72146e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.14624181706459
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.60836122387811
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.49041990796652
variable        y0 equal ${yi}
variable        y0 equal 4.63726146572992

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.439718993106748
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.68264415615961
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2522   -2.9871562   -2.7475769    -2.736988 
    2523   -2.9871562   -2.7475769   -2.7344642 
Loop time of 3.83672e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.49041990796652
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.63726146572992
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.18849291880342
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.52632815783221
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2523   -2.9871562   -2.7475769   -2.7344642 
    2524   -2.9871562   -2.7475769   -2.7118649 
Loop time of 3.81398e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78270576516277
variable        y0 equal ${yi}
variable        y0 equal 4.66047749871181

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.72176316300518
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.60984217280315
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2524   -2.9871562   -2.7475769   -2.7118649 
    2525   -2.9871562   -2.7475769   -2.7388375 
Loop time of 3.77472e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78270576516277
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.66047749871181
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.1777931276928
variable        y0 equal ${yi}
variable        y0 equal 3.72489689154755

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.21831980387078
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.62648330493103
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2525   -2.9871562   -2.7475769   -2.7388375 
    2526   -2.9871562   -2.7475769   -2.7243137 
Loop time of 3.73555e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.1777931276928
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.72489689154755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.35614831844235
variable        y0 equal ${yi}
variable        y0 equal 3.74340068860184

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.27243640819455
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.67094530625473
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2526   -2.9871562   -2.7475769   -2.7243137 
    2527   -2.9871562   -2.7475769   -2.6952728 
Loop time of 3.80704e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.35614831844235
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.74340068860184
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.53207862217199
variable        y0 equal ${yi}
variable        y0 equal 9.2839910458359

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.54144344169866
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.20346650588839
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2527   -2.9871562   -2.7475769   -2.6952728 
    2528   -2.9871562   -2.7475769   -2.7353399 
Loop time of 3.80816e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.53207862217199
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.2839910458359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.84264154393664
variable        y0 equal ${yi}
variable        y0 equal 4.64205295199321

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.82639148194781
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.70796897763179
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2528   -2.9871562   -2.7475769   -2.7353399 
    2529   -2.9871562   -2.7475769   -2.7314405 
Loop time of 3.82046e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.84264154393664
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.64205295199321
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.59509903668044
variable        y0 equal ${yi}
variable        y0 equal 5.54114934151369

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.65641721962569
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.63188927118975
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2529   -2.9871562   -2.7475769   -2.7314405 
    2530   -2.9871562   -2.7475769   -2.7311054 
Loop time of 3.68307e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.59509903668044
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.54114934151369
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.0681977808366
variable        y0 equal ${yi}
variable        y0 equal 4.6233086740391

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.03021518586971
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.59654492491648
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2530   -2.9871562   -2.7475769   -2.7311054 
    2531   -2.9871562   -2.7475769   -2.7367074 
Loop time of 3.7741e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.0681977808366
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.6233086740391
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.36031145254042
variable        y0 equal ${yi}
variable        y0 equal 5.55776102488237

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.39962128797438
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.481746434619
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2531   -2.9871562   -2.7475769   -2.7367074 
    2532   -2.9871562   -2.7475769   -2.7164591 
Loop time of 3.77516e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.36031145254042
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.55776102488237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.00662141441203
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.61160910860528
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2532   -2.9871562   -2.7475769   -2.7164591 
    2533   -2.9871562   -2.7475769    -2.705568 
Loop time of 3.82479e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.81859772721415
variable        y0 equal ${yi}
variable        y0 equal 6.51868253485194

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.78533812085276
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.5534119559907
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2533   -2.9871562   -2.7475769    -2.705568 
    2534   -2.9871562   -2.7475769   -2.7512219 
Loop time of 3.736e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.75122187833558
variable naccept equal ${increment}
variable naccept equal 453

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.84264154393664
variable        y0 equal ${yi}
variable        y0 equal 4.64205295199321

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.74420617778292
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.58218485468791
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2534   -2.9871562   -2.7512219   -2.7512219 
    2535   -2.9871562   -2.7512219   -2.6821924 
Loop time of 3.79755e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.84264154393664
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.64205295199321
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.2259225610752
variable        y0 equal ${yi}
variable        y0 equal 0.949090560186237

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.2052143696804
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.973963053930133
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2535   -2.9871562   -2.7512219   -2.6821924 
    2536   -2.9871562   -2.7512219   -2.7482937 
Loop time of 3.75619e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.2259225610752
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.949090560186237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.05731099564582
variable        y0 equal ${yi}
variable        y0 equal 8.44346694864328

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.09282467085868
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.46241891302164
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2536   -2.9871562   -2.7512219   -2.7482937 
    2537   -2.9871562   -2.7512219   -2.7437119 
Loop time of 3.87294e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.05731099564582
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.44346694864328
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.77372619389173
variable        y0 equal ${yi}
variable        y0 equal 1.9292484082944

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.84884953974363
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.95286218307086
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2537   -2.9871562   -2.7512219   -2.7437119 
    2538   -2.9871562   -2.7512219   -2.7369288 
Loop time of 3.88944e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.77372619389173
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.9292484082944
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78270576516277
variable        y0 equal ${yi}
variable        y0 equal 4.66047749871181

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.80110332289821
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.71887539977001
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2538   -2.9871562   -2.7512219   -2.7369288 
    2539   -2.9871562   -2.7512219   -2.7398492 
Loop time of 3.78381e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78270576516277
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.66047749871181
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.42935876050855
variable        y0 equal ${yi}
variable        y0 equal 7.38294791307711

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.34016553560163
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.3898782524135
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2539   -2.9871562   -2.7512219   -2.7398492 
    2540   -2.9871562   -2.7512219   -2.7326827 
Loop time of 3.94526e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.42935876050855
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.38294791307711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.1955849651357
variable        y0 equal ${yi}
variable        y0 equal 4.64925400370525

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.2275141600629
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.63129712695049
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2540   -2.9871562   -2.7512219   -2.7326827 
    2541   -2.9871562   -2.7512219   -2.7459342 
Loop time of 3.822e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.1955849651357
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.64925400370525
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.09319434760905
variable        y0 equal ${yi}
variable        y0 equal 0.990582271325916

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.15939325689173
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 1.00308979343209
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2541   -2.9871562   -2.7512219   -2.7459342 
    2542   -2.9871562   -2.7512219   -2.7378355 
Loop time of 3.7557e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.09319434760905
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 0.990582271325916
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.76264746387434
variable        y0 equal ${yi}
variable        y0 equal 8.40153711952266

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.70561543901396
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.49398739255962
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2542   -2.9871562   -2.7512219   -2.7378355 
    2543   -2.9871562   -2.7512219   -2.7228606 
Loop time of 3.77802e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.76264746387434
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.40153711952266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.59509903668044
variable        y0 equal ${yi}
variable        y0 equal 5.54114934151369

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.52997062681792
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.62096328680712
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2543   -2.9871562   -2.7512219   -2.7228606 
    2544   -2.9871562   -2.7512219   -2.7206911 
Loop time of 3.90241e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.59509903668044
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.54114934151369
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.02058532555753
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.55069309797549
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2544   -2.9871562   -2.7512219   -2.7206911 
    2545   -2.9871562   -2.7512219   -2.7206429 
Loop time of 3.76257e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 68

variable        x0 equal ${xi}
variable        x0 equal 6.41449785946924
variable        y0 equal ${yi}
variable        y0 equal 5.54428255503374

set             atom $i x ${xnew}
set             atom 68 x ${xnew}
set             atom 68 x 6.3908845853718
  1 settings made for x
set             atom $i y ${ynew}
set             atom 68 y ${ynew}
set             atom 68 y 5.46690077727037
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2545   -2.9871562   -2.7512219   -2.7206429 
    2546   -2.9871562   -2.7512219   -2.7341891 
Loop time of 3.70665e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 68 x ${x0}
set atom 68 x 6.41449785946924
  1 settings made for x
set atom $i y ${y0}
set atom 68 y ${y0}
set atom 68 y 5.54428255503374
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.73731143672897
variable        y0 equal ${yi}
variable        y0 equal 4.63249358290597

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.78571455676986
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.62642850035592
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2546   -2.9871562   -2.7512219   -2.7341891 
    2547   -2.9871562   -2.7512219   -2.7406073 
Loop time of 3.82818e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.73731143672897
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.63249358290597
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.1777931276928
variable        y0 equal ${yi}
variable        y0 equal 3.72489689154755

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.27316848675118
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.65160181088578
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2547   -2.9871562   -2.7512219   -2.7406073 
    2548   -2.9871562   -2.7512219   -2.7235904 
Loop time of 3.7806e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.1777931276928
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.72489689154755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.508004017272855
variable        y0 equal ${yi}
variable        y0 equal 8.35369931377467

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.60331395427313
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.31364232219752
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2548   -2.9871562   -2.7512219   -2.7235904 
    2549   -2.9871562   -2.7512219   -2.7232071 
Loop time of 6.87198e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.508004017272855
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.35369931377467
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.6573487090933
variable        y0 equal ${yi}
variable        y0 equal 7.44725758161806

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.75684977053282
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.48617180910372
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2549   -2.9871562   -2.7512219   -2.7232071 
    2550   -2.9871562   -2.7512219    -2.710016 
Loop time of 3.8229e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 99 x ${x0}
set atom 99 x 9.6573487090933
  1 settings made for x
set atom $i y ${y0}
set atom 99 y ${y0}
set atom 99 y 7.44725758161806
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.48385869104635
variable        y0 equal ${yi}
variable        y0 equal 7.38020931806827

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.49927381117117
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.4024957450893
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2550   -2.9871562   -2.7512219    -2.710016 
    2551   -2.9871562   -2.7512219   -2.7540362 
Loop time of 3.82281e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.75403624574934
variable naccept equal ${increment}
variable naccept equal 454

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.0832990586648
variable        y0 equal ${yi}
variable        y0 equal 2.88667256804804

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.08106065391398
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.81335496875147
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2551   -2.9871562   -2.7540362   -2.7540362 
    2552   -2.9871562   -2.7540362   -2.7628752 
Loop time of 3.70227e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.76287523708955
variable naccept equal ${increment}
variable naccept equal 455

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20813699721852
variable        y0 equal ${yi}
variable        y0 equal 5.56420804207521

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.13896400689641
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.48430629914003
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2552   -2.9871562   -2.7628752   -2.7628752 
    2553   -2.9871562   -2.7628752   -2.7213279 
Loop time of 3.85193e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20813699721852
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56420804207521
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.23461158911094
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.85735478780335
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2553   -2.9871562   -2.7628752   -2.7213279 
    2554   -2.9871562   -2.7628752    -2.755318 
Loop time of 3.80033e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.26465234199867
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.48927501764559
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2554   -2.9871562   -2.7628752    -2.755318 
    2555   -2.9871562   -2.7628752   -2.7505098 
Loop time of 3.841e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.36031145254042
variable        y0 equal ${yi}
variable        y0 equal 5.55776102488237

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.42462965646651
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.65123498385149
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2555   -2.9871562   -2.7628752   -2.7505098 
    2556   -2.9871562   -2.7628752   -2.7062835 
Loop time of 3.95518e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.36031145254042
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.55776102488237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 1.10092277844601
variable        y0 equal ${yi}
variable        y0 equal 9.22189815748065

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 1.07474994977169
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.25899240482181
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2556   -2.9871562   -2.7628752   -2.7062835 
    2557   -2.9871562   -2.7628752   -2.7635461 
Loop time of 3.76222e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.76354611241039
variable naccept equal ${increment}
variable naccept equal 456

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.59509903668044
variable        y0 equal ${yi}
variable        y0 equal 5.54114934151369

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.51657672403929
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.54650827591616
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2557   -2.9871562   -2.7635461   -2.7635461 
    2558   -2.9871562   -2.7635461   -2.7472381 
Loop time of 3.81939e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.59509903668044
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.54114934151369
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.92722187876045
variable        y0 equal ${yi}
variable        y0 equal 8.34011304296548

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.91280202507316
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.25913454212243
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2558   -2.9871562   -2.7635461   -2.7472381 
    2559   -2.9871562   -2.7635461   -2.7383385 
Loop time of 3.88776e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.92722187876045
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.34011304296548
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78417022426559
variable        y0 equal ${yi}
variable        y0 equal 1.03279469798836

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.73525495727493
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.10682208131584
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2559   -2.9871562   -2.7635461   -2.7383385 
    2560   -2.9871562   -2.7635461   -2.7437814 
Loop time of 3.87611e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.78417022426559
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.03279469798836
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.92722187876045
variable        y0 equal ${yi}
variable        y0 equal 8.34011304296548

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 5.00975304483711
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.30277833856637
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2560   -2.9871562   -2.7635461   -2.7437814 
    2561   -2.9871562   -2.7635461   -2.7408614 
Loop time of 3.80855e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.92722187876045
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.34011304296548
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.1955849651357
variable        y0 equal ${yi}
variable        y0 equal 4.64925400370525

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.2596191767713
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.63459927195476
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2561   -2.9871562   -2.7635461   -2.7408614 
    2562   -2.9871562   -2.7635461   -2.7470937 
Loop time of 3.88482e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.1955849651357
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.64925400370525
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20813699721852
variable        y0 equal ${yi}
variable        y0 equal 5.56420804207521

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.30552391767064
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.48896470015245
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2562   -2.9871562   -2.7635461   -2.7470937 
    2563   -2.9871562   -2.7635461   -2.7247518 
Loop time of 3.78091e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20813699721852
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56420804207521
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.68944142937442
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.58257600800028
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2563   -2.9871562   -2.7635461   -2.7247518 
    2564   -2.9871562   -2.7635461   -2.7316152 
Loop time of 3.89494e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 0.960574761230287
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.55208790626788
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2564   -2.9871562   -2.7635461   -2.7316152 
    2565   -2.9871562   -2.7635461   -2.7048238 
Loop time of 3.79802e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.47866305827219
variable        y0 equal ${yi}
variable        y0 equal 9.25160747278063

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.47871875285227
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.25827397811739
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2565   -2.9871562   -2.7635461   -2.7048238 
    2566   -2.9871562   -2.7635461   -2.7640713 
Loop time of 3.773e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.76407125154862
variable naccept equal ${increment}
variable naccept equal 457

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.56227880874101
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.65627968256669
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2566   -2.9871562   -2.7640713   -2.7640713 
    2567   -2.9871562   -2.7640713   -2.7531553 
Loop time of 3.68399e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.0712319020292
variable        y0 equal ${yi}
variable        y0 equal 8.4037723175436

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.1377164248487
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.38071602500973
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2567   -2.9871562   -2.7640713   -2.7531553 
    2568   -2.9871562   -2.7640713   -2.7689965 
Loop time of 3.9069e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.76899649663035
variable naccept equal ${increment}
variable naccept equal 458

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.00774297991439
variable        y0 equal ${yi}
variable        y0 equal 2.80172786685327

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.95835563221618
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.71815630170206
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2568   -2.9871562   -2.7689965   -2.7689965 
    2569   -2.9871562   -2.7689965   -2.7347779 
Loop time of 3.90615e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 7.00774297991439
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.80172786685327
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.49472845632804
variable        y0 equal ${yi}
variable        y0 equal 5.57788908426957

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.55627038318885
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.63425939028458
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2569   -2.9871562   -2.7689965   -2.7347779 
    2570   -2.9871562   -2.7689965   -2.7469287 
Loop time of 3.74316e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.49472845632804
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.57788908426957
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.46636033772546
variable        y0 equal ${yi}
variable        y0 equal 3.78071368498932

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.54954990862924
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.79593175215851
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2570   -2.9871562   -2.7689965   -2.7469287 
    2571   -2.9871562   -2.7689965   -2.7498312 
Loop time of 3.87788e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.46636033772546
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.78071368498932
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.37309358198854
variable        y0 equal ${yi}
variable        y0 equal 7.47418843832278

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.35135756809923
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.40746177759433
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2571   -2.9871562   -2.7689965   -2.7498312 
    2572   -2.9871562   -2.7689965   -2.7667103 
Loop time of 3.73241e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.37309358198854
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.47418843832278
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.88880834538928
variable        y0 equal ${yi}
variable        y0 equal 6.44203974739543

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.93963416774264
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.45324131981364
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2572   -2.9871562   -2.7689965   -2.7667103 
    2573   -2.9871562   -2.7689965   -2.7686896 
Loop time of 3.71179e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.76868964235109
variable naccept equal ${increment}
variable naccept equal 459

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.65424995302935
variable        y0 equal ${yi}
variable        y0 equal 0.940276082265705

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.60296515106936
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.858206113088459
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2573   -2.9871562   -2.7686896   -2.7686896 
    2574   -2.9871562   -2.7686896   -2.7588958 
Loop time of 3.77945e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.65424995302935
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.940276082265705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.56337015468847
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.81189566416871
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2574   -2.9871562   -2.7686896   -2.7588958 
    2575   -2.9871562   -2.7686896   -2.7467943 
Loop time of 3.84631e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20813699721852
variable        y0 equal ${yi}
variable        y0 equal 5.56420804207521

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.29167072534123
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.52898887341219
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2575   -2.9871562   -2.7686896   -2.7467943 
    2576   -2.9871562   -2.7686896   -2.7522274 
Loop time of 3.75929e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20813699721852
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56420804207521
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.42935876050855
variable        y0 equal ${yi}
variable        y0 equal 7.38294791307711

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.35925952592756
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.40855654802584
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2576   -2.9871562   -2.7686896   -2.7522274 
    2577   -2.9871562   -2.7686896   -2.7578371 
Loop time of 3.80219e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.42935876050855
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.38294791307711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.2259225610752
variable        y0 equal ${yi}
variable        y0 equal 0.949090560186237

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.1706056837101
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 0.951093085515827
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2577   -2.9871562   -2.7686896   -2.7578371 
    2578   -2.9871562   -2.7686896   -2.7576869 
Loop time of 3.8579e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.2259225610752
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.949090560186237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.99489848890945
variable        y0 equal ${yi}
variable        y0 equal 4.67387059086726

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 7.05707719603225
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.65129800194667
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2578   -2.9871562   -2.7686896   -2.7576869 
    2579   -2.9871562   -2.7686896   -2.7595583 
Loop time of 3.78591e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.99489848890945
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.67387059086726
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.94595673918066
variable        y0 equal ${yi}
variable        y0 equal 2.80184977027276

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 5.00181346773443
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.76950048180917
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2579   -2.9871562   -2.7686896   -2.7595583 
    2580   -2.9871562   -2.7686896   -2.7479181 
Loop time of 3.7412e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.94595673918066
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.80184977027276
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6997664650136
variable        y0 equal ${yi}
variable        y0 equal 5.5742603296538

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.6779878099614
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.65531424229342
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2580   -2.9871562   -2.7686896   -2.7479181 
    2581   -2.9871562   -2.7686896   -2.7568902 
Loop time of 3.79835e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.6997664650136
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.5742603296538
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.39493876774522
variable        y0 equal ${yi}
variable        y0 equal 1.88860803029603

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.37450953800889
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.98037939450807
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2581   -2.9871562   -2.7686896   -2.7568902 
    2582   -2.9871562   -2.7686896   -2.7298508 
Loop time of 3.80631e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.39493876774522
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.88860803029603
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.97845824916355
variable        y0 equal ${yi}
variable        y0 equal 8.32162626899776

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.03506876189701
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.40096940912303
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2582   -2.9871562   -2.7686896   -2.7298508 
    2583   -2.9871562   -2.7686896    -2.728415 
Loop time of 3.80366e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 5.97845824916355
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.32162626899776
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.29362520932713
variable        y0 equal ${yi}
variable        y0 equal 0.011324155330658

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.27190577744999
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y 0.0790049433708191
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2583   -2.9871562   -2.7686896    -2.728415 
    2584   -2.9871562   -2.7686896   -2.7620766 
Loop time of 3.85698e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.29362520932713
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.011324155330658
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.95838304717534
variable        y0 equal ${yi}
variable        y0 equal 2.82275391789772

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.99820660312169
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.82055082293846
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2584   -2.9871562   -2.7686896   -2.7620766 
    2585   -2.9871562   -2.7686896   -2.7677828 
Loop time of 3.75769e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.95838304717534
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.82275391789772
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.5829854265732
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.5993082160254
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2585   -2.9871562   -2.7686896   -2.7677828 
    2586   -2.9871562   -2.7686896   -2.7683781 
Loop time of 3.77748e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.87144294301158
variable        y0 equal ${yi}
variable        y0 equal 2.78142455788949

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.96563591281062
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.75593838664392
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2586   -2.9871562   -2.7686896   -2.7683781 
    2587   -2.9871562   -2.7686896   -2.7386414 
Loop time of 3.75395e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.87144294301158
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.78142455788949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.34161317427369
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.53668440525729
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2587   -2.9871562   -2.7686896   -2.7386414 
    2588   -2.9871562   -2.7686896   -2.7509093 
Loop time of 3.69278e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.84038932839518
variable        y0 equal ${yi}
variable        y0 equal 8.35802853025493

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.82034868518
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.36977583087978
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2588   -2.9871562   -2.7686896   -2.7509093 
    2589   -2.9871562   -2.7686896   -2.7696303 
Loop time of 3.76396e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.76963034492403
variable naccept equal ${increment}
variable naccept equal 460

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.18119961341076
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.83288923881119
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2589   -2.9871562   -2.7696303   -2.7696303 
    2590   -2.9871562   -2.7696303    -2.758788 
Loop time of 3.82515e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.49041990796652
variable        y0 equal ${yi}
variable        y0 equal 4.63726146572992

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.532816608348753
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.59858382100031
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2590   -2.9871562   -2.7696303    -2.758788 
    2591   -2.9871562   -2.7696303    -2.765455 
Loop time of 3.83505e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.49041990796652
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.63726146572992
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82207543173915
variable        y0 equal ${yi}
variable        y0 equal 0.923057528245776

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.78288132468349
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.871046050298541
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2591   -2.9871562   -2.7696303    -2.765455 
    2592   -2.9871562   -2.7696303   -2.7541719 
Loop time of 3.81216e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.82207543173915
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.923057528245776
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.508004017272855
variable        y0 equal ${yi}
variable        y0 equal 8.35369931377467

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.510015650192167
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.28484345592555
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2592   -2.9871562   -2.7696303   -2.7541719 
    2593   -2.9871562   -2.7696303   -2.7492642 
Loop time of 3.89571e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.508004017272855
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.35369931377467
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.99489848890945
variable        y0 equal ${yi}
variable        y0 equal 4.67387059086726

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.91715529242202
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.72078198546336
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2593   -2.9871562   -2.7696303   -2.7492642 
    2594   -2.9871562   -2.7696303   -2.7518321 
Loop time of 3.76178e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.99489848890945
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.67387059086726
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6761052210979
variable        y0 equal ${yi}
variable        y0 equal 9.25454356181949

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.6280667503528
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.16987500894397
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2594   -2.9871562   -2.7696303   -2.7518321 
    2595   -2.9871562   -2.7696303   -2.7233133 
Loop time of 3.92323e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6761052210979
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.25454356181949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.14428817628719
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.57297480837335
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2595   -2.9871562   -2.7696303   -2.7233133 
    2596   -2.9871562   -2.7696303   -2.7516567 
Loop time of 3.92025e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.47871875285227
variable        y0 equal ${yi}
variable        y0 equal 9.25827397811739

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.47628130435068
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.28394211042254
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2596   -2.9871562   -2.7696303   -2.7516567 
    2597   -2.9871562   -2.7696303   -2.7700039 
Loop time of 3.8018e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.77000389956627
variable naccept equal ${increment}
variable naccept equal 461

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.16359445492134
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.32280795898699
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2597   -2.9871562   -2.7700039   -2.7700039 
    2598   -2.9871562   -2.7700039   -2.7411751 
Loop time of 3.84243e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.97845824916355
variable        y0 equal ${yi}
variable        y0 equal 8.32162626899776

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 5.97761599977009
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.28446922220287
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2598   -2.9871562   -2.7700039   -2.7411751 
    2599   -2.9871562   -2.7700039   -2.7679718 
Loop time of 3.84465e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.767971834478
variable naccept equal ${increment}
variable naccept equal 462

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.08106065391398
variable        y0 equal ${yi}
variable        y0 equal 2.81335496875147

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.12756555675364
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.83343232842783
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2599   -2.9871562   -2.7679718   -2.7679718 
    2600   -2.9871562   -2.7679718   -2.7659385 
Loop time of 3.81557e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.08106065391398
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.81335496875147
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.27258467117654
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y 0.0894657969474824
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2600   -2.9871562   -2.7679718   -2.7659385 
    2601   -2.9871562   -2.7679718   -2.7594709 
Loop time of 3.76956e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.51870072960635
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.51135785118571
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2601   -2.9871562   -2.7679718   -2.7594709 
    2602   -2.9871562   -2.7679718    -2.760738 
Loop time of 3.66897e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.44636772075559
variable        y0 equal ${yi}
variable        y0 equal 9.24993084180682

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.47349325815107
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.1794726322922
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2602   -2.9871562   -2.7679718    -2.760738 
    2603   -2.9871562   -2.7679718   -2.7534983 
Loop time of 3.81162e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.44636772075559
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.24993084180682
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.49662729024011
variable        y0 equal ${yi}
variable        y0 equal 1.85665681741302

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.49619702815134
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.94918405196731
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2603   -2.9871562   -2.7679718   -2.7534983 
    2604   -2.9871562   -2.7679718   -2.7533871 
Loop time of 3.90659e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.49662729024011
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.85665681741302
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.59558219193098
variable        y0 equal ${yi}
variable        y0 equal 0.106504940986633

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.65418849466917
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.194982361793518
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2604   -2.9871562   -2.7679718   -2.7533871 
    2605   -2.9871562   -2.7679718   -2.7313525 
Loop time of 3.70175e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 79 x ${x0}
set atom 79 x 9.59558219193098
  1 settings made for x
set atom $i y ${y0}
set atom 79 y ${y0}
set atom 79 y 0.106504940986633
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78417022426559
variable        y0 equal ${yi}
variable        y0 equal 1.03279469798836

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.80549656351043
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.04229516576561
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2605   -2.9871562   -2.7679718   -2.7313525 
    2606   -2.9871562   -2.7679718   -2.7626303 
Loop time of 3.86359e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.78417022426559
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.03279469798836
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.09727446476326
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.42662099924349
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2606   -2.9871562   -2.7679718   -2.7626303 
    2607   -2.9871562   -2.7679718   -2.7559494 
Loop time of 3.72283e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.12681160885841
variable        y0 equal ${yi}
variable        y0 equal 6.47935723797312

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.16471171099693
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.54039408699503
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2607   -2.9871562   -2.7679718   -2.7559494 
    2608   -2.9871562   -2.7679718   -2.7583742 
Loop time of 3.85006e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.12681160885841
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.47935723797312
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.39493876774522
variable        y0 equal ${yi}
variable        y0 equal 1.88860803029603

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.3382132418892
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.91869671723908
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2608   -2.9871562   -2.7679718   -2.7583742 
    2609   -2.9871562   -2.7679718   -2.7517763 
Loop time of 3.64159e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.39493876774522
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.88860803029603
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.46139991680051
variable        y0 equal ${yi}
variable        y0 equal 1.85337124250001

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.47157912650968
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.9315128721959
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2609   -2.9871562   -2.7679718   -2.7517763 
    2610   -2.9871562   -2.7679718   -2.7553725 
Loop time of 3.68115e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.46139991680051
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.85337124250001
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.13813330570564
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.42639541950488
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2610   -2.9871562   -2.7679718   -2.7553725 
    2611   -2.9871562   -2.7679718   -2.7645013 
Loop time of 3.6958e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.99489848890945
variable        y0 equal ${yi}
variable        y0 equal 4.67387059086726

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 7.03370394983932
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.77093019837306
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2611   -2.9871562   -2.7679718   -2.7645013 
    2612   -2.9871562   -2.7679718   -2.7200733 
Loop time of 3.80255e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.99489848890945
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.67387059086726
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78270576516277
variable        y0 equal ${yi}
variable        y0 equal 4.66047749871181

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.70273706236965
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.59146204346584
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2612   -2.9871562   -2.7679718   -2.7200733 
    2613   -2.9871562   -2.7679718     -2.74829 
Loop time of 3.61184e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78270576516277
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.66047749871181
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.59558219193098
variable        y0 equal ${yi}
variable        y0 equal 0.106504940986633

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.66591517208692
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.0997873902320859
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2613   -2.9871562   -2.7679718     -2.74829 
    2614   -2.9871562   -2.7679718   -2.7642271 
Loop time of 3.59539e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 79 x ${x0}
set atom 79 x 9.59558219193098
  1 settings made for x
set atom $i y ${y0}
set atom 79 y ${y0}
set atom 79 y 0.106504940986633
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.1377164248487
variable        y0 equal ${yi}
variable        y0 equal 8.38071602500973

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.216527486231
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.47142120517788
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2614   -2.9871562   -2.7679718   -2.7642271 
    2615   -2.9871562   -2.7679718   -2.7072422 
Loop time of 6.38552e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.1377164248487
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.38071602500973
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.61455693402712
variable        y0 equal ${yi}
variable        y0 equal 7.4608101996448

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.58402909198229
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.40834535684847
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2615   -2.9871562   -2.7679718   -2.7072422 
    2616   -2.9871562   -2.7679718   -2.7639685 
Loop time of 3.8624e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.61455693402712
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.4608101996448
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.84264154393664
variable        y0 equal ${yi}
variable        y0 equal 4.64205295199321

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.75250455100527
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.63751418942378
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2616   -2.9871562   -2.7679718   -2.7639685 
    2617   -2.9871562   -2.7679718   -2.7281981 
Loop time of 3.69434e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.84264154393664
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.64205295199321
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.82034868518
variable        y0 equal ${yi}
variable        y0 equal 8.36977583087978

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.8068845562089
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.3481332055479
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2617   -2.9871562   -2.7679718   -2.7281981 
    2618   -2.9871562   -2.7679718   -2.7663868 
Loop time of 3.71662e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.82034868518
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.36977583087978
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.71956859707613
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.40856704629954
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2618   -2.9871562   -2.7679718   -2.7663868 
    2619   -2.9871562   -2.7679718    -2.763657 
Loop time of 3.67376e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.00191021560528
variable        y0 equal ${yi}
variable        y0 equal 8.32666997827585

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 7.90920194982388
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.25841989435251
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2619   -2.9871562   -2.7679718    -2.763657 
    2620   -2.9871562   -2.7679718   -2.7024077 
Loop time of 3.72924e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.00191021560528
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.32666997827585
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.21497879663811
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.35720630016589
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2620   -2.9871562   -2.7679718   -2.7024077 
    2621   -2.9871562   -2.7679718   -2.7541213 
Loop time of 3.8196e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6997664650136
variable        y0 equal ${yi}
variable        y0 equal 5.5742603296538

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.7200539191419
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.49317895119387
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2621   -2.9871562   -2.7679718   -2.7541213 
    2622   -2.9871562   -2.7679718   -2.7492216 
Loop time of 3.57268e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.6997664650136
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.5742603296538
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78417022426559
variable        y0 equal ${yi}
variable        y0 equal 1.03279469798836

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.82280285556747
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 0.93848831247124
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2622   -2.9871562   -2.7679718   -2.7492216 
    2623   -2.9871562   -2.7679718   -2.7612858 
Loop time of 3.70979e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.78417022426559
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.03279469798836
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.1955849651357
variable        y0 equal ${yi}
variable        y0 equal 4.64925400370525

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.2224814657232
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.67662017697262
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2623   -2.9871562   -2.7679718   -2.7612858 
    2624   -2.9871562   -2.7679718   -2.7628488 
Loop time of 3.60357e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.1955849651357
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.64925400370525
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.49662729024011
variable        y0 equal ${yi}
variable        y0 equal 1.85665681741302

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.40222845791894
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.91824344775741
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2624   -2.9871562   -2.7679718   -2.7628488 
    2625   -2.9871562   -2.7679718   -2.7352326 
Loop time of 3.77488e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.49662729024011
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.85665681741302
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.1777931276928
variable        y0 equal ${yi}
variable        y0 equal 3.72489689154755

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.10877051988946
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.74462592167984
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2625   -2.9871562   -2.7679718   -2.7352326 
    2626   -2.9871562   -2.7679718   -2.7605175 
Loop time of 3.61462e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.1777931276928
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.72489689154755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.12475378831081
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.9032215871579
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2626   -2.9871562   -2.7679718   -2.7605175 
    2627   -2.9871562   -2.7679718   -2.7667123 
Loop time of 3.73222e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 10.7438378771
variable        y0 equal ${yi}
variable        y0 equal 3.74340155882966

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 10.7869710405521
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.64595911069047
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2627   -2.9871562   -2.7679718   -2.7667123 
    2628   -2.9871562   -2.7679718   -2.7403579 
Loop time of 3.6405e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 10.7438378771
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.74340155882966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 83

variable        x0 equal ${xi}
variable        x0 equal 9.20629341322929
variable        y0 equal ${yi}
variable        y0 equal 2.76325721713403

set             atom $i x ${xnew}
set             atom 83 x ${xnew}
set             atom 83 x 9.19749282319099
  1 settings made for x
set             atom $i y ${ynew}
set             atom 83 y ${ynew}
set             atom 83 y 2.77685404988626
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2628   -2.9871562   -2.7679718   -2.7403579 
    2629   -2.9871562   -2.7679718   -2.7704646 
Loop time of 3.62726e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.77046461672924
variable naccept equal ${increment}
variable naccept equal 463

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.49662729024011
variable        y0 equal ${yi}
variable        y0 equal 1.85665681741302

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.48123937367517
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.9255457200772
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2629   -2.9871562   -2.7704646   -2.7704646 
    2630   -2.9871562   -2.7704646   -2.7634066 
Loop time of 3.70076e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.49662729024011
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.85665681741302
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.0800673158949
variable        y0 equal ${yi}
variable        y0 equal 3.73807540698182

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.11081437190229
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.75025914473664
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2630   -2.9871562   -2.7704646   -2.7634066 
    2631   -2.9871562   -2.7704646    -2.769436 
Loop time of 3.71554e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.0800673158949
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.73807540698182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6761052210979
variable        y0 equal ${yi}
variable        y0 equal 9.25454356181949

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.7314410050563
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.23880385864108
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2631   -2.9871562   -2.7704646    -2.769436 
    2632   -2.9871562   -2.7704646   -2.7685644 
Loop time of 3.59487e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6761052210979
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.25454356181949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.82034868518
variable        y0 equal ${yi}
variable        y0 equal 8.36977583087978

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.89270102301722
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.46578022159633
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2632   -2.9871562   -2.7704646   -2.7685644 
    2633   -2.9871562   -2.7704646   -2.7383407 
Loop time of 3.57849e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.82034868518
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.36977583087978
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.05731099564582
variable        y0 equal ${yi}
variable        y0 equal 8.44346694864328

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.11201520878821
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.43868080295618
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2633   -2.9871562   -2.7704646   -2.7383407 
    2634   -2.9871562   -2.7704646   -2.7689471 
Loop time of 3.60447e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.05731099564582
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.44346694864328
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.25444893280372
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.32453458633685
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2634   -2.9871562   -2.7704646   -2.7689471 
    2635   -2.9871562   -2.7704646   -2.7290026 
Loop time of 3.66206e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 25 x ${x0}
set atom 25 x 2.19470320383415
  1 settings made for x
set atom $i y ${y0}
set atom 25 y ${y0}
set atom 25 y 7.41677955713534
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 7.0781883386676
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.26140713609752
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2635   -2.9871562   -2.7704646   -2.7290026 
    2636   -2.9871562   -2.7704646   -2.7144383 
Loop time of 3.64505e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.49662729024011
variable        y0 equal ${yi}
variable        y0 equal 1.85665681741302

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.50231586217004
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.77253833196228
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2636   -2.9871562   -2.7704646   -2.7144383 
    2637   -2.9871562   -2.7704646   -2.7568904 
Loop time of 3.71316e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.49662729024011
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.85665681741302
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.566282685199644
variable        y0 equal ${yi}
variable        y0 equal 0.865556212175219

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.562153263488676
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.907725413549273
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2637   -2.9871562   -2.7704646   -2.7568904 
    2638   -2.9871562   -2.7704646   -2.7706089 
Loop time of 3.7414e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.77060890246229
variable naccept equal ${increment}
variable naccept equal 464

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.08106065391398
variable        y0 equal ${yi}
variable        y0 equal 2.81335496875147

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.08444314597941
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.78041137429575
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2638   -2.9871562   -2.7706089   -2.7706089 
    2639   -2.9871562   -2.7706089    -2.765857 
Loop time of 3.75855e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.08106065391398
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.81335496875147
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.00191021560528
variable        y0 equal ${yi}
variable        y0 equal 8.32666997827585

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.03981565831997
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.4229176036268
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2639   -2.9871562   -2.7706089    -2.765857 
    2640   -2.9871562   -2.7706089   -2.7662761 
Loop time of 3.69059e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 96 x ${x0}
set atom 96 x 8.00191021560528
  1 settings made for x
set atom $i y ${y0}
set atom 96 y ${y0}
set atom 96 y 8.32666997827585
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.73731143672897
variable        y0 equal ${yi}
variable        y0 equal 4.63249358290597

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.68498188455536
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.63141861313745
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2640   -2.9871562   -2.7706089   -2.7662761 
    2641   -2.9871562   -2.7706089   -2.7718435 
Loop time of 3.59423e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.77184353553146
variable naccept equal ${increment}
variable naccept equal 465

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.51896284658682
variable        y0 equal ${yi}
variable        y0 equal 1.92514754912919

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.48792598087561
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.89407437226838
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2641   -2.9871562   -2.7718435   -2.7718435 
    2642   -2.9871562   -2.7718435   -2.7683029 
Loop time of 3.64574e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.51896284658682
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.92514754912919
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.94595673918066
variable        y0 equal ${yi}
variable        y0 equal 2.80184977027276

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.85736974119482
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.71214421960214
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2642   -2.9871562   -2.7718435   -2.7683029 
    2643   -2.9871562   -2.7718435   -2.7380876 
Loop time of 3.60793e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.94595673918066
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.80184977027276
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.09856075643398
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.49916858211984
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2643   -2.9871562   -2.7718435   -2.7380876 
    2644   -2.9871562   -2.7718435   -2.7682451 
Loop time of 3.63104e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.29362520932713
variable        y0 equal ${yi}
variable        y0 equal 0.011324155330658

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.304918286796
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.0414592981338501
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2644   -2.9871562   -2.7718435   -2.7682451 
    2645   -2.9871562   -2.7718435    -2.764896 
Loop time of 3.80499e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.29362520932713
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.011324155330658
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.77372619389173
variable        y0 equal ${yi}
variable        y0 equal 1.9292484082944

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.69317087410566
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.95198215625354
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2645   -2.9871562   -2.7718435    -2.764896 
    2646   -2.9871562   -2.7718435   -2.7534074 
Loop time of 3.80602e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.77372619389173
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.9292484082944
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.46636033772546
variable        y0 equal ${yi}
variable        y0 equal 3.78071368498932

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.42451576708871
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.7093271212114
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2646   -2.9871562   -2.7718435   -2.7534074 
    2647   -2.9871562   -2.7718435   -2.7663876 
Loop time of 4.00243e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.46636033772546
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.78071368498932
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 6.99216622391388
variable        y0 equal ${yi}
variable        y0 equal 6.45942620769968

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 6.97370140829727
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.50963139072886
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2647   -2.9871562   -2.7718435   -2.7663876 
    2648   -2.9871562   -2.7718435   -2.7656944 
Loop time of 3.71469e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 6.99216622391388
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.45942620769968
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.44636772075559
variable        y0 equal ${yi}
variable        y0 equal 9.24993084180682

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.44680332342054
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.30322401035159
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2648   -2.9871562   -2.7718435   -2.7656944 
    2649   -2.9871562   -2.7718435   -2.7703159 
Loop time of 3.74904e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.44636772075559
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.24993084180682
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.44636772075559
variable        y0 equal ${yi}
variable        y0 equal 9.24993084180682

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.4082928220358
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.3087977479729
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2649   -2.9871562   -2.7718435   -2.7703159 
    2650   -2.9871562   -2.7718435   -2.7672398 
Loop time of 3.67205e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.44636772075559
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.24993084180682
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.3067332633278
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.76335407061708
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2650   -2.9871562   -2.7718435   -2.7672398 
    2651   -2.9871562   -2.7718435   -2.7685602 
Loop time of 3.71974e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.59444475372267
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.5597612573289
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2651   -2.9871562   -2.7718435   -2.7685602 
    2652   -2.9871562   -2.7718435   -2.7357728 
Loop time of 3.61146e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.35614831844235
variable        y0 equal ${yi}
variable        y0 equal 3.74340068860184

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.41628532806302
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.69586811823975
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2652   -2.9871562   -2.7718435   -2.7357728 
    2653   -2.9871562   -2.7718435   -2.7672394 
Loop time of 3.66824e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.35614831844235
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.74340068860184
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6997664650136
variable        y0 equal ${yi}
variable        y0 equal 5.5742603296538

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.7581301768476
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.49460197632509
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2653   -2.9871562   -2.7718435   -2.7672394 
    2654   -2.9871562   -2.7718435   -2.7483744 
Loop time of 3.6683e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.6997664650136
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.5742603296538
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.59509903668044
variable        y0 equal ${yi}
variable        y0 equal 5.54114934151369

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.54024456022857
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.51546145622927
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2654   -2.9871562   -2.7718435   -2.7483744 
    2655   -2.9871562   -2.7718435    -2.759431 
Loop time of 3.69024e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.59509903668044
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.54114934151369
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.35614831844235
variable        y0 equal ${yi}
variable        y0 equal 3.74340068860184

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.39612588086987
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.68720587058197
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2655   -2.9871562   -2.7718435    -2.759431 
    2656   -2.9871562   -2.7718435   -2.7662652 
Loop time of 3.72085e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.35614831844235
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.74340068860184
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.82207543173915
variable        y0 equal ${yi}
variable        y0 equal 0.923057528245776

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.83473797360545
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.925000270116656
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2656   -2.9871562   -2.7718435   -2.7662652 
    2657   -2.9871562   -2.7718435   -2.7726023 
Loop time of 3.56395e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.7726023479579
variable naccept equal ${increment}
variable naccept equal 466

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.83473797360545
variable        y0 equal ${yi}
variable        y0 equal 0.925000270116656

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.7517774037469
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 1.01574166606697
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2657   -2.9871562   -2.7726023   -2.7726023 
    2658   -2.9871562   -2.7726023   -2.7456765 
Loop time of 3.85932e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.83473797360545
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.925000270116656
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 57

variable        x0 equal ${xi}
variable        x0 equal 5.95838304717534
variable        y0 equal ${yi}
variable        y0 equal 2.82275391789772

set             atom $i x ${xnew}
set             atom 57 x ${xnew}
set             atom 57 x 5.91606210429662
  1 settings made for x
set             atom $i y ${ynew}
set             atom 57 y ${ynew}
set             atom 57 y 2.80493757697441
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2658   -2.9871562   -2.7726023   -2.7456765 
    2659   -2.9871562   -2.7726023   -2.7612484 
Loop time of 3.79964e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 57 x ${x0}
set atom 57 x 5.95838304717534
  1 settings made for x
set atom $i y ${y0}
set atom 57 y ${y0}
set atom 57 y 2.82275391789772
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.56384705462877
variable        y0 equal ${yi}
variable        y0 equal 0.0929038047790526

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.57936273971025
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.14442572593689
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2659   -2.9871562   -2.7726023   -2.7612484 
    2660   -2.9871562   -2.7726023    -2.762086 
Loop time of 3.66025e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.56384705462877
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.0929038047790526
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.74047867217485
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.72261772914064
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2660   -2.9871562   -2.7726023    -2.762086 
    2661   -2.9871562   -2.7726023   -2.7389415 
Loop time of 3.63505e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03143052180462
variable        y0 equal ${yi}
variable        y0 equal 5.57988774721818

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 0.933171048957635
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.61961036865907
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2661   -2.9871562   -2.7726023   -2.7389415 
    2662   -2.9871562   -2.7726023   -2.7469809 
Loop time of 3.65321e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03143052180462
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.57988774721818
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.35614831844235
variable        y0 equal ${yi}
variable        y0 equal 3.74340068860184

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.37132815519238
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.71904631419312
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2662   -2.9871562   -2.7726023   -2.7469809 
    2663   -2.9871562   -2.7726023   -2.7725653 
Loop time of 3.70289e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.77256531430153
variable naccept equal ${increment}
variable naccept equal 467

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.36031145254042
variable        y0 equal ${yi}
variable        y0 equal 5.55776102488237

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.34503909746077
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.52377486174303
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2663   -2.9871562   -2.7725653   -2.7725653 
    2664   -2.9871562   -2.7725653    -2.766737 
Loop time of 3.71741e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.36031145254042
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.55776102488237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.08106065391398
variable        y0 equal ${yi}
variable        y0 equal 2.81335496875147

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.13801874517298
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.7439719435821
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2664   -2.9871562   -2.7725653    -2.766737 
    2665   -2.9871562   -2.7725653   -2.7486793 
Loop time of 3.77237e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.08106065391398
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.81335496875147
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.1955849651357
variable        y0 equal ${yi}
variable        y0 equal 4.64925400370525

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.2637990240117
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.66566859835552
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2665   -2.9871562   -2.7725653   -2.7486793 
    2666   -2.9871562   -2.7725653    -2.753918 
Loop time of 3.74739e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.1955849651357
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.64925400370525
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3012223724386
variable        y0 equal ${yi}
variable        y0 equal 2.8246198293815

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.3775013808271
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.91582423421243
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2666   -2.9871562   -2.7725653    -2.753918 
    2667   -2.9871562   -2.7725653   -2.6829063 
Loop time of 3.60229e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3012223724386
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.8246198293815
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.97761599977009
variable        y0 equal ${yi}
variable        y0 equal 8.28446922220287

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 5.92694518525593
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.1948948613554
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2667   -2.9871562   -2.7725653   -2.6829063 
    2668   -2.9871562   -2.7725653    -2.737044 
Loop time of 3.75107e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 5.97761599977009
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.28446922220287
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.44636772075559
variable        y0 equal ${yi}
variable        y0 equal 9.24993084180682

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.47328451076413
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.32978662956088
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2668   -2.9871562   -2.7725653    -2.737044 
    2669   -2.9871562   -2.7725653   -2.7634059 
Loop time of 3.68884e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.44636772075559
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.24993084180682
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.61455693402712
variable        y0 equal ${yi}
variable        y0 equal 7.4608101996448

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.54021386065905
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.40157564010882
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2669   -2.9871562   -2.7725653   -2.7634059 
    2670   -2.9871562   -2.7725653   -2.7590962 
Loop time of 3.66832e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.61455693402712
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.4608101996448
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3012223724386
variable        y0 equal ${yi}
variable        y0 equal 2.8246198293815

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.2358597997686
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.77282664748529
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2670   -2.9871562   -2.7725653   -2.7590962 
    2671   -2.9871562   -2.7725653   -2.7617403 
Loop time of 3.70302e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3012223724386
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.8246198293815
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.46636033772546
variable        y0 equal ${yi}
variable        y0 equal 3.78071368498932

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.43192972659188
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.73780856890808
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2671   -2.9871562   -2.7725653   -2.7617403 
    2672   -2.9871562   -2.7725653   -2.7715851 
Loop time of 3.70773e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.46636033772546
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.78071368498932
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.53207862217199
variable        y0 equal ${yi}
variable        y0 equal 9.2839910458359

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.48746000368368
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.29822014081805
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2672   -2.9871562   -2.7725653   -2.7715851 
    2673   -2.9871562   -2.7725653    -2.767587 
Loop time of 3.54851e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.53207862217199
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.2839910458359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6761052210979
variable        y0 equal ${yi}
variable        y0 equal 9.25454356181949

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.6004716952495
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.22115500676959
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2673   -2.9871562   -2.7725653    -2.767587 
    2674   -2.9871562   -2.7725653   -2.7461127 
Loop time of 3.66953e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6761052210979
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.25454356181949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.76264746387434
variable        y0 equal ${yi}
variable        y0 equal 8.40153711952266

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.76760959823561
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.49782392896709
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2674   -2.9871562   -2.7725653   -2.7461127 
    2675   -2.9871562   -2.7725653   -2.7449075 
Loop time of 3.63529e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.76264746387434
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.40153711952266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 10.7438378771
variable        y0 equal ${yi}
variable        y0 equal 3.74340155882966

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 10.6512055357151
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.73981414599549
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2675   -2.9871562   -2.7725653   -2.7449075 
    2676   -2.9871562   -2.7725653   -2.7374333 
Loop time of 3.62395e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 10.7438378771
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.74340155882966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.16749859173946
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.8086396136052
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2676   -2.9871562   -2.7725653   -2.7374333 
    2677   -2.9871562   -2.7725653   -2.7614156 
Loop time of 3.66068e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.39493876774522
variable        y0 equal ${yi}
variable        y0 equal 1.88860803029603

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.37320003588411
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.98856474540299
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2677   -2.9871562   -2.7725653   -2.7614156 
    2678   -2.9871562   -2.7725653   -2.7269422 
Loop time of 3.9089e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.39493876774522
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.88860803029603
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.09319434760905
variable        y0 equal ${yi}
variable        y0 equal 0.990582271325916

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.10257350801325
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 1.00189624618325
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2678   -2.9871562   -2.7725653   -2.7269422 
    2679   -2.9871562   -2.7725653   -2.7723105 
Loop time of 3.61219e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.7723105217379
variable naccept equal ${increment}
variable naccept equal 468

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 5.97854424674504
variable        y0 equal ${yi}
variable        y0 equal 0.914465494859546

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 5.96447169740193
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.994404335725635
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2679   -2.9871562   -2.7723105   -2.7723105 
    2680   -2.9871562   -2.7723105   -2.7577532 
Loop time of 3.83244e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 5.97854424674504
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.914465494859546
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 20

variable        x0 equal ${xi}
variable        x0 equal 2.13915432134971
variable        y0 equal ${yi}
variable        y0 equal 5.57011886780458

set             atom $i x ${xnew}
set             atom 20 x ${xnew}
set             atom 20 x 2.12576162258491
  1 settings made for x
set             atom $i y ${ynew}
set             atom 20 y ${ynew}
set             atom 20 y 5.55996560995775
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2680   -2.9871562   -2.7723105   -2.7577532 
    2681   -2.9871562   -2.7723105   -2.7721451 
Loop time of 3.69854e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 20 x ${x0}
set atom 20 x 2.13915432134971
  1 settings made for x
set atom $i y ${y0}
set atom 20 y ${y0}
set atom 20 y 5.57011886780458
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.508004017272855
variable        y0 equal ${yi}
variable        y0 equal 8.35369931377467

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.423803980747129
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.30093809284266
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2681   -2.9871562   -2.7723105   -2.7721451 
    2682   -2.9871562   -2.7723105   -2.7496337 
Loop time of 3.64536e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.508004017272855
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.35369931377467
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.61535184541169
variable        y0 equal ${yi}
variable        y0 equal 1.91233646056717

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.66534973540726
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.98460567376679
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2682   -2.9871562   -2.7723105   -2.7496337 
    2683   -2.9871562   -2.7723105   -2.7529875 
Loop time of 3.64196e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.61535184541169
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.91233646056717
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.99489848890945
variable        y0 equal ${yi}
variable        y0 equal 4.67387059086726

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.91941610851928
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.66655744666026
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2683   -2.9871562   -2.7723105   -2.7529875 
    2684   -2.9871562   -2.7723105   -2.7644389 
Loop time of 3.60559e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.99489848890945
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.67387059086726
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.68498188455536
variable        y0 equal ${yi}
variable        y0 equal 4.63141861313745

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.59854188163712
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.71319749707147
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2684   -2.9871562   -2.7723105   -2.7644389 
    2685   -2.9871562   -2.7723105   -2.7404626 
Loop time of 6.5263e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.68498188455536
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.63141861313745
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.14624181706459
variable        y0 equal ${yi}
variable        y0 equal 4.60836122387811

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.23848771769554
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.54635238999292
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2685   -2.9871562   -2.7723105   -2.7404626 
    2686   -2.9871562   -2.7723105    -2.730702 
Loop time of 3.90722e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.14624181706459
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.60836122387811
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.47628130435068
variable        y0 equal ${yi}
variable        y0 equal 9.28394211042254

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.53355408429224
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.26924126851885
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2686   -2.9871562   -2.7723105    -2.730702 
    2687   -2.9871562   -2.7723105   -2.7672477 
Loop time of 3.8016e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.47628130435068
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.28394211042254
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.42935876050855
variable        y0 equal ${yi}
variable        y0 equal 7.38294791307711

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.5110411922064
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.32623309221529
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2687   -2.9871562   -2.7723105   -2.7672477 
    2688   -2.9871562   -2.7723105   -2.7323998 
Loop time of 3.90803e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.42935876050855
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.38294791307711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.59558219193098
variable        y0 equal ${yi}
variable        y0 equal 0.106504940986633

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.53578609703657
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.0863272190093991
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2688   -2.9871562   -2.7723105   -2.7323998 
    2689   -2.9871562   -2.7723105   -2.7583417 
Loop time of 4.26795e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 79 x ${x0}
set atom 79 x 9.59558219193098
  1 settings made for x
set atom $i y ${y0}
set atom 79 y ${y0}
set atom 79 y 0.106504940986633
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.00774297991439
variable        y0 equal ${yi}
variable        y0 equal 2.80172786685327

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.92570709267303
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.82859998914102
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2689   -2.9871562   -2.7723105   -2.7583417 
    2690   -2.9871562   -2.7723105   -2.7589244 
Loop time of 4.03641e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 7.00774297991439
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.80172786685327
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.26462735890904
variable        y0 equal ${yi}
variable        y0 equal 3.68544435067308

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.21920619964161
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.75117003483903
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2690   -2.9871562   -2.7723105   -2.7589244 
    2691   -2.9871562   -2.7723105   -2.7696198 
Loop time of 3.69256e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.26462735890904
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.68544435067308
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.47735198576223
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.77950027747285
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2691   -2.9871562   -2.7723105   -2.7696198 
    2692   -2.9871562   -2.7723105    -2.761519 
Loop time of 3.58371e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.56089502730791
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.79089117808473
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2692   -2.9871562   -2.7723105    -2.761519 
    2693   -2.9871562   -2.7723105   -2.7450106 
Loop time of 3.61127e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.51896284658682
variable        y0 equal ${yi}
variable        y0 equal 1.92514754912919

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.57710869152319
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.89296272180146
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2693   -2.9871562   -2.7723105   -2.7450106 
    2694   -2.9871562   -2.7723105   -2.7757369 
Loop time of 3.67625e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.77573694761085
variable naccept equal ${increment}
variable naccept equal 469

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.99489848890945
variable        y0 equal ${yi}
variable        y0 equal 4.67387059086726

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 7.01196754255935
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.74501197689936
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2694   -2.9871562   -2.7757369   -2.7757369 
    2695   -2.9871562   -2.7757369   -2.7529443 
Loop time of 3.56867e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.99489848890945
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.67387059086726
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.29362520932713
variable        y0 equal ${yi}
variable        y0 equal 0.011324155330658

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.35390280246296
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.0339482069015503
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2695   -2.9871562   -2.7757369   -2.7529443 
    2696   -2.9871562   -2.7757369   -2.7651184 
Loop time of 3.72837e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.29362520932713
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.011324155330658
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.94595673918066
variable        y0 equal ${yi}
variable        y0 equal 2.80184977027276

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.88248906969366
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.8934375998626
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2696   -2.9871562   -2.7757369   -2.7651184 
    2697   -2.9871562   -2.7757369    -2.753634 
Loop time of 3.6897e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.94595673918066
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.80184977027276
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.83473797360545
variable        y0 equal ${yi}
variable        y0 equal 0.925000270116656

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.73585892239695
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.913454588163226
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2697   -2.9871562   -2.7757369    -2.753634 
    2698   -2.9871562   -2.7757369   -2.7466074 
Loop time of 3.69024e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.83473797360545
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.925000270116656
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.56285958130132
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.83887328667772
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2698   -2.9871562   -2.7757369   -2.7466074 
    2699   -2.9871562   -2.7757369   -2.7350825 
Loop time of 3.8017e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.06127923129893
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.46991152302255
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2699   -2.9871562   -2.7757369   -2.7350825 
    2700   -2.9871562   -2.7757369   -2.7710272 
Loop time of 3.65071e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20813699721852
variable        y0 equal ${yi}
variable        y0 equal 5.56420804207521

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.17862673759022
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.60625108425813
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2700   -2.9871562   -2.7757369   -2.7710272 
    2701   -2.9871562   -2.7757369   -2.7702295 
Loop time of 3.6679e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20813699721852
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56420804207521
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.37132815519238
variable        y0 equal ${yi}
variable        y0 equal 3.71904631419312

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.38555111089611
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.63036641640793
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2701   -2.9871562   -2.7757369   -2.7702295 
    2702   -2.9871562   -2.7757369   -2.7380363 
Loop time of 3.63674e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.37132815519238
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.71904631419312
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.14624181706459
variable        y0 equal ${yi}
variable        y0 equal 4.60836122387811

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.05807102639229
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.5710869585888
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2702   -2.9871562   -2.7757369   -2.7380363 
    2703   -2.9871562   -2.7757369   -2.7480523 
Loop time of 3.80516e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.14624181706459
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.60836122387811
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.03528786023313
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.50487603273654
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2703   -2.9871562   -2.7757369   -2.7480523 
    2704   -2.9871562   -2.7757369   -2.7684759 
Loop time of 3.77785e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.03727689066574
variable        y0 equal ${yi}
variable        y0 equal 0.91603718589577

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.03332808294937
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.976936968076556
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2704   -2.9871562   -2.7757369   -2.7684759 
    2705   -2.9871562   -2.7757369   -2.7721602 
Loop time of 3.62268e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.03727689066574
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.91603718589577
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.78533812085276
variable        y0 equal ${yi}
variable        y0 equal 6.5534119559907

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.84132950822001
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.61854993835917
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2705   -2.9871562   -2.7757369   -2.7721602 
    2706   -2.9871562   -2.7757369   -2.7521303 
Loop time of 3.63462e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.78533812085276
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.5534119559907
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78417022426559
variable        y0 equal ${yi}
variable        y0 equal 1.03279469798836

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.82551214893295
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 1.07010789703163
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2706   -2.9871562   -2.7757369   -2.7521303 
    2707   -2.9871562   -2.7757369   -2.7589897 
Loop time of 3.61799e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.78417022426559
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 1.03279469798836
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.93963416774264
variable        y0 equal ${yi}
variable        y0 equal 6.45324131981364

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 6.01690772731295
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.44163547293177
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2707   -2.9871562   -2.7757369   -2.7589897 
    2708   -2.9871562   -2.7757369   -2.7492867 
Loop time of 3.59734e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.93963416774264
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.45324131981364
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.62432969648611
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.67292861504686
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2708   -2.9871562   -2.7757369   -2.7492867 
    2709   -2.9871562   -2.7757369   -2.7580299 
Loop time of 3.65594e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.04019835313016
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.4155686768558
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2709   -2.9871562   -2.7757369   -2.7580299 
    2710   -2.9871562   -2.7757369   -2.7747911 
Loop time of 3.69467e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.99489848890945
variable        y0 equal ${yi}
variable        y0 equal 4.67387059086726

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.91942030468628
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.61521882170604
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2710   -2.9871562   -2.7757369   -2.7747911 
    2711   -2.9871562   -2.7757369   -2.7543887 
Loop time of 3.83439e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.99489848890945
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.67387059086726
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 80

variable        x0 equal ${xi}
variable        x0 equal 10.2259225610752
variable        y0 equal ${yi}
variable        y0 equal 0.949090560186237

set             atom $i x ${xnew}
set             atom 80 x ${xnew}
set             atom 80 x 10.2375795249004
  1 settings made for x
set             atom $i y ${ynew}
set             atom 80 y ${ynew}
set             atom 80 y 1.00769487212929
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2711   -2.9871562   -2.7757369   -2.7543887 
    2712   -2.9871562   -2.7757369   -2.7712668 
Loop time of 3.61037e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 80 x ${x0}
set atom 80 x 10.2259225610752
  1 settings made for x
set atom $i y ${y0}
set atom 80 y ${y0}
set atom 80 y 0.949090560186237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.0800673158949
variable        y0 equal ${yi}
variable        y0 equal 3.73807540698182

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.08133814652616
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.7760181025995
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2712   -2.9871562   -2.7757369   -2.7712668 
    2713   -2.9871562   -2.7757369   -2.7739185 
Loop time of 3.7724e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.0800673158949
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.73807540698182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.05731099564582
variable        y0 equal ${yi}
variable        y0 equal 8.44346694864328

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.06463275868446
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.34677785553033
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2713   -2.9871562   -2.7757369   -2.7739185 
    2714   -2.9871562   -2.7757369   -2.7638372 
Loop time of 3.60045e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.05731099564582
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.44346694864328
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.101794230937958
variable        y0 equal ${yi}
variable        y0 equal 1.84877194545335

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.201327538490296
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.88656329295701
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2714   -2.9871562   -2.7757369   -2.7638372 
    2715   -2.9871562   -2.7757369   -2.7153757 
Loop time of 3.71365e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 6 x ${x0}
set atom 6 x 0.101794230937958
  1 settings made for x
set atom $i y ${y0}
set atom 6 y ${y0}
set atom 6 y 1.84877194545335
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.21513073762112
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.90558656833237
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2715   -2.9871562   -2.7757369   -2.7153757 
    2716   -2.9871562   -2.7757369   -2.7475418 
Loop time of 3.90496e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.4587552738102
variable        y0 equal ${yi}
variable        y0 equal 7.36176157322192

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.39442873715477
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.39628658619189
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2716   -2.9871562   -2.7757369   -2.7475418 
    2717   -2.9871562   -2.7757369   -2.7523798 
Loop time of 3.84577e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.4587552738102
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.36176157322192
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.46636033772546
variable        y0 equal ${yi}
variable        y0 equal 3.78071368498932

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.49110152243692
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.80115879340302
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2717   -2.9871562   -2.7757369   -2.7523798 
    2718   -2.9871562   -2.7757369   -2.7706091 
Loop time of 3.8171e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.46636033772546
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.78071368498932
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.92722187876045
variable        y0 equal ${yi}
variable        y0 equal 8.34011304296548

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 5.00320652365028
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.40048117555673
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2718   -2.9871562   -2.7757369   -2.7706091 
    2719   -2.9871562   -2.7757369   -2.7447051 
Loop time of 3.70122e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.92722187876045
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.34011304296548
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.61455693402712
variable        y0 equal ${yi}
variable        y0 equal 7.4608101996448

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.55146243730013
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.44223819103503
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2719   -2.9871562   -2.7757369   -2.7447051 
    2720   -2.9871562   -2.7757369   -2.7713371 
Loop time of 3.5931e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.61455693402712
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.4608101996448
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.570451636711027
variable        y0 equal ${yi}
variable        y0 equal 2.81422812911371

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.623208315769102
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.8472835299621
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2720   -2.9871562   -2.7757369   -2.7713371 
    2721   -2.9871562   -2.7757369   -2.7675756 
Loop time of 3.77717e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.570451636711027
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.81422812911371
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78270576516277
variable        y0 equal ${yi}
variable        y0 equal 4.66047749871181

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.81331508675701
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.61705712431835
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2721   -2.9871562   -2.7757369   -2.7675756 
    2722   -2.9871562   -2.7757369   -2.7652954 
Loop time of 3.66069e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78270576516277
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.66047749871181
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.8900455796653
variable        y0 equal ${yi}
variable        y0 equal 0.887486429918145

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.94123677849114
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.829113813150262
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2722   -2.9871562   -2.7757369   -2.7652954 
    2723   -2.9871562   -2.7757369   -2.7651069 
Loop time of 3.7225e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.8900455796653
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.887486429918145
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.562153263488676
variable        y0 equal ${yi}
variable        y0 equal 0.907725413549273

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.62932234565344
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.996013673055499
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2723   -2.9871562   -2.7757369   -2.7651069 
    2724   -2.9871562   -2.7757369   -2.7559174 
Loop time of 3.65243e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.562153263488676
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.907725413549273
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.68498188455536
variable        y0 equal ${yi}
variable        y0 equal 4.63141861313745

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.68930492599442
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.62397498244211
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2724   -2.9871562   -2.7757369   -2.7559174 
    2725   -2.9871562   -2.7757369   -2.7756884 
Loop time of 3.68985e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.77568843300901
variable naccept equal ${increment}
variable naccept equal 470

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.77372619389173
variable        y0 equal ${yi}
variable        y0 equal 1.9292484082944

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.80471840380308
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.84145673892566
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2725   -2.9871562   -2.7756884   -2.7756884 
    2726   -2.9871562   -2.7756884   -2.7592206 
Loop time of 3.67206e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.77372619389173
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.9292484082944
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.7772155809271
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.62417449517381
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2726   -2.9871562   -2.7756884   -2.7592206 
    2727   -2.9871562   -2.7756884   -2.7385705 
Loop time of 3.64456e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.49472845632804
variable        y0 equal ${yi}
variable        y0 equal 5.57788908426957

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.50792251665366
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.48970594351487
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2727   -2.9871562   -2.7756884   -2.7385705 
    2728   -2.9871562   -2.7756884    -2.757378 
Loop time of 3.67798e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.49472845632804
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.57788908426957
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6997664650136
variable        y0 equal ${yi}
variable        y0 equal 5.5742603296538

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.7199896653348
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.5352410191794
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2728   -2.9871562   -2.7756884    -2.757378 
    2729   -2.9871562   -2.7756884   -2.7704303 
Loop time of 3.69059e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.6997664650136
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.5742603296538
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.44636772075559
variable        y0 equal ${yi}
variable        y0 equal 9.24993084180682

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.34722593227292
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.25798565852969
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2729   -2.9871562   -2.7756884   -2.7704303 
    2730   -2.9871562   -2.7756884   -2.7506497 
Loop time of 3.69061e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.44636772075559
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.24993084180682
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.39493876774522
variable        y0 equal ${yi}
variable        y0 equal 1.88860803029603

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.44426125366899
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.82641801021165
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2730   -2.9871562   -2.7756884   -2.7506497 
    2731   -2.9871562   -2.7756884   -2.7726712 
Loop time of 3.7238e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.39493876774522
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.88860803029603
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 51

variable        x0 equal ${xi}
variable        x0 equal 5.44636772075559
variable        y0 equal ${yi}
variable        y0 equal 9.24993084180682

set             atom $i x ${xnew}
set             atom 51 x ${xnew}
set             atom 51 x 5.39719825187589
  1 settings made for x
set             atom $i y ${ynew}
set             atom 51 y ${ynew}
set             atom 51 y 9.1726810764107
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2731   -2.9871562   -2.7756884   -2.7726712 
    2732   -2.9871562   -2.7756884    -2.749283 
Loop time of 3.72586e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 51 x ${x0}
set atom 51 x 5.44636772075559
  1 settings made for x
set atom $i y ${y0}
set atom 51 y ${y0}
set atom 51 y 9.24993084180682
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.508004017272855
variable        y0 equal ${yi}
variable        y0 equal 8.35369931377467

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.543282123008634
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.30187239564952
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2732   -2.9871562   -2.7756884    -2.749283 
    2733   -2.9871562   -2.7756884   -2.7597887 
Loop time of 3.62623e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.508004017272855
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.35369931377467
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.12681160885841
variable        y0 equal ${yi}
variable        y0 equal 6.47935723797312

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.15657551009208
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.49191708103647
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2733   -2.9871562   -2.7756884   -2.7597887 
    2734   -2.9871562   -2.7756884   -2.7706223 
Loop time of 3.70158e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.12681160885841
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.47935723797312
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.0681977808366
variable        y0 equal ${yi}
variable        y0 equal 4.6233086740391

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.13978714345791
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.67931303137705
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2734   -2.9871562   -2.7756884   -2.7706223 
    2735   -2.9871562   -2.7756884   -2.7564621 
Loop time of 3.64489e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.0681977808366
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.6233086740391
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.508004017272855
variable        y0 equal ${yi}
variable        y0 equal 8.35369931377467

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.408683081069852
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.32475416578349
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2735   -2.9871562   -2.7756884   -2.7564621 
    2736   -2.9871562   -2.7756884   -2.7563885 
Loop time of 3.58361e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 22 x ${x0}
set atom 22 x 0.508004017272855
  1 settings made for x
set atom $i y ${y0}
set atom 22 y ${y0}
set atom 22 y 8.35369931377467
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.65424995302935
variable        y0 equal ${yi}
variable        y0 equal 0.940276082265705

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.69332105994006
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.85890212844643
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2736   -2.9871562   -2.7756884   -2.7563885 
    2737   -2.9871562   -2.7756884   -2.7627791 
Loop time of 3.66876e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.65424995302935
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.940276082265705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6997664650136
variable        y0 equal ${yi}
variable        y0 equal 5.5742603296538

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.605257304495
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.58328883593279
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2737   -2.9871562   -2.7756884   -2.7627791 
    2738   -2.9871562   -2.7756884   -2.7601567 
Loop time of 3.83306e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.6997664650136
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.5742603296538
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.82874970077812
variable        y0 equal ${yi}
variable        y0 equal 6.51564840809336

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.74813631414711
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.43341072336664
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2738   -2.9871562   -2.7756884   -2.7601567 
    2739   -2.9871562   -2.7756884    -2.732874 
Loop time of 3.65832e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.82874970077812
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.51564840809336
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.36031145254042
variable        y0 equal ${yi}
variable        y0 equal 5.55776102488237

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.41615938344862
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.53768475001054
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2739   -2.9871562   -2.7756884    -2.732874 
    2740   -2.9871562   -2.7756884   -2.7602809 
Loop time of 3.57016e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.36031145254042
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.55776102488237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.49662729024011
variable        y0 equal ${yi}
variable        y0 equal 1.85665681741302

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.504962487212
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.95457674644058
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2740   -2.9871562   -2.7756884   -2.7602809 
    2741   -2.9871562   -2.7756884   -2.7591824 
Loop time of 3.63841e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.49662729024011
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.85665681741302
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.76264746387434
variable        y0 equal ${yi}
variable        y0 equal 8.40153711952266

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.77196835477781
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.35902554906902
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2741   -2.9871562   -2.7756884   -2.7591824 
    2742   -2.9871562   -2.7756884   -2.7754552 
Loop time of 3.72429e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.76264746387434
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.40153711952266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20813699721852
variable        y0 equal ${yi}
variable        y0 equal 5.56420804207521

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.1670378303484
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.49610093777376
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2742   -2.9871562   -2.7756884   -2.7754552 
    2743   -2.9871562   -2.7756884   -2.7601716 
Loop time of 3.64155e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20813699721852
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56420804207521
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20813699721852
variable        y0 equal ${yi}
variable        y0 equal 5.56420804207521

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.16021821260014
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.49291863386827
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2743   -2.9871562   -2.7756884   -2.7601716 
    2744   -2.9871562   -2.7756884   -2.7575669 
Loop time of 3.73723e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20813699721852
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56420804207521
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.78533812085276
variable        y0 equal ${yi}
variable        y0 equal 6.5534119559907

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.75793115416651
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.62456821934214
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2744   -2.9871562   -2.7756884   -2.7575669 
    2745   -2.9871562   -2.7756884   -2.7469189 
Loop time of 3.65249e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.78533812085276
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.5534119559907
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 39

variable        x0 equal ${xi}
variable        x0 equal 3.78270576516277
variable        y0 equal ${yi}
variable        y0 equal 4.66047749871181

set             atom $i x ${xnew}
set             atom 39 x ${xnew}
set             atom 39 x 3.75854543963558
  1 settings made for x
set             atom $i y ${ynew}
set             atom 39 y ${ynew}
set             atom 39 y 4.60805321091579
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2745   -2.9871562   -2.7756884   -2.7469189 
    2746   -2.9871562   -2.7756884   -2.7754491 
Loop time of 3.77171e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 39 x ${x0}
set atom 39 x 3.78270576516277
  1 settings made for x
set atom $i y ${y0}
set atom 39 y ${y0}
set atom 39 y 4.66047749871181
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.83473797360545
variable        y0 equal ${yi}
variable        y0 equal 0.925000270116656

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.90045903245097
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.84424866031441
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2746   -2.9871562   -2.7756884   -2.7754491 
    2747   -2.9871562   -2.7756884   -2.7522839 
Loop time of 3.70676e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.83473797360545
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.925000270116656
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.0004652678857
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.50461668507089
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2747   -2.9871562   -2.7756884   -2.7522839 
    2748   -2.9871562   -2.7756884   -2.7685055 
Loop time of 3.72073e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 1.07474994977169
variable        y0 equal ${yi}
variable        y0 equal 9.25899240482181

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 1.06173906644039
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.17239706027835
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2748   -2.9871562   -2.7756884   -2.7685055 
    2749   -2.9871562   -2.7756884   -2.7593212 
Loop time of 3.56437e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 1.07474994977169
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.25899240482181
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.7304738302989
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.37994344965449
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2749   -2.9871562   -2.7756884   -2.7593212 
    2750   -2.9871562   -2.7756884    -2.739514 
Loop time of 3.66405e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.26356642881738
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y -0.0119078397750823
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2750   -2.9871562   -2.7756884    -2.739514 
    2751   -2.9871562   -2.7756884   -2.7672528 
Loop time of 3.76819e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.153654468443
variable        y0 equal ${yi}
variable        y0 equal 6.49468966261377

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.1314417604466
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.56817893520822
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2751   -2.9871562   -2.7756884   -2.7672528 
    2752   -2.9871562   -2.7756884    -2.762218 
Loop time of 3.72839e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.153654468443
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.49468966261377
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.92722187876045
variable        y0 equal ${yi}
variable        y0 equal 8.34011304296548

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.95929432749092
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.36510621227319
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2752   -2.9871562   -2.7756884    -2.762218 
    2753   -2.9871562   -2.7756884   -2.7706842 
Loop time of 3.69726e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.92722187876045
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.34011304296548
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.93963416774264
variable        y0 equal ${yi}
variable        y0 equal 6.45324131981364

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 6.01564364392749
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.52060936228266
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2753   -2.9871562   -2.7756884   -2.7706842 
    2754   -2.9871562   -2.7756884   -2.7371762 
Loop time of 3.72124e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.93963416774264
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.45324131981364
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 7.01008662262604
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.40628185190257
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2754   -2.9871562   -2.7756884   -2.7371762 
    2755   -2.9871562   -2.7756884   -2.7677706 
Loop time of 3.66516e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 10.7438378771
variable        y0 equal ${yi}
variable        y0 equal 3.74340155882966

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 10.6448442419224
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.83361763520371
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2755   -2.9871562   -2.7756884   -2.7677706 
    2756   -2.9871562   -2.7756884   -2.7091121 
Loop time of 3.78354e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 10.7438378771
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.74340155882966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.03727689066574
variable        y0 equal ${yi}
variable        y0 equal 0.91603718589577

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.02140382805511
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 1.00163526128563
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2756   -2.9871562   -2.7756884   -2.7091121 
    2757   -2.9871562   -2.7756884   -2.7657248 
Loop time of 3.56818e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.03727689066574
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.91603718589577
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.49662729024011
variable        y0 equal ${yi}
variable        y0 equal 1.85665681741302

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.5107245755108
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.82106520316665
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2757   -2.9871562   -2.7756884   -2.7657248 
    2758   -2.9871562   -2.7756884   -2.7737293 
Loop time of 3.79396e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.49662729024011
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.85665681741302
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.59277797777425
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.74201770587098
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2758   -2.9871562   -2.7756884   -2.7737293 
    2759   -2.9871562   -2.7756884   -2.7713389 
Loop time of 3.67324e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.68817537903567
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.59405068890085
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2759   -2.9871562   -2.7756884   -2.7713389 
    2760   -2.9871562   -2.7756884   -2.7405842 
Loop time of 3.7447e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.49472845632804
variable        y0 equal ${yi}
variable        y0 equal 5.57788908426957

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.40880474884284
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.4821429485579
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2760   -2.9871562   -2.7756884   -2.7405842 
    2761   -2.9871562   -2.7756884   -2.7138195 
Loop time of 3.74713e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.49472845632804
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.57788908426957
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.84264154393664
variable        y0 equal ${yi}
variable        y0 equal 4.64205295199321

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.91189687211505
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.73377606028484
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2761   -2.9871562   -2.7756884   -2.7138195 
    2762   -2.9871562   -2.7756884    -2.748771 
Loop time of 3.6752e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.84264154393664
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.64205295199321
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.49472845632804
variable        y0 equal ${yi}
variable        y0 equal 5.57788908426957

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.57418610889686
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.49588426296906
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2762   -2.9871562   -2.7756884    -2.748771 
    2763   -2.9871562   -2.7756884    -2.737299 
Loop time of 3.67414e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.49472845632804
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.57788908426957
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.10257350801325
variable        y0 equal ${yi}
variable        y0 equal 1.00189624618325

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.11351624130106
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.94895263503823
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2763   -2.9871562   -2.7756884    -2.737299 
    2764   -2.9871562   -2.7756884    -2.767531 
Loop time of 3.61744e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.10257350801325
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 1.00189624618325
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.0681977808366
variable        y0 equal ${yi}
variable        y0 equal 4.6233086740391

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.14201272128918
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.6047183310406
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2764   -2.9871562   -2.7756884    -2.767531 
    2765   -2.9871562   -2.7756884    -2.766345 
Loop time of 3.91326e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.0681977808366
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.6233086740391
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.78417022426559
variable        y0 equal ${yi}
variable        y0 equal 1.03279469798836

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.79031698902084
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 0.950206168401568
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2765   -2.9871562   -2.7756884    -2.766345 
    2766   -2.9871562   -2.7756884   -2.7778456 
Loop time of 3.83271e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.77784555117663
variable naccept equal ${increment}
variable naccept equal 471

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.03727689066574
variable        y0 equal ${yi}
variable        y0 equal 0.91603718589577

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.00157360115692
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.870325597036212
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2766   -2.9871562   -2.7778456   -2.7778456 
    2767   -2.9871562   -2.7778456   -2.7697626 
Loop time of 4.04453e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.03727689066574
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.91603718589577
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.10895692745552
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.9121771015889
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2767   -2.9871562   -2.7778456   -2.7697626 
    2768   -2.9871562   -2.7778456   -2.7645927 
Loop time of 3.82989e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.00774297991439
variable        y0 equal ${yi}
variable        y0 equal 2.80172786685327

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.91542027273818
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.87349886866907
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2768   -2.9871562   -2.7778456   -2.7645927 
    2769   -2.9871562   -2.7778456   -2.7493944 
Loop time of 3.61736e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 7.00774297991439
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.80172786685327
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.0681977808366
variable        y0 equal ${yi}
variable        y0 equal 4.6233086740391

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.04885045884945
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.66395711058543
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2769   -2.9871562   -2.7778456   -2.7493944 
    2770   -2.9871562   -2.7778456   -2.7761261 
Loop time of 3.63974e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.0681977808366
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.6233086740391
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.61305398821612
variable        y0 equal ${yi}
variable        y0 equal 4.66496637219354

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.54378738283892
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.63616613501474
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2770   -2.9871562   -2.7778456   -2.7761261 
    2771   -2.9871562   -2.7778456   -2.7723402 
Loop time of 3.86406e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.61305398821612
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.66496637219354
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.49472845632804
variable        y0 equal ${yi}
variable        y0 equal 5.57788908426957

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.58159792263282
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.62838813011842
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2771   -2.9871562   -2.7778456   -2.7723402 
    2772   -2.9871562   -2.7778456    -2.740594 
Loop time of 3.60488e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.49472845632804
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.57788908426957
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.37132815519238
variable        y0 equal ${yi}
variable        y0 equal 3.71904631419312

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.44480085769558
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.73543376488816
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2772   -2.9871562   -2.7778456    -2.740594 
    2773   -2.9871562   -2.7778456   -2.7690965 
Loop time of 3.58861e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.37132815519238
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.71904631419312
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6761052210979
variable        y0 equal ${yi}
variable        y0 equal 9.25454356181949

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.5782221635036
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.23517516362995
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2773   -2.9871562   -2.7778456   -2.7690965 
    2774   -2.9871562   -2.7778456   -2.7469381 
Loop time of 3.5828e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6761052210979
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.25454356181949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.11253125110969
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.96479565284317
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2774   -2.9871562   -2.7778456   -2.7469381 
    2775   -2.9871562   -2.7778456   -2.7548367 
Loop time of 3.6024e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.08106065391398
variable        y0 equal ${yi}
variable        y0 equal 2.81335496875147

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.08236802219248
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.83939957591395
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2775   -2.9871562   -2.7778456   -2.7548367 
    2776   -2.9871562   -2.7778456   -2.7779673 
Loop time of 3.79233e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.77796726841246
variable naccept equal ${increment}
variable naccept equal 472

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 22

variable        x0 equal ${xi}
variable        x0 equal 0.508004017272855
variable        y0 equal ${yi}
variable        y0 equal 8.35369931377467

set             atom $i x ${xnew}
set             atom 22 x ${xnew}
set             atom 22 x 0.535984046855832
  1 settings made for x
set             atom $i y ${ynew}
set             atom 22 y ${ynew}
set             atom 22 y 8.37801740087565
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2776   -2.9871562   -2.7779673   -2.7779673 
    2777   -2.9871562   -2.7779673    -2.777338 
Loop time of 3.72975e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.77733799116846
variable naccept equal ${increment}
variable naccept equal 473

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 99

variable        x0 equal ${xi}
variable        x0 equal 9.6573487090933
variable        y0 equal ${yi}
variable        y0 equal 7.44725758161806

set             atom $i x ${xnew}
set             atom 99 x ${xnew}
set             atom 99 x 9.63496402977583
  1 settings made for x
set             atom $i y ${ynew}
set             atom 99 y ${ynew}
set             atom 99 y 7.44992808428072
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2777   -2.9871562    -2.777338    -2.777338 
    2778   -2.9871562    -2.777338    -2.777045 
Loop time of 3.66241e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 99 x ${x0}
set atom 99 x 9.6573487090933
  1 settings made for x
set atom $i y ${y0}
set atom 99 y ${y0}
set atom 99 y 7.44725758161806
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.56466485142489
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.58825176493159
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2778   -2.9871562    -2.777338    -2.777045 
    2779   -2.9871562    -2.777338    -2.770255 
Loop time of 3.82151e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.1777931276928
variable        y0 equal ${yi}
variable        y0 equal 3.72489689154755

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.09360608497963
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.75192682309281
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2779   -2.9871562    -2.777338    -2.770255 
    2780   -2.9871562    -2.777338   -2.7667125 
Loop time of 3.74605e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.1777931276928
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.72489689154755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.48682004371111
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.48625703995423
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2780   -2.9871562    -2.777338   -2.7667125 
    2781   -2.9871562    -2.777338    -2.753482 
Loop time of 3.68605e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.87144294301158
variable        y0 equal ${yi}
variable        y0 equal 2.78142455788949

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.85500573435908
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.82389258118966
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2781   -2.9871562    -2.777338    -2.753482 
    2782   -2.9871562    -2.777338   -2.7769062 
Loop time of 3.69566e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.77690616975353
variable naccept equal ${increment}
variable naccept equal 474

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.82034868518
variable        y0 equal ${yi}
variable        y0 equal 8.36977583087978

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.7343915871728
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.39627897657451
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2782   -2.9871562   -2.7769062   -2.7769062 
    2783   -2.9871562   -2.7769062   -2.7563589 
Loop time of 3.65739e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.82034868518
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.36977583087978
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.101794230937958
variable        y0 equal ${yi}
variable        y0 equal 1.84877194545335

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.0118701696395876
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.84798332831926
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2783   -2.9871562   -2.7769062   -2.7563589 
    2784   -2.9871562   -2.7769062   -2.7707417 
Loop time of 3.69128e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 6 x ${x0}
set atom 6 x 0.101794230937958
  1 settings made for x
set atom $i y ${y0}
set atom 6 y ${y0}
set atom 6 y 1.84877194545335
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.7453461547656
variable        y0 equal ${yi}
variable        y0 equal 2.79009700986245

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.84086479146909
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.75763660642007
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2784   -2.9871562   -2.7769062   -2.7707417 
    2785   -2.9871562   -2.7769062   -2.7499297 
Loop time of 3.7685e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.7453461547656
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.79009700986245
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.93963416774264
variable        y0 equal ${yi}
variable        y0 equal 6.45324131981364

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.89472551305285
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.39718603626719
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2785   -2.9871562   -2.7769062   -2.7499297 
    2786   -2.9871562   -2.7769062    -2.767003 
Loop time of 3.78279e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.93963416774264
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.45324131981364
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.84264154393664
variable        y0 equal ${yi}
variable        y0 equal 4.64205295199321

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.91014250476351
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.56969110125468
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2786   -2.9871562   -2.7769062    -2.767003 
    2787   -2.9871562   -2.7769062   -2.7597453 
Loop time of 3.76236e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.84264154393664
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.64205295199321
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 38

variable        x0 equal ${xi}
variable        x0 equal 2.68930492599442
variable        y0 equal ${yi}
variable        y0 equal 4.62397498244211

set             atom $i x ${xnew}
set             atom 38 x ${xnew}
set             atom 38 x 2.76101904113724
  1 settings made for x
set             atom $i y ${ynew}
set             atom 38 y ${ynew}
set             atom 38 y 4.62286018484995
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2787   -2.9871562   -2.7769062   -2.7597453 
    2788   -2.9871562   -2.7769062   -2.7719606 
Loop time of 6.4996e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 38 x ${x0}
set atom 38 x 2.68930492599442
  1 settings made for x
set atom $i y ${y0}
set atom 38 y ${y0}
set atom 38 y 4.62397498244211
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.1912204511902
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.5322381252547
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2788   -2.9871562   -2.7769062   -2.7719606 
    2789   -2.9871562   -2.7769062   -2.7431034 
Loop time of 3.68738e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.79031698902084
variable        y0 equal ${yi}
variable        y0 equal 0.950206168401568

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.81512605150177
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 0.926784594762652
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2789   -2.9871562   -2.7769062   -2.7431034 
    2790   -2.9871562   -2.7769062   -2.7700833 
Loop time of 3.67885e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.79031698902084
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 0.950206168401568
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.562153263488676
variable        y0 equal ${yi}
variable        y0 equal 0.907725413549273

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.657237942615416
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.86455499719414
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2790   -2.9871562   -2.7769062   -2.7700833 
    2791   -2.9871562   -2.7769062   -2.7606982 
Loop time of 3.69497e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.562153263488676
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.907725413549273
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.59509903668044
variable        y0 equal ${yi}
variable        y0 equal 5.54114934151369

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.62531409739135
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.57897175495821
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2791   -2.9871562   -2.7769062   -2.7606982 
    2792   -2.9871562   -2.7769062   -2.7763889 
Loop time of 3.73235e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.59509903668044
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.54114934151369
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.55801884093706
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.48501539175706
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2792   -2.9871562   -2.7769062   -2.7763889 
    2793   -2.9871562   -2.7769062   -2.7698175 
Loop time of 3.72736e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3012223724386
variable        y0 equal ${yi}
variable        y0 equal 2.8246198293815

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.2110354784986
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.90414255830148
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2793   -2.9871562   -2.7769062   -2.7698175 
    2794   -2.9871562   -2.7769062   -2.7425997 
Loop time of 3.67167e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3012223724386
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.8246198293815
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.84264154393664
variable        y0 equal ${yi}
variable        y0 equal 4.64205295199321

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.93685722310534
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.62808927649425
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2794   -2.9871562   -2.7769062   -2.7425997 
    2795   -2.9871562   -2.7769062   -2.7728671 
Loop time of 3.72253e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 64 x ${x0}
set atom 64 x 5.84264154393664
  1 settings made for x
set atom $i y ${y0}
set atom 64 y ${y0}
set atom 64 y 4.64205295199321
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.76264746387434
variable        y0 equal ${yi}
variable        y0 equal 8.40153711952266

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.71881091793013
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.4587339750677
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2795   -2.9871562   -2.7769062   -2.7728671 
    2796   -2.9871562   -2.7769062   -2.7663022 
Loop time of 3.54872e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 46 x ${x0}
set atom 46 x 2.76264746387434
  1 settings made for x
set atom $i y ${y0}
set atom 46 y ${y0}
set atom 46 y 8.40153711952266
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 69

variable        x0 equal ${xi}
variable        x0 equal 6.99216622391388
variable        y0 equal ${yi}
variable        y0 equal 6.45942620769968

set             atom $i x ${xnew}
set             atom 69 x ${xnew}
set             atom 69 x 7.00221247950241
  1 settings made for x
set             atom $i y ${ynew}
set             atom 69 y ${ynew}
set             atom 69 y 6.42606418863764
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2796   -2.9871562   -2.7769062   -2.7663022 
    2797   -2.9871562   -2.7769062   -2.7704743 
Loop time of 3.68035e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 69 x ${x0}
set atom 69 x 6.99216622391388
  1 settings made for x
set atom $i y ${y0}
set atom 69 y ${y0}
set atom 69 y 6.45942620769968
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.62427199044649
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.80290659232271
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2797   -2.9871562   -2.7769062   -2.7704743 
    2798   -2.9871562   -2.7769062    -2.751097 
Loop time of 3.71085e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.60014088311616
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.57840079014497
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2798   -2.9871562   -2.7769062    -2.751097 
    2799   -2.9871562   -2.7769062   -2.7745476 
Loop time of 3.68019e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.506249304214384
variable        y0 equal ${yi}
variable        y0 equal 6.52357215420237

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.576728244224455
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.50275588766566
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2799   -2.9871562   -2.7769062   -2.7745476 
    2800   -2.9871562   -2.7769062    -2.767025 
Loop time of 3.62454e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.506249304214384
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.52357215420237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 97

variable        x0 equal ${xi}
variable        x0 equal 8.61455693402712
variable        y0 equal ${yi}
variable        y0 equal 7.4608101996448

set             atom $i x ${xnew}
set             atom 97 x ${xnew}
set             atom 97 x 8.69703136840288
  1 settings made for x
set             atom $i y ${ynew}
set             atom 97 y ${ynew}
set             atom 97 y 7.55245397415423
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2800   -2.9871562   -2.7769062    -2.767025 
    2801   -2.9871562   -2.7769062   -2.7332438 
Loop time of 3.64683e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 97 x ${x0}
set atom 97 x 8.61455693402712
  1 settings made for x
set atom $i y ${y0}
set atom 97 y ${y0}
set atom 97 y 7.4608101996448
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.53207862217199
variable        y0 equal ${yi}
variable        y0 equal 9.2839910458359

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.54881361562978
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.23100304115145
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2801   -2.9871562   -2.7769062   -2.7332438 
    2802   -2.9871562   -2.7769062   -2.7707602 
Loop time of 3.5959e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.53207862217199
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.2839910458359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.49472845632804
variable        y0 equal ${yi}
variable        y0 equal 5.57788908426957

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.55770916778815
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.49979227726655
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2802   -2.9871562   -2.7769062   -2.7707602 
    2803   -2.9871562   -2.7769062   -2.7501558 
Loop time of 3.69774e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.49472845632804
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.57788908426957
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.1377164248487
variable        y0 equal ${yi}
variable        y0 equal 8.38071602500973

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.188112700369
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.34954838670788
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2803   -2.9871562   -2.7769062   -2.7501558 
    2804   -2.9871562   -2.7769062   -2.7730069 
Loop time of 3.69548e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.1377164248487
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.38071602500973
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.1377164248487
variable        y0 equal ${yi}
variable        y0 equal 8.38071602500973

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.0658348087331
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.32419990219174
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2804   -2.9871562   -2.7769062   -2.7730069 
    2805   -2.9871562   -2.7769062   -2.7558241 
Loop time of 3.64425e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.1377164248487
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.38071602500973
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 1.07474994977169
variable        y0 equal ${yi}
variable        y0 equal 9.25899240482181

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 1.01709459145718
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.21508018482059
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2805   -2.9871562   -2.7769062   -2.7558241 
    2806   -2.9871562   -2.7769062   -2.7573726 
Loop time of 3.61496e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 1.07474994977169
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.25899240482181
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3012223724386
variable        y0 equal ${yi}
variable        y0 equal 2.8246198293815

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.226811433222
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.750123631681
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2806   -2.9871562   -2.7769062   -2.7573726 
    2807   -2.9871562   -2.7769062   -2.7514841 
Loop time of 3.65375e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3012223724386
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.8246198293815
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03143052180462
variable        y0 equal ${yi}
variable        y0 equal 5.57988774721818

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 0.986988321143914
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.48861372416215
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2807   -2.9871562   -2.7769062   -2.7514841 
    2808   -2.9871562   -2.7769062    -2.756319 
Loop time of 3.73356e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03143052180462
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.57988774721818
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20813699721852
variable        y0 equal ${yi}
variable        y0 equal 5.56420804207521

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.21879940986195
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.61136776154237
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2808   -2.9871562   -2.7769062    -2.756319 
    2809   -2.9871562   -2.7769062   -2.7753925 
Loop time of 3.72212e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20813699721852
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56420804207521
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.44114927211229
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.50670368616777
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2809   -2.9871562   -2.7769062   -2.7753925 
    2810   -2.9871562   -2.7769062   -2.7334895 
Loop time of 3.68726e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.97761599977009
variable        y0 equal ${yi}
variable        y0 equal 8.28446922220287

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 6.03997344930165
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.2530781022459
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2810   -2.9871562   -2.7769062   -2.7334895 
    2811   -2.9871562   -2.7769062   -2.7442011 
Loop time of 3.63013e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 5.97761599977009
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.28446922220287
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.93963416774264
variable        y0 equal ${yi}
variable        y0 equal 6.45324131981364

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.85358519513598
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.40363425747386
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2811   -2.9871562   -2.7769062   -2.7442011 
    2812   -2.9871562   -2.7769062   -2.7631309 
Loop time of 3.74417e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.93963416774264
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.45324131981364
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.49041990796652
variable        y0 equal ${yi}
variable        y0 equal 4.63726146572992

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.581417186656858
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.71089268082544
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2812   -2.9871562   -2.7769062   -2.7631309 
    2813   -2.9871562   -2.7769062   -2.7660396 
Loop time of 3.63171e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.49041990796652
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.63726146572992
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 72

variable        x0 equal ${xi}
variable        x0 equal 5.97761599977009
variable        y0 equal ${yi}
variable        y0 equal 8.28446922220287

set             atom $i x ${xnew}
set             atom 72 x ${xnew}
set             atom 72 x 5.99217282493107
  1 settings made for x
set             atom $i y ${ynew}
set             atom 72 y ${ynew}
set             atom 72 y 8.22598181881008
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2813   -2.9871562   -2.7769062   -2.7660396 
    2814   -2.9871562   -2.7769062   -2.7581879 
Loop time of 3.66494e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 72 x ${x0}
set atom 72 x 5.97761599977009
  1 settings made for x
set atom $i y ${y0}
set atom 72 y ${y0}
set atom 72 y 8.28446922220287
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.32259763240376
variable        y0 equal ${yi}
variable        y0 equal 1.91972836635178

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.28958694695988
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.91325869939392
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2814   -2.9871562   -2.7769062   -2.7581879 
    2815   -2.9871562   -2.7769062   -2.7776919 
Loop time of 3.65221e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.77769191235791
variable naccept equal ${increment}
variable naccept equal 475

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.75304803728838
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.37570878185328
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2815   -2.9871562   -2.7776919   -2.7776919 
    2816   -2.9871562   -2.7776919    -2.768947 
Loop time of 3.87192e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.53207862217199
variable        y0 equal ${yi}
variable        y0 equal 9.2839910458359

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.58742402632009
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.24692619550555
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2816   -2.9871562   -2.7776919    -2.768947 
    2817   -2.9871562   -2.7776919   -2.7650072 
Loop time of 3.77588e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.53207862217199
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.2839910458359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.570451636711027
variable        y0 equal ${yi}
variable        y0 equal 2.81422812911371

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.531410022178556
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.82792832824091
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2817   -2.9871562   -2.7776919   -2.7650072 
    2818   -2.9871562   -2.7776919   -2.7686933 
Loop time of 3.9152e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.570451636711027
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.81422812911371
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.29362520932713
variable        y0 equal ${yi}
variable        y0 equal 0.011324155330658

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.19510349988499
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.0116793394088745
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2818   -2.9871562   -2.7776919   -2.7686933 
    2819   -2.9871562   -2.7776919   -2.7520841 
Loop time of 3.80871e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.29362520932713
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.011324155330658
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.26551517009297
variable        y0 equal ${yi}
variable        y0 equal 7.42613175239824

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.28956504821339
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.34198710050844
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2819   -2.9871562   -2.7776919   -2.7520841 
    2820   -2.9871562   -2.7776919   -2.7410155 
Loop time of 3.69176e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.26551517009297
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.42613175239824
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 7.03107449093506
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.34908499635753
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2820   -2.9871562   -2.7776919   -2.7410155 
    2821   -2.9871562   -2.7776919   -2.7705334 
Loop time of 3.6766e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.92722187876045
variable        y0 equal ${yi}
variable        y0 equal 8.34011304296548

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.84445461868583
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.25446389831598
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2821   -2.9871562   -2.7776919   -2.7705334 
    2822   -2.9871562   -2.7776919   -2.7198009 
Loop time of 3.68768e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.92722187876045
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.34011304296548
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.46636033772546
variable        y0 equal ${yi}
variable        y0 equal 3.78071368498932

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.49305741309243
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.75303452773224
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2822   -2.9871562   -2.7776919   -2.7198009 
    2823   -2.9871562   -2.7776919   -2.7778632 
Loop time of 3.72645e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.77786321288053
variable naccept equal ${increment}
variable naccept equal 476

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3012223724386
variable        y0 equal ${yi}
variable        y0 equal 2.8246198293815

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.3520211581251
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.86952896090845
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2823   -2.9871562   -2.7778632   -2.7778632 
    2824   -2.9871562   -2.7778632   -2.7468961 
Loop time of 3.71864e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3012223724386
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.8246198293815
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.61305398821612
variable        y0 equal ${yi}
variable        y0 equal 4.66496637219354

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.52871931671877
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.7509771382229
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2824   -2.9871562   -2.7778632   -2.7468961 
    2825   -2.9871562   -2.7778632   -2.7518122 
Loop time of 3.82062e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.61305398821612
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.66496637219354
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.26551517009297
variable        y0 equal ${yi}
variable        y0 equal 7.42613175239824

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.32840075254002
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.48267811861299
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2825   -2.9871562   -2.7778632   -2.7518122 
    2826   -2.9871562   -2.7778632   -2.7705481 
Loop time of 3.72529e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.26551517009297
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.42613175239824
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.42935876050855
variable        y0 equal ${yi}
variable        y0 equal 7.38294791307711

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.41138646999265
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.34562672701144
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2826   -2.9871562   -2.7778632   -2.7705481 
    2827   -2.9871562   -2.7778632   -2.7740687 
Loop time of 3.59518e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.42935876050855
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.38294791307711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.153654468443
variable        y0 equal ${yi}
variable        y0 equal 6.49468966261377

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.0548383239766
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.4871692372941
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2827   -2.9871562   -2.7778632   -2.7740687 
    2828   -2.9871562   -2.7778632   -2.7329277 
Loop time of 3.6159e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.153654468443
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.49468966261377
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.562153263488676
variable        y0 equal ${yi}
variable        y0 equal 0.907725413549273

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.499912090698149
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.882322974908679
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2828   -2.9871562   -2.7778632   -2.7329277 
    2829   -2.9871562   -2.7778632    -2.772187 
Loop time of 3.62459e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.562153263488676
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.907725413549273
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.99489848890945
variable        y0 equal ${yi}
variable        y0 equal 4.67387059086726

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 7.03047228136703
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.60779251212046
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2829   -2.9871562   -2.7778632    -2.772187 
    2830   -2.9871562   -2.7778632   -2.7665864 
Loop time of 3.66466e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.99489848890945
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.67387059086726
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.49041990796652
variable        y0 equal ${yi}
variable        y0 equal 4.63726146572992

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.505572493472959
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.67320375794336
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2830   -2.9871562   -2.7778632   -2.7665864 
    2831   -2.9871562   -2.7778632   -2.7805948 
Loop time of 3.71088e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.78059479531234
variable naccept equal ${increment}
variable naccept equal 477

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.49662729024011
variable        y0 equal ${yi}
variable        y0 equal 1.85665681741302

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.51371473788339
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.86760732314651
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2831   -2.9871562   -2.7805948   -2.7805948 
    2832   -2.9871562   -2.7805948   -2.7810562 
Loop time of 3.76994e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.7810562202766
variable naccept equal ${increment}
variable naccept equal 478

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.53207862217199
variable        y0 equal ${yi}
variable        y0 equal 9.2839910458359

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.56000702221166
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.20490669715731
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2832   -2.9871562   -2.7810562   -2.7810562 
    2833   -2.9871562   -2.7810562   -2.7659851 
Loop time of 3.6361e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.53207862217199
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.2839910458359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.14624181706459
variable        y0 equal ${yi}
variable        y0 equal 4.60836122387811

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.14593883473427
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.59196747893258
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2833   -2.9871562   -2.7810562   -2.7659851 
    2834   -2.9871562   -2.7810562   -2.7789715 
Loop time of 3.7825e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.14624181706459
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.60836122387811
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.21051719506435
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.98221279761857
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2834   -2.9871562   -2.7810562   -2.7789715 
    2835   -2.9871562   -2.7810562   -2.7276042 
Loop time of 3.5173e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 74

variable        x0 equal ${xi}
variable        x0 equal 6.9814669040744
variable        y0 equal ${yi}
variable        y0 equal 8.31534441627559

set             atom $i x ${xnew}
set             atom 74 x ${xnew}
set             atom 74 x 6.89440086165115
  1 settings made for x
set             atom $i y ${ynew}
set             atom 74 y ${ynew}
set             atom 74 y 8.25227440513667
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2835   -2.9871562   -2.7810562   -2.7276042 
    2836   -2.9871562   -2.7810562   -2.7273809 
Loop time of 3.64455e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 74 x ${x0}
set atom 74 x 6.9814669040744
  1 settings made for x
set atom $i y ${y0}
set atom 74 y ${y0}
set atom 74 y 8.31534441627559
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.77372619389173
variable        y0 equal ${yi}
variable        y0 equal 1.9292484082944

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.81259001968976
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.97924627444812
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2836   -2.9871562   -2.7810562   -2.7273809 
    2837   -2.9871562   -2.7810562   -2.7652949 
Loop time of 3.5996e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.77372619389173
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.9292484082944
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20813699721852
variable        y0 equal ${yi}
variable        y0 equal 5.56420804207521

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.12230897903004
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.61704844181734
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2837   -2.9871562   -2.7810562   -2.7652949 
    2838   -2.9871562   -2.7810562   -2.7530155 
Loop time of 3.57786e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20813699721852
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56420804207521
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.26462735890904
variable        y0 equal ${yi}
variable        y0 equal 3.68544435067308

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.30181669950047
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.72347416443956
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2838   -2.9871562   -2.7810562   -2.7530155 
    2839   -2.9871562   -2.7810562   -2.7776495 
Loop time of 3.71099e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 36 x ${x0}
set atom 36 x 3.26462735890904
  1 settings made for x
set atom $i y ${y0}
set atom 36 y ${y0}
set atom 36 y 3.68544435067308
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.3840241916916
variable        y0 equal ${yi}
variable        y0 equal 9.27708193767397

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.40365114290925
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.21220194804995
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2839   -2.9871562   -2.7810562   -2.7776495 
    2840   -2.9871562   -2.7810562   -2.7721886 
Loop time of 3.74511e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.3840241916916
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.27708193767397
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6761052210979
variable        y0 equal ${yi}
variable        y0 equal 9.25454356181949

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.6124956091098
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.22521026838153
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2840   -2.9871562   -2.7810562   -2.7721886 
    2841   -2.9871562   -2.7810562   -2.7609554 
Loop time of 3.79796e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 1 x ${x0}
set atom 1 x 10.6761052210979
  1 settings made for x
set atom $i y ${y0}
set atom 1 y ${y0}
set atom 1 y 9.25454356181949
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.42935876050855
variable        y0 equal ${yi}
variable        y0 equal 7.38294791307711

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.43110506931211
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.45987059202456
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2841   -2.9871562   -2.7810562   -2.7609554 
    2842   -2.9871562   -2.7810562   -2.7677913 
Loop time of 3.74695e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.42935876050855
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.38294791307711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.69136598267976
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.70688530964983
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2842   -2.9871562   -2.7810562   -2.7677913 
    2843   -2.9871562   -2.7810562   -2.7746042 
Loop time of 3.77007e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.77372619389173
variable        y0 equal ${yi}
variable        y0 equal 1.9292484082944

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.78108972786542
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.83696858069964
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2843   -2.9871562   -2.7810562   -2.7746042 
    2844   -2.9871562   -2.7810562   -2.7623883 
Loop time of 3.7571e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.77372619389173
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.9292484082944
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.1777931276928
variable        y0 equal ${yi}
variable        y0 equal 3.72489689154755

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.25309558550225
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.81053257746827
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2844   -2.9871562   -2.7810562   -2.7623883 
    2845   -2.9871562   -2.7810562   -2.7301596 
Loop time of 3.58163e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.1777931276928
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.72489689154755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.46139991680051
variable        y0 equal ${yi}
variable        y0 equal 1.85337124250001

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.40953063169385
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.94657057902879
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2845   -2.9871562   -2.7810562   -2.7301596 
    2846   -2.9871562   -2.7810562    -2.756255 
Loop time of 3.70224e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.46139991680051
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.85337124250001
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.28958694695988
variable        y0 equal ${yi}
variable        y0 equal 1.91325869939392

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.2835146880106
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.9290374197728
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2846   -2.9871562   -2.7810562    -2.756255 
    2847   -2.9871562   -2.7810562   -2.7782488 
Loop time of 3.68211e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.28958694695988
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.91325869939392
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.57710869152319
variable        y0 equal ${yi}
variable        y0 equal 1.89296272180146

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.65931176979315
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.94926035783356
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2847   -2.9871562   -2.7810562   -2.7782488 
    2848   -2.9871562   -2.7810562   -2.7473467 
Loop time of 3.66692e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.57710869152319
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.89296272180146
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 93

variable        x0 equal ${xi}
variable        x0 equal 9.12681160885841
variable        y0 equal ${yi}
variable        y0 equal 6.47935723797312

set             atom $i x ${xnew}
set             atom 93 x ${xnew}
set             atom 93 x 9.04720302540809
  1 settings made for x
set             atom $i y ${ynew}
set             atom 93 y ${ynew}
set             atom 93 y 6.47500504986277
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2848   -2.9871562   -2.7810562   -2.7473467 
    2849   -2.9871562   -2.7810562   -2.7717257 
Loop time of 3.76229e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 93 x ${x0}
set atom 93 x 9.12681160885841
  1 settings made for x
set atom $i y ${y0}
set atom 93 y ${y0}
set atom 93 y 6.47935723797312
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.78533812085276
variable        y0 equal ${yi}
variable        y0 equal 6.5534119559907

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.77240649977808
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.60609093443384
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2849   -2.9871562   -2.7810562   -2.7717257 
    2850   -2.9871562   -2.7810562   -2.7656565 
Loop time of 3.67875e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.78533812085276
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.5534119559907
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.61535184541169
variable        y0 equal ${yi}
variable        y0 equal 1.91233646056717

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.70793162742081
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.87194396636551
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2850   -2.9871562   -2.7810562   -2.7656565 
    2851   -2.9871562   -2.7810562   -2.7402251 
Loop time of 3.69777e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.61535184541169
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.91233646056717
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.82034868518
variable        y0 equal ${yi}
variable        y0 equal 8.36977583087978

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.78742362776881
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.3751550427824
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2851   -2.9871562   -2.7810562   -2.7402251 
    2852   -2.9871562   -2.7810562   -2.7783116 
Loop time of 0.000101297 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.82034868518
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.36977583087978
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.506249304214384
variable        y0 equal ${yi}
variable        y0 equal 6.52357215420237

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.410976369777586
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.52951114908686
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2852   -2.9871562   -2.7810562   -2.7783116 
    2853   -2.9871562   -2.7810562    -2.767211 
Loop time of 3.64835e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.506249304214384
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.52357215420237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 4

variable        x0 equal ${xi}
variable        x0 equal 1.65424995302935
variable        y0 equal ${yi}
variable        y0 equal 0.940276082265705

set             atom $i x ${xnew}
set             atom 4 x ${xnew}
set             atom 4 x 1.61995936512728
  1 settings made for x
set             atom $i y ${ynew}
set             atom 4 y ${ynew}
set             atom 4 y 0.977563615548939
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2853   -2.9871562   -2.7810562    -2.767211 
    2854   -2.9871562   -2.7810562   -2.7762774 
Loop time of 3.75678e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 4 x ${x0}
set atom 4 x 1.65424995302935
  1 settings made for x
set atom $i y ${y0}
set atom 4 y ${y0}
set atom 4 y 0.940276082265705
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.39493876774522
variable        y0 equal ${yi}
variable        y0 equal 1.88860803029603

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.33218462546083
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.94844174764222
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2854   -2.9871562   -2.7810562   -2.7762774 
    2855   -2.9871562   -2.7810562    -2.767325 
Loop time of 3.65011e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.39493876774522
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.88860803029603
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.506249304214384
variable        y0 equal ${yi}
variable        y0 equal 6.52357215420237

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.454523833194639
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.4804459406518
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2855   -2.9871562   -2.7810562    -2.767325 
    2856   -2.9871562   -2.7810562   -2.7756051 
Loop time of 3.79521e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.506249304214384
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.52357215420237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.59509903668044
variable        y0 equal ${yi}
variable        y0 equal 5.54114934151369

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.61509058951018
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.63716891949373
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2856   -2.9871562   -2.7810562   -2.7756051 
    2857   -2.9871562   -2.7810562   -2.7627968 
Loop time of 3.82611e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.59509903668044
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.54114934151369
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.79031698902084
variable        y0 equal ${yi}
variable        y0 equal 0.950206168401568

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.74453513820602
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 0.916303940522997
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2857   -2.9871562   -2.7810562   -2.7627968 
    2858   -2.9871562   -2.7810562   -2.7799465 
Loop time of 3.71233e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.79031698902084
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 0.950206168401568
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.93963416774264
variable        y0 equal ${yi}
variable        y0 equal 6.45324131981364

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 6.01777532060137
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.37271981970301
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2858   -2.9871562   -2.7810562   -2.7799465 
    2859   -2.9871562   -2.7810562   -2.7190492 
Loop time of 3.66829e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.93963416774264
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.45324131981364
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 7

variable        x0 equal ${xi}
variable        x0 equal 0.570451636711027
variable        y0 equal ${yi}
variable        y0 equal 2.81422812911371

set             atom $i x ${xnew}
set             atom 7 x ${xnew}
set             atom 7 x 0.613424070278074
  1 settings made for x
set             atom $i y ${ynew}
set             atom 7 y ${ynew}
set             atom 7 y 2.8435292837272
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2859   -2.9871562   -2.7810562   -2.7190492 
    2860   -2.9871562   -2.7810562   -2.7759534 
Loop time of 3.7873e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 7 x ${x0}
set atom 7 x 0.570451636711027
  1 settings made for x
set atom $i y ${y0}
set atom 7 y ${y0}
set atom 7 y 2.81422812911371
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 12

variable        x0 equal ${xi}
variable        x0 equal 1.0800673158949
variable        y0 equal ${yi}
variable        y0 equal 3.73807540698182

set             atom $i x ${xnew}
set             atom 12 x ${xnew}
set             atom 12 x 1.16998063643628
  1 settings made for x
set             atom $i y ${ynew}
set             atom 12 y ${ynew}
set             atom 12 y 3.72064084572923
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2860   -2.9871562   -2.7810562   -2.7759534 
    2861   -2.9871562   -2.7810562   -2.7651648 
Loop time of 3.70377e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 12 x ${x0}
set atom 12 x 1.0800673158949
  1 settings made for x
set atom $i y ${y0}
set atom 12 y ${y0}
set atom 12 y 3.73807540698182
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 61

variable        x0 equal ${xi}
variable        x0 equal 5.37132815519238
variable        y0 equal ${yi}
variable        y0 equal 3.71904631419312

set             atom $i x ${xnew}
set             atom 61 x ${xnew}
set             atom 61 x 5.36964185634518
  1 settings made for x
set             atom $i y ${ynew}
set             atom 61 y ${ynew}
set             atom 61 y 3.68092410130631
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2861   -2.9871562   -2.7810562   -2.7651648 
    2862   -2.9871562   -2.7810562   -2.7718605 
Loop time of 0.000379552 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 61 x ${x0}
set atom 61 x 5.37132815519238
  1 settings made for x
set atom $i y ${y0}
set atom 61 y ${y0}
set atom 61 y 3.71904631419312
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.77372619389173
variable        y0 equal ${yi}
variable        y0 equal 1.9292484082944

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.86500669001218
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 2.00759368321963
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2862   -2.9871562   -2.7810562   -2.7718605 
    2863   -2.9871562   -2.7810562   -2.7282819 
Loop time of 5.7722e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.77372619389173
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.9292484082944
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.62515191871892
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.76499832434785
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2863   -2.9871562   -2.7810562   -2.7282819 
    2864   -2.9871562   -2.7810562   -2.7631619 
Loop time of 3.62829e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 1

variable        x0 equal ${xi}
variable        x0 equal 10.6761052210979
variable        y0 equal ${yi}
variable        y0 equal 9.25454356181949

set             atom $i x ${xnew}
set             atom 1 x ${xnew}
set             atom 1 x 10.7075046261005
  1 settings made for x
set             atom $i y ${ynew}
set             atom 1 y ${ynew}
set             atom 1 y 9.27931719529956
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2864   -2.9871562   -2.7810562   -2.7631619 
    2865   -2.9871562   -2.7810562   -2.7851024 
Loop time of 3.70194e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.78510241063627
variable naccept equal ${increment}
variable naccept equal 479

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.0681977808366
variable        y0 equal ${yi}
variable        y0 equal 4.6233086740391

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.13677639364101
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.69510280245707
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2865   -2.9871562   -2.7851024   -2.7851024 
    2866   -2.9871562   -2.7851024   -2.7595982 
Loop time of 3.63151e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.0681977808366
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.6233086740391
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.0681977808366
variable        y0 equal ${yi}
variable        y0 equal 4.6233086740391

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.16363925336696
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.6083116447346
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2866   -2.9871562   -2.7851024   -2.7595982 
    2867   -2.9871562   -2.7851024   -2.7682866 
Loop time of 3.69603e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.0681977808366
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.6233086740391
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.53207862217199
variable        y0 equal ${yi}
variable        y0 equal 9.2839910458359

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.57246074516546
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.35043729055255
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2867   -2.9871562   -2.7851024   -2.7682866 
    2868   -2.9871562   -2.7851024   -2.7752267 
Loop time of 3.97176e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.53207862217199
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.2839910458359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.29828972895356
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.80315944714677
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2868   -2.9871562   -2.7851024   -2.7752267 
    2869   -2.9871562   -2.7851024    -2.773868 
Loop time of 3.74244e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.28958694695988
variable        y0 equal ${yi}
variable        y0 equal 1.91325869939392

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.19773971795597
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.94611914537018
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2869   -2.9871562   -2.7851024    -2.773868 
    2870   -2.9871562   -2.7851024   -2.7583075 
Loop time of 3.75345e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.28958694695988
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.91325869939392
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 28

variable        x0 equal ${xi}
variable        x0 equal 3.83473797360545
variable        y0 equal ${yi}
variable        y0 equal 0.925000270116656

set             atom $i x ${xnew}
set             atom 28 x ${xnew}
set             atom 28 x 3.77536380807048
  1 settings made for x
set             atom $i y ${ynew}
set             atom 28 y ${ynew}
set             atom 28 y 0.829480036008685
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2870   -2.9871562   -2.7851024   -2.7583075 
    2871   -2.9871562   -2.7851024   -2.7453192 
Loop time of 3.91649e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 28 x ${x0}
set atom 28 x 3.83473797360545
  1 settings made for x
set atom $i y ${y0}
set atom 28 y ${y0}
set atom 28 y 0.925000270116656
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 14

variable        x0 equal ${xi}
variable        x0 equal 0.505572493472959
variable        y0 equal ${yi}
variable        y0 equal 4.67320375794336

set             atom $i x ${xnew}
set             atom 14 x ${xnew}
set             atom 14 x 0.461363907256986
  1 settings made for x
set             atom $i y ${ynew}
set             atom 14 y ${ynew}
set             atom 14 y 4.64040596836969
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2871   -2.9871562   -2.7851024   -2.7453192 
    2872   -2.9871562   -2.7851024   -2.7760944 
Loop time of 3.68306e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 14 x ${x0}
set atom 14 x 0.505572493472959
  1 settings made for x
set atom $i y ${y0}
set atom 14 y ${y0}
set atom 14 y 4.67320375794336
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.37309358198854
variable        y0 equal ${yi}
variable        y0 equal 7.47418843832278

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.33533585150453
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.39495356407428
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2872   -2.9871562   -2.7851024   -2.7760944 
    2873   -2.9871562   -2.7851024   -2.7772476 
Loop time of 6.48053e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.37309358198854
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.47418843832278
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 96

variable        x0 equal ${xi}
variable        x0 equal 8.00191021560528
variable        y0 equal ${yi}
variable        y0 equal 8.32666997827585

set             atom $i x ${xnew}
set             atom 96 x ${xnew}
set             atom 96 x 8.05706761478283
  1 settings made for x
set             atom $i y ${ynew}
set             atom 96 y ${ynew}
set             atom 96 y 8.34413964666422
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2873   -2.9871562   -2.7851024   -2.7772476 
    2874   -2.9871562   -2.7851024   -2.7848897 
Loop time of 3.78435e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.78488972772374
variable naccept equal ${increment}
variable naccept equal 480

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.00774297991439
variable        y0 equal ${yi}
variable        y0 equal 2.80172786685327

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.94939704218551
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.83700571032861
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2874   -2.9871562   -2.7848897   -2.7848897 
    2875   -2.9871562   -2.7848897    -2.772456 
Loop time of 3.74455e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 7.00774297991439
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.80172786685327
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 58

variable        x0 equal ${xi}
variable        x0 equal 6.51371473788339
variable        y0 equal ${yi}
variable        y0 equal 1.86760732314651

set             atom $i x ${xnew}
set             atom 58 x ${xnew}
set             atom 58 x 6.57852630137521
  1 settings made for x
set             atom $i y ${ynew}
set             atom 58 y ${ynew}
set             atom 58 y 1.85495412728851
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2875   -2.9871562   -2.7848897    -2.772456 
    2876   -2.9871562   -2.7848897   -2.7748155 
Loop time of 3.70679e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 58 x ${x0}
set atom 58 x 6.51371473788339
  1 settings made for x
set atom $i y ${y0}
set atom 58 y ${y0}
set atom 58 y 1.86760732314651
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.56384705462877
variable        y0 equal ${yi}
variable        y0 equal 0.0929038047790526

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.53350058951799
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.0298826575279234
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2876   -2.9871562   -2.7848897   -2.7748155 
    2877   -2.9871562   -2.7848897   -2.7824594 
Loop time of 3.68187e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.56384705462877
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.0929038047790526
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.36031145254042
variable        y0 equal ${yi}
variable        y0 equal 5.55776102488237

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.30592807927992
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.51927719061571
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2877   -2.9871562   -2.7848897   -2.7824594 
    2878   -2.9871562   -2.7848897   -2.7739341 
Loop time of 3.5842e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.36031145254042
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.55776102488237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.1377164248487
variable        y0 equal ${yi}
variable        y0 equal 8.38071602500973

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.1373280171415
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.33358000434933
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2878   -2.9871562   -2.7848897   -2.7739341 
    2879   -2.9871562   -2.7848897   -2.7777447 
Loop time of 3.69987e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.1377164248487
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.38071602500973
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.94595673918066
variable        y0 equal ${yi}
variable        y0 equal 2.80184977027276

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.88046604036627
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.87129123183587
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2879   -2.9871562   -2.7848897   -2.7777447 
    2880   -2.9871562   -2.7848897   -2.7750572 
Loop time of 3.59287e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.94595673918066
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.80184977027276
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.7453461547656
variable        y0 equal ${yi}
variable        y0 equal 2.79009700986245

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.79046057661008
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.77235763045647
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2880   -2.9871562   -2.7848897   -2.7750572 
    2881   -2.9871562   -2.7848897   -2.7760614 
Loop time of 3.72922e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.7453461547656
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.79009700986245
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.57710869152319
variable        y0 equal ${yi}
variable        y0 equal 1.89296272180146

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.62237042028677
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.81129777810639
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2881   -2.9871562   -2.7848897   -2.7760614 
    2882   -2.9871562   -2.7848897    -2.748719 
Loop time of 3.70988e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.57710869152319
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.89296272180146
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.08236802219248
variable        y0 equal ${yi}
variable        y0 equal 2.83939957591395

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.13736042379236
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.91801290484767
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2882   -2.9871562   -2.7848897    -2.748719 
    2883   -2.9871562   -2.7848897   -2.7534276 
Loop time of 3.76247e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.08236802219248
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.83939957591395
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.49305741309243
variable        y0 equal ${yi}
variable        y0 equal 3.75303452773224

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.48631493567544
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.75364394946228
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2883   -2.9871562   -2.7848897   -2.7534276 
    2884   -2.9871562   -2.7848897   -2.7854555 
Loop time of 6.76465e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.78545553152169
variable naccept equal ${increment}
variable naccept equal 481

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 100

variable        x0 equal ${xi}
variable        x0 equal 10.1377164248487
variable        y0 equal ${yi}
variable        y0 equal 8.38071602500973

set             atom $i x ${xnew}
set             atom 100 x ${xnew}
set             atom 100 x 10.0775277737638
  1 settings made for x
set             atom $i y ${ynew}
set             atom 100 y ${ynew}
set             atom 100 y 8.46044082559643
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2884   -2.9871562   -2.7854555   -2.7854555 
    2885   -2.9871562   -2.7854555   -2.7772835 
Loop time of 3.67061e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 100 x ${x0}
set atom 100 x 10.1377164248487
  1 settings made for x
set atom $i y ${y0}
set atom 100 y ${y0}
set atom 100 y 8.38071602500973
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.7453461547656
variable        y0 equal ${yi}
variable        y0 equal 2.79009700986245

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.71367470224332
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.73274120065072
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2885   -2.9871562   -2.7854555   -2.7772835 
    2886   -2.9871562   -2.7854555   -2.7736706 
Loop time of 3.69163e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.7453461547656
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.79009700986245
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 55

variable        x0 equal ${xi}
variable        x0 equal 7.53207862217199
variable        y0 equal ${yi}
variable        y0 equal 9.2839910458359

set             atom $i x ${xnew}
set             atom 55 x ${xnew}
set             atom 55 x 7.57224633533727
  1 settings made for x
set             atom $i y ${ynew}
set             atom 55 y ${ynew}
set             atom 55 y 9.26118161189883
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2886   -2.9871562   -2.7854555   -2.7736706 
    2887   -2.9871562   -2.7854555   -2.7797186 
Loop time of 3.66473e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 55 x ${x0}
set atom 55 x 7.53207862217199
  1 settings made for x
set atom $i y ${y0}
set atom 55 y ${y0}
set atom 55 y 9.2839910458359
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.14624181706459
variable        y0 equal ${yi}
variable        y0 equal 4.60836122387811

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.20295989234001
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.60845210904046
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2887   -2.9871562   -2.7854555   -2.7797186 
    2888   -2.9871562   -2.7854555    -2.773612 
Loop time of 3.71382e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.14624181706459
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.60836122387811
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 5

variable        x0 equal ${xi}
variable        x0 equal 2.21645496527063
variable        y0 equal ${yi}
variable        y0 equal 0.023480272293094

set             atom $i x ${xnew}
set             atom 5 x ${xnew}
set             atom 5 x 2.26126222053873
  1 settings made for x
set             atom $i y ${ynew}
set             atom 5 y ${ynew}
set             atom 5 y -0.0395759224891631
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2888   -2.9871562   -2.7854555    -2.773612 
    2889   -2.9871562   -2.7854555   -2.7734028 
Loop time of 3.67855e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 5 x ${x0}
set atom 5 x 2.21645496527063
  1 settings made for x
set atom $i y ${y0}
set atom 5 y ${y0}
set atom 5 y 0.023480272293094
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.62633978009005
variable        y0 equal ${yi}
variable        y0 equal 2.82587088319162

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.56302591442843
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.73251786204675
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2889   -2.9871562   -2.7854555   -2.7734028 
    2890   -2.9871562   -2.7854555   -2.7507975 
Loop time of 3.7907e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.62633978009005
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.82587088319162
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 44

variable        x0 equal ${xi}
variable        x0 equal 4.28353248913499
variable        y0 equal ${yi}
variable        y0 equal 5.60404488985736

set             atom $i x ${xnew}
set             atom 44 x ${xnew}
set             atom 44 x 4.27881239731523
  1 settings made for x
set             atom $i y ${ynew}
set             atom 44 y ${ynew}
set             atom 44 y 5.63304680531223
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2890   -2.9871562   -2.7854555   -2.7507975 
    2891   -2.9871562   -2.7854555   -2.7834826 
Loop time of 3.6473e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 44 x ${x0}
set atom 44 x 4.28353248913499
  1 settings made for x
set atom $i y ${y0}
set atom 44 y ${y0}
set atom 44 y 5.60404488985736
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 1.07474994977169
variable        y0 equal ${yi}
variable        y0 equal 9.25899240482181

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 1.03695715983562
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.2253543924126
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2891   -2.9871562   -2.7854555   -2.7834826 
    2892   -2.9871562   -2.7854555   -2.7734118 
Loop time of 3.58062e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 1.07474994977169
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.25899240482181
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.99489848890945
variable        y0 equal ${yi}
variable        y0 equal 4.67387059086726

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.91813726702377
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.65256376618312
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2892   -2.9871562   -2.7854555   -2.7734118 
    2893   -2.9871562   -2.7854555    -2.779003 
Loop time of 3.67376e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.99489848890945
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.67387059086726
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.60465685009738
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.44369049803248
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2893   -2.9871562   -2.7854555    -2.779003 
    2894   -2.9871562   -2.7854555   -2.7774703 
Loop time of 3.65926e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.94595673918066
variable        y0 equal ${yi}
variable        y0 equal 2.80184977027276

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 5.00342256664572
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.79303523274758
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2894   -2.9871562   -2.7854555   -2.7774703 
    2895   -2.9871562   -2.7854555   -2.7616527 
Loop time of 4.2628e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 35 x ${x0}
set atom 35 x 4.94595673918066
  1 settings made for x
set atom $i y ${y0}
set atom 35 y ${y0}
set atom 35 y 2.80184977027276
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.49927381117117
variable        y0 equal ${yi}
variable        y0 equal 7.4024957450893

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.57293746311438
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.31321585502887
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2895   -2.9871562   -2.7854555   -2.7616527 
    2896   -2.9871562   -2.7854555   -2.7342745 
Loop time of 3.65029e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.49927381117117
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.4024957450893
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.153654468443
variable        y0 equal ${yi}
variable        y0 equal 6.49468966261377

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.2283463362714
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.45141714350214
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2896   -2.9871562   -2.7854555   -2.7342745 
    2897   -2.9871562   -2.7854555   -2.7763788 
Loop time of 3.93941e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.153654468443
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.49468966261377
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.0681977808366
variable        y0 equal ${yi}
variable        y0 equal 4.6233086740391

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 8.14745697378017
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.54744757765696
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2897   -2.9871562   -2.7854555   -2.7763788 
    2898   -2.9871562   -2.7854555   -2.7595506 
Loop time of 3.85194e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.0681977808366
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.6233086740391
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.47628130435068
variable        y0 equal ${yi}
variable        y0 equal 9.28394211042254

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.44248898743708
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.2403755496773
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2898   -2.9871562   -2.7854555   -2.7595506 
    2899   -2.9871562   -2.7854555   -2.7797103 
Loop time of 3.87457e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.47628130435068
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.28394211042254
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.47628130435068
variable        y0 equal ${yi}
variable        y0 equal 9.28394211042254

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.44684755324442
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.23730772245257
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2899   -2.9871562   -2.7854555   -2.7797103 
    2900   -2.9871562   -2.7854555   -2.7805027 
Loop time of 3.75698e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.47628130435068
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.28394211042254
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.79031698902084
variable        y0 equal ${yi}
variable        y0 equal 0.950206168401568

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.75947441060974
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 0.944491108167498
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2900   -2.9871562   -2.7854555   -2.7805027 
    2901   -2.9871562   -2.7854555   -2.7876101 
Loop time of 3.61243e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.78761014759
variable naccept equal ${increment}
variable naccept equal 482

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.7002997148015
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.24115890182551
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2901   -2.9871562   -2.7876101   -2.7876101 
    2902   -2.9871562   -2.7876101   -2.7584968 
Loop time of 3.76866e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.28958694695988
variable        y0 equal ${yi}
variable        y0 equal 1.91325869939392

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.29673342465916
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.83417944095199
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2902   -2.9871562   -2.7876101   -2.7584968 
    2903   -2.9871562   -2.7876101   -2.7873574 
Loop time of 3.6134e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.28958694695988
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.91325869939392
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.05731099564582
variable        y0 equal ${yi}
variable        y0 equal 8.44346694864328

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 9.05787859875709
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.51480531610544
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2903   -2.9871562   -2.7876101   -2.7873574 
    2904   -2.9871562   -2.7876101   -2.7802215 
Loop time of 3.55759e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.05731099564582
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.44346694864328
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 88

variable        x0 equal ${xi}
variable        x0 equal 8.0681977808366
variable        y0 equal ${yi}
variable        y0 equal 4.6233086740391

set             atom $i x ${xnew}
set             atom 88 x ${xnew}
set             atom 88 x 7.99307764171459
  1 settings made for x
set             atom $i y ${ynew}
set             atom 88 y ${ynew}
set             atom 88 y 4.53354852551386
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2904   -2.9871562   -2.7876101   -2.7802215 
    2905   -2.9871562   -2.7876101   -2.7130794 
Loop time of 3.55553e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 88 x ${x0}
set atom 88 x 8.0681977808366
  1 settings made for x
set atom $i y ${y0}
set atom 88 y ${y0}
set atom 88 y 4.6233086740391
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 1.07474994977169
variable        y0 equal ${yi}
variable        y0 equal 9.25899240482181

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 1.04285099824123
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.23019258487552
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2905   -2.9871562   -2.7876101   -2.7130794 
    2906   -2.9871562   -2.7876101   -2.7781526 
Loop time of 3.69613e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 1.07474994977169
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.25899240482181
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 2

variable        x0 equal ${xi}
variable        x0 equal 0.562153263488676
variable        y0 equal ${yi}
variable        y0 equal 0.907725413549273

set             atom $i x ${xnew}
set             atom 2 x ${xnew}
set             atom 2 x 0.543116791644957
  1 settings made for x
set             atom $i y ${ynew}
set             atom 2 y ${ynew}
set             atom 2 y 0.916397364843218
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2906   -2.9871562   -2.7876101   -2.7781526 
    2907   -2.9871562   -2.7876101   -2.7856579 
Loop time of 5.93776e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 2 x ${x0}
set atom 2 x 0.562153263488676
  1 settings made for x
set atom $i y ${y0}
set atom 2 y ${y0}
set atom 2 y 0.907725413549273
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.4587552738102
variable        y0 equal ${yi}
variable        y0 equal 7.36176157322192

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.43585534810143
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.40584540691638
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2907   -2.9871562   -2.7876101   -2.7856579 
    2908   -2.9871562   -2.7876101   -2.7794479 
Loop time of 3.63896e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.4587552738102
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.36176157322192
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 26

variable        x0 equal ${xi}
variable        x0 equal 2.75947441060974
variable        y0 equal ${yi}
variable        y0 equal 0.944491108167498

set             atom $i x ${xnew}
set             atom 26 x ${xnew}
set             atom 26 x 2.67277314861252
  1 settings made for x
set             atom $i y ${ynew}
set             atom 26 y ${ynew}
set             atom 26 y 0.985916908490984
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2908   -2.9871562   -2.7876101   -2.7794479 
    2909   -2.9871562   -2.7876101   -2.7802141 
Loop time of 3.80133e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 26 x ${x0}
set atom 26 x 2.75947441060974
  1 settings made for x
set atom $i y ${y0}
set atom 26 y ${y0}
set atom 26 y 0.944491108167498
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.7453461547656
variable        y0 equal ${yi}
variable        y0 equal 2.79009700986245

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.83549528320264
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.77572470876077
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2909   -2.9871562   -2.7876101   -2.7802141 
    2910   -2.9871562   -2.7876101   -2.7640988 
Loop time of 3.68521e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.7453461547656
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.79009700986245
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 18

variable        x0 equal ${xi}
variable        x0 equal 1.03143052180462
variable        y0 equal ${yi}
variable        y0 equal 5.57988774721818

set             atom $i x ${xnew}
set             atom 18 x ${xnew}
set             atom 18 x 0.958346632320215
  1 settings made for x
set             atom $i y ${ynew}
set             atom 18 y ${ynew}
set             atom 18 y 5.60664626305299
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2910   -2.9871562   -2.7876101   -2.7640988 
    2911   -2.9871562   -2.7876101   -2.7733726 
Loop time of 3.67916e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 18 x ${x0}
set atom 18 x 1.03143052180462
  1 settings made for x
set atom $i y ${y0}
set atom 18 y ${y0}
set atom 18 y 5.57988774721818
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.58229824185152
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.39074113287028
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2911   -2.9871562   -2.7876101   -2.7733726 
    2912   -2.9871562   -2.7876101   -2.7784024 
Loop time of 3.63831e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 9

variable        x0 equal ${xi}
variable        x0 equal 1.62633978009005
variable        y0 equal ${yi}
variable        y0 equal 2.82587088319162

set             atom $i x ${xnew}
set             atom 9 x ${xnew}
set             atom 9 x 1.71574748635073
  1 settings made for x
set             atom $i y ${ynew}
set             atom 9 y ${ynew}
set             atom 9 y 2.76428918811182
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2912   -2.9871562   -2.7876101   -2.7784024 
    2913   -2.9871562   -2.7876101   -2.7680879 
Loop time of 3.67324e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 9 x ${x0}
set atom 9 x 1.62633978009005
  1 settings made for x
set atom $i y ${y0}
set atom 9 y ${y0}
set atom 9 y 2.82587088319162
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 81

variable        x0 equal ${xi}
variable        x0 equal 8.08236802219248
variable        y0 equal ${yi}
variable        y0 equal 2.83939957591395

set             atom $i x ${xnew}
set             atom 81 x ${xnew}
set             atom 81 x 8.03856064676142
  1 settings made for x
set             atom $i y ${ynew}
set             atom 81 y ${ynew}
set             atom 81 y 2.90746389600138
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2913   -2.9871562   -2.7876101   -2.7680879 
    2914   -2.9871562   -2.7876101   -2.7663161 
Loop time of 3.69981e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 81 x ${x0}
set atom 81 x 8.08236802219248
  1 settings made for x
set atom $i y ${y0}
set atom 81 y ${y0}
set atom 81 y 2.83939957591395
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 40

variable        x0 equal ${xi}
variable        x0 equal 4.79829481481848
variable        y0 equal ${yi}
variable        y0 equal 4.66341626995966

set             atom $i x ${xnew}
set             atom 40 x ${xnew}
set             atom 40 x 4.85341924070654
  1 settings made for x
set             atom $i y ${ynew}
set             atom 40 y ${ynew}
set             atom 40 y 4.75291147583887
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2914   -2.9871562   -2.7876101   -2.7663161 
    2915   -2.9871562   -2.7876101   -2.7551073 
Loop time of 3.59143e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 40 x ${x0}
set atom 40 x 4.79829481481848
  1 settings made for x
set atom $i y ${y0}
set atom 40 y ${y0}
set atom 40 y 4.66341626995966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 1.09907218535596
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.44545188274645
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2915   -2.9871562   -2.7876101   -2.7551073 
    2916   -2.9871562   -2.7876101   -2.7869326 
Loop time of 3.7077e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 13

variable        x0 equal ${xi}
variable        x0 equal 2.1777931276928
variable        y0 equal ${yi}
variable        y0 equal 3.72489689154755

set             atom $i x ${xnew}
set             atom 13 x ${xnew}
set             atom 13 x 2.26792926231728
  1 settings made for x
set             atom $i y ${ynew}
set             atom 13 y ${ynew}
set             atom 13 y 3.65438082976471
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2916   -2.9871562   -2.7876101   -2.7869326 
    2917   -2.9871562   -2.7876101   -2.7644252 
Loop time of 4.18398e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 13 x ${x0}
set atom 13 x 2.1777931276928
  1 settings made for x
set atom $i y ${y0}
set atom 13 y ${y0}
set atom 13 y 3.72489689154755
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.57710869152319
variable        y0 equal ${yi}
variable        y0 equal 1.89296272180146

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.65323544580709
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.91911317489213
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2917   -2.9871562   -2.7876101   -2.7644252 
    2918   -2.9871562   -2.7876101   -2.7620618 
Loop time of 3.64358e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.57710869152319
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.89296272180146
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 82

variable        x0 equal ${xi}
variable        x0 equal 8.61535184541169
variable        y0 equal ${yi}
variable        y0 equal 1.91233646056717

set             atom $i x ${xnew}
set             atom 82 x ${xnew}
set             atom 82 x 8.70125020900193
  1 settings made for x
set             atom $i y ${ynew}
set             atom 82 y ${ynew}
set             atom 82 y 1.89857913634842
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2918   -2.9871562   -2.7876101   -2.7620618 
    2919   -2.9871562   -2.7876101   -2.7660385 
Loop time of 3.62586e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 82 x ${x0}
set atom 82 x 8.61535184541169
  1 settings made for x
set atom $i y ${y0}
set atom 82 y ${y0}
set atom 82 y 1.91233646056717
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 92

variable        x0 equal ${xi}
variable        x0 equal 8.50745934405748
variable        y0 equal ${yi}
variable        y0 equal 5.56924527828889

set             atom $i x ${xnew}
set             atom 92 x ${xnew}
set             atom 92 x 8.50808055558626
  1 settings made for x
set             atom $i y ${ynew}
set             atom 92 y ${ynew}
set             atom 92 y 5.61042350475984
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2919   -2.9871562   -2.7876101   -2.7660385 
    2920   -2.9871562   -2.7876101   -2.7852168 
Loop time of 3.59024e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 92 x ${x0}
set atom 92 x 8.50745934405748
  1 settings made for x
set atom $i y ${y0}
set atom 92 y ${y0}
set atom 92 y 5.56924527828889
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 19

variable        x0 equal ${xi}
variable        x0 equal 1.59274229883929
variable        y0 equal ${yi}
variable        y0 equal 6.53889024988642

set             atom $i x ${xnew}
set             atom 19 x ${xnew}
set             atom 19 x 1.54621958613177
  1 settings made for x
set             atom $i y ${ynew}
set             atom 19 y ${ynew}
set             atom 19 y 6.61146480576029
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2920   -2.9871562   -2.7876101   -2.7852168 
    2921   -2.9871562   -2.7876101   -2.7721358 
Loop time of 3.76222e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 19 x ${x0}
set atom 19 x 1.59274229883929
  1 settings made for x
set atom $i y ${y0}
set atom 19 y ${y0}
set atom 19 y 6.53889024988642
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.93963416774264
variable        y0 equal ${yi}
variable        y0 equal 6.45324131981364

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.94797158200732
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.41118431822291
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2921   -2.9871562   -2.7876101   -2.7721358 
    2922   -2.9871562   -2.7876101   -2.7789517 
Loop time of 3.5842e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.93963416774264
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.45324131981364
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 35

variable        x0 equal ${xi}
variable        x0 equal 4.94595673918066
variable        y0 equal ${yi}
variable        y0 equal 2.80184977027276

set             atom $i x ${xnew}
set             atom 35 x ${xnew}
set             atom 35 x 4.88987946152029
  1 settings made for x
set             atom $i y ${ynew}
set             atom 35 y ${ynew}
set             atom 35 y 2.75587086650231
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2922   -2.9871562   -2.7876101   -2.7789517 
    2923   -2.9871562   -2.7876101   -2.7876888 
Loop time of 3.74471e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.78768878311732
variable naccept equal ${increment}
variable naccept equal 483

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 36

variable        x0 equal ${xi}
variable        x0 equal 3.26462735890904
variable        y0 equal ${yi}
variable        y0 equal 3.68544435067308

set             atom $i x ${xnew}
set             atom 36 x ${xnew}
set             atom 36 x 3.24559173345128
  1 settings made for x
set             atom $i y ${ynew}
set             atom 36 y ${ynew}
set             atom 36 y 3.75797440571916
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2923   -2.9871562   -2.7876888   -2.7876888 
    2924   -2.9871562   -2.7876888   -2.7881568 
Loop time of 3.66835e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.78815679133256
variable naccept equal ${increment}
variable naccept equal 484

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.17130542119198
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.93089419982499
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2924   -2.9871562   -2.7881568   -2.7881568 
    2925   -2.9871562   -2.7881568   -2.7762964 
Loop time of 3.63824e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 48

variable        x0 equal ${xi}
variable        x0 equal 3.82034868518
variable        y0 equal ${yi}
variable        y0 equal 8.36977583087978

set             atom $i x ${xnew}
set             atom 48 x ${xnew}
set             atom 48 x 3.88509567299967
  1 settings made for x
set             atom $i y ${ynew}
set             atom 48 y ${ynew}
set             atom 48 y 8.29338668502865
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2925   -2.9871562   -2.7881568   -2.7762964 
    2926   -2.9871562   -2.7881568   -2.7616829 
Loop time of 3.65016e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 48 x ${x0}
set atom 48 x 3.82034868518
  1 settings made for x
set atom $i y ${y0}
set atom 48 y ${y0}
set atom 48 y 8.36977583087978
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 79

variable        x0 equal ${xi}
variable        x0 equal 9.59558219193098
variable        y0 equal ${yi}
variable        y0 equal 0.106504940986633

set             atom $i x ${xnew}
set             atom 79 x ${xnew}
set             atom 79 x 9.67483900068876
  1 settings made for x
set             atom $i y ${ynew}
set             atom 79 y ${ynew}
set             atom 79 y 0.141514432430267
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2926   -2.9871562   -2.7881568   -2.7616829 
    2927   -2.9871562   -2.7881568   -2.7749639 
Loop time of 3.7455e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 79 x ${x0}
set atom 79 x 9.59558219193098
  1 settings made for x
set atom $i y ${y0}
set atom 79 y ${y0}
set atom 79 y 0.106504940986633
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 43

variable        x0 equal ${xi}
variable        x0 equal 3.78533812085276
variable        y0 equal ${yi}
variable        y0 equal 6.5534119559907

set             atom $i x ${xnew}
set             atom 43 x ${xnew}
set             atom 43 x 3.87506280461436
  1 settings made for x
set             atom $i y ${ynew}
set             atom 43 y ${ynew}
set             atom 43 y 6.57035694853297
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2927   -2.9871562   -2.7881568   -2.7749639 
    2928   -2.9871562   -2.7881568   -2.7609918 
Loop time of 3.81535e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 43 x ${x0}
set atom 43 x 3.78533812085276
  1 settings made for x
set atom $i y ${y0}
set atom 43 y ${y0}
set atom 43 y 6.5534119559907
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 65

variable        x0 equal ${xi}
variable        x0 equal 6.99489848890945
variable        y0 equal ${yi}
variable        y0 equal 4.67387059086726

set             atom $i x ${xnew}
set             atom 65 x ${xnew}
set             atom 65 x 6.94509171524688
  1 settings made for x
set             atom $i y ${ynew}
set             atom 65 y ${ynew}
set             atom 65 y 4.73129332417414
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2928   -2.9871562   -2.7881568   -2.7609918 
    2929   -2.9871562   -2.7881568   -2.7712692 
Loop time of 3.57291e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 65 x ${x0}
set atom 65 x 6.99489848890945
  1 settings made for x
set atom $i y ${y0}
set atom 65 y ${y0}
set atom 65 y 4.67387059086726
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 33

variable        x0 equal ${xi}
variable        x0 equal 3.85500573435908
variable        y0 equal ${yi}
variable        y0 equal 2.82389258118966

set             atom $i x ${xnew}
set             atom 33 x ${xnew}
set             atom 33 x 3.77769065419322
  1 settings made for x
set             atom $i y ${ynew}
set             atom 33 y ${ynew}
set             atom 33 y 2.91090452643731
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2929   -2.9871562   -2.7881568   -2.7712692 
    2930   -2.9871562   -2.7881568    -2.768004 
Loop time of 3.52126e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 33 x ${x0}
set atom 33 x 3.85500573435908
  1 settings made for x
set atom $i y ${y0}
set atom 33 y ${y0}
set atom 33 y 2.82389258118966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.22936580816612
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.93435119769638
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2930   -2.9871562   -2.7881568    -2.768004 
    2931   -2.9871562   -2.7881568   -2.7812316 
Loop time of 3.67971e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.7453461547656
variable        y0 equal ${yi}
variable        y0 equal 2.79009700986245

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.81498971183729
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.87559406730035
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2931   -2.9871562   -2.7881568   -2.7812316 
    2932   -2.9871562   -2.7881568   -2.7730654 
Loop time of 3.68145e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.7453461547656
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.79009700986245
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 47

variable        x0 equal ${xi}
variable        x0 equal 3.26551517009297
variable        y0 equal ${yi}
variable        y0 equal 7.42613175239824

set             atom $i x ${xnew}
set             atom 47 x ${xnew}
set             atom 47 x 3.17457728147069
  1 settings made for x
set             atom $i y ${ynew}
set             atom 47 y ${ynew}
set             atom 47 y 7.51574348535799
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2932   -2.9871562   -2.7881568   -2.7730654 
    2933   -2.9871562   -2.7881568   -2.7630331 
Loop time of 3.5831e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 47 x ${x0}
set atom 47 x 3.26551517009297
  1 settings made for x
set atom $i y ${y0}
set atom 47 y ${y0}
set atom 47 y 7.42613175239824
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 30

variable        x0 equal ${xi}
variable        x0 equal 4.8900455796653
variable        y0 equal ${yi}
variable        y0 equal 0.887486429918145

set             atom $i x ${xnew}
set             atom 30 x ${xnew}
set             atom 30 x 4.88138534664452
  1 settings made for x
set             atom $i y ${ynew}
set             atom 30 y ${ynew}
set             atom 30 y 0.814894791353082
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2933   -2.9871562   -2.7881568   -2.7630331 
    2934   -2.9871562   -2.7881568   -2.7702076 
Loop time of 3.75904e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 30 x ${x0}
set atom 30 x 4.8900455796653
  1 settings made for x
set atom $i y ${y0}
set atom 30 y ${y0}
set atom 30 y 0.887486429918145
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.34334052880021
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.64900718493592
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2934   -2.9871562   -2.7881568   -2.7702076 
    2935   -2.9871562   -2.7881568   -2.7700924 
Loop time of 3.68095e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 70

variable        x0 equal ${xi}
variable        x0 equal 7.49472845632804
variable        y0 equal ${yi}
variable        y0 equal 5.57788908426957

set             atom $i x ${xnew}
set             atom 70 x ${xnew}
set             atom 70 x 7.41137775022758
  1 settings made for x
set             atom $i y ${ynew}
set             atom 70 y ${ynew}
set             atom 70 y 5.4888589138289
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2935   -2.9871562   -2.7881568   -2.7700924 
    2936   -2.9871562   -2.7881568    -2.734845 
Loop time of 3.7563e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 70 x ${x0}
set atom 70 x 7.49472845632804
  1 settings made for x
set atom $i y ${y0}
set atom 70 y ${y0}
set atom 70 y 5.57788908426957
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 8

variable        x0 equal ${xi}
variable        x0 equal 1.11691451390438
variable        y0 equal ${yi}
variable        y0 equal 1.88451303622788

set             atom $i x ${xnew}
set             atom 8 x ${xnew}
set             atom 8 x 1.19303642829113
  1 settings made for x
set             atom $i y ${ynew}
set             atom 8 y ${ynew}
set             atom 8 y 1.9311200656659
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2936   -2.9871562   -2.7881568    -2.734845 
    2937   -2.9871562   -2.7881568   -2.7677224 
Loop time of 3.63337e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 8 x ${x0}
set atom 8 x 1.11691451390438
  1 settings made for x
set atom $i y ${y0}
set atom 8 y ${y0}
set atom 8 y 1.88451303622788
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.7453461547656
variable        y0 equal ${yi}
variable        y0 equal 2.79009700986245

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.72350077827405
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.74337311955788
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2937   -2.9871562   -2.7881568   -2.7677224 
    2938   -2.9871562   -2.7881568   -2.7773274 
Loop time of 3.56995e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.7453461547656
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.79009700986245
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 98

variable        x0 equal ${xi}
variable        x0 equal 9.05731099564582
variable        y0 equal ${yi}
variable        y0 equal 8.44346694864328

set             atom $i x ${xnew}
set             atom 98 x ${xnew}
set             atom 98 x 8.97675057370216
  1 settings made for x
set             atom $i y ${ynew}
set             atom 98 y ${ynew}
set             atom 98 y 8.41705626167352
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2938   -2.9871562   -2.7881568   -2.7773274 
    2939   -2.9871562   -2.7881568   -2.7409365 
Loop time of 3.6719e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 98 x ${x0}
set atom 98 x 9.05731099564582
  1 settings made for x
set atom $i y ${y0}
set atom 98 y ${y0}
set atom 98 y 8.44346694864328
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 17

variable        x0 equal ${xi}
variable        x0 equal 0.506249304214384
variable        y0 equal ${yi}
variable        y0 equal 6.52357215420237

set             atom $i x ${xnew}
set             atom 17 x ${xnew}
set             atom 17 x 0.569842596450712
  1 settings made for x
set             atom $i y ${ynew}
set             atom 17 y ${ynew}
set             atom 17 y 6.44187637106409
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2939   -2.9871562   -2.7881568   -2.7409365 
    2940   -2.9871562   -2.7881568   -2.7672542 
Loop time of 3.71734e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 17 x ${x0}
set atom 17 x 0.506249304214384
  1 settings made for x
set atom $i y ${y0}
set atom 17 y ${y0}
set atom 17 y 6.52357215420237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 54

variable        x0 equal ${xi}
variable        x0 equal 7.03727689066574
variable        y0 equal ${yi}
variable        y0 equal 0.91603718589577

set             atom $i x ${xnew}
set             atom 54 x ${xnew}
set             atom 54 x 7.12010807076141
  1 settings made for x
set             atom $i y ${ynew}
set             atom 54 y ${ynew}
set             atom 54 y 0.85641130994591
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2940   -2.9871562   -2.7881568   -2.7672542 
    2941   -2.9871562   -2.7881568   -2.7614343 
Loop time of 3.6839e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 54 x ${x0}
set atom 54 x 7.03727689066574
  1 settings made for x
set atom $i y ${y0}
set atom 54 y ${y0}
set atom 54 y 0.91603718589577
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.37309358198854
variable        y0 equal ${yi}
variable        y0 equal 7.47418843832278

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.4080777653
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.42594758596682
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2941   -2.9871562   -2.7881568   -2.7614343 
    2942   -2.9871562   -2.7881568   -2.7803947 
Loop time of 3.58515e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.37309358198854
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.47418843832278
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 75

variable        x0 equal ${xi}
variable        x0 equal 7.49927381117117
variable        y0 equal ${yi}
variable        y0 equal 7.4024957450893

set             atom $i x ${xnew}
set             atom 75 x ${xnew}
set             atom 75 x 7.58240645963919
  1 settings made for x
set             atom $i y ${ynew}
set             atom 75 y ${ynew}
set             atom 75 y 7.38158930864597
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2942   -2.9871562   -2.7881568   -2.7803947 
    2943   -2.9871562   -2.7881568   -2.7749367 
Loop time of 3.60819e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 75 x ${x0}
set atom 75 x 7.49927381117117
  1 settings made for x
set atom $i y ${y0}
set atom 75 y ${y0}
set atom 75 y 7.4024957450893
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 50

variable        x0 equal ${xi}
variable        x0 equal 4.92722187876045
variable        y0 equal ${yi}
variable        y0 equal 8.34011304296548

set             atom $i x ${xnew}
set             atom 50 x ${xnew}
set             atom 50 x 4.8697290861541
  1 settings made for x
set             atom $i y ${ynew}
set             atom 50 y ${ynew}
set             atom 50 y 8.37540308155114
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2943   -2.9871562   -2.7881568   -2.7749367 
    2944   -2.9871562   -2.7881568   -2.7838671 
Loop time of 3.59152e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 50 x ${x0}
set atom 50 x 4.92722187876045
  1 settings made for x
set atom $i y ${y0}
set atom 50 y ${y0}
set atom 50 y 8.34011304296548
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 91

variable        x0 equal ${xi}
variable        x0 equal 8.06752826570369
variable        y0 equal ${yi}
variable        y0 equal 6.5408651901864

set             atom $i x ${xnew}
set             atom 91 x ${xnew}
set             atom 91 x 8.1529107510934
  1 settings made for x
set             atom $i y ${ynew}
set             atom 91 y ${ynew}
set             atom 91 y 6.52468261257638
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2944   -2.9871562   -2.7881568   -2.7838671 
    2945   -2.9871562   -2.7881568   -2.7696512 
Loop time of 3.72653e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 91 x ${x0}
set atom 91 x 8.06752826570369
  1 settings made for x
set atom $i y ${y0}
set atom 91 y ${y0}
set atom 91 y 6.5408651901864
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 3

variable        x0 equal ${xi}
variable        x0 equal 1.07474994977169
variable        y0 equal ${yi}
variable        y0 equal 9.25899240482181

set             atom $i x ${xnew}
set             atom 3 x ${xnew}
set             atom 3 x 1.11049489100628
  1 settings made for x
set             atom $i y ${ynew}
set             atom 3 y ${ynew}
set             atom 3 y 9.19828955638736
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2945   -2.9871562   -2.7881568   -2.7696512 
    2946   -2.9871562   -2.7881568   -2.7786214 
Loop time of 3.69873e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 3 x ${x0}
set atom 3 x 1.07474994977169
  1 settings made for x
set atom $i y ${y0}
set atom 3 y ${y0}
set atom 3 y 9.25899240482181
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.4587552738102
variable        y0 equal ${yi}
variable        y0 equal 7.36176157322192

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.41083489178734
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.36466812219882
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2946   -2.9871562   -2.7881568   -2.7786214 
    2947   -2.9871562   -2.7881568   -2.7769118 
Loop time of 3.55921e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.4587552738102
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.36176157322192
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.47628130435068
variable        y0 equal ${yi}
variable        y0 equal 9.28394211042254

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.55172334431726
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.33818559158175
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2947   -2.9871562   -2.7881568   -2.7769118 
    2948   -2.9871562   -2.7881568   -2.7701816 
Loop time of 3.71672e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.47628130435068
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.28394211042254
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.47744183380376
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.83282770676744
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2948   -2.9871562   -2.7881568   -2.7701816 
    2949   -2.9871562   -2.7881568   -2.7537723 
Loop time of 3.75865e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 42

variable        x0 equal ${xi}
variable        x0 equal 3.20813699721852
variable        y0 equal ${yi}
variable        y0 equal 5.56420804207521

set             atom $i x ${xnew}
set             atom 42 x ${xnew}
set             atom 42 x 3.19172392844716
  1 settings made for x
set             atom $i y ${ynew}
set             atom 42 y ${ynew}
set             atom 42 y 5.46996775810915
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2949   -2.9871562   -2.7881568   -2.7537723 
    2950   -2.9871562   -2.7881568   -2.7661422 
Loop time of 3.62912e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 42 x ${x0}
set atom 42 x 3.20813699721852
  1 settings made for x
set atom $i y ${y0}
set atom 42 y ${y0}
set atom 42 y 5.56420804207521
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 78

variable        x0 equal ${xi}
variable        x0 equal 9.17300830800087
variable        y0 equal ${yi}
variable        y0 equal 1.0788206536654

set             atom $i x ${xnew}
set             atom 78 x ${xnew}
set             atom 78 x 9.13097185809166
  1 settings made for x
set             atom $i y ${ynew}
set             atom 78 y ${ynew}
set             atom 78 y 1.11592826436791
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2950   -2.9871562   -2.7881568   -2.7661422 
    2951   -2.9871562   -2.7881568   -2.7668658 
Loop time of 3.69332e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 78 x ${x0}
set atom 78 x 9.17300830800087
  1 settings made for x
set atom $i y ${y0}
set atom 78 y ${y0}
set atom 78 y 1.0788206536654
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 23

variable        x0 equal ${xi}
variable        x0 equal 1.03926513512784
variable        y0 equal ${yi}
variable        y0 equal 7.4691895755794

set             atom $i x ${xnew}
set             atom 23 x ${xnew}
set             atom 23 x 0.940998652774629
  1 settings made for x
set             atom $i y ${ynew}
set             atom 23 y ${ynew}
set             atom 23 y 7.42237704124712
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2951   -2.9871562   -2.7881568   -2.7668658 
    2952   -2.9871562   -2.7881568   -2.7628676 
Loop time of 3.61414e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 23 x ${x0}
set atom 23 x 1.03926513512784
  1 settings made for x
set atom $i y ${y0}
set atom 23 y ${y0}
set atom 23 y 7.4691895755794
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 45

variable        x0 equal ${xi}
variable        x0 equal 4.82874970077812
variable        y0 equal ${yi}
variable        y0 equal 6.51564840809336

set             atom $i x ${xnew}
set             atom 45 x ${xnew}
set             atom 45 x 4.85567317842781
  1 settings made for x
set             atom $i y ${ynew}
set             atom 45 y ${ynew}
set             atom 45 y 6.55141571299067
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2952   -2.9871562   -2.7881568   -2.7628676 
    2953   -2.9871562   -2.7881568   -2.7840215 
Loop time of 3.59635e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 45 x ${x0}
set atom 45 x 4.82874970077812
  1 settings made for x
set atom $i y ${y0}
set atom 45 y ${y0}
set atom 45 y 6.51564840809336
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.28958694695988
variable        y0 equal ${yi}
variable        y0 equal 1.91325869939392

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.19398809432545
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.9361417093045
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2953   -2.9871562   -2.7881568   -2.7840215 
    2954   -2.9871562   -2.7881568   -2.7642278 
Loop time of 3.67431e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.28958694695988
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.91325869939392
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.74063794770662
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.72023000283373
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2954   -2.9871562   -2.7881568   -2.7642278 
    2955   -2.9871562   -2.7881568   -2.7565825 
Loop time of 3.59367e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 41

variable        x0 equal ${xi}
variable        x0 equal 2.66282268960905
variable        y0 equal ${yi}
variable        y0 equal 6.47586878077021

set             atom $i x ${xnew}
set             atom 41 x ${xnew}
set             atom 41 x 2.5929153700633
  1 settings made for x
set             atom $i y ${ynew}
set             atom 41 y ${ynew}
set             atom 41 y 6.5359864069604
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2955   -2.9871562   -2.7881568   -2.7565825 
    2956   -2.9871562   -2.7881568   -2.7624771 
Loop time of 3.70155e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 41 x ${x0}
set atom 41 x 2.66282268960905
  1 settings made for x
set atom $i y ${y0}
set atom 41 y ${y0}
set atom 41 y 6.47586878077021
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 56

variable        x0 equal ${xi}
variable        x0 equal 5.46139991680051
variable        y0 equal ${yi}
variable        y0 equal 1.85337124250001

set             atom $i x ${xnew}
set             atom 56 x ${xnew}
set             atom 56 x 5.36957859197522
  1 settings made for x
set             atom $i y ${ynew}
set             atom 56 y ${ynew}
set             atom 56 y 1.86536003730363
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2956   -2.9871562   -2.7881568   -2.7624771 
    2957   -2.9871562   -2.7881568   -2.7685951 
Loop time of 3.67029e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 56 x ${x0}
set atom 56 x 5.46139991680051
  1 settings made for x
set atom $i y ${y0}
set atom 56 y ${y0}
set atom 56 y 1.85337124250001
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.38550443728181
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.72745018763673
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2957   -2.9871562   -2.7881568   -2.7685951 
    2958   -2.9871562   -2.7881568   -2.7800361 
Loop time of 3.78546e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 53

variable        x0 equal ${xi}
variable        x0 equal 6.47628130435068
variable        y0 equal ${yi}
variable        y0 equal 9.28394211042254

set             atom $i x ${xnew}
set             atom 53 x ${xnew}
set             atom 53 x 6.46341115950662
  1 settings made for x
set             atom $i y ${ynew}
set             atom 53 y ${ynew}
set             atom 53 y 9.32530655372469
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2958   -2.9871562   -2.7881568   -2.7800361 
    2959   -2.9871562   -2.7881568   -2.7817956 
Loop time of 3.62535e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 53 x ${x0}
set atom 53 x 6.47628130435068
  1 settings made for x
set atom $i y ${y0}
set atom 53 y ${y0}
set atom 53 y 9.28394211042254
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 24

variable        x0 equal ${xi}
variable        x0 equal 1.66585860132952
variable        y0 equal ${yi}
variable        y0 equal 8.32581171907481

set             atom $i x ${xnew}
set             atom 24 x ${xnew}
set             atom 24 x 1.59361889242907
  1 settings made for x
set             atom $i y ${ynew}
set             atom 24 y ${ynew}
set             atom 24 y 8.26658972419795
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2959   -2.9871562   -2.7881568   -2.7817956 
    2960   -2.9871562   -2.7881568   -2.7663259 
Loop time of 3.63333e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 24 x ${x0}
set atom 24 x 1.66585860132952
  1 settings made for x
set atom $i y ${y0}
set atom 24 y ${y0}
set atom 24 y 8.32581171907481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 59

variable        x0 equal ${xi}
variable        x0 equal 7.00774297991439
variable        y0 equal ${yi}
variable        y0 equal 2.80172786685327

set             atom $i x ${xnew}
set             atom 59 x ${xnew}
set             atom 59 x 6.93442223349258
  1 settings made for x
set             atom $i y ${ynew}
set             atom 59 y ${ynew}
set             atom 59 y 2.74177507134775
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2960   -2.9871562   -2.7881568   -2.7663259 
    2961   -2.9871562   -2.7881568   -2.7574407 
Loop time of 3.59759e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 59 x ${x0}
set atom 59 x 7.00774297991439
  1 settings made for x
set atom $i y ${y0}
set atom 59 y ${y0}
set atom 59 y 2.80172786685327
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 60

variable        x0 equal ${xi}
variable        x0 equal 7.57710869152319
variable        y0 equal ${yi}
variable        y0 equal 1.89296272180146

set             atom $i x ${xnew}
set             atom 60 x ${xnew}
set             atom 60 x 7.54062530834448
  1 settings made for x
set             atom $i y ${ynew}
set             atom 60 y ${ynew}
set             atom 60 y 1.82255150458878
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2961   -2.9871562   -2.7881568   -2.7574407 
    2962   -2.9871562   -2.7881568   -2.7782955 
Loop time of 3.59425e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 60 x ${x0}
set atom 60 x 7.57710869152319
  1 settings made for x
set atom $i y ${y0}
set atom 60 y ${y0}
set atom 60 y 1.89296272180146
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 63

variable        x0 equal ${xi}
variable        x0 equal 7.54946586925756
variable        y0 equal ${yi}
variable        y0 equal 3.75025760693681

set             atom $i x ${xnew}
set             atom 63 x ${xnew}
set             atom 63 x 7.50438873607885
  1 settings made for x
set             atom $i y ${ynew}
set             atom 63 y ${ynew}
set             atom 63 y 3.80752216143739
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2962   -2.9871562   -2.7881568   -2.7782955 
    2963   -2.9871562   -2.7881568   -2.7722709 
Loop time of 3.78656e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 63 x ${x0}
set atom 63 x 7.54946586925756
  1 settings made for x
set atom $i y ${y0}
set atom 63 y ${y0}
set atom 63 y 3.75025760693681
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 94

variable        x0 equal ${xi}
variable        x0 equal 9.59509903668044
variable        y0 equal ${yi}
variable        y0 equal 5.54114934151369

set             atom $i x ${xnew}
set             atom 94 x ${xnew}
set             atom 94 x 9.64267420052169
  1 settings made for x
set             atom $i y ${ynew}
set             atom 94 y ${ynew}
set             atom 94 y 5.46045837347704
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2963   -2.9871562   -2.7881568   -2.7722709 
    2964   -2.9871562   -2.7881568   -2.7653838 
Loop time of 3.67885e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 94 x ${x0}
set atom 94 x 9.59509903668044
  1 settings made for x
set atom $i y ${y0}
set atom 94 y ${y0}
set atom 94 y 5.54114934151369
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 29

variable        x0 equal ${xi}
variable        x0 equal 4.3840241916916
variable        y0 equal ${yi}
variable        y0 equal 9.27708193767397

set             atom $i x ${xnew}
set             atom 29 x ${xnew}
set             atom 29 x 4.44023939449998
  1 settings made for x
set             atom $i y ${ynew}
set             atom 29 y ${ynew}
set             atom 29 y 9.20252936590044
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2964   -2.9871562   -2.7881568   -2.7653838 
    2965   -2.9871562   -2.7881568   -2.7688648 
Loop time of 3.62432e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 29 x ${x0}
set atom 29 x 4.3840241916916
  1 settings made for x
set atom $i y ${y0}
set atom 29 y ${y0}
set atom 29 y 9.27708193767397
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 11

variable        x0 equal ${xi}
variable        x0 equal 10.7438378771
variable        y0 equal ${yi}
variable        y0 equal 3.74340155882966

set             atom $i x ${xnew}
set             atom 11 x ${xnew}
set             atom 11 x 10.791923685854
  1 settings made for x
set             atom $i y ${ynew}
set             atom 11 y ${ynew}
set             atom 11 y 3.81355102820527
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2965   -2.9871562   -2.7881568   -2.7688648 
    2966   -2.9871562   -2.7881568   -2.7748905 
Loop time of 3.72481e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 11 x ${x0}
set atom 11 x 10.7438378771
  1 settings made for x
set atom $i y ${y0}
set atom 11 y ${y0}
set atom 11 y 3.74340155882966
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 15

variable        x0 equal ${xi}
variable        x0 equal 1.61305398821612
variable        y0 equal ${yi}
variable        y0 equal 4.66496637219354

set             atom $i x ${xnew}
set             atom 15 x ${xnew}
set             atom 15 x 1.64636559366961
  1 settings made for x
set             atom $i y ${ynew}
set             atom 15 y ${ynew}
set             atom 15 y 4.64173713082238
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2966   -2.9871562   -2.7881568   -2.7748905 
    2967   -2.9871562   -2.7881568   -2.7851939 
Loop time of 3.60806e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 15 x ${x0}
set atom 15 x 1.61305398821612
  1 settings made for x
set atom $i y ${y0}
set atom 15 y ${y0}
set atom 15 y 4.66496637219354
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 87

variable        x0 equal ${xi}
variable        x0 equal 9.70109274862882
variable        y0 equal ${yi}
variable        y0 equal 3.70061683220994

set             atom $i x ${xnew}
set             atom 87 x ${xnew}
set             atom 87 x 9.70697058914777
  1 settings made for x
set             atom $i y ${ynew}
set             atom 87 y ${ynew}
set             atom 87 y 3.76111825270783
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2967   -2.9871562   -2.7881568   -2.7851939 
    2968   -2.9871562   -2.7881568   -2.7805668 
Loop time of 3.64275e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 87 x ${x0}
set atom 87 x 9.70109274862882
  1 settings made for x
set atom $i y ${y0}
set atom 87 y ${y0}
set atom 87 y 3.70061683220994
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 5.97854424674504
variable        y0 equal ${yi}
variable        y0 equal 0.914465494859546

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 5.9624010201215
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.88390976976189
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2968   -2.9871562   -2.7881568   -2.7805668 
    2969   -2.9871562   -2.7881568   -2.7869678 
Loop time of 3.61159e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 5.97854424674504
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.914465494859546
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 67

variable        x0 equal ${xi}
variable        x0 equal 5.93963416774264
variable        y0 equal ${yi}
variable        y0 equal 6.45324131981364

set             atom $i x ${xnew}
set             atom 67 x ${xnew}
set             atom 67 x 5.91048840243807
  1 settings made for x
set             atom $i y ${ynew}
set             atom 67 y ${ynew}
set             atom 67 y 6.50119726196757
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2969   -2.9871562   -2.7881568   -2.7869678 
    2970   -2.9871562   -2.7881568   -2.7841884 
Loop time of 3.67715e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 67 x ${x0}
set atom 67 x 5.93963416774264
  1 settings made for x
set atom $i y ${y0}
set atom 67 y ${y0}
set atom 67 y 6.45324131981364
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 85

variable        x0 equal ${xi}
variable        x0 equal 10.3012223724386
variable        y0 equal ${yi}
variable        y0 equal 2.8246198293815

set             atom $i x ${xnew}
set             atom 85 x ${xnew}
set             atom 85 x 10.3708028677961
  1 settings made for x
set             atom $i y ${ynew}
set             atom 85 y ${ynew}
set             atom 85 y 2.76249070140222
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2970   -2.9871562   -2.7881568   -2.7841884 
    2971   -2.9871562   -2.7881568   -2.7618796 
Loop time of 3.54738e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 85 x ${x0}
set atom 85 x 10.3012223724386
  1 settings made for x
set atom $i y ${y0}
set atom 85 y ${y0}
set atom 85 y 2.8246198293815
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 10

variable        x0 equal ${xi}
variable        x0 equal 2.16610246340141
variable        y0 equal ${yi}
variable        y0 equal 1.90517050406998

set             atom $i x ${xnew}
set             atom 10 x ${xnew}
set             atom 10 x 2.09896577040062
  1 settings made for x
set             atom $i y ${ynew}
set             atom 10 y ${ynew}
set             atom 10 y 1.83873800418442
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2971   -2.9871562   -2.7881568   -2.7618796 
    2972   -2.9871562   -2.7881568   -2.7686095 
Loop time of 3.5812e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 10 x ${x0}
set atom 10 x 2.16610246340141
  1 settings made for x
set atom $i y ${y0}
set atom 10 y ${y0}
set atom 10 y 1.90517050406998
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 77

variable        x0 equal ${xi}
variable        x0 equal 8.56384705462877
variable        y0 equal ${yi}
variable        y0 equal 0.0929038047790526

set             atom $i x ${xnew}
set             atom 77 x ${xnew}
set             atom 77 x 8.61191501775209
  1 settings made for x
set             atom $i y ${ynew}
set             atom 77 y ${ynew}
set             atom 77 y 0.0353517293930052
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2972   -2.9871562   -2.7881568   -2.7686095 
    2973   -2.9871562   -2.7881568    -2.778722 
Loop time of 3.60553e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 77 x ${x0}
set atom 77 x 8.56384705462877
  1 settings made for x
set atom $i y ${y0}
set atom 77 y ${y0}
set atom 77 y 0.0929038047790526
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 46

variable        x0 equal ${xi}
variable        x0 equal 2.76264746387434
variable        y0 equal ${yi}
variable        y0 equal 8.40153711952266

set             atom $i x ${xnew}
set             atom 46 x ${xnew}
set             atom 46 x 2.76858189304304
  1 settings made for x
set             atom $i y ${ynew}
set             atom 46 y ${ynew}
set             atom 46 y 8.37271194376048
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2973   -2.9871562   -2.7881568    -2.778722 
    2974   -2.9871562   -2.7881568   -2.7886521 
Loop time of 3.73887e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.78865205723245
variable naccept equal ${increment}
variable naccept equal 485

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.28958694695988
variable        y0 equal ${yi}
variable        y0 equal 1.91325869939392

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.2917040204958
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.94942258975571
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2974   -2.9871562   -2.7886521   -2.7886521 
    2975   -2.9871562   -2.7886521    -2.781035 
Loop time of 3.73887e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.28958694695988
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.91325869939392
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.29362520932713
variable        y0 equal ${yi}
variable        y0 equal 0.011324155330658

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.35518097638646
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.0419979333877563
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2975   -2.9871562   -2.7886521    -2.781035 
    2976   -2.9871562   -2.7886521   -2.7783803 
Loop time of 3.66945e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.29362520932713
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.011324155330658
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 25

variable        x0 equal ${xi}
variable        x0 equal 2.19470320383415
variable        y0 equal ${yi}
variable        y0 equal 7.41677955713534

set             atom $i x ${xnew}
set             atom 25 x ${xnew}
set             atom 25 x 2.19020165840492
  1 settings made for x
set             atom $i y ${ynew}
set             atom 25 y ${ynew}
set             atom 25 y 7.44191404905581
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2976   -2.9871562   -2.7886521   -2.7783803 
    2977   -2.9871562   -2.7886521   -2.7884276 
Loop time of 3.52435e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.7884276415942
variable naccept equal ${increment}
variable naccept equal 486

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 95

variable        x0 equal ${xi}
variable        x0 equal 10.153654468443
variable        y0 equal ${yi}
variable        y0 equal 6.49468966261377

set             atom $i x ${xnew}
set             atom 95 x ${xnew}
set             atom 95 x 10.0568315986653
  1 settings made for x
set             atom $i y ${ynew}
set             atom 95 y ${ynew}
set             atom 95 y 6.42928642765512
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2977   -2.9871562   -2.7884276   -2.7884276 
    2978   -2.9871562   -2.7884276    -2.739928 
Loop time of 3.74909e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 95 x ${x0}
set atom 95 x 10.153654468443
  1 settings made for x
set atom $i y ${y0}
set atom 95 y ${y0}
set atom 95 y 6.49468966261377
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 31

variable        x0 equal ${xi}
variable        x0 equal 2.7453461547656
variable        y0 equal ${yi}
variable        y0 equal 2.79009700986245

set             atom $i x ${xnew}
set             atom 31 x ${xnew}
set             atom 31 x 2.72168115575742
  1 settings made for x
set             atom $i y ${ynew}
set             atom 31 y ${ynew}
set             atom 31 y 2.76169707747796
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2978   -2.9871562   -2.7884276    -2.739928 
    2979   -2.9871562   -2.7884276   -2.7832015 
Loop time of 3.77167e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 31 x ${x0}
set atom 31 x 2.7453461547656
  1 settings made for x
set atom $i y ${y0}
set atom 31 y ${y0}
set atom 31 y 2.79009700986245
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 64

variable        x0 equal ${xi}
variable        x0 equal 5.84264154393664
variable        y0 equal ${yi}
variable        y0 equal 4.64205295199321

set             atom $i x ${xnew}
set             atom 64 x ${xnew}
set             atom 64 x 5.9265888090848
  1 settings made for x
set             atom $i y ${ynew}
set             atom 64 y ${ynew}
set             atom 64 y 4.63859268778728
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2979   -2.9871562   -2.7884276   -2.7832015 
    2980   -2.9871562   -2.7884276    -2.790467 
Loop time of 3.63849e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.79046704062092
variable naccept equal ${increment}
variable naccept equal 487

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 62

variable        x0 equal ${xi}
variable        x0 equal 6.48631493567544
variable        y0 equal ${yi}
variable        y0 equal 3.75364394946228

set             atom $i x ${xnew}
set             atom 62 x ${xnew}
set             atom 62 x 6.52970457791406
  1 settings made for x
set             atom $i y ${ynew}
set             atom 62 y ${ynew}
set             atom 62 y 3.81826476616989
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2980   -2.9871562    -2.790467    -2.790467 
    2981   -2.9871562    -2.790467   -2.7682068 
Loop time of 3.67401e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 62 x ${x0}
set atom 62 x 6.48631493567544
  1 settings made for x
set atom $i y ${y0}
set atom 62 y ${y0}
set atom 62 y 3.75364394946228
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 76

variable        x0 equal ${xi}
variable        x0 equal 8.10257350801325
variable        y0 equal ${yi}
variable        y0 equal 1.00189624618325

set             atom $i x ${xnew}
set             atom 76 x ${xnew}
set             atom 76 x 8.05394043325281
  1 settings made for x
set             atom $i y ${ynew}
set             atom 76 y ${ynew}
set             atom 76 y 0.98510336469445
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2981   -2.9871562    -2.790467   -2.7682068 
    2982   -2.9871562    -2.790467   -2.7892735 
Loop time of 3.69384e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 76 x ${x0}
set atom 76 x 8.10257350801325
  1 settings made for x
set atom $i y ${y0}
set atom 76 y ${y0}
set atom 76 y 1.00189624618325
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.36031145254042
variable        y0 equal ${yi}
variable        y0 equal 5.55776102488237

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.43959124484923
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.64207411949831
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2982   -2.9871562    -2.790467   -2.7892735 
    2983   -2.9871562    -2.790467   -2.7518335 
Loop time of 3.67249e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.36031145254042
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.55776102488237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 86

variable        x0 equal ${xi}
variable        x0 equal 8.6576410786194
variable        y0 equal ${yi}
variable        y0 equal 3.7081167058481

set             atom $i x ${xnew}
set             atom 86 x ${xnew}
set             atom 86 x 8.58549246945802
  1 settings made for x
set             atom $i y ${ynew}
set             atom 86 y ${ynew}
set             atom 86 y 3.79913249774111
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2983   -2.9871562    -2.790467   -2.7518335 
    2984   -2.9871562    -2.790467   -2.7655526 
Loop time of 3.6575e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 86 x ${x0}
set atom 86 x 8.6576410786194
  1 settings made for x
set atom $i y ${y0}
set atom 86 y ${y0}
set atom 86 y 3.7081167058481
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.77372619389173
variable        y0 equal ${yi}
variable        y0 equal 1.9292484082944

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.8297874140608
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 2.02259250066348
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2984   -2.9871562    -2.790467   -2.7655526 
    2985   -2.9871562    -2.790467   -2.7407939 
Loop time of 3.58594e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 84 x ${x0}
set atom 84 x 9.77372619389173
  1 settings made for x
set atom $i y ${y0}
set atom 84 y ${y0}
set atom 84 y 1.9292484082944
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 27

variable        x0 equal ${xi}
variable        x0 equal 3.29362520932713
variable        y0 equal ${yi}
variable        y0 equal 0.011324155330658

set             atom $i x ${xnew}
set             atom 27 x ${xnew}
set             atom 27 x 3.20174463748494
  1 settings made for x
set             atom $i y ${ynew}
set             atom 27 y ${ynew}
set             atom 27 y -0.050924801826477
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2985   -2.9871562    -2.790467   -2.7407939 
    2986   -2.9871562    -2.790467   -2.7651666 
Loop time of 3.67835e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 27 x ${x0}
set atom 27 x 3.29362520932713
  1 settings made for x
set atom $i y ${y0}
set atom 27 y ${y0}
set atom 27 y 0.011324155330658
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 73

variable        x0 equal ${xi}
variable        x0 equal 6.4587552738102
variable        y0 equal ${yi}
variable        y0 equal 7.36176157322192

set             atom $i x ${xnew}
set             atom 73 x ${xnew}
set             atom 73 x 6.46593603610116
  1 settings made for x
set             atom $i y ${ynew}
set             atom 73 y ${ynew}
set             atom 73 y 7.27544842090869
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2986   -2.9871562    -2.790467   -2.7651666 
    2987   -2.9871562    -2.790467    -2.764488 
Loop time of 3.76307e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 73 x ${x0}
set atom 73 x 6.4587552738102
  1 settings made for x
set atom $i y ${y0}
set atom 73 y ${y0}
set atom 73 y 7.36176157322192
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 32

variable        x0 equal ${xi}
variable        x0 equal 3.28958694695988
variable        y0 equal ${yi}
variable        y0 equal 1.91325869939392

set             atom $i x ${xnew}
set             atom 32 x ${xnew}
set             atom 32 x 3.34457401990452
  1 settings made for x
set             atom $i y ${ynew}
set             atom 32 y ${ynew}
set             atom 32 y 1.92369964501923
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2987   -2.9871562    -2.790467    -2.764488 
    2988   -2.9871562    -2.790467   -2.7868928 
Loop time of 3.57224e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 32 x ${x0}
set atom 32 x 3.28958694695988
  1 settings made for x
set atom $i y ${y0}
set atom 32 y ${y0}
set atom 32 y 1.91325869939392
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 49

variable        x0 equal ${xi}
variable        x0 equal 4.37309358198854
variable        y0 equal ${yi}
variable        y0 equal 7.47418843832278

set             atom $i x ${xnew}
set             atom 49 x ${xnew}
set             atom 49 x 4.30631213267061
  1 settings made for x
set             atom $i y ${ynew}
set             atom 49 y ${ynew}
set             atom 49 y 7.49401879635119
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2988   -2.9871562    -2.790467   -2.7868928 
    2989   -2.9871562    -2.790467   -2.7850677 
Loop time of 3.74931e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 49 x ${x0}
set atom 49 x 4.37309358198854
  1 settings made for x
set atom $i y ${y0}
set atom 49 y ${y0}
set atom 49 y 7.47418843832278
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 6

variable        x0 equal ${xi}
variable        x0 equal 0.101794230937958
variable        y0 equal ${yi}
variable        y0 equal 1.84877194545335

set             atom $i x ${xnew}
set             atom 6 x ${xnew}
set             atom 6 x 0.178269803524018
  1 settings made for x
set             atom $i y ${ynew}
set             atom 6 y ${ynew}
set             atom 6 y 1.76079683682985
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2989   -2.9871562    -2.790467   -2.7850677 
    2990   -2.9871562    -2.790467   -2.7279946 
Loop time of 3.72943e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 6 x ${x0}
set atom 6 x 0.101794230937958
  1 settings made for x
set atom $i y ${y0}
set atom 6 y ${y0}
set atom 6 y 1.84877194545335
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 89

variable        x0 equal ${xi}
variable        x0 equal 9.14624181706459
variable        y0 equal ${yi}
variable        y0 equal 4.60836122387811

set             atom $i x ${xnew}
set             atom 89 x ${xnew}
set             atom 89 x 9.15284846741707
  1 settings made for x
set             atom $i y ${ynew}
set             atom 89 y ${ynew}
set             atom 89 y 4.54217812174722
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2990   -2.9871562    -2.790467   -2.7279946 
    2991   -2.9871562    -2.790467   -2.7714038 
Loop time of 3.60844e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 89 x ${x0}
set atom 89 x 9.14624181706459
  1 settings made for x
set atom $i y ${y0}
set atom 89 y ${y0}
set atom 89 y 4.60836122387811
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 71

variable        x0 equal ${xi}
variable        x0 equal 5.42935876050855
variable        y0 equal ${yi}
variable        y0 equal 7.38294791307711

set             atom $i x ${xnew}
set             atom 71 x ${xnew}
set             atom 71 x 5.466302446517
  1 settings made for x
set             atom $i y ${ynew}
set             atom 71 y ${ynew}
set             atom 71 y 7.38777832117342
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2991   -2.9871562    -2.790467   -2.7714038 
    2992   -2.9871562    -2.790467   -2.7832327 
Loop time of 3.65853e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 71 x ${x0}
set atom 71 x 5.42935876050855
  1 settings made for x
set atom $i y ${y0}
set atom 71 y ${y0}
set atom 71 y 7.38294791307711
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 16

variable        x0 equal ${xi}
variable        x0 equal 10.6997664650136
variable        y0 equal ${yi}
variable        y0 equal 5.5742603296538

set             atom $i x ${xnew}
set             atom 16 x ${xnew}
set             atom 16 x 10.7903243978673
  1 settings made for x
set             atom $i y ${ynew}
set             atom 16 y ${ynew}
set             atom 16 y 5.53763686363894
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2992   -2.9871562    -2.790467   -2.7832327 
    2993   -2.9871562    -2.790467   -2.7647993 
Loop time of 3.66507e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 16 x ${x0}
set atom 16 x 10.6997664650136
  1 settings made for x
set atom $i y ${y0}
set atom 16 y ${y0}
set atom 16 y 5.5742603296538
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 37

variable        x0 equal ${xi}
variable        x0 equal 4.30488829691621
variable        y0 equal ${yi}
variable        y0 equal 3.72380816502702

set             atom $i x ${xnew}
set             atom 37 x ${xnew}
set             atom 37 x 4.38392670233461
  1 settings made for x
set             atom $i y ${ynew}
set             atom 37 y ${ynew}
set             atom 37 y 3.71435775323045
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2993   -2.9871562    -2.790467   -2.7647993 
    2994   -2.9871562    -2.790467   -2.7829886 
Loop time of 3.58579e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 37 x ${x0}
set atom 37 x 4.30488829691621
  1 settings made for x
set atom $i y ${y0}
set atom 37 y ${y0}
set atom 37 y 3.72380816502702
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 84

variable        x0 equal ${xi}
variable        x0 equal 9.77372619389173
variable        y0 equal ${yi}
variable        y0 equal 1.9292484082944

set             atom $i x ${xnew}
set             atom 84 x ${xnew}
set             atom 84 x 9.80390117643949
  1 settings made for x
set             atom $i y ${ynew}
set             atom 84 y ${ynew}
set             atom 84 y 1.91664781949588
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2994   -2.9871562    -2.790467   -2.7829886 
    2995   -2.9871562    -2.790467    -2.789999 
Loop time of 3.6176e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
variable elast equal $e
variable elast equal -2.78999898355704
variable naccept equal ${increment}
variable naccept equal 488

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 66

variable        x0 equal ${xi}
variable        x0 equal 5.36031145254042
variable        y0 equal ${yi}
variable        y0 equal 5.55776102488237

set             atom $i x ${xnew}
set             atom 66 x ${xnew}
set             atom 66 x 5.32599838176634
  1 settings made for x
set             atom $i y ${ynew}
set             atom 66 y ${ynew}
set             atom 66 y 5.5632608289023
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2995   -2.9871562    -2.789999    -2.789999 
    2996   -2.9871562    -2.789999   -2.7888661 
Loop time of 3.7056e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 66 x ${x0}
set atom 66 x 5.36031145254042
  1 settings made for x
set atom $i y ${y0}
set atom 66 y ${y0}
set atom 66 y 5.55776102488237
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 21

variable        x0 equal ${xi}
variable        x0 equal 10.7073550899677
variable        y0 equal ${yi}
variable        y0 equal 7.45095640745426

set             atom $i x ${xnew}
set             atom 21 x ${xnew}
set             atom 21 x 10.8010260899715
  1 settings made for x
set             atom $i y ${ynew}
set             atom 21 y ${ynew}
set             atom 21 y 7.49749026623035
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2996   -2.9871562    -2.789999   -2.7888661 
    2997   -2.9871562    -2.789999    -2.769271 
Loop time of 3.77689e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 21 x ${x0}
set atom 21 x 10.7073550899677
  1 settings made for x
set atom $i y ${y0}
set atom 21 y ${y0}
set atom 21 y 7.45095640745426
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 34

variable        x0 equal ${xi}
variable        x0 equal 4.39493876774522
variable        y0 equal ${yi}
variable        y0 equal 1.88860803029603

set             atom $i x ${xnew}
set             atom 34 x ${xnew}
set             atom 34 x 4.34888207991334
  1 settings made for x
set             atom $i y ${ynew}
set             atom 34 y ${ynew}
set             atom 34 y 1.94404620311326
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2997   -2.9871562    -2.789999    -2.769271 
    2998   -2.9871562    -2.789999   -2.7744715 
Loop time of 3.60119e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 34 x ${x0}
set atom 34 x 4.39493876774522
  1 settings made for x
set atom $i y ${y0}
set atom 34 y ${y0}
set atom 34 y 1.88860803029603
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 90

variable        x0 equal ${xi}
variable        x0 equal 10.1955849651357
variable        y0 equal ${yi}
variable        y0 equal 4.64925400370525

set             atom $i x ${xnew}
set             atom 90 x ${xnew}
set             atom 90 x 10.1757787827512
  1 settings made for x
set             atom $i y ${ynew}
set             atom 90 y ${ynew}
set             atom 90 y 4.58302171582149
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2998   -2.9871562    -2.789999   -2.7744715 
    2999   -2.9871562    -2.789999   -2.7784828 
Loop time of 3.85941e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 90 x ${x0}
set atom 90 x 10.1955849651357
  1 settings made for x
set atom $i y ${y0}
set atom 90 y ${y0}
set atom 90 y 4.64925400370525
  1 settings made for y

next            iter
jump            SELF loop

variable        i equal ${irandom}
variable        i equal 52

variable        x0 equal ${xi}
variable        x0 equal 5.97854424674504
variable        y0 equal ${yi}
variable        y0 equal 0.914465494859546

set             atom $i x ${xnew}
set             atom 52 x ${xnew}
set             atom 52 x 5.9139833207845
  1 settings made for x
set             atom $i y ${ynew}
set             atom 52 y ${ynew}
set             atom 52 y 0.972595818746417
  1 settings made for y

run             1 pre no post no
Step v_emin v_elast PotEng 
    2999   -2.9871562    -2.789999   -2.7784828 
    3000   -2.9871562    -2.789999   -2.7769537 
Loop time of 3.67728e-05 on 8 procs for 1 steps with 100 atoms


if              "$e <= ${elast}" then                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 elif "${rn} <= ${boltzfactor}"                   "variable elast equal $e"                   "variable naccept equal ${increment}"                 else                   "set atom $i x ${x0}"                   "set atom $i y ${y0}"
set atom $i x ${x0}
set atom 52 x ${x0}
set atom 52 x 5.97854424674504
  1 settings made for x
set atom $i y ${y0}
set atom 52 y ${y0}
set atom 52 y 0.914465494859546
  1 settings made for y

next            iter
jump            SELF loop

# final energy and stats

variable       nb equal nbuild
variable       nbuild equal ${nb}
variable       nbuild equal 38

run             0
WARNING: No fixes defined, atoms won't move (../verlet.cpp:55)
Per MPI rank memory allocation (min/avg/max) = 2.933 | 2.933 | 2.933 Mbytes
Step v_emin v_elast PotEng 
    3000   -2.9871562    -2.789999    -2.789999 
Loop time of 3.99626e-06 on 8 procs for 0 steps with 100 atoms

100.1% CPU use with 8 MPI tasks x no OpenMP threads

MPI task timing breakdown:
Section |  min time  |  avg time  |  max time  |%varavg| %total
---------------------------------------------------------------
Pair    | 0          | 0          | 0          |   0.0 |  0.00
Neigh   | 0          | 0          | 0          |   0.0 |  0.00
Comm    | 0          | 0          | 0          |   0.0 |  0.00
Output  | 0          | 0          | 0          |   0.0 |  0.00
Modify  | 0          | 0          | 0          |   0.0 |  0.00
Other   |            | 3.996e-06  |            |       |100.00

Nlocal:    12.5 ave 16 max 10 min
Histogram: 2 0 0 2 0 2 1 0 0 1
Nghost:    77.125 ave 80 max 73 min
Histogram: 1 0 0 0 2 1 0 2 1 1
Neighs:    127.875 ave 175 max 94 min
Histogram: 1 2 0 0 3 0 1 0 0 1

Total # of neighbors = 1023
Ave neighs/atom = 10.23
Neighbor list builds = 0
Dangerous builds = 0

print           "MC stats:"
MC stats:
print           "  starting energy = ${estart}"
  starting energy = 19.1997808254901
print           "  final energy = $e"
  final energy = -2.78999898355704
print           "  minimum energy of perfect lattice = ${emin}"
  minimum energy of perfect lattice = -2.98715616447944
print           "  accepted MC moves = ${naccept}"
  accepted MC moves = 488
print           "  neighbor list rebuilds = ${nbuild}"
  neighbor list rebuilds = 38
Total wall time: 0:00:00
